'''
# AWS::QuickSight Construct Library

<!--BEGIN STABILITY BANNER-->---


![cfn-resources: Stable](https://img.shields.io/badge/cfn--resources-stable-success.svg?style=for-the-badge)

> All classes with the `Cfn` prefix in this module ([CFN Resources](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_lib)) are always stable and safe to use.

---
<!--END STABILITY BANNER-->

This module is part of the [AWS Cloud Development Kit](https://github.com/aws/aws-cdk) project.

```python
import aws_cdk.aws_quicksight as quicksight
```

<!--BEGIN CFNONLY DISCLAIMER-->

There are no official hand-written ([L2](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_lib)) constructs for this service yet. Here are some suggestions on how to proceed:

* Search [Construct Hub for QuickSight construct libraries](https://constructs.dev/search?q=quicksight)
* Use the automatically generated [L1](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_l1_using) constructs, in the same way you would use [the CloudFormation AWS::QuickSight resources](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/AWS_QuickSight.html) directly.

<!--BEGIN CFNONLY DISCLAIMER-->

There are no hand-written ([L2](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_lib)) constructs for this service yet.
However, you can still use the automatically generated [L1](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_l1_using) constructs, and use this service exactly as you would using CloudFormation directly.

For more information on the resources and properties available for this service, see the [CloudFormation documentation for AWS::QuickSight](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/AWS_QuickSight.html).

(Read the [CDK Contributing Guide](https://github.com/aws/aws-cdk/blob/master/CONTRIBUTING.md) and submit an RFC if you are interested in contributing to this construct library.)

<!--END CFNONLY DISCLAIMER-->
'''
import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

from ._jsii import *

import aws_cdk.core as _aws_cdk_core_f4b25747


@jsii.implements(_aws_cdk_core_f4b25747.IInspectable)
class CfnAnalysis(
    _aws_cdk_core_f4b25747.CfnResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis",
):
    '''A CloudFormation ``AWS::QuickSight::Analysis``.

    Creates an analysis in Amazon QuickSight.

    :cloudformationResource: AWS::QuickSight::Analysis
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        import aws_cdk.aws_quicksight as quicksight
        
        # data_driven: Any
        
        cfn_analysis = quicksight.CfnAnalysis(self, "MyCfnAnalysis",
            analysis_id="analysisId",
            aws_account_id="awsAccountId",
            name="name",
        
            # the properties below are optional
            definition=quicksight.CfnAnalysis.AnalysisDefinitionProperty(
                data_set_identifier_declarations=[quicksight.CfnAnalysis.DataSetIdentifierDeclarationProperty(
                    data_set_arn="dataSetArn",
                    identifier="identifier"
                )],
        
                # the properties below are optional
                analysis_defaults=quicksight.CfnAnalysis.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                ),
                calculated_fields=[quicksight.CfnAnalysis.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )],
                column_configurations=[quicksight.CfnAnalysis.ColumnConfigurationProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
        
                    # the properties below are optional
                    colors_configuration=quicksight.CfnAnalysis.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnAnalysis.CustomColorProperty(
                            color="color",
        
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )],
                filter_groups=[quicksight.CfnAnalysis.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnAnalysis.FilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
        
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
        
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
        
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
        
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnAnalysis.NumericRangeFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
        
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
        
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
        
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
        
                            # the properties below are optional
                            parameter_name="parameterName",
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
        
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
        
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
        
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
        
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnAnalysis.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection"
                            )],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
        
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnAnalysis.FilterScopeConfigurationProperty(
                        selected_sheets=quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
        
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
        
                    # the properties below are optional
                    status="status"
                )],
                parameter_declarations=[quicksight.CfnAnalysis.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty(
                        name="name",
        
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                expression="expression",
        
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnAnalysis.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnAnalysis.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnAnalysis.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )],
                sheets=[quicksight.CfnAnalysis.SheetDefinitionProperty(
                    sheet_id="sheetId",
        
                    # the properties below are optional
                    content_type="contentType",
                    description="description",
                    filter_controls=[quicksight.CfnAnalysis.FilterControlProperty(
                        date_time_picker=quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        dropdown=quicksight.CfnAnalysis.FilterDropDownControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnAnalysis.FilterListControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        relative_date_time=quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        slider=quicksight.CfnAnalysis.FilterSliderControlProperty(
                            filter_control_id="filterControlId",
                            maximum_value=123,
                            minimum_value=123,
                            source_filter_id="sourceFilterId",
                            step_size=123,
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        text_area=quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    layouts=[quicksight.CfnAnalysis.LayoutProperty(
                        configuration=quicksight.CfnAnalysis.LayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
        
                                    # the properties below are optional
                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
        
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                                body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                                    content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
        
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                        after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                            status="status"
                                        )
                                    ),
                                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                ),
                                footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
        
                                                # the properties below are optional
                                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
        
                                                # the properties below are optional
                                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )]
                            )
                        )
                    )],
                    name="name",
                    parameter_controls=[quicksight.CfnAnalysis.ParameterControlProperty(
                        date_time_picker=quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        dropdown=quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnAnalysis.ParameterListControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        slider=quicksight.CfnAnalysis.ParameterSliderControlProperty(
                            maximum_value=123,
                            minimum_value=123,
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            step_size=123,
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_area=quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    sheet_control_layouts=[quicksight.CfnAnalysis.SheetControlLayoutProperty(
                        configuration=quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                            grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
        
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        )
                    )],
                    text_boxes=[quicksight.CfnAnalysis.SheetTextBoxProperty(
                        sheet_text_box_id="sheetTextBoxId",
        
                        # the properties below are optional
                        content="content"
                    )],
                    title="title",
                    visuals=[quicksight.CfnAnalysis.VisualProperty(
                        bar_chart_visual=quicksight.CfnAnalysis.BarChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.BarChartConfigurationProperty(
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                                    bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                orientation="orientation",
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        box_plot_visual=quicksight.CfnAnalysis.BoxPlotVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                                box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                                    all_data_points_visibility="allDataPointsVisibility",
                                    outlier_visibility="outlierVisibility",
                                    style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                                        fill_style="fillStyle"
                                    )
                                ),
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                                    box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    )
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        combo_chart_visual=quicksight.CfnAnalysis.ComboChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                                bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                                    combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                                        bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        custom_content_visual=quicksight.CfnAnalysis.CustomContentVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                                content_type="contentType",
                                content_url="contentUrl",
                                image_scaling="imageScaling"
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        empty_visual=quicksight.CfnAnalysis.EmptyVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )]
                        ),
                        filled_map_visual=quicksight.CfnAnalysis.FilledMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                                field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                                    filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                                        geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                                    shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        funnel_chart_visual=quicksight.CfnAnalysis.FunnelChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    label_color="labelColor",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_data_label_style="measureDataLabelStyle",
                                    measure_label_visibility="measureLabelVisibility",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                                    funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        gauge_chart_visual=quicksight.CfnAnalysis.GaugeChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                                    target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                                    arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                                        arc_angle=123,
                                        arc_thickness="arcThickness"
                                    ),
                                    arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                                        range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                            max=123,
                                            min=123
                                        ),
                                        reserve_range=123
                                    ),
                                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                ),
                                tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            conditional_formatting=quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                                    arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
        
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        geospatial_map_visual=quicksight.CfnAnalysis.GeospatialMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                                field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                                    geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                                    cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                                        cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                            simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                                color="color"
                                            )
                                        )
                                    ),
                                    selected_point_style="selectedPointStyle"
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        heat_map_visual=quicksight.CfnAnalysis.HeatMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                                color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
        
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                                    heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                                    heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        histogram_visual=quicksight.CfnAnalysis.HistogramVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.HistogramConfigurationProperty(
                                bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                                    bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                                        value=123
                                    ),
                                    bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                                        bin_count_limit=123,
                                        value=123
                                    ),
                                    selected_bin_type="selectedBinType",
                                    start_value=123
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                                    histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                )
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        insight_visual=quicksight.CfnAnalysis.InsightVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            insight_configuration=quicksight.CfnAnalysis.InsightConfigurationProperty(
                                computations=[quicksight.CfnAnalysis.ComputationProperty(
                                    forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        custom_seasonality_value=123,
                                        lower_boundary=123,
                                        name="name",
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality="seasonality",
                                        upper_boundary=123,
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        period_size=123,
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
        
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                                        computation_id="computationId",
                                        from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        period_time_granularity="periodTimeGranularity",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
        
                                        # the properties below are optional
                                        mover_size=123,
                                        name="name",
                                        sort_order="sortOrder",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        type="type",
        
                                        # the properties below are optional
                                        name="name",
                                        result_size=123,
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                                        computation_id="computationId",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
        
                                        # the properties below are optional
                                        name="name"
                                    )
                                )],
                                custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                                    narrative="narrative"
                                )
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        kpi_visual=quicksight.CfnAnalysis.KPIVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.KPIConfigurationProperty(
                                field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                                    target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                                    trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                                    primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
        
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        line_chart_visual=quicksight.CfnAnalysis.LineChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.LineChartConfigurationProperty(
                                contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                                    axis_binding="axisBinding",
                                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                                    line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                                    forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                                        lower_boundary=123,
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality=123,
                                        upper_boundary=123
                                    ),
                                    scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                                        what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                            date="date",
                                            value=123
                                        ),
                                        what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                            end_date="endDate",
                                            start_date="startDate",
                                            value=123
                                        )
                                    )
                                )],
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                series=[quicksight.CfnAnalysis.SeriesItemProperty(
                                    data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        field_value="fieldValue",
                                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    ),
                                    field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    )
                                )],
                                small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                                    category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                type="type",
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pie_chart_visual=quicksight.CfnAnalysis.PieChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.PieChartConfigurationProperty(
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                                    arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                                        arc_thickness="arcThickness"
                                    ),
                                    donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                                        label_visibility="labelVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                                    pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pivot_table_visual=quicksight.CfnAnalysis.PivotTableVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                                field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                                    data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                                        data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )],
        
                                        # the properties below are optional
                                        width="width"
                                    )],
                                    selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        visibility="visibility"
                                    )]
                                ),
                                field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                                    pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                                    field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                                        field_id="fieldId",
                                        sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                            column=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                                direction="direction",
                                                sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                    field_id="fieldId",
                                                    field_value="fieldValue"
                                                )]
                                            ),
                                            field=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )
                                    )]
                                ),
                                table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_names_visibility="columnNamesVisibility",
                                    metric_placement="metricPlacement",
                                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    ),
                                    row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    single_metric_visibility="singleMetricVisibility",
                                    toggle_buttons_visibility="toggleButtonsVisibility"
                                ),
                                total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                                    column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                )
                            ),
                            conditional_formatting=quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                            role="role"
                                        ),
                                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
        
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        radar_chart_visual=quicksight.CfnAnalysis.RadarChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                                alternate_band_colors_visibility="alternateBandColorsVisibility",
                                alternate_band_even_color="alternateBandEvenColor",
                                alternate_band_odd_color="alternateBandOddColor",
                                base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                                    area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                                    radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                shape="shape",
                                sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                start_angle=123,
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        sankey_diagram_visual=quicksight.CfnAnalysis.SankeyDiagramVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                                    sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                                        destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                                    destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        scatter_plot_visual=quicksight.CfnAnalysis.ScatterPlotVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        table_visual=quicksight.CfnAnalysis.TableVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.TableConfigurationProperty(
                                field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                                    order=["order"],
                                    selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                            image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                                sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                )
                                            ),
                                            link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                                content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                                    custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                                        icon="icon"
                                                    ),
                                                    custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                            font_color="fontColor",
                                                            font_decoration="fontDecoration",
                                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                                relative="relative"
                                                            ),
                                                            font_style="fontStyle",
                                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                                name="name"
                                                            )
                                                        ),
        
                                                        # the properties below are optional
                                                        value="value"
                                                    )
                                                ),
                                                target="target"
                                            )
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    )]
                                ),
                                field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                                    table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                                        values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                                date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    ),
                                    row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                                    data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        negative_color="negativeColor",
                                        positive_color="positiveColor"
                                    )
                                )],
                                table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    orientation="orientation",
                                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    )
                                ),
                                total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                                    custom_label="customLabel",
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility"
                                )
                            ),
                            conditional_formatting=quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
        
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    ),
                                    row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        tree_map_visual=quicksight.CfnAnalysis.TreeMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
        
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                                    tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                                    tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        waterfall_visual=quicksight.CfnAnalysis.WaterfallVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                                category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                                    waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                                        breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                                    breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                                    total_bar_label="totalBarLabel"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        word_cloud_visual=quicksight.CfnAnalysis.WordCloudVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                                    word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                                    cloud_layout="cloudLayout",
                                    maximum_string_length=123,
                                    word_casing="wordCasing",
                                    word_orientation="wordOrientation",
                                    word_padding="wordPadding",
                                    word_scaling="wordScaling"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        )
                    )]
                )]
            ),
            parameters=quicksight.CfnAnalysis.ParametersProperty(
                date_time_parameters=[quicksight.CfnAnalysis.DateTimeParameterProperty(
                    name="name",
                    values=["values"]
                )],
                decimal_parameters=[quicksight.CfnAnalysis.DecimalParameterProperty(
                    name="name",
                    values=[123]
                )],
                integer_parameters=[quicksight.CfnAnalysis.IntegerParameterProperty(
                    name="name",
                    values=[123]
                )],
                string_parameters=[quicksight.CfnAnalysis.StringParameterProperty(
                    name="name",
                    values=["values"]
                )]
            ),
            permissions=[quicksight.CfnAnalysis.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal",
        
                # the properties below are optional
                resource="resource"
            )],
            source_entity=quicksight.CfnAnalysis.AnalysisSourceEntityProperty(
                source_template=quicksight.CfnAnalysis.AnalysisSourceTemplateProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnAnalysis.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                )
            ),
            status="status",
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            theme_arn="themeArn"
        )
    '''

    def __init__(
        self,
        scope: _aws_cdk_core_f4b25747.Construct,
        id: builtins.str,
        *,
        analysis_id: builtins.str,
        aws_account_id: builtins.str,
        name: builtins.str,
        definition: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AnalysisDefinitionProperty", typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]] = None,
        parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        source_entity: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AnalysisSourceEntityProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        status: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
        theme_arn: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::Analysis``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param analysis_id: The ID for the analysis that you're creating. This ID displays in the URL of the analysis.
        :param aws_account_id: The ID of the AWS account where you are creating an analysis.
        :param name: A descriptive name for the analysis that you're creating. This name displays for the analysis in the Amazon QuickSight console.
        :param definition: ``AWS::QuickSight::Analysis.Definition``.
        :param parameters: The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.
        :param permissions: A structure that describes the principals and the resource-level permissions on an analysis. You can use the ``Permissions`` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN). To specify no permissions, omit ``Permissions`` .
        :param source_entity: A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets. Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.
        :param status: Status associated with the analysis.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
        :param theme_arn: The ARN for the theme to apply to the analysis that you're creating. To see the theme in the Amazon QuickSight console, make sure that you have access to it.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b1fce8c313f55f5670c2715a689cf3d56b4e20121c9f12b1bd332ee4aea8f5e)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnAnalysisProps(
            analysis_id=analysis_id,
            aws_account_id=aws_account_id,
            name=name,
            definition=definition,
            parameters=parameters,
            permissions=permissions,
            source_entity=source_entity,
            status=status,
            tags=tags,
            theme_arn=theme_arn,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _aws_cdk_core_f4b25747.TreeInspector) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__83d99561c4cd89e458e1a0bfb21832f2fccc6838e45fc75a8f33afeaaa2b0bd5)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__890025bfa01a2d86ffd84169b263a1f637ec5d823a4b8359add0f664658555c5)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the analysis.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time that the analysis was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrDataSetArns")
    def attr_data_set_arns(self) -> typing.List[builtins.str]:
        '''The ARNs of the datasets of the analysis.

        :cloudformationAttribute: DataSetArns
        '''
        return typing.cast(typing.List[builtins.str], jsii.get(self, "attrDataSetArns"))

    @builtins.property
    @jsii.member(jsii_name="attrErrors")
    def attr_errors(self) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: Errors
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrErrors"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time that the analysis was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrSheets")
    def attr_sheets(self) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: Sheets
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrSheets"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _aws_cdk_core_f4b25747.TagManager:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-tags
        '''
        return typing.cast(_aws_cdk_core_f4b25747.TagManager, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="analysisId")
    def analysis_id(self) -> builtins.str:
        '''The ID for the analysis that you're creating.

        This ID displays in the URL of the analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-analysisid
        '''
        return typing.cast(builtins.str, jsii.get(self, "analysisId"))

    @analysis_id.setter
    def analysis_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a20c5ce03f5536d14402a8b8e303e2203d7dec28e01ce32cd34a033d09805540)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "analysisId", value)

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you are creating an analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-awsaccountid
        '''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d144a6f13ba657b212b82523a2a45dc878ce0ae01704e0918df144ecfbf2c94e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        '''A descriptive name for the analysis that you're creating.

        This name displays for the analysis in the Amazon QuickSight console.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-name
        '''
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e7ab38764caa040b6d2810d4a2c284ca670275f7a51ffda19c4835df0f08a64a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="definition")
    def definition(
        self,
    ) -> typing.Optional[typing.Union["CfnAnalysis.AnalysisDefinitionProperty", _aws_cdk_core_f4b25747.IResolvable]]:
        '''``AWS::QuickSight::Analysis.Definition``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-definition
        '''
        return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AnalysisDefinitionProperty", _aws_cdk_core_f4b25747.IResolvable]], jsii.get(self, "definition"))

    @definition.setter
    def definition(
        self,
        value: typing.Optional[typing.Union["CfnAnalysis.AnalysisDefinitionProperty", _aws_cdk_core_f4b25747.IResolvable]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ef709cf36c65f9d40291088bc1fdba68a9d3ed3ae43306e248f14fda5bbd5e23)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "definition", value)

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParametersProperty"]]:
        '''The parameter names and override values that you want to use.

        An analysis can have any parameter type, and some parameters might accept multiple values.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-parameters
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParametersProperty"]], jsii.get(self, "parameters"))

    @parameters.setter
    def parameters(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParametersProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd862feedb35fd65f19d36c7a3897fe7cf163a638449bc26f49a7256fcc43b2c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "parameters", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ResourcePermissionProperty"]]]]:
        '''A structure that describes the principals and the resource-level permissions on an analysis.

        You can use the ``Permissions`` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN).

        To specify no permissions, omit ``Permissions`` .

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-permissions
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ResourcePermissionProperty"]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ResourcePermissionProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__713b5d9027f8d95c33ea9d444992362270d3ac7b31ed744cda089707d37f7d25)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="sourceEntity")
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AnalysisSourceEntityProperty"]]:
        '''A source entity to use for the analysis that you're creating.

        This metadata structure contains details that describe a source template and one or more datasets.

        Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-sourceentity
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AnalysisSourceEntityProperty"]], jsii.get(self, "sourceEntity"))

    @source_entity.setter
    def source_entity(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AnalysisSourceEntityProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e6aa3ba5841c43dfade18f5cd08832d0f8362b2867556f5b64b98846f6795a64)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sourceEntity", value)

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> typing.Optional[builtins.str]:
        '''Status associated with the analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-status
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "status"))

    @status.setter
    def status(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da0cb51d15c3d2812e92e618336846041391444e4ffa036ad4e1c2d39c872165)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "status", value)

    @builtins.property
    @jsii.member(jsii_name="themeArn")
    def theme_arn(self) -> typing.Optional[builtins.str]:
        '''The ARN for the theme to apply to the analysis that you're creating.

        To see the theme in the Amazon QuickSight console, make sure that you have access to it.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-themearn
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "themeArn"))

    @theme_arn.setter
    def theme_arn(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3dd7327da1bdc4d2b5187e44f09b10eff8f5ab17ec3ce7d001fdfae267d3fc18)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "themeArn", value)

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_aggregation_function": "categoricalAggregationFunction",
            "date_aggregation_function": "dateAggregationFunction",
            "numerical_aggregation_function": "numericalAggregationFunction",
        },
    )
    class AggregationFunctionProperty:
        def __init__(
            self,
            *,
            categorical_aggregation_function: typing.Optional[builtins.str] = None,
            date_aggregation_function: typing.Optional[builtins.str] = None,
            numerical_aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''An aggregation function aggregates values from a dimension or measure.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param categorical_aggregation_function: Aggregation for categorical values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            :param date_aggregation_function: Aggregation for date values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values. - ``MIN`` : Select the smallest date value. - ``MAX`` : Select the largest date value.
            :param numerical_aggregation_function: Aggregation for numerical values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                aggregation_function_property = quicksight.CfnAnalysis.AggregationFunctionProperty(
                    categorical_aggregation_function="categoricalAggregationFunction",
                    date_aggregation_function="dateAggregationFunction",
                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b06fa2f4f355e67f88cc715b75405b4132a6853aaaaffa8343ae24c3f37c58b8)
                check_type(argname="argument categorical_aggregation_function", value=categorical_aggregation_function, expected_type=type_hints["categorical_aggregation_function"])
                check_type(argname="argument date_aggregation_function", value=date_aggregation_function, expected_type=type_hints["date_aggregation_function"])
                check_type(argname="argument numerical_aggregation_function", value=numerical_aggregation_function, expected_type=type_hints["numerical_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_aggregation_function is not None:
                self._values["categorical_aggregation_function"] = categorical_aggregation_function
            if date_aggregation_function is not None:
                self._values["date_aggregation_function"] = date_aggregation_function
            if numerical_aggregation_function is not None:
                self._values["numerical_aggregation_function"] = numerical_aggregation_function

        @builtins.property
        def categorical_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for categorical values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-categoricalaggregationfunction
            '''
            result = self._values.get("categorical_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def date_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for date values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            - ``MIN`` : Select the smallest date value.
            - ``MAX`` : Select the largest date value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-dateaggregationfunction
            '''
            result = self._values.get("date_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def numerical_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericalAggregationFunctionProperty"]]:
            '''Aggregation for numerical values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-numericalaggregationfunction
            '''
            result = self._values.get("numerical_aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericalAggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AggregationSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_function": "aggregationFunction",
            "column": "column",
            "sort_direction": "sortDirection",
        },
    )
    class AggregationSortConfigurationProperty:
        def __init__(
            self,
            *,
            aggregation_function: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            sort_direction: builtins.str,
        ) -> None:
            '''The configuration options to sort aggregated values.

            :param aggregation_function: The function that aggregates the values in ``Column`` .
            :param column: The column that determines the sort order of aggregated values.
            :param sort_direction: The sort direction of values. - ``ASC`` : Sort in ascending order. - ``DESC`` : Sort in descending order.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                aggregation_sort_configuration_property = quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    sort_direction="sortDirection"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__707d4d779e53637a39a6c7cdb86826b6866b8a467b2c3721450caac819bc0280)
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument sort_direction", value=sort_direction, expected_type=type_hints["sort_direction"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_function": aggregation_function,
                "column": column,
                "sort_direction": sort_direction,
            }

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationFunctionProperty"]:
            '''The function that aggregates the values in ``Column`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            assert result is not None, "Required property 'aggregation_function' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationFunctionProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that determines the sort order of aggregated values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def sort_direction(self) -> builtins.str:
            '''The sort direction of values.

            - ``ASC`` : Sort in ascending order.
            - ``DESC`` : Sort in descending order.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-sortdirection
            '''
            result = self._values.get("sort_direction")
            assert result is not None, "Required property 'sort_direction' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AnalysisDefaultsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_new_sheet_configuration": "defaultNewSheetConfiguration",
        },
    )
    class AnalysisDefaultsProperty:
        def __init__(
            self,
            *,
            default_new_sheet_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DefaultNewSheetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The configuration for default analysis settings.

            :param default_new_sheet_configuration: The configuration for default new sheet settings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefaults.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                analysis_defaults_property = quicksight.CfnAnalysis.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__54dcf5bf066087e5e9752805222d38e30cffa8b5765a6b794f6f32357b975d0e)
                check_type(argname="argument default_new_sheet_configuration", value=default_new_sheet_configuration, expected_type=type_hints["default_new_sheet_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_new_sheet_configuration": default_new_sheet_configuration,
            }

        @builtins.property
        def default_new_sheet_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DefaultNewSheetConfigurationProperty"]:
            '''The configuration for default new sheet settings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefaults.html#cfn-quicksight-analysis-analysisdefaults-defaultnewsheetconfiguration
            '''
            result = self._values.get("default_new_sheet_configuration")
            assert result is not None, "Required property 'default_new_sheet_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DefaultNewSheetConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisDefaultsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AnalysisDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier_declarations": "dataSetIdentifierDeclarations",
            "analysis_defaults": "analysisDefaults",
            "calculated_fields": "calculatedFields",
            "column_configurations": "columnConfigurations",
            "filter_groups": "filterGroups",
            "parameter_declarations": "parameterDeclarations",
            "sheets": "sheets",
        },
    )
    class AnalysisDefinitionProperty:
        def __init__(
            self,
            *,
            data_set_identifier_declarations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataSetIdentifierDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AnalysisDefaultsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            calculated_fields: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CalculatedFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            column_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            filter_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterGroupProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            parameter_declarations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SheetDefinitionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The definition of an analysis.

            :param data_set_identifier_declarations: An array of dataset identifier declarations. This mapping allows the usage of dataset identifiers instead of dataset ARNs throughout analysis sub-structures.
            :param analysis_defaults: ``CfnAnalysis.AnalysisDefinitionProperty.AnalysisDefaults``.
            :param calculated_fields: An array of calculated field definitions for the analysis.
            :param column_configurations: An array of analysis-level column configurations. Column configurations can be used to set default formatting for a column to be used throughout an analysis.
            :param filter_groups: Filter definitions for an analysis. For more information, see `Filtering Data in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html>`_ in the *Amazon QuickSight User Guide* .
            :param parameter_declarations: An array of parameter declarations for an analysis. Parameters are named variables that can transfer a value for use by an action or an object. For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheets: An array of sheet definitions for an analysis. Each ``SheetDefinition`` provides detailed information about a sheet within this analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                analysis_definition_property = quicksight.CfnAnalysis.AnalysisDefinitionProperty(
                    data_set_identifier_declarations=[quicksight.CfnAnalysis.DataSetIdentifierDeclarationProperty(
                        data_set_arn="dataSetArn",
                        identifier="identifier"
                    )],
                
                    # the properties below are optional
                    analysis_defaults=quicksight.CfnAnalysis.AnalysisDefaultsProperty(
                        default_new_sheet_configuration=quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty(
                            interactive_layout_configuration=quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                                free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            ),
                            paginated_layout_configuration=quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                                section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    )
                                )
                            ),
                            sheet_content_type="sheetContentType"
                        )
                    ),
                    calculated_fields=[quicksight.CfnAnalysis.CalculatedFieldProperty(
                        data_set_identifier="dataSetIdentifier",
                        expression="expression",
                        name="name"
                    )],
                    column_configurations=[quicksight.CfnAnalysis.ColumnConfigurationProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        colors_configuration=quicksight.CfnAnalysis.ColorsConfigurationProperty(
                            custom_colors=[quicksight.CfnAnalysis.CustomColorProperty(
                                color="color",
                
                                # the properties below are optional
                                field_value="fieldValue",
                                special_value="specialValue"
                            )]
                        ),
                        format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        role="role"
                    )],
                    filter_groups=[quicksight.CfnAnalysis.FilterGroupProperty(
                        cross_dataset="crossDataset",
                        filter_group_id="filterGroupId",
                        filters=[quicksight.CfnAnalysis.FilterProperty(
                            category_filter=quicksight.CfnAnalysis.CategoryFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                                    custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
                
                                        # the properties below are optional
                                        category_value="categoryValue",
                                        parameter_name="parameterName",
                                        select_all_options="selectAllOptions"
                                    ),
                                    custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
                
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    ),
                                    filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                                        match_operator="matchOperator",
                
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    )
                                ),
                                filter_id="filterId"
                            ),
                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions",
                                value=123
                            ),
                            numeric_range_filter=quicksight.CfnAnalysis.NumericRangeFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                select_all_options="selectAllOptions"
                            ),
                            relative_dates_filter=quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                                anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                                    anchor_option="anchorOption",
                                    parameter_name="parameterName"
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                                relative_date_type="relativeDateType",
                                time_granularity="timeGranularity",
                
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
                
                                    # the properties below are optional
                                    status="status"
                                ),
                                minimum_granularity="minimumGranularity",
                                parameter_name="parameterName",
                                relative_date_value=123
                            ),
                            time_equality_filter=quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                
                                # the properties below are optional
                                parameter_name="parameterName",
                                time_granularity="timeGranularity",
                                value="value"
                            ),
                            time_range_filter=quicksight.CfnAnalysis.TimeRangeFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
                
                                    # the properties below are optional
                                    status="status"
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                time_granularity="timeGranularity"
                            ),
                            top_bottom_filter=quicksight.CfnAnalysis.TopBottomFilterProperty(
                                aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    sort_direction="sortDirection"
                                )],
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                
                                # the properties below are optional
                                limit=123,
                                parameter_name="parameterName",
                                time_granularity="timeGranularity"
                            )
                        )],
                        scope_configuration=quicksight.CfnAnalysis.FilterScopeConfigurationProperty(
                            selected_sheets=quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                                sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                                    scope="scope",
                                    sheet_id="sheetId",
                
                                    # the properties below are optional
                                    visual_ids=["visualIds"]
                                )]
                            )
                        ),
                
                        # the properties below are optional
                        status="status"
                    )],
                    parameter_declarations=[quicksight.CfnAnalysis.ParameterDeclarationProperty(
                        date_time_parameter_declaration=quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty(
                            name="name",
                
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            time_granularity="timeGranularity",
                            value_when_unset=quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        decimal_parameter_declaration=quicksight.CfnAnalysis.DecimalParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        integer_parameter_declaration=quicksight.CfnAnalysis.IntegerParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        string_parameter_declaration=quicksight.CfnAnalysis.StringParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.StringDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        )
                    )],
                    sheets=[quicksight.CfnAnalysis.SheetDefinitionProperty(
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        content_type="contentType",
                        description="description",
                        filter_controls=[quicksight.CfnAnalysis.FilterControlProperty(
                            date_time_picker=quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            dropdown=quicksight.CfnAnalysis.FilterDropDownControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnAnalysis.FilterListControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            relative_date_time=quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            slider=quicksight.CfnAnalysis.FilterSliderControlProperty(
                                filter_control_id="filterControlId",
                                maximum_value=123,
                                minimum_value=123,
                                source_filter_id="sourceFilterId",
                                step_size=123,
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            text_area=quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        layouts=[quicksight.CfnAnalysis.LayoutProperty(
                            configuration=quicksight.CfnAnalysis.LayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
                
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                                    body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                                        content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                            layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                                free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                        element_id="elementId",
                                                        element_type="elementType",
                                                        height="height",
                                                        width="width",
                                                        x_axis_location="xAxisLocation",
                                                        y_axis_location="yAxisLocation",
                
                                                        # the properties below are optional
                                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                            visibility="visibility"
                                                        ),
                                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                                visibility="visibility"
                                                            ),
                                                            expression="expression"
                                                        )],
                                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        visibility="visibility"
                                                    )]
                                                )
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                            after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                                status="status"
                                            )
                                        ),
                                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    ),
                                    footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )]
                                )
                            )
                        )],
                        name="name",
                        parameter_controls=[quicksight.CfnAnalysis.ParameterControlProperty(
                            date_time_picker=quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            dropdown=quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnAnalysis.ParameterListControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            slider=quicksight.CfnAnalysis.ParameterSliderControlProperty(
                                maximum_value=123,
                                minimum_value=123,
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                step_size=123,
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_area=quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        sheet_control_layouts=[quicksight.CfnAnalysis.SheetControlLayoutProperty(
                            configuration=quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                                grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
                
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            )
                        )],
                        text_boxes=[quicksight.CfnAnalysis.SheetTextBoxProperty(
                            sheet_text_box_id="sheetTextBoxId",
                
                            # the properties below are optional
                            content="content"
                        )],
                        title="title",
                        visuals=[quicksight.CfnAnalysis.VisualProperty(
                            bar_chart_visual=quicksight.CfnAnalysis.BarChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.BarChartConfigurationProperty(
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                                        bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    orientation="orientation",
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            box_plot_visual=quicksight.CfnAnalysis.BoxPlotVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                                    box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                                        all_data_points_visibility="allDataPointsVisibility",
                                        outlier_visibility="outlierVisibility",
                                        style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                                            fill_style="fillStyle"
                                        )
                                    ),
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                                        box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        )
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            combo_chart_visual=quicksight.CfnAnalysis.ComboChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                                    bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                                        combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                                            bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            custom_content_visual=quicksight.CfnAnalysis.CustomContentVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                                    content_type="contentType",
                                    content_url="contentUrl",
                                    image_scaling="imageScaling"
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            empty_visual=quicksight.CfnAnalysis.EmptyVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )]
                            ),
                            filled_map_visual=quicksight.CfnAnalysis.FilledMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                                    field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                                        filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                                            geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                                        shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            funnel_chart_visual=quicksight.CfnAnalysis.FunnelChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        label_color="labelColor",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_data_label_style="measureDataLabelStyle",
                                        measure_label_visibility="measureLabelVisibility",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                                        funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            gauge_chart_visual=quicksight.CfnAnalysis.GaugeChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                                        target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                                        arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                                            arc_angle=123,
                                            arc_thickness="arcThickness"
                                        ),
                                        arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                                            range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                                max=123,
                                                min=123
                                            ),
                                            reserve_range=123
                                        ),
                                        comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    ),
                                    tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                conditional_formatting=quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                                        arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            geospatial_map_visual=quicksight.CfnAnalysis.GeospatialMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                                    field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                                        geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                                        cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                                            cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                                simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                                    color="color"
                                                )
                                            )
                                        ),
                                        selected_point_style="selectedPointStyle"
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            heat_map_visual=quicksight.CfnAnalysis.HeatMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                                    color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
                
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                                        heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                                        heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            histogram_visual=quicksight.CfnAnalysis.HistogramVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.HistogramConfigurationProperty(
                                    bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                                        bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                                            value=123
                                        ),
                                        bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                                            bin_count_limit=123,
                                            value=123
                                        ),
                                        selected_bin_type="selectedBinType",
                                        start_value=123
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                                        histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    )
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            insight_visual=quicksight.CfnAnalysis.InsightVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                insight_configuration=quicksight.CfnAnalysis.InsightConfigurationProperty(
                                    computations=[quicksight.CfnAnalysis.ComputationProperty(
                                        forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            custom_seasonality_value=123,
                                            lower_boundary=123,
                                            name="name",
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality="seasonality",
                                            upper_boundary=123,
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            period_size=123,
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
                
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                                            computation_id="computationId",
                                            from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            period_time_granularity="periodTimeGranularity",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
                
                                            # the properties below are optional
                                            mover_size=123,
                                            name="name",
                                            sort_order="sortOrder",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            type="type",
                
                                            # the properties below are optional
                                            name="name",
                                            result_size=123,
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                                            computation_id="computationId",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                
                                            # the properties below are optional
                                            name="name"
                                        )
                                    )],
                                    custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                                        narrative="narrative"
                                    )
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            kpi_visual=quicksight.CfnAnalysis.KPIVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.KPIConfigurationProperty(
                                    field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                                        target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                                        comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                                        trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                                        primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            line_chart_visual=quicksight.CfnAnalysis.LineChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.LineChartConfigurationProperty(
                                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                                        axis_binding="axisBinding",
                                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                                        line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                                        forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                                            lower_boundary=123,
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality=123,
                                            upper_boundary=123
                                        ),
                                        scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                                            what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                                date="date",
                                                value=123
                                            ),
                                            what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                                end_date="endDate",
                                                start_date="startDate",
                                                value=123
                                            )
                                        )
                                    )],
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    series=[quicksight.CfnAnalysis.SeriesItemProperty(
                                        data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            field_value="fieldValue",
                                            settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        ),
                                        field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                                        category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    type="type",
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pie_chart_visual=quicksight.CfnAnalysis.PieChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.PieChartConfigurationProperty(
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                                        arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                                            arc_thickness="arcThickness"
                                        ),
                                        donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                                            label_visibility="labelVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                                        pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pivot_table_visual=quicksight.CfnAnalysis.PivotTableVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                                    field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                                        data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                                            data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )],
                
                                            # the properties below are optional
                                            width="width"
                                        )],
                                        selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            visibility="visibility"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                                        pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                                        field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                                            field_id="fieldId",
                                            sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                                column=quicksight.CfnAnalysis.ColumnSortProperty(
                                                    direction="direction",
                                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    )
                                                ),
                                                data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                                    direction="direction",
                                                    sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                        field_id="fieldId",
                                                        field_value="fieldValue"
                                                    )]
                                                ),
                                                field=quicksight.CfnAnalysis.FieldSortProperty(
                                                    direction="direction",
                                                    field_id="fieldId"
                                                )
                                            )
                                        )]
                                    ),
                                    table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                                        cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_names_visibility="columnNamesVisibility",
                                        metric_placement="metricPlacement",
                                        row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        ),
                                        row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        single_metric_visibility="singleMetricVisibility",
                                        toggle_buttons_visibility="toggleButtonsVisibility"
                                    ),
                                    total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                                        column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    )
                                ),
                                conditional_formatting=quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                                role="role"
                                            ),
                                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
                
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            radar_chart_visual=quicksight.CfnAnalysis.RadarChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                                    alternate_band_even_color="alternateBandEvenColor",
                                    alternate_band_odd_color="alternateBandOddColor",
                                    base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                                        area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                                        radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    shape="shape",
                                    sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    start_angle=123,
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            sankey_diagram_visual=quicksight.CfnAnalysis.SankeyDiagramVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                                        sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                                            destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                                        destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            scatter_plot_visual=quicksight.CfnAnalysis.ScatterPlotVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            table_visual=quicksight.CfnAnalysis.TableVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.TableConfigurationProperty(
                                    field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                                        order=["order"],
                                        selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                                image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                                    sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                    )
                                                ),
                                                link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                                    content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                                        custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                                            icon="icon"
                                                        ),
                                                        custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                                font_color="fontColor",
                                                                font_decoration="fontDecoration",
                                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                                    relative="relative"
                                                                ),
                                                                font_style="fontStyle",
                                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                                    name="name"
                                                                )
                                                            ),
                
                                                            # the properties below are optional
                                                            value="value"
                                                        )
                                                    ),
                                                    target="target"
                                                )
                                            ),
                                            visibility="visibility",
                                            width="width"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                                        table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                                            values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                                    date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                                        pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        ),
                                        row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                                        data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            negative_color="negativeColor",
                                            positive_color="positiveColor"
                                        )
                                    )],
                                    table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                                        cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        orientation="orientation",
                                        row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        )
                                    ),
                                    total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                                        custom_label="customLabel",
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility"
                                    )
                                ),
                                conditional_formatting=quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
                
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        ),
                                        row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            tree_map_visual=quicksight.CfnAnalysis.TreeMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
                
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                                        tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                                        tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            waterfall_visual=quicksight.CfnAnalysis.WaterfallVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                                    category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                                        waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                                            breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                                        breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                                        total_bar_label="totalBarLabel"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            word_cloud_visual=quicksight.CfnAnalysis.WordCloudVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                                        word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                                        cloud_layout="cloudLayout",
                                        maximum_string_length=123,
                                        word_casing="wordCasing",
                                        word_orientation="wordOrientation",
                                        word_padding="wordPadding",
                                        word_scaling="wordScaling"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__772b2658fa007306fadbcfba0ec00db97c08a5c24e25fe7846091d13e0dc3855)
                check_type(argname="argument data_set_identifier_declarations", value=data_set_identifier_declarations, expected_type=type_hints["data_set_identifier_declarations"])
                check_type(argname="argument analysis_defaults", value=analysis_defaults, expected_type=type_hints["analysis_defaults"])
                check_type(argname="argument calculated_fields", value=calculated_fields, expected_type=type_hints["calculated_fields"])
                check_type(argname="argument column_configurations", value=column_configurations, expected_type=type_hints["column_configurations"])
                check_type(argname="argument filter_groups", value=filter_groups, expected_type=type_hints["filter_groups"])
                check_type(argname="argument parameter_declarations", value=parameter_declarations, expected_type=type_hints["parameter_declarations"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier_declarations": data_set_identifier_declarations,
            }
            if analysis_defaults is not None:
                self._values["analysis_defaults"] = analysis_defaults
            if calculated_fields is not None:
                self._values["calculated_fields"] = calculated_fields
            if column_configurations is not None:
                self._values["column_configurations"] = column_configurations
            if filter_groups is not None:
                self._values["filter_groups"] = filter_groups
            if parameter_declarations is not None:
                self._values["parameter_declarations"] = parameter_declarations
            if sheets is not None:
                self._values["sheets"] = sheets

        @builtins.property
        def data_set_identifier_declarations(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataSetIdentifierDeclarationProperty"]]]:
            '''An array of dataset identifier declarations.

            This mapping allows the usage of dataset identifiers instead of dataset ARNs throughout analysis sub-structures.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-datasetidentifierdeclarations
            '''
            result = self._values.get("data_set_identifier_declarations")
            assert result is not None, "Required property 'data_set_identifier_declarations' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataSetIdentifierDeclarationProperty"]]], result)

        @builtins.property
        def analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AnalysisDefaultsProperty"]]:
            '''``CfnAnalysis.AnalysisDefinitionProperty.AnalysisDefaults``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-analysisdefaults
            '''
            result = self._values.get("analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AnalysisDefaultsProperty"]], result)

        @builtins.property
        def calculated_fields(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CalculatedFieldProperty"]]]]:
            '''An array of calculated field definitions for the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-calculatedfields
            '''
            result = self._values.get("calculated_fields")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CalculatedFieldProperty"]]]], result)

        @builtins.property
        def column_configurations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnConfigurationProperty"]]]]:
            '''An array of analysis-level column configurations.

            Column configurations can be used to set default formatting for a column to be used throughout an analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-columnconfigurations
            '''
            result = self._values.get("column_configurations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnConfigurationProperty"]]]], result)

        @builtins.property
        def filter_groups(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterGroupProperty"]]]]:
            '''Filter definitions for an analysis.

            For more information, see `Filtering Data in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-filtergroups
            '''
            result = self._values.get("filter_groups")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterGroupProperty"]]]], result)

        @builtins.property
        def parameter_declarations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterDeclarationProperty"]]]]:
            '''An array of parameter declarations for an analysis.

            Parameters are named variables that can transfer a value for use by an action or an object.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-parameterdeclarations
            '''
            result = self._values.get("parameter_declarations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterDeclarationProperty"]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetDefinitionProperty"]]]]:
            '''An array of sheet definitions for an analysis.

            Each ``SheetDefinition`` provides detailed information about a sheet within this analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetDefinitionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AnalysisErrorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "message": "message",
            "type": "type",
            "violated_entities": "violatedEntities",
        },
    )
    class AnalysisErrorProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
            violated_entities: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.EntityProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Analysis error.

            :param message: The message associated with the analysis error.
            :param type: The type of the analysis error.
            :param violated_entities: Lists the violated entities that caused the analysis error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                analysis_error_property = quicksight.CfnAnalysis.AnalysisErrorProperty(
                    message="message",
                    type="type",
                    violated_entities=[quicksight.CfnAnalysis.EntityProperty(
                        path="path"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e22cc5d762db992524875b94a2c36c96b814808b5a8934fb508f135ed25c194b)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument violated_entities", value=violated_entities, expected_type=type_hints["violated_entities"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type
            if violated_entities is not None:
                self._values["violated_entities"] = violated_entities

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''The message associated with the analysis error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of the analysis error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def violated_entities(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.EntityProperty"]]]]:
            '''Lists the violated entities that caused the analysis error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-violatedentities
            '''
            result = self._values.get("violated_entities")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.EntityProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisErrorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AnalysisSourceEntityProperty",
        jsii_struct_bases=[],
        name_mapping={"source_template": "sourceTemplate"},
    )
    class AnalysisSourceEntityProperty:
        def __init__(
            self,
            *,
            source_template: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AnalysisSourceTemplateProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The source entity of an analysis.

            :param source_template: The source template for the source entity of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourceentity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                analysis_source_entity_property = quicksight.CfnAnalysis.AnalysisSourceEntityProperty(
                    source_template=quicksight.CfnAnalysis.AnalysisSourceTemplateProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnAnalysis.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b306bfc3f9cbb6620ce938988f1731f678cf18004219081e7ff5fc7dfb7d183d)
                check_type(argname="argument source_template", value=source_template, expected_type=type_hints["source_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_template is not None:
                self._values["source_template"] = source_template

        @builtins.property
        def source_template(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AnalysisSourceTemplateProperty"]]:
            '''The source template for the source entity of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourceentity.html#cfn-quicksight-analysis-analysissourceentity-sourcetemplate
            '''
            result = self._values.get("source_template")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AnalysisSourceTemplateProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisSourceEntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AnalysisSourceTemplateProperty",
        jsii_struct_bases=[],
        name_mapping={"arn": "arn", "data_set_references": "dataSetReferences"},
    )
    class AnalysisSourceTemplateProperty:
        def __init__(
            self,
            *,
            arn: builtins.str,
            data_set_references: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataSetReferenceProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The source template of an analysis.

            :param arn: The Amazon Resource Name (ARN) of the source template of an analysis.
            :param data_set_references: The dataset references of the source template of an analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                analysis_source_template_property = quicksight.CfnAnalysis.AnalysisSourceTemplateProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnAnalysis.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d50c5ea15b2ce8c8bf4b90dcff5f82ce746389f3c5196809915cb845081ae884)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument data_set_references", value=data_set_references, expected_type=type_hints["data_set_references"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
                "data_set_references": data_set_references,
            }

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the source template of an analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html#cfn-quicksight-analysis-analysissourcetemplate-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_references(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataSetReferenceProperty"]]]:
            '''The dataset references of the source template of an analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html#cfn-quicksight-analysis-analysissourcetemplate-datasetreferences
            '''
            result = self._values.get("data_set_references")
            assert result is not None, "Required property 'data_set_references' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataSetReferenceProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisSourceTemplateProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AnchorDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_option": "anchorOption",
            "parameter_name": "parameterName",
        },
    )
    class AnchorDateConfigurationProperty:
        def __init__(
            self,
            *,
            anchor_option: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The date configuration of the filter.

            :param anchor_option: The options for the date configuration. Choose one of the options below:. - ``NOW``
            :param parameter_name: The name of the parameter that is used for the anchor date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                anchor_date_configuration_property = quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                    anchor_option="anchorOption",
                    parameter_name="parameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f5d5ba82b15bcff5ac1b7a4ea3aeb46d41e4d2ab9f8b394c74b828b4a9877f87)
                check_type(argname="argument anchor_option", value=anchor_option, expected_type=type_hints["anchor_option"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if anchor_option is not None:
                self._values["anchor_option"] = anchor_option
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name

        @builtins.property
        def anchor_option(self) -> typing.Optional[builtins.str]:
            '''The options for the date configuration. Choose one of the options below:.

            - ``NOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html#cfn-quicksight-analysis-anchordateconfiguration-anchoroption
            '''
            result = self._values.get("anchor_option")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The name of the parameter that is used for the anchor date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html#cfn-quicksight-analysis-anchordateconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnchorDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ArcAxisConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "reserve_range": "reserveRange"},
    )
    class ArcAxisConfigurationProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ArcAxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reserve_range: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :param range: The arc axis range of a ``GaugeChartVisual`` .
            :param reserve_range: The reserved range of the arc axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                arc_axis_configuration_property = quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                    range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                        max=123,
                        min=123
                    ),
                    reserve_range=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__02deb962f62e7fb7fda4811d0934eb790b43c2d89156a421ec472c08e8b179d9)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument reserve_range", value=reserve_range, expected_type=type_hints["reserve_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if reserve_range is not None:
                self._values["reserve_range"] = reserve_range

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ArcAxisDisplayRangeProperty"]]:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html#cfn-quicksight-analysis-arcaxisconfiguration-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ArcAxisDisplayRangeProperty"]], result)

        @builtins.property
        def reserve_range(self) -> typing.Optional[jsii.Number]:
            '''The reserved range of the arc axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html#cfn-quicksight-analysis-arcaxisconfiguration-reserverange
            '''
            result = self._values.get("reserve_range")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"max": "max", "min": "min"},
    )
    class ArcAxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            max: typing.Optional[jsii.Number] = None,
            min: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :param max: The maximum value of the arc axis range.
            :param min: The minimum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                arc_axis_display_range_property = quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                    max=123,
                    min=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0307d0862519a847530b788bc8ba6b28802542557f4b4e14523122ec04cc9165)
                check_type(argname="argument max", value=max, expected_type=type_hints["max"])
                check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max is not None:
                self._values["max"] = max
            if min is not None:
                self._values["min"] = min

        @builtins.property
        def max(self) -> typing.Optional[jsii.Number]:
            '''The maximum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html#cfn-quicksight-analysis-arcaxisdisplayrange-max
            '''
            result = self._values.get("max")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def min(self) -> typing.Optional[jsii.Number]:
            '''The minimum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html#cfn-quicksight-analysis-arcaxisdisplayrange-min
            '''
            result = self._values.get("min")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ArcConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_angle": "arcAngle", "arc_thickness": "arcThickness"},
    )
    class ArcConfigurationProperty:
        def __init__(
            self,
            *,
            arc_angle: typing.Optional[jsii.Number] = None,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :param arc_angle: The option that determines the arc angle of a ``GaugeChartVisual`` .
            :param arc_thickness: The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                arc_configuration_property = quicksight.CfnAnalysis.ArcConfigurationProperty(
                    arc_angle=123,
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ed4d40dc2c1217ef0ec7b62fac904c3670875361931f3b52e2a3b8f25b7dff9)
                check_type(argname="argument arc_angle", value=arc_angle, expected_type=type_hints["arc_angle"])
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_angle is not None:
                self._values["arc_angle"] = arc_angle
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_angle(self) -> typing.Optional[jsii.Number]:
            '''The option that determines the arc angle of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html#cfn-quicksight-analysis-arcconfiguration-arcangle
            '''
            result = self._values.get("arc_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html#cfn-quicksight-analysis-arcconfiguration-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ArcOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_thickness": "arcThickness"},
    )
    class ArcOptionsProperty:
        def __init__(
            self,
            *,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :param arc_thickness: The arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                arc_options_property = quicksight.CfnAnalysis.ArcOptionsProperty(
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4241d86441a9e2f4d2710a85e4a9d2a3633688f84d262273ae6f06569a7d679e)
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcoptions.html#cfn-quicksight-analysis-arcoptions-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AxisDataOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_axis_options": "dateAxisOptions",
            "numeric_axis_options": "numericAxisOptions",
        },
    )
    class AxisDataOptionsProperty:
        def __init__(
            self,
            *,
            date_axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DateAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data options for an axis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_axis_options: The options for an axis with a date field.
            :param numeric_axis_options: The options for an axis with a numeric field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_data_options_property = quicksight.CfnAnalysis.AxisDataOptionsProperty(
                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                        missing_date_visibility="missingDateVisibility"
                    ),
                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                            data_driven=data_driven,
                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                maximum=123,
                                minimum=123
                            )
                        ),
                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                step_count=123,
                                step_size=123
                            ),
                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                base=123
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fe05f10384174634d4321a63159411f22eb1dd513acc8ffca1ca51feccb94f1a)
                check_type(argname="argument date_axis_options", value=date_axis_options, expected_type=type_hints["date_axis_options"])
                check_type(argname="argument numeric_axis_options", value=numeric_axis_options, expected_type=type_hints["numeric_axis_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_axis_options is not None:
                self._values["date_axis_options"] = date_axis_options
            if numeric_axis_options is not None:
                self._values["numeric_axis_options"] = numeric_axis_options

        @builtins.property
        def date_axis_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateAxisOptionsProperty"]]:
            '''The options for an axis with a date field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html#cfn-quicksight-analysis-axisdataoptions-dateaxisoptions
            '''
            result = self._values.get("date_axis_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateAxisOptionsProperty"]], result)

        @builtins.property
        def numeric_axis_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericAxisOptionsProperty"]]:
            '''The options for an axis with a numeric field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html#cfn-quicksight-analysis-axisdataoptions-numericaxisoptions
            '''
            result = self._values.get("numeric_axis_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericAxisOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDataOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"maximum": "maximum", "minimum": "minimum"},
    )
    class AxisDisplayMinMaxRangeProperty:
        def __init__(
            self,
            *,
            maximum: typing.Optional[jsii.Number] = None,
            minimum: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The minimum and maximum setup for an axis display range.

            :param maximum: The maximum setup for an axis display range.
            :param minimum: The minimum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_display_min_max_range_property = quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                    maximum=123,
                    minimum=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__54b6dc0f91a398a608054875282adf2b742ea8ee8d3eb75ad48251325f8f459b)
                check_type(argname="argument maximum", value=maximum, expected_type=type_hints["maximum"])
                check_type(argname="argument minimum", value=minimum, expected_type=type_hints["minimum"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if maximum is not None:
                self._values["maximum"] = maximum
            if minimum is not None:
                self._values["minimum"] = minimum

        @builtins.property
        def maximum(self) -> typing.Optional[jsii.Number]:
            '''The maximum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html#cfn-quicksight-analysis-axisdisplayminmaxrange-maximum
            '''
            result = self._values.get("maximum")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def minimum(self) -> typing.Optional[jsii.Number]:
            '''The minimum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html#cfn-quicksight-analysis-axisdisplayminmaxrange-minimum
            '''
            result = self._values.get("minimum")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayMinMaxRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_line_visibility": "axisLineVisibility",
            "axis_offset": "axisOffset",
            "data_options": "dataOptions",
            "grid_line_visibility": "gridLineVisibility",
            "scrollbar_options": "scrollbarOptions",
            "tick_label_options": "tickLabelOptions",
        },
    )
    class AxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_line_visibility: typing.Optional[builtins.str] = None,
            axis_offset: typing.Optional[builtins.str] = None,
            data_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDataOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid_line_visibility: typing.Optional[builtins.str] = None,
            scrollbar_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ScrollBarOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tick_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisTickLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options for the axis label.

            :param axis_line_visibility: Determines whether or not the axis line is visible.
            :param axis_offset: The offset value that determines the starting placement of the axis within a visual's bounds.
            :param data_options: The data options for an axis.
            :param grid_line_visibility: Determines whether or not the grid line is visible.
            :param scrollbar_options: The scroll bar options for an axis.
            :param tick_label_options: The tick label options of an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_options_property = quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                    axis_line_visibility="axisLineVisibility",
                    axis_offset="axisOffset",
                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                            missing_date_visibility="missingDateVisibility"
                        ),
                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                data_driven=data_driven,
                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                    maximum=123,
                                    minimum=123
                                )
                            ),
                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                    step_count=123,
                                    step_size=123
                                ),
                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                    base=123
                                )
                            )
                        )
                    ),
                    grid_line_visibility="gridLineVisibility",
                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                        visibility="visibility",
                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                from=123,
                                to=123
                            )
                        )
                    ),
                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        rotation_angle=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__514f83eddd8d4a660c3e70562beb31b6c9dde97cce0401986da5d9ef4af4bc16)
                check_type(argname="argument axis_line_visibility", value=axis_line_visibility, expected_type=type_hints["axis_line_visibility"])
                check_type(argname="argument axis_offset", value=axis_offset, expected_type=type_hints["axis_offset"])
                check_type(argname="argument data_options", value=data_options, expected_type=type_hints["data_options"])
                check_type(argname="argument grid_line_visibility", value=grid_line_visibility, expected_type=type_hints["grid_line_visibility"])
                check_type(argname="argument scrollbar_options", value=scrollbar_options, expected_type=type_hints["scrollbar_options"])
                check_type(argname="argument tick_label_options", value=tick_label_options, expected_type=type_hints["tick_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_line_visibility is not None:
                self._values["axis_line_visibility"] = axis_line_visibility
            if axis_offset is not None:
                self._values["axis_offset"] = axis_offset
            if data_options is not None:
                self._values["data_options"] = data_options
            if grid_line_visibility is not None:
                self._values["grid_line_visibility"] = grid_line_visibility
            if scrollbar_options is not None:
                self._values["scrollbar_options"] = scrollbar_options
            if tick_label_options is not None:
                self._values["tick_label_options"] = tick_label_options

        @builtins.property
        def axis_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the axis line is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-axislinevisibility
            '''
            result = self._values.get("axis_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def axis_offset(self) -> typing.Optional[builtins.str]:
            '''The offset value that determines the starting placement of the axis within a visual's bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-axisoffset
            '''
            result = self._values.get("axis_offset")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDataOptionsProperty"]]:
            '''The data options for an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-dataoptions
            '''
            result = self._values.get("data_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDataOptionsProperty"]], result)

        @builtins.property
        def grid_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the grid line is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-gridlinevisibility
            '''
            result = self._values.get("grid_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scrollbar_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ScrollBarOptionsProperty"]]:
            '''The scroll bar options for an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-scrollbaroptions
            '''
            result = self._values.get("scrollbar_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ScrollBarOptionsProperty"]], result)

        @builtins.property
        def tick_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisTickLabelOptionsProperty"]]:
            '''The tick label options of an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-ticklabeloptions
            '''
            result = self._values.get("tick_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisTickLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"data_driven": "dataDriven", "min_max": "minMax"},
    )
    class AxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            data_driven: typing.Any = None,
            min_max: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayMinMaxRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The range setup of a numeric axis display range.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_driven: The data-driven setup of an axis display range.
            :param min_max: The minimum and maximum setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_range_property = quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                    data_driven=data_driven,
                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                        maximum=123,
                        minimum=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e0eaf66dd8211856479578f80ff46b8aea84c54b3081431beb5ecf69e5abf89e)
                check_type(argname="argument data_driven", value=data_driven, expected_type=type_hints["data_driven"])
                check_type(argname="argument min_max", value=min_max, expected_type=type_hints["min_max"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_driven is not None:
                self._values["data_driven"] = data_driven
            if min_max is not None:
                self._values["min_max"] = min_max

        @builtins.property
        def data_driven(self) -> typing.Any:
            '''The data-driven setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html#cfn-quicksight-analysis-axisdisplayrange-datadriven
            '''
            result = self._values.get("data_driven")
            return typing.cast(typing.Any, result)

        @builtins.property
        def min_max(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayMinMaxRangeProperty"]]:
            '''The minimum and maximum setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html#cfn-quicksight-analysis-axisdisplayrange-minmax
            '''
            result = self._values.get("min_max")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayMinMaxRangeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "apply_to": "applyTo",
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
        },
    )
    class AxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            apply_to: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisLabelReferenceOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The label options for a chart axis.

            You must specify the field that the label is targeted to.

            :param apply_to: The options that indicate which field the label belongs to.
            :param custom_label: The text for the axis label.
            :param font_configuration: The font configuration of the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_label_options_property = quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId"
                    ),
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7a83364119dacd8f2542e77a3cc73fd0217f886aa51a7b2c50e2d27a89375ae3)
                check_type(argname="argument apply_to", value=apply_to, expected_type=type_hints["apply_to"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if apply_to is not None:
                self._values["apply_to"] = apply_to
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration

        @builtins.property
        def apply_to(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisLabelReferenceOptionsProperty"]]:
            '''The options that indicate which field the label belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-applyto
            '''
            result = self._values.get("apply_to")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisLabelReferenceOptionsProperty"]], result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The font configuration of the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "field_id": "fieldId"},
    )
    class AxisLabelReferenceOptionsProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
        ) -> None:
            '''The reference that specifies where the axis label is applied to.

            :param column: The column that the axis label is targeted to.
            :param field_id: The field that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_label_reference_options_property = quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b5a88fcdb887f9fa32143430469d3048389fb45b4cbc1aef1177c7ee95d2327d)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html#cfn-quicksight-analysis-axislabelreferenceoptions-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html#cfn-quicksight-analysis-axislabelreferenceoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelReferenceOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AxisLinearScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"step_count": "stepCount", "step_size": "stepSize"},
    )
    class AxisLinearScaleProperty:
        def __init__(
            self,
            *,
            step_count: typing.Optional[jsii.Number] = None,
            step_size: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The liner axis scale setup.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param step_count: The step count setup of a linear axis.
            :param step_size: The step size setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_linear_scale_property = quicksight.CfnAnalysis.AxisLinearScaleProperty(
                    step_count=123,
                    step_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8fb4f5326bdf4d3d8c8e65aab44d5435e88e5186e6a99c7258a31c35143ff0ac)
                check_type(argname="argument step_count", value=step_count, expected_type=type_hints["step_count"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if step_count is not None:
                self._values["step_count"] = step_count
            if step_size is not None:
                self._values["step_size"] = step_size

        @builtins.property
        def step_count(self) -> typing.Optional[jsii.Number]:
            '''The step count setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html#cfn-quicksight-analysis-axislinearscale-stepcount
            '''
            result = self._values.get("step_count")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def step_size(self) -> typing.Optional[jsii.Number]:
            '''The step size setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html#cfn-quicksight-analysis-axislinearscale-stepsize
            '''
            result = self._values.get("step_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLinearScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AxisLogarithmicScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"base": "base"},
    )
    class AxisLogarithmicScaleProperty:
        def __init__(self, *, base: typing.Optional[jsii.Number] = None) -> None:
            '''The logarithmic axis scale setup.

            :param base: The base setup of a logarithmic axis scale.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislogarithmicscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_logarithmic_scale_property = quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                    base=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__35d856e3f1482af7c8269c1fd39946da39bb80039c2613d658f68e8e446c2e4e)
                check_type(argname="argument base", value=base, expected_type=type_hints["base"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base is not None:
                self._values["base"] = base

        @builtins.property
        def base(self) -> typing.Optional[jsii.Number]:
            '''The base setup of a logarithmic axis scale.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislogarithmicscale.html#cfn-quicksight-analysis-axislogarithmicscale-base
            '''
            result = self._values.get("base")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLogarithmicScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AxisScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"linear": "linear", "logarithmic": "logarithmic"},
    )
    class AxisScaleProperty:
        def __init__(
            self,
            *,
            linear: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisLinearScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            logarithmic: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisLogarithmicScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The scale setup options for a numeric axis display.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param linear: The linear axis scale setup.
            :param logarithmic: The logarithmic axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_scale_property = quicksight.CfnAnalysis.AxisScaleProperty(
                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                        step_count=123,
                        step_size=123
                    ),
                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                        base=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e2fd7aefb784a330743fd375b51f50d2dd67c0db2148ee40dacc2a5a5fc445fc)
                check_type(argname="argument linear", value=linear, expected_type=type_hints["linear"])
                check_type(argname="argument logarithmic", value=logarithmic, expected_type=type_hints["logarithmic"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if linear is not None:
                self._values["linear"] = linear
            if logarithmic is not None:
                self._values["logarithmic"] = logarithmic

        @builtins.property
        def linear(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisLinearScaleProperty"]]:
            '''The linear axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html#cfn-quicksight-analysis-axisscale-linear
            '''
            result = self._values.get("linear")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisLinearScaleProperty"]], result)

        @builtins.property
        def logarithmic(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisLogarithmicScaleProperty"]]:
            '''The logarithmic axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html#cfn-quicksight-analysis-axisscale-logarithmic
            '''
            result = self._values.get("logarithmic")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisLogarithmicScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.AxisTickLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "label_options": "labelOptions",
            "rotation_angle": "rotationAngle",
        },
    )
    class AxisTickLabelOptionsProperty:
        def __init__(
            self,
            *,
            label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rotation_angle: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The tick label options of an axis.

            :param label_options: Determines whether or not the axis ticks are visible.
            :param rotation_angle: The rotation angle of the axis tick labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_tick_label_options_property = quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    rotation_angle=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4e637716aac5cf3edcd0b101378f84759379452db8697a26658bcaf69f5c8155)
                check_type(argname="argument label_options", value=label_options, expected_type=type_hints["label_options"])
                check_type(argname="argument rotation_angle", value=rotation_angle, expected_type=type_hints["rotation_angle"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_options is not None:
                self._values["label_options"] = label_options
            if rotation_angle is not None:
                self._values["rotation_angle"] = rotation_angle

        @builtins.property
        def label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]]:
            '''Determines whether or not the axis ticks are visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html#cfn-quicksight-analysis-axisticklabeloptions-labeloptions
            '''
            result = self._values.get("label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]], result)

        @builtins.property
        def rotation_angle(self) -> typing.Optional[jsii.Number]:
            '''The rotation angle of the axis tick labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html#cfn-quicksight-analysis-axisticklabeloptions-rotationangle
            '''
            result = self._values.get("rotation_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisTickLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class BarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a bar chart.

            :param category: The category (y-axis) field well of a bar chart.
            :param colors: The color (group/color) field well of a bar chart.
            :param small_multiples: The small multiples field well of a bar chart.
            :param values: The value field wells of a bar chart. Values are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bar_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4ea121fd8cc534afba373e75c8ac7e707d79e09b98955352826e4e708fcdf84e)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The category (y-axis) field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The color (group/color) field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a bar chart.

            Values are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "orientation": "orientation",
            "reference_lines": "referenceLines",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_axis": "valueAxis",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class BarChartConfigurationProperty:
        def __init__(
            self,
            *,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            orientation: typing.Optional[builtins.str] = None,
            reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``BarChartVisual`` .

            :param bars_arrangement: Determines the arrangement of the bars. The orientation and arrangement of bars determine the type of bar that is used in the visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) for bar chart category.
            :param category_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart.
            :param color_label_options: The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param orientation: The orientation of the bars in a bar chart visual. There are two valid values in this structure:. - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts. - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
            :param reference_lines: The reference line setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a ``BarChartVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param value_axis: The label display options (grid line, range, scale, axis step) for a bar chart value.
            :param value_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart value.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                bar_chart_configuration_property = quicksight.CfnAnalysis.BarChartConfigurationProperty(
                    bars_arrangement="barsArrangement",
                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                        bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    orientation="orientation",
                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4f2ef81188e298b4724cbc00d2c53af09f2038fb6399691be2c9845784b36837)
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_axis", value=value_axis, expected_type=type_hints["value_axis"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if orientation is not None:
                self._values["orientation"] = orientation
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_axis is not None:
                self._values["value_axis"] = value_axis
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the arrangement of the bars.

            The orientation and arrangement of bars determine the type of bar that is used in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) for bar chart category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ContributionAnalysisDefaultProperty"]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BarChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BarChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation of the bars in a bar chart visual. There are two valid values in this structure:.

            - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
            - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineProperty"]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BarChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``BarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BarChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) for a bar chart value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-valueaxis
            '''
            result = self._values.get("value_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_aggregated_field_wells": "barChartAggregatedFieldWells",
        },
    )
    class BarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``BarChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_aggregated_field_wells: The aggregated field wells of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bar_chart_field_wells_property = quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                    bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8f931e83286baf43cf4eb5a9bc2596e238a5990c855fb35a00b16635cf24a727)
                check_type(argname="argument bar_chart_aggregated_field_wells", value=bar_chart_aggregated_field_wells, expected_type=type_hints["bar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_aggregated_field_wells is not None:
                self._values["bar_chart_aggregated_field_wells"] = bar_chart_aggregated_field_wells

        @builtins.property
        def bar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BarChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartfieldwells.html#cfn-quicksight-analysis-barchartfieldwells-barchartaggregatedfieldwells
            '''
            result = self._values.get("bar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BarChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class BarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''sort-configuration-description.

            :param category_items_limit: The limit on the number of categories displayed in a bar chart.
            :param category_sort: The sort configuration of category fields.
            :param color_items_limit: The limit on the number of values displayed in a bar chart.
            :param color_sort: The sort configuration of color fields in a bar chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bar_chart_sort_configuration_property = quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0100036eea832de868e033add2cd77efbe8fd07b1a95f06655f02bdc3d586d37)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories displayed in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of values displayed in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of color fields in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A bar chart.

            The ``BarChartVisual`` structure describes a visual that is a member of the bar chart family. The following charts can be described using this structure:

            - Horizontal bar chart
            - Vertical bar chart
            - Horizontal stacked bar chart
            - Vertical stacked bar chart
            - Horizontal stacked 100% bar chart
            - Vertical stacked 100% bar chart

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                bar_chart_visual_property = quicksight.CfnAnalysis.BarChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.BarChartConfigurationProperty(
                        bars_arrangement="barsArrangement",
                        category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                            bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        orientation="orientation",
                        reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                            data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__20ceb98ab41c62303b26229aa11497d255f9a91b73a8b60a5f73c42ea68353ec)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BarChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BarChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BinCountOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class BinCountOptionsProperty:
        def __init__(self, *, value: typing.Optional[jsii.Number] = None) -> None:
            '''The options that determine the bin count of a histogram.

            :param value: The options that determine the bin count value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bincountoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bin_count_options_property = quicksight.CfnAnalysis.BinCountOptionsProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c00cb3acee002938487d6aff7bc0126338748e42fc81bdf769ac499aa444ac6f)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bincountoptions.html#cfn-quicksight-analysis-bincountoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinCountOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BinWidthOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bin_count_limit": "binCountLimit", "value": "value"},
    )
    class BinWidthOptionsProperty:
        def __init__(
            self,
            *,
            bin_count_limit: typing.Optional[jsii.Number] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the bin width of a histogram.

            :param bin_count_limit: The options that determine the bin count limit.
            :param value: The options that determine the bin width value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bin_width_options_property = quicksight.CfnAnalysis.BinWidthOptionsProperty(
                    bin_count_limit=123,
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__634fa92577e183d961a1b93636fcb4154d4800d48517ecfc0ea30a05a9219a2e)
                check_type(argname="argument bin_count_limit", value=bin_count_limit, expected_type=type_hints["bin_count_limit"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count_limit is not None:
                self._values["bin_count_limit"] = bin_count_limit
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def bin_count_limit(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count limit.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html#cfn-quicksight-analysis-binwidthoptions-bincountlimit
            '''
            result = self._values.get("bin_count_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin width value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html#cfn-quicksight-analysis-binwidthoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinWidthOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BodySectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content": "content",
            "section_id": "sectionId",
            "page_break_configuration": "pageBreakConfiguration",
            "style": "style",
        },
    )
    class BodySectionConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BodySectionContentProperty", typing.Dict[builtins.str, typing.Any]]],
            section_id: builtins.str,
            page_break_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SectionPageBreakConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a body section.

            :param content: The configuration of content in a body section.
            :param section_id: The unique identifier of a body section.
            :param page_break_configuration: The configuration of a page break for a section.
            :param style: The style options of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                body_section_configuration_property = quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                    content=quicksight.CfnAnalysis.BodySectionContentProperty(
                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                        after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                            status="status"
                        )
                    ),
                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnAnalysis.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__11328aad986b594e3415154bf163ad896cdff1ae5cb6a725f17646bcfa2a0894)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument page_break_configuration", value=page_break_configuration, expected_type=type_hints["page_break_configuration"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "section_id": section_id,
            }
            if page_break_configuration is not None:
                self._values["page_break_configuration"] = page_break_configuration
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def content(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BodySectionContentProperty"]:
            '''The configuration of content in a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BodySectionContentProperty"], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def page_break_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionPageBreakConfigurationProperty"]]:
            '''The configuration of a page break for a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-pagebreakconfiguration
            '''
            result = self._values.get("page_break_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionPageBreakConfigurationProperty"]], result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionStyleProperty"]]:
            '''The style options of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BodySectionContentProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout"},
    )
    class BodySectionContentProperty:
        def __init__(
            self,
            *,
            layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of content in a body section.

            :param layout: The layout configuration of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectioncontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                body_section_content_property = quicksight.CfnAnalysis.BodySectionContentProperty(
                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9af14e1f3fc497175eefb7db911deefca552668f2af8b4bce8e843eb3b686ebc)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if layout is not None:
                self._values["layout"] = layout

        @builtins.property
        def layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionLayoutConfigurationProperty"]]:
            '''The layout configuration of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectioncontent.html#cfn-quicksight-analysis-bodysectioncontent-layout
            '''
            result = self._values.get("layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class BoxPlotAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for a box plot.

            :param group_by: The group by field well of a box plot chart. Values are grouped based on group by fields.
            :param values: The value field well of a box plot chart. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_aggregated_field_wells_property = quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c8bfc95b29ceb7bcaed3039f20b9aefeb0330e5ff626df4e925f492548e195e6)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The group by field well of a box plot chart.

            Values are grouped based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html#cfn-quicksight-analysis-boxplotaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field well of a box plot chart.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html#cfn-quicksight-analysis-boxplotaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_options": "boxPlotOptions",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class BoxPlotChartConfigurationProperty:
        def __init__(
            self,
            *,
            box_plot_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BoxPlotOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BoxPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BoxPlotSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``BoxPlotVisual`` .

            :param box_plot_options: The box plot chart options for a box plot visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param category_label_options: The label options (label text, label visibility and sort Icon visibility) of a box plot category.
            :param field_wells: The field wells of the visual.
            :param legend: ``CfnAnalysis.BoxPlotChartConfigurationProperty.Legend``.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param primary_y_axis_label_options: The label options (label text, label visibility and sort icon visibility) of a box plot value.
            :param reference_lines: The reference line setup of the visual.
            :param sort_configuration: The sort configuration of a ``BoxPlotVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                box_plot_chart_configuration_property = quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                    box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                        all_data_points_visibility="allDataPointsVisibility",
                        outlier_visibility="outlierVisibility",
                        style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                            fill_style="fillStyle"
                        )
                    ),
                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                        box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                            page_number=123,
                            page_size=123
                        )
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ef069cdd6a273594b22206949eebc6d4df91900e511790168bab7a222a02f0fa)
                check_type(argname="argument box_plot_options", value=box_plot_options, expected_type=type_hints["box_plot_options"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_options is not None:
                self._values["box_plot_options"] = box_plot_options
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def box_plot_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotOptionsProperty"]]:
            '''The box plot chart options for a box plot visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-boxplotoptions
            '''
            result = self._values.get("box_plot_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotOptionsProperty"]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort Icon visibility) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]]:
            '''``CfnAnalysis.BoxPlotChartConfigurationProperty.Legend``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) of a box plot value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineProperty"]]]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotSortConfigurationProperty"]]:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BoxPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_aggregated_field_wells": "boxPlotAggregatedFieldWells",
        },
    )
    class BoxPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            box_plot_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BoxPlotAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``BoxPlotVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param box_plot_aggregated_field_wells: The aggregated field wells of a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_field_wells_property = quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                    box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c11cd5b5ece7457375b17c273d12c5f2bba3299b43f29002ad34e92160e77afa)
                check_type(argname="argument box_plot_aggregated_field_wells", value=box_plot_aggregated_field_wells, expected_type=type_hints["box_plot_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_aggregated_field_wells is not None:
                self._values["box_plot_aggregated_field_wells"] = box_plot_aggregated_field_wells

        @builtins.property
        def box_plot_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotfieldwells.html#cfn-quicksight-analysis-boxplotfieldwells-boxplotaggregatedfieldwells
            '''
            result = self._values.get("box_plot_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BoxPlotOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "all_data_points_visibility": "allDataPointsVisibility",
            "outlier_visibility": "outlierVisibility",
            "style_options": "styleOptions",
        },
    )
    class BoxPlotOptionsProperty:
        def __init__(
            self,
            *,
            all_data_points_visibility: typing.Optional[builtins.str] = None,
            outlier_visibility: typing.Optional[builtins.str] = None,
            style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BoxPlotStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options of a box plot visual.

            :param all_data_points_visibility: Determines the visibility of all data points of the box plot.
            :param outlier_visibility: Determines the visibility of the outlier in a box plot.
            :param style_options: The style options of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_options_property = quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                    all_data_points_visibility="allDataPointsVisibility",
                    outlier_visibility="outlierVisibility",
                    style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                        fill_style="fillStyle"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dae6b024acf60c845f50cf9dddd02dee617160e3b2417127098b02acba3faf50)
                check_type(argname="argument all_data_points_visibility", value=all_data_points_visibility, expected_type=type_hints["all_data_points_visibility"])
                check_type(argname="argument outlier_visibility", value=outlier_visibility, expected_type=type_hints["outlier_visibility"])
                check_type(argname="argument style_options", value=style_options, expected_type=type_hints["style_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if all_data_points_visibility is not None:
                self._values["all_data_points_visibility"] = all_data_points_visibility
            if outlier_visibility is not None:
                self._values["outlier_visibility"] = outlier_visibility
            if style_options is not None:
                self._values["style_options"] = style_options

        @builtins.property
        def all_data_points_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of all data points of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-alldatapointsvisibility
            '''
            result = self._values.get("all_data_points_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def outlier_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the outlier in a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-outliervisibility
            '''
            result = self._values.get("outlier_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotStyleOptionsProperty"]]:
            '''The style options of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-styleoptions
            '''
            result = self._values.get("style_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotStyleOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_sort": "categorySort",
            "pagination_configuration": "paginationConfiguration",
        },
    )
    class BoxPlotSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            pagination_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :param category_sort: The sort configuration of a group by fields.
            :param pagination_configuration: The pagination configuration of a table visual or box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_sort_configuration_property = quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7ad430defba4c2af9e7a83d85f49e7b2e330dc8a9a7e50d50fec6139ab6c5ed2)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of a group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html#cfn-quicksight-analysis-boxplotsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PaginationConfigurationProperty"]]:
            '''The pagination configuration of a table visual or box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html#cfn-quicksight-analysis-boxplotsortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PaginationConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"fill_style": "fillStyle"},
    )
    class BoxPlotStyleOptionsProperty:
        def __init__(self, *, fill_style: typing.Optional[builtins.str] = None) -> None:
            '''The style options of the box plot.

            :param fill_style: The fill styles (solid, transparent) of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_style_options_property = quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                    fill_style="fillStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2905f8c4747225aeecd1c5407d446447db471241ef57def1daad9c636d3cc129)
                check_type(argname="argument fill_style", value=fill_style, expected_type=type_hints["fill_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if fill_style is not None:
                self._values["fill_style"] = fill_style

        @builtins.property
        def fill_style(self) -> typing.Optional[builtins.str]:
            '''The fill styles (solid, transparent) of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotstyleoptions.html#cfn-quicksight-analysis-boxplotstyleoptions-fillstyle
            '''
            result = self._values.get("fill_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.BoxPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BoxPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BoxPlotChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                box_plot_visual_property = quicksight.CfnAnalysis.BoxPlotVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                        box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                            all_data_points_visibility="allDataPointsVisibility",
                            outlier_visibility="outlierVisibility",
                            style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                                fill_style="fillStyle"
                            )
                        ),
                        category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                            box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                            data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                page_number=123,
                                page_size=123
                            )
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3158acfd922aba17cbe00864c000adc18c3dbb57008a7a6086651a224e66afeb)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CalculatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "expression": "expression",
            "name": "name",
        },
    )
    class CalculatedFieldProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            expression: builtins.str,
            name: builtins.str,
        ) -> None:
            '''The calculated field of an analysis.

            :param data_set_identifier: The data set that is used in this calculated field.
            :param expression: The expression of the calculated field.
            :param name: The name of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                calculated_field_property = quicksight.CfnAnalysis.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__28f4c6754779f6f09af0c019c83305f5b4c905ebe5d42e7305b64769ef19ff1d)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "expression": expression,
                "name": name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in this calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CalculatedMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "field_id": "fieldId"},
    )
    class CalculatedMeasureFieldProperty:
        def __init__(self, *, expression: builtins.str, field_id: builtins.str) -> None:
            '''The table calculation measure field for pivot tables.

            :param expression: The expression in the table calculation.
            :param field_id: The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                calculated_measure_field_property = quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                    expression="expression",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1bef9289e943e57c69d50518c0260c2e24d2d479f02e93a38104bd9d06532142)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "field_id": field_id,
            }

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression in the table calculation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html#cfn-quicksight-analysis-calculatedmeasurefield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html#cfn-quicksight-analysis-calculatedmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CascadingControlConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"source_controls": "sourceControls"},
    )
    class CascadingControlConfigurationProperty:
        def __init__(
            self,
            *,
            source_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CascadingControlSourceProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :param source_controls: A list of source controls that determine the values that are used in the current control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                cascading_control_configuration_property = quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        source_sheet_control_id="sourceSheetControlId"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d13692ded38fc61c29abf79f5d3af18037b1b587645740a1018c77aa6eee2ca2)
                check_type(argname="argument source_controls", value=source_controls, expected_type=type_hints["source_controls"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_controls is not None:
                self._values["source_controls"] = source_controls

        @builtins.property
        def source_controls(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CascadingControlSourceProperty"]]]]:
            '''A list of source controls that determine the values that are used in the current control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolconfiguration.html#cfn-quicksight-analysis-cascadingcontrolconfiguration-sourcecontrols
            '''
            result = self._values.get("source_controls")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CascadingControlSourceProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CascadingControlSourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_to_match": "columnToMatch",
            "source_sheet_control_id": "sourceSheetControlId",
        },
    )
    class CascadingControlSourceProperty:
        def __init__(
            self,
            *,
            column_to_match: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_sheet_control_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The source controls that are used in a ``CascadingControlConfiguration`` .

            :param column_to_match: The column identifier that determines which column to look up for the source sheet control.
            :param source_sheet_control_id: The source sheet control ID of a ``CascadingControlSource`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                cascading_control_source_property = quicksight.CfnAnalysis.CascadingControlSourceProperty(
                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    source_sheet_control_id="sourceSheetControlId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b493ef763227987098e3b917d774c1863a4bf6827234c34b0470ceb81235b206)
                check_type(argname="argument column_to_match", value=column_to_match, expected_type=type_hints["column_to_match"])
                check_type(argname="argument source_sheet_control_id", value=source_sheet_control_id, expected_type=type_hints["source_sheet_control_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_to_match is not None:
                self._values["column_to_match"] = column_to_match
            if source_sheet_control_id is not None:
                self._values["source_sheet_control_id"] = source_sheet_control_id

        @builtins.property
        def column_to_match(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]]:
            '''The column identifier that determines which column to look up for the source sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html#cfn-quicksight-analysis-cascadingcontrolsource-columntomatch
            '''
            result = self._values.get("column_to_match")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]], result)

        @builtins.property
        def source_sheet_control_id(self) -> typing.Optional[builtins.str]:
            '''The source sheet control ID of a ``CascadingControlSource`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html#cfn-quicksight-analysis-cascadingcontrolsource-sourcesheetcontrolid
            '''
            result = self._values.get("source_sheet_control_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlSourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CategoricalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class CategoricalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with categorical type columns..

            :param column: The column that is used in the ``CategoricalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                categorical_dimension_field_property = quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1fb41de23ca98ff54a98d2268a7d885d77cee132508b36061965cf9049b46b58)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``CategoricalDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CategoricalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class CategoricalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with categorical type columns.

            :param column: The column that is used in the ``CategoricalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                categorical_measure_field_property = quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__40fe259f9bac113e0eda4d2bdfa4ba2d54bb645331499381a1b3f7cb9bcc1f47)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``CategoricalMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CategoryDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"category_values": "categoryValues", "column": "column"},
    )
    class CategoryDrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_values: typing.Sequence[builtins.str],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The numeric equality type drill down filter.

            :param category_values: A list of the string inputs that are the values of the category drill down filter.
            :param column: The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                category_drill_down_filter_property = quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                    category_values=["categoryValues"],
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1f689302b3aeb1291bc7f6b373ed8d203940f0f8984ed9dd012883745b3bfce7)
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category_values": category_values,
                "column": column,
            }

        @builtins.property
        def category_values(self) -> typing.List[builtins.str]:
            '''A list of the string inputs that are the values of the category drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html#cfn-quicksight-analysis-categorydrilldownfilter-categoryvalues
            '''
            result = self._values.get("category_values")
            assert result is not None, "Required property 'category_values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html#cfn-quicksight-analysis-categorydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CategoryFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_filter_configuration": "customFilterConfiguration",
            "custom_filter_list_configuration": "customFilterListConfiguration",
            "filter_list_configuration": "filterListConfiguration",
        },
    )
    class CategoryFilterConfigurationProperty:
        def __init__(
            self,
            *,
            custom_filter_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CustomFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_filter_list_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CustomFilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filter_list_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``CategoryFilter`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_filter_configuration: A custom filter that filters based on a single value. This filter can be partially matched.
            :param custom_filter_list_configuration: A list of custom filter values. In the Amazon QuickSight console, this filter type is called a custom filter list.
            :param filter_list_configuration: A list of filter configurations. In the Amazon QuickSight console, this filter type is called a filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                category_filter_configuration_property = quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                    custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_value="categoryValue",
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions"
                    ),
                    custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    ),
                    filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                        match_operator="matchOperator",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2cade7920ca3e9834580a0d02641f931b4cbf3c527c3ab0b5f008fc6172db61a)
                check_type(argname="argument custom_filter_configuration", value=custom_filter_configuration, expected_type=type_hints["custom_filter_configuration"])
                check_type(argname="argument custom_filter_list_configuration", value=custom_filter_list_configuration, expected_type=type_hints["custom_filter_list_configuration"])
                check_type(argname="argument filter_list_configuration", value=filter_list_configuration, expected_type=type_hints["filter_list_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_filter_configuration is not None:
                self._values["custom_filter_configuration"] = custom_filter_configuration
            if custom_filter_list_configuration is not None:
                self._values["custom_filter_list_configuration"] = custom_filter_list_configuration
            if filter_list_configuration is not None:
                self._values["filter_list_configuration"] = filter_list_configuration

        @builtins.property
        def custom_filter_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomFilterConfigurationProperty"]]:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-customfilterconfiguration
            '''
            result = self._values.get("custom_filter_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomFilterConfigurationProperty"]], result)

        @builtins.property
        def custom_filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomFilterListConfigurationProperty"]]:
            '''A list of custom filter values.

            In the Amazon QuickSight console, this filter type is called a custom filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-customfilterlistconfiguration
            '''
            result = self._values.get("custom_filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomFilterListConfigurationProperty"]], result)

        @builtins.property
        def filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterListConfigurationProperty"]]:
            '''A list of filter configurations.

            In the Amazon QuickSight console, this filter type is called a filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-filterlistconfiguration
            '''
            result = self._values.get("filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterListConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CategoryFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "configuration": "configuration",
            "filter_id": "filterId",
        },
    )
    class CategoryFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CategoryFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
        ) -> None:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :param column: The column that the filter is applied to.
            :param configuration: The configuration for a ``CategoryFilter`` .
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                category_filter_property = quicksight.CfnAnalysis.CategoryFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                        custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_value="categoryValue",
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions"
                        ),
                        custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        ),
                        filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                            match_operator="matchOperator",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        )
                    ),
                    filter_id="filterId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__90b611566d7fce79c31cda545f3500cfb1322c0dc73a8dd1c5755b4be244b215)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "configuration": configuration,
                "filter_id": filter_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CategoryFilterConfigurationProperty"]:
            '''The configuration for a ``CategoryFilter`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CategoryFilterConfigurationProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_label_options": "axisLabelOptions",
            "sort_icon_visibility": "sortIconVisibility",
            "visibility": "visibility",
        },
    )
    class ChartAxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sort_icon_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options for an axis on a chart.

            :param axis_label_options: The label options for a chart axis.
            :param sort_icon_visibility: The visibility configuration of the sort icon on a chart's axis label.
            :param visibility: The visibility of an axis label on a chart. Choose one of the following options:. - ``VISIBLE`` : Shows the axis. - ``HIDDEN`` : Hides the axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                chart_axis_label_options_property = quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId"
                        ),
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        )
                    )],
                    sort_icon_visibility="sortIconVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b0d0df224c04d87ef597866230cfb71f15e736200769b42d6672358705af1c0d)
                check_type(argname="argument axis_label_options", value=axis_label_options, expected_type=type_hints["axis_label_options"])
                check_type(argname="argument sort_icon_visibility", value=sort_icon_visibility, expected_type=type_hints["sort_icon_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_label_options is not None:
                self._values["axis_label_options"] = axis_label_options
            if sort_icon_visibility is not None:
                self._values["sort_icon_visibility"] = sort_icon_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisLabelOptionsProperty"]]]]:
            '''The label options for a chart axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-axislabeloptions
            '''
            result = self._values.get("axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisLabelOptionsProperty"]]]], result)

        @builtins.property
        def sort_icon_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the sort icon on a chart's axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-sorticonvisibility
            '''
            result = self._values.get("sort_icon_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an axis label on a chart. Choose one of the following options:.

            - ``VISIBLE`` : Shows the axis.
            - ``HIDDEN`` : Hides the axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ChartAxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"cluster_marker": "clusterMarker"},
    )
    class ClusterMarkerConfigurationProperty:
        def __init__(
            self,
            *,
            cluster_marker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cluster marker configuration of the geospatial map selected point style.

            :param cluster_marker: The cluster marker that is a part of the cluster marker configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarkerconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                cluster_marker_configuration_property = quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                    cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                        simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__31698b7a88dad357d9121f1aeb16901e12ce237bc5a9a4fcabde2040ad1be1ab)
                check_type(argname="argument cluster_marker", value=cluster_marker, expected_type=type_hints["cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker is not None:
                self._values["cluster_marker"] = cluster_marker

        @builtins.property
        def cluster_marker(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ClusterMarkerProperty"]]:
            '''The cluster marker that is a part of the cluster marker configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarkerconfiguration.html#cfn-quicksight-analysis-clustermarkerconfiguration-clustermarker
            '''
            result = self._values.get("cluster_marker")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ClusterMarkerProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"simple_cluster_marker": "simpleClusterMarker"},
    )
    class ClusterMarkerProperty:
        def __init__(
            self,
            *,
            simple_cluster_marker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SimpleClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cluster marker that is a part of the cluster marker configuration.

            :param simple_cluster_marker: The simple cluster marker of the cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                cluster_marker_property = quicksight.CfnAnalysis.ClusterMarkerProperty(
                    simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e687d2a694b716e5fb6aa67e1ddb677d335b80a4984558c83cce12aa2807d3a9)
                check_type(argname="argument simple_cluster_marker", value=simple_cluster_marker, expected_type=type_hints["simple_cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_cluster_marker is not None:
                self._values["simple_cluster_marker"] = simple_cluster_marker

        @builtins.property
        def simple_cluster_marker(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SimpleClusterMarkerProperty"]]:
            '''The simple cluster marker of the cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarker.html#cfn-quicksight-analysis-clustermarker-simpleclustermarker
            '''
            result = self._values.get("simple_cluster_marker")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SimpleClusterMarkerProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ColorScaleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_fill_type": "colorFillType",
            "colors": "colors",
            "null_value_color": "nullValueColor",
        },
    )
    class ColorScaleProperty:
        def __init__(
            self,
            *,
            color_fill_type: builtins.str,
            colors: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataColorProperty", typing.Dict[builtins.str, typing.Any]]]]],
            null_value_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the color scale that is applied to the visual.

            :param color_fill_type: Determines the color fill type.
            :param colors: Determines the list of colors that are applied to the visual.
            :param null_value_color: Determines the color that is applied to null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                color_scale_property = quicksight.CfnAnalysis.ColorScaleProperty(
                    color_fill_type="colorFillType",
                    colors=[quicksight.CfnAnalysis.DataColorProperty(
                        color="color",
                        data_value=123
                    )],
                
                    # the properties below are optional
                    null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                        color="color",
                        data_value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f1522b51450a61f13c04a38a92939942e2bd38ff4222df53bc0a64936857adbf)
                check_type(argname="argument color_fill_type", value=color_fill_type, expected_type=type_hints["color_fill_type"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument null_value_color", value=null_value_color, expected_type=type_hints["null_value_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color_fill_type": color_fill_type,
                "colors": colors,
            }
            if null_value_color is not None:
                self._values["null_value_color"] = null_value_color

        @builtins.property
        def color_fill_type(self) -> builtins.str:
            '''Determines the color fill type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-colorfilltype
            '''
            result = self._values.get("color_fill_type")
            assert result is not None, "Required property 'color_fill_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataColorProperty"]]]:
            '''Determines the list of colors that are applied to the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-colors
            '''
            result = self._values.get("colors")
            assert result is not None, "Required property 'colors' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataColorProperty"]]], result)

        @builtins.property
        def null_value_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataColorProperty"]]:
            '''Determines the color that is applied to null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-nullvaluecolor
            '''
            result = self._values.get("null_value_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ColorsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_colors": "customColors"},
    )
    class ColorsConfigurationProperty:
        def __init__(
            self,
            *,
            custom_colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CustomColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''
            :param custom_colors: ``CfnAnalysis.ColorsConfigurationProperty.CustomColors``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                colors_configuration_property = quicksight.CfnAnalysis.ColorsConfigurationProperty(
                    custom_colors=[quicksight.CfnAnalysis.CustomColorProperty(
                        color="color",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        special_value="specialValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8651146206e67afab6d8a5e3178254f71ad1612280457128b2a543d4ce078ce6)
                check_type(argname="argument custom_colors", value=custom_colors, expected_type=type_hints["custom_colors"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_colors is not None:
                self._values["custom_colors"] = custom_colors

        @builtins.property
        def custom_colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomColorProperty"]]]]:
            '''``CfnAnalysis.ColorsConfigurationProperty.CustomColors``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorsconfiguration.html#cfn-quicksight-analysis-colorsconfiguration-customcolors
            '''
            result = self._values.get("custom_colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ColumnConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "colors_configuration": "colorsConfiguration",
            "format_configuration": "formatConfiguration",
            "role": "role",
        },
    )
    class ColumnConfigurationProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            colors_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColorsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            role: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The general configuration of a column.

            :param column: The column.
            :param colors_configuration: ``CfnAnalysis.ColumnConfigurationProperty.ColorsConfiguration``.
            :param format_configuration: The format configuration of a column.
            :param role: The role of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_configuration_property = quicksight.CfnAnalysis.ColumnConfigurationProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    colors_configuration=quicksight.CfnAnalysis.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnAnalysis.CustomColorProperty(
                            color="color",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b310530156df84e63740b04235cfff0f92b4789a413c28815b6074bf319f0eb)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument colors_configuration", value=colors_configuration, expected_type=type_hints["colors_configuration"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if colors_configuration is not None:
                self._values["colors_configuration"] = colors_configuration
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def colors_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColorsConfigurationProperty"]]:
            '''``CfnAnalysis.ColumnConfigurationProperty.ColorsConfiguration``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-colorsconfiguration
            '''
            result = self._values.get("colors_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColorsConfigurationProperty"]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FormatConfigurationProperty"]]:
            '''The format configuration of a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FormatConfigurationProperty"]], result)

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ColumnHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_hierarchy": "dateTimeHierarchy",
            "explicit_hierarchy": "explicitHierarchy",
            "predefined_hierarchy": "predefinedHierarchy",
        },
    )
    class ColumnHierarchyProperty:
        def __init__(
            self,
            *,
            date_time_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DateTimeHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            explicit_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ExplicitHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            predefined_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PredefinedHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields for a visual element.

            :param date_time_hierarchy: The option that determines the hierarchy of any ``DateTime`` fields.
            :param explicit_hierarchy: The option that determines the hierarchy of the fields that are built within a visual's field wells. These fields can't be duplicated to other visuals.
            :param predefined_hierarchy: The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_hierarchy_property = quicksight.CfnAnalysis.ColumnHierarchyProperty(
                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e3e11f3916474b266f6149cd61e2cdc0504a3fe90748e962b72c72eb09974d64)
                check_type(argname="argument date_time_hierarchy", value=date_time_hierarchy, expected_type=type_hints["date_time_hierarchy"])
                check_type(argname="argument explicit_hierarchy", value=explicit_hierarchy, expected_type=type_hints["explicit_hierarchy"])
                check_type(argname="argument predefined_hierarchy", value=predefined_hierarchy, expected_type=type_hints["predefined_hierarchy"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_hierarchy is not None:
                self._values["date_time_hierarchy"] = date_time_hierarchy
            if explicit_hierarchy is not None:
                self._values["explicit_hierarchy"] = explicit_hierarchy
            if predefined_hierarchy is not None:
                self._values["predefined_hierarchy"] = predefined_hierarchy

        @builtins.property
        def date_time_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeHierarchyProperty"]]:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-datetimehierarchy
            '''
            result = self._values.get("date_time_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeHierarchyProperty"]], result)

        @builtins.property
        def explicit_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ExplicitHierarchyProperty"]]:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-explicithierarchy
            '''
            result = self._values.get("explicit_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ExplicitHierarchyProperty"]], result)

        @builtins.property
        def predefined_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PredefinedHierarchyProperty"]]:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-predefinedhierarchy
            '''
            result = self._values.get("predefined_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PredefinedHierarchyProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ColumnIdentifierProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class ColumnIdentifierProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            data_set_identifier: builtins.str,
        ) -> None:
            '''A column of a data set.

            :param column_name: The name of the column.
            :param data_set_identifier: The data set that the column belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_identifier_property = quicksight.CfnAnalysis.ColumnIdentifierProperty(
                    column_name="columnName",
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__38f28f01525e947b3cdbee21b6f92245f728be65e3f5e851394c28496e60e3e6)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "data_set_identifier": data_set_identifier,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The name of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html#cfn-quicksight-analysis-columnidentifier-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that the column belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html#cfn-quicksight-analysis-columnidentifier-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnIdentifierProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ColumnSortProperty",
        jsii_struct_bases=[],
        name_mapping={
            "direction": "direction",
            "sort_by": "sortBy",
            "aggregation_function": "aggregationFunction",
        },
    )
    class ColumnSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_by: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort configuration for a column that is not used in a field well.

            :param direction: The sort direction.
            :param sort_by: ``CfnAnalysis.ColumnSortProperty.SortBy``.
            :param aggregation_function: The aggregation function that is defined in the column sort.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_sort_property = quicksight.CfnAnalysis.ColumnSortProperty(
                    direction="direction",
                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2938531646915e6078f4a8f67dde8c87089acbfbe4f33823ca1d4ba571424845)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_by": sort_by,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''``CfnAnalysis.ColumnSortProperty.SortBy``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationFunctionProperty"]]:
            '''The aggregation function that is defined in the column sort.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ColumnTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "aggregation": "aggregation",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class ColumnTooltipItemProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the columns that are not part of a field well.

            :param column: The target column of the tooltip item.
            :param aggregation: The aggregation function of the column tooltip item.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_tooltip_item_property = quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e27334dc20879b6e02b5013b981a18b12fa7088050ba09f40030f21cc1b0653)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The target column of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def aggregation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationFunctionProperty"]]:
            '''The aggregation function of the column tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationFunctionProperty"]], result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_values": "barValues",
            "category": "category",
            "colors": "colors",
            "line_values": "lineValues",
        },
    )
    class ComboChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            line_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a combo chart.

            :param bar_values: The aggregated ``BarValues`` field well of a combo chart.
            :param category: The aggregated category field wells of a combo chart.
            :param colors: The aggregated colors field well of a combo chart.
            :param line_values: The aggregated ``LineValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                combo_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                    bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4da7dae4c6bc56b7b127626b59e892e7351be6b1f2569ab0ec727679f947940c)
                check_type(argname="argument bar_values", value=bar_values, expected_type=type_hints["bar_values"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument line_values", value=line_values, expected_type=type_hints["line_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_values is not None:
                self._values["bar_values"] = bar_values
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if line_values is not None:
                self._values["line_values"] = line_values

        @builtins.property
        def bar_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The aggregated ``BarValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-barvalues
            '''
            result = self._values.get("bar_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The aggregated category field wells of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The aggregated colors field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def line_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The aggregated ``LineValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-linevalues
            '''
            result = self._values.get("line_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ComboChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_data_labels": "barDataLabels",
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "line_data_labels": "lineDataLabels",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class ComboChartConfigurationProperty:
        def __init__(
            self,
            *,
            bar_data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ComboChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            line_data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ComboChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``ComboChartVisual`` .

            :param bar_data_labels: The options that determine if visual data labels are displayed. The data label options for a bar in a combo chart.
            :param bars_arrangement: Determines the bar arrangement in a combo chart. The following are valid values in this structure:. - ``CLUSTERED`` : For clustered bar combo charts. - ``STACKED`` : For stacked bar combo charts. - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.
            :param category_axis: The category axis of a combo chart.
            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
            :param color_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param line_data_labels: The options that determine if visual data labels are displayed. The data label options for a line in a combo chart.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
            :param primary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
            :param reference_lines: The reference line setup of the visual.
            :param secondary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
            :param secondary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
            :param sort_configuration: The sort configuration of a ``ComboChartVisual`` .
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                combo_chart_configuration_property = quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                    bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    bars_arrangement="barsArrangement",
                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                        combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                            bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9bd443b9224046f8a05cfdd54143cf7e1d397fb702f55cb331c8a4451580be9f)
                check_type(argname="argument bar_data_labels", value=bar_data_labels, expected_type=type_hints["bar_data_labels"])
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument line_data_labels", value=line_data_labels, expected_type=type_hints["line_data_labels"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_data_labels is not None:
                self._values["bar_data_labels"] = bar_data_labels
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if line_data_labels is not None:
                self._values["line_data_labels"] = line_data_labels
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bar_data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a bar in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-bardatalabels
            '''
            result = self._values.get("bar_data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the bar arrangement in a combo chart. The following are valid values in this structure:.

            - ``CLUSTERED`` : For clustered bar combo charts.
            - ``STACKED`` : For stacked bar combo charts.
            - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The category axis of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComboChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComboChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def line_data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a line in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-linedatalabels
            '''
            result = self._values.get("line_data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineProperty"]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComboChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``ComboChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComboChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ComboChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "combo_chart_aggregated_field_wells": "comboChartAggregatedFieldWells",
        },
    )
    class ComboChartFieldWellsProperty:
        def __init__(
            self,
            *,
            combo_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ComboChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of the visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param combo_chart_aggregated_field_wells: The aggregated field wells of a combo chart. Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                combo_chart_field_wells_property = quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                    combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                        bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__211ca5c38b33660b71c4e86baab41b970eaca71627037345e47ddb0f9188eb46)
                check_type(argname="argument combo_chart_aggregated_field_wells", value=combo_chart_aggregated_field_wells, expected_type=type_hints["combo_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if combo_chart_aggregated_field_wells is not None:
                self._values["combo_chart_aggregated_field_wells"] = combo_chart_aggregated_field_wells

        @builtins.property
        def combo_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComboChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a combo chart.

            Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartfieldwells.html#cfn-quicksight-analysis-combochartfieldwells-combochartaggregatedfieldwells
            '''
            result = self._values.get("combo_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComboChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ComboChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class ComboChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``ComboChartVisual`` .

            :param category_items_limit: The item limit configuration for the category field well of a combo chart.
            :param category_sort: The sort configuration of the category field well in a combo chart.
            :param color_items_limit: The item limit configuration of the color field well in a combo chart.
            :param color_sort: The sort configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                combo_chart_sort_configuration_property = quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__20df5eedc96b8f0b4f86da61b0ef109e9af7f30ca2c9df4ab3a3f632deb8cc34)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The item limit configuration for the category field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The item limit configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ComboChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ComboChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ComboChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A combo chart.

            The ``ComboChartVisual`` includes stacked bar combo charts and clustered bar combo charts

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                combo_chart_visual_property = quicksight.CfnAnalysis.ComboChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                        bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        bars_arrangement="barsArrangement",
                        category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                            combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                                bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                            data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__febab50d375f26f94cc5f444bd2ab80b2061c2bed58aa7ea63fc1c02c10646a6)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComboChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComboChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ComparisonConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison_format": "comparisonFormat",
            "comparison_method": "comparisonMethod",
        },
    )
    class ComparisonConfigurationProperty:
        def __init__(
            self,
            *,
            comparison_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ComparisonFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison_method: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The comparison display configuration of a KPI or gauge chart.

            :param comparison_format: The format of the comparison.
            :param comparison_method: The method of the comparison. Choose from the following options:. - ``DIFFERENCE`` - ``PERCENT_DIFFERENCE`` - ``PERCENT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                comparison_configuration_property = quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                    comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    comparison_method="comparisonMethod"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__013300f268c29642e995379f482650e5637358a939f1a1234848f1f563245219)
                check_type(argname="argument comparison_format", value=comparison_format, expected_type=type_hints["comparison_format"])
                check_type(argname="argument comparison_method", value=comparison_method, expected_type=type_hints["comparison_method"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison_format is not None:
                self._values["comparison_format"] = comparison_format
            if comparison_method is not None:
                self._values["comparison_method"] = comparison_method

        @builtins.property
        def comparison_format(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComparisonFormatConfigurationProperty"]]:
            '''The format of the comparison.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html#cfn-quicksight-analysis-comparisonconfiguration-comparisonformat
            '''
            result = self._values.get("comparison_format")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComparisonFormatConfigurationProperty"]], result)

        @builtins.property
        def comparison_method(self) -> typing.Optional[builtins.str]:
            '''The method of the comparison. Choose from the following options:.

            - ``DIFFERENCE``
            - ``PERCENT_DIFFERENCE``
            - ``PERCENT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html#cfn-quicksight-analysis-comparisonconfiguration-comparisonmethod
            '''
            result = self._values.get("comparison_method")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class ComparisonFormatConfigurationProperty:
        def __init__(
            self,
            *,
            number_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The format of the comparison.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param number_display_format_configuration: The number display format.
            :param percentage_display_format_configuration: The percentage display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                comparison_format_configuration_property = quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c1815fcba9aab19158e9eb01045776128715504e23060c05a3b710ff26e05cb)
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumberDisplayFormatConfigurationProperty"]]:
            '''The number display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html#cfn-quicksight-analysis-comparisonformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumberDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PercentageDisplayFormatConfigurationProperty"]]:
            '''The percentage display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html#cfn-quicksight-analysis-comparisonformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PercentageDisplayFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast": "forecast",
            "growth_rate": "growthRate",
            "maximum_minimum": "maximumMinimum",
            "metric_comparison": "metricComparison",
            "period_over_period": "periodOverPeriod",
            "period_to_date": "periodToDate",
            "top_bottom_movers": "topBottomMovers",
            "top_bottom_ranked": "topBottomRanked",
            "total_aggregation": "totalAggregation",
            "unique_values": "uniqueValues",
        },
    )
    class ComputationProperty:
        def __init__(
            self,
            *,
            forecast: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ForecastComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            growth_rate: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GrowthRateComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maximum_minimum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MaximumMinimumComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            metric_comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MetricComparisonComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            period_over_period: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PeriodOverPeriodComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            period_to_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PeriodToDateComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_movers: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TopBottomMoversComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_ranked: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TopBottomRankedComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TotalAggregationComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            unique_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.UniqueValuesComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The computation union that is used in an insight visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param forecast: The forecast computation configuration.
            :param growth_rate: The growth rate computation configuration.
            :param maximum_minimum: The maximum and minimum computation configuration.
            :param metric_comparison: The metric comparison computation configuration.
            :param period_over_period: The period over period computation configuration.
            :param period_to_date: The period to ``DataSetIdentifier`` computation configuration.
            :param top_bottom_movers: The top movers and bottom movers computation configuration.
            :param top_bottom_ranked: The top ranked and bottom ranked computation configuration.
            :param total_aggregation: The total aggregation computation configuration.
            :param unique_values: The unique values computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                computation_property = quicksight.CfnAnalysis.ComputationProperty(
                    forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        custom_seasonality_value=123,
                        lower_boundary=123,
                        name="name",
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality="seasonality",
                        upper_boundary=123,
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        period_size=123,
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        type="type",
                
                        # the properties below are optional
                        name="name",
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                        computation_id="computationId",
                        from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                        target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name"
                    ),
                    period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        period_time_granularity="periodTimeGranularity",
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        type="type",
                
                        # the properties below are optional
                        mover_size=123,
                        name="name",
                        sort_order="sortOrder",
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                        type="type",
                
                        # the properties below are optional
                        name="name",
                        result_size=123,
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                        computation_id="computationId",
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                
                        # the properties below are optional
                        name="name"
                    ),
                    unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                
                        # the properties below are optional
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a611a66166c5b194070e1a4d7e0b7728d5b5e2cdc85cf014322c9d3b7b41d5d3)
                check_type(argname="argument forecast", value=forecast, expected_type=type_hints["forecast"])
                check_type(argname="argument growth_rate", value=growth_rate, expected_type=type_hints["growth_rate"])
                check_type(argname="argument maximum_minimum", value=maximum_minimum, expected_type=type_hints["maximum_minimum"])
                check_type(argname="argument metric_comparison", value=metric_comparison, expected_type=type_hints["metric_comparison"])
                check_type(argname="argument period_over_period", value=period_over_period, expected_type=type_hints["period_over_period"])
                check_type(argname="argument period_to_date", value=period_to_date, expected_type=type_hints["period_to_date"])
                check_type(argname="argument top_bottom_movers", value=top_bottom_movers, expected_type=type_hints["top_bottom_movers"])
                check_type(argname="argument top_bottom_ranked", value=top_bottom_ranked, expected_type=type_hints["top_bottom_ranked"])
                check_type(argname="argument total_aggregation", value=total_aggregation, expected_type=type_hints["total_aggregation"])
                check_type(argname="argument unique_values", value=unique_values, expected_type=type_hints["unique_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast is not None:
                self._values["forecast"] = forecast
            if growth_rate is not None:
                self._values["growth_rate"] = growth_rate
            if maximum_minimum is not None:
                self._values["maximum_minimum"] = maximum_minimum
            if metric_comparison is not None:
                self._values["metric_comparison"] = metric_comparison
            if period_over_period is not None:
                self._values["period_over_period"] = period_over_period
            if period_to_date is not None:
                self._values["period_to_date"] = period_to_date
            if top_bottom_movers is not None:
                self._values["top_bottom_movers"] = top_bottom_movers
            if top_bottom_ranked is not None:
                self._values["top_bottom_ranked"] = top_bottom_ranked
            if total_aggregation is not None:
                self._values["total_aggregation"] = total_aggregation
            if unique_values is not None:
                self._values["unique_values"] = unique_values

        @builtins.property
        def forecast(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ForecastComputationProperty"]]:
            '''The forecast computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-forecast
            '''
            result = self._values.get("forecast")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ForecastComputationProperty"]], result)

        @builtins.property
        def growth_rate(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GrowthRateComputationProperty"]]:
            '''The growth rate computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-growthrate
            '''
            result = self._values.get("growth_rate")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GrowthRateComputationProperty"]], result)

        @builtins.property
        def maximum_minimum(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MaximumMinimumComputationProperty"]]:
            '''The maximum and minimum computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-maximumminimum
            '''
            result = self._values.get("maximum_minimum")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MaximumMinimumComputationProperty"]], result)

        @builtins.property
        def metric_comparison(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MetricComparisonComputationProperty"]]:
            '''The metric comparison computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-metriccomparison
            '''
            result = self._values.get("metric_comparison")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MetricComparisonComputationProperty"]], result)

        @builtins.property
        def period_over_period(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PeriodOverPeriodComputationProperty"]]:
            '''The period over period computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-periodoverperiod
            '''
            result = self._values.get("period_over_period")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PeriodOverPeriodComputationProperty"]], result)

        @builtins.property
        def period_to_date(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PeriodToDateComputationProperty"]]:
            '''The period to ``DataSetIdentifier`` computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-periodtodate
            '''
            result = self._values.get("period_to_date")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PeriodToDateComputationProperty"]], result)

        @builtins.property
        def top_bottom_movers(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TopBottomMoversComputationProperty"]]:
            '''The top movers and bottom movers computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-topbottommovers
            '''
            result = self._values.get("top_bottom_movers")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TopBottomMoversComputationProperty"]], result)

        @builtins.property
        def top_bottom_ranked(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TopBottomRankedComputationProperty"]]:
            '''The top ranked and bottom ranked computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-topbottomranked
            '''
            result = self._values.get("top_bottom_ranked")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TopBottomRankedComputationProperty"]], result)

        @builtins.property
        def total_aggregation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TotalAggregationComputationProperty"]]:
            '''The total aggregation computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-totalaggregation
            '''
            result = self._values.get("total_aggregation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TotalAggregationComputationProperty"]], result)

        @builtins.property
        def unique_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.UniqueValuesComputationProperty"]]:
            '''The unique values computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-uniquevalues
            '''
            result = self._values.get("unique_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.UniqueValuesComputationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ConditionalFormattingColorProperty",
        jsii_struct_bases=[],
        name_mapping={"gradient": "gradient", "solid": "solid"},
    )
    class ConditionalFormattingColorProperty:
        def __init__(
            self,
            *,
            gradient: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingGradientColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            solid: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingSolidColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for the color.

            :param gradient: Formatting configuration for gradient color.
            :param solid: Formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_color_property = quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                        color=quicksight.CfnAnalysis.GradientColorProperty(
                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                gradient_offset=123,
                
                                # the properties below are optional
                                color="color",
                                data_value=123
                            )]
                        ),
                        expression="expression"
                    ),
                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                        expression="expression",
                
                        # the properties below are optional
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__44c6cb1ede49de42e2d5d0acf17eac74bb9640f46cfd9a659b0bd9f43c9b6c99)
                check_type(argname="argument gradient", value=gradient, expected_type=type_hints["gradient"])
                check_type(argname="argument solid", value=solid, expected_type=type_hints["solid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if gradient is not None:
                self._values["gradient"] = gradient
            if solid is not None:
                self._values["solid"] = solid

        @builtins.property
        def gradient(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingGradientColorProperty"]]:
            '''Formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html#cfn-quicksight-analysis-conditionalformattingcolor-gradient
            '''
            result = self._values.get("gradient")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingGradientColorProperty"]], result)

        @builtins.property
        def solid(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingSolidColorProperty"]]:
            '''Formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html#cfn-quicksight-analysis-conditionalformattingcolor-solid
            '''
            result = self._values.get("solid")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingSolidColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "icon_options": "iconOptions",
            "color": "color",
            "display_configuration": "displayConfiguration",
        },
    )
    class ConditionalFormattingCustomIconConditionProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
            color: typing.Optional[builtins.str] = None,
            display_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the custom condition for an icon set.

            :param expression: The expression that determines the condition of the icon set.
            :param icon_options: Custom icon options for an icon set.
            :param color: Determines the color of the icon.
            :param display_configuration: Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_condition_property = quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                    expression="expression",
                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                        icon="icon",
                        unicode_icon="unicodeIcon"
                    ),
                
                    # the properties below are optional
                    color="color",
                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                        icon_display_option="iconDisplayOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6181670db4f74c2a0c2930e33c51dbe9060d5127decf627d50ab67c6df0b662a)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_options", value=icon_options, expected_type=type_hints["icon_options"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument display_configuration", value=display_configuration, expected_type=type_hints["display_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "icon_options": icon_options,
            }
            if color is not None:
                self._values["color"] = color
            if display_configuration is not None:
                self._values["display_configuration"] = display_configuration

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the condition of the icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty"]:
            '''Custom icon options for an icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-iconoptions
            '''
            result = self._values.get("icon_options")
            assert result is not None, "Required property 'icon_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty"], result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty"]]:
            '''Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-displayconfiguration
            '''
            result = self._values.get("display_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconConditionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "unicode_icon": "unicodeIcon"},
    )
    class ConditionalFormattingCustomIconOptionsProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[builtins.str] = None,
            unicode_icon: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Custom icon options for an icon set.

            :param icon: Determines the type of icon.
            :param unicode_icon: Determines the Unicode icon type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_options_property = quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                    icon="icon",
                    unicode_icon="unicodeIcon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d37444466424961531c73c56aff15a5db955f06aa85c82047b1e22c855724f55)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument unicode_icon", value=unicode_icon, expected_type=type_hints["unicode_icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if unicode_icon is not None:
                self._values["unicode_icon"] = unicode_icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''Determines the type of icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html#cfn-quicksight-analysis-conditionalformattingcustomiconoptions-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def unicode_icon(self) -> typing.Optional[builtins.str]:
            '''Determines the Unicode icon type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html#cfn-quicksight-analysis-conditionalformattingcustomiconoptions-unicodeicon
            '''
            result = self._values.get("unicode_icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "expression": "expression"},
    )
    class ConditionalFormattingGradientColorProperty:
        def __init__(
            self,
            *,
            color: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GradientColorProperty", typing.Dict[builtins.str, typing.Any]]],
            expression: builtins.str,
        ) -> None:
            '''Formatting configuration for gradient color.

            :param color: Determines the color.
            :param expression: The expression that determines the formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_gradient_color_property = quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                    color=quicksight.CfnAnalysis.GradientColorProperty(
                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                            gradient_offset=123,
                
                            # the properties below are optional
                            color="color",
                            data_value=123
                        )]
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__20c45f519e167a0ecc7d079eb4c1b795f3f910859ecaf24c123c64a5207bcf94)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "expression": expression,
            }

        @builtins.property
        def color(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GradientColorProperty"]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html#cfn-quicksight-analysis-conditionalformattinggradientcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GradientColorProperty"], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html#cfn-quicksight-analysis-conditionalformattinggradientcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingGradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"icon_display_option": "iconDisplayOption"},
    )
    class ConditionalFormattingIconDisplayConfigurationProperty:
        def __init__(
            self,
            *,
            icon_display_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the icon display configuration.

            :param icon_display_option: Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicondisplayconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_icon_display_configuration_property = quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                    icon_display_option="iconDisplayOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0d95566b1ee23d4937fbc265917b35fa24a7626b3146fe7c3d69c1779535333a)
                check_type(argname="argument icon_display_option", value=icon_display_option, expected_type=type_hints["icon_display_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon_display_option is not None:
                self._values["icon_display_option"] = icon_display_option

        @builtins.property
        def icon_display_option(self) -> typing.Optional[builtins.str]:
            '''Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-analysis-conditionalformattingicondisplayconfiguration-icondisplayoption
            '''
            result = self._values.get("icon_display_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconDisplayConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ConditionalFormattingIconProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_condition": "customCondition", "icon_set": "iconSet"},
    )
    class ConditionalFormattingIconProperty:
        def __init__(
            self,
            *,
            custom_condition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingCustomIconConditionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            icon_set: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingIconSetProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for the icon.

            :param custom_condition: Determines the custom condition for an icon set.
            :param icon_set: Formatting configuration for icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_icon_property = quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                        expression="expression",
                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                            icon="icon",
                            unicode_icon="unicodeIcon"
                        ),
                
                        # the properties below are optional
                        color="color",
                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                            icon_display_option="iconDisplayOption"
                        )
                    ),
                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                        expression="expression",
                
                        # the properties below are optional
                        icon_set_type="iconSetType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f4b430928ff3492fce2bf021a9059438738fde5409f19850e67c3f3e3d3ab4b)
                check_type(argname="argument custom_condition", value=custom_condition, expected_type=type_hints["custom_condition"])
                check_type(argname="argument icon_set", value=icon_set, expected_type=type_hints["icon_set"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_condition is not None:
                self._values["custom_condition"] = custom_condition
            if icon_set is not None:
                self._values["icon_set"] = icon_set

        @builtins.property
        def custom_condition(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingCustomIconConditionProperty"]]:
            '''Determines the custom condition for an icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html#cfn-quicksight-analysis-conditionalformattingicon-customcondition
            '''
            result = self._values.get("custom_condition")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingCustomIconConditionProperty"]], result)

        @builtins.property
        def icon_set(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingIconSetProperty"]]:
            '''Formatting configuration for icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html#cfn-quicksight-analysis-conditionalformattingicon-iconset
            '''
            result = self._values.get("icon_set")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingIconSetProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "icon_set_type": "iconSetType"},
    )
    class ConditionalFormattingIconSetProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_set_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for icon set.

            :param expression: The expression that determines the formatting configuration for the icon set.
            :param icon_set_type: Determines the icon set type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_icon_set_property = quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                    expression="expression",
                
                    # the properties below are optional
                    icon_set_type="iconSetType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8fa67e4dde2f0e4e9da3d676a22261fc798708624584fad23499c14f1fb8cd69)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_set_type", value=icon_set_type, expected_type=type_hints["icon_set_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if icon_set_type is not None:
                self._values["icon_set_type"] = icon_set_type

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for the icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html#cfn-quicksight-analysis-conditionalformattingiconset-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_set_type(self) -> typing.Optional[builtins.str]:
            '''Determines the icon set type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html#cfn-quicksight-analysis-conditionalformattingiconset-iconsettype
            '''
            result = self._values.get("icon_set_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconSetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "color": "color"},
    )
    class ConditionalFormattingSolidColorProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for solid color.

            :param expression: The expression that determines the formatting configuration for solid color.
            :param color: Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_solid_color_property = quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                    expression="expression",
                
                    # the properties below are optional
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0aad88146879c47fa33dd2c0d29714201b46e227d02d819c9c5e720eca16edf2)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html#cfn-quicksight-analysis-conditionalformattingsolidcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html#cfn-quicksight-analysis-conditionalformattingsolidcolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingSolidColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contributor_dimensions": "contributorDimensions",
            "measure_field_id": "measureFieldId",
        },
    )
    class ContributionAnalysisDefaultProperty:
        def __init__(
            self,
            *,
            contributor_dimensions: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            measure_field_id: builtins.str,
        ) -> None:
            '''The contribution analysis visual display for a line, pie, or bar chart.

            :param contributor_dimensions: The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .
            :param measure_field_id: The measure field that is used in the contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                contribution_analysis_default_property = quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    measure_field_id="measureFieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__66a771228ca4cf9774e514dc37c6e38bcdb3b3d4a2654555cd6e6a620c815a4e)
                check_type(argname="argument contributor_dimensions", value=contributor_dimensions, expected_type=type_hints["contributor_dimensions"])
                check_type(argname="argument measure_field_id", value=measure_field_id, expected_type=type_hints["measure_field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "contributor_dimensions": contributor_dimensions,
                "measure_field_id": measure_field_id,
            }

        @builtins.property
        def contributor_dimensions(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]]]:
            '''The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html#cfn-quicksight-analysis-contributionanalysisdefault-contributordimensions
            '''
            result = self._values.get("contributor_dimensions")
            assert result is not None, "Required property 'contributor_dimensions' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def measure_field_id(self) -> builtins.str:
            '''The measure field that is used in the contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html#cfn-quicksight-analysis-contributionanalysisdefault-measurefieldid
            '''
            result = self._values.get("measure_field_id")
            assert result is not None, "Required property 'measure_field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ContributionAnalysisDefaultProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
            "symbol": "symbol",
        },
    )
    class CurrencyDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
            symbol: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the currency display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value for the currency format.
            :param prefix: Determines the prefix value of the currency format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the currency format.
            :param symbol: Determines the symbol for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                currency_display_format_configuration_property = quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix",
                    symbol="symbol"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc3d01f31007aa3225b0db607b8d19cf05e2e242a77765271a87fd3de1287783)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix
            if symbol is not None:
                self._values["symbol"] = symbol

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the symbol for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CurrencyDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CustomActionFilterOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_fields_configuration": "selectedFieldsConfiguration",
            "target_visuals_configuration": "targetVisualsConfiguration",
        },
    )
    class CustomActionFilterOperationProperty:
        def __init__(
            self,
            *,
            selected_fields_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            target_visuals_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :param selected_fields_configuration: The configuration that chooses the fields to be filtered.
            :param target_visuals_configuration: The configuration that chooses the target visuals to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_action_filter_operation_property = quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                        selected_field_options="selectedFieldOptions",
                        selected_fields=["selectedFields"]
                    ),
                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                            target_visual_options="targetVisualOptions",
                            target_visuals=["targetVisuals"]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__775d6cb725f278dc4b3065acab14f251adf747bee5d0a713f39e5fa5f2b7963e)
                check_type(argname="argument selected_fields_configuration", value=selected_fields_configuration, expected_type=type_hints["selected_fields_configuration"])
                check_type(argname="argument target_visuals_configuration", value=target_visuals_configuration, expected_type=type_hints["target_visuals_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "selected_fields_configuration": selected_fields_configuration,
                "target_visuals_configuration": target_visuals_configuration,
            }

        @builtins.property
        def selected_fields_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty"]:
            '''The configuration that chooses the fields to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html#cfn-quicksight-analysis-customactionfilteroperation-selectedfieldsconfiguration
            '''
            result = self._values.get("selected_fields_configuration")
            assert result is not None, "Required property 'selected_fields_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty"], result)

        @builtins.property
        def target_visuals_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty"]:
            '''The configuration that chooses the target visuals to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html#cfn-quicksight-analysis-customactionfilteroperation-targetvisualsconfiguration
            '''
            result = self._values.get("target_visuals_configuration")
            assert result is not None, "Required property 'target_visuals_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionFilterOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CustomActionNavigationOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "local_navigation_configuration": "localNavigationConfiguration",
        },
    )
    class CustomActionNavigationOperationProperty:
        def __init__(
            self,
            *,
            local_navigation_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LocalNavigationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The navigation operation that navigates between different sheets in the same analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param local_navigation_configuration: The configuration that chooses the navigation target.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionnavigationoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_action_navigation_operation_property = quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                        target_sheet_id="targetSheetId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b77b116aeb1efb20b9916cea780d057605e27e32563c2c0660a5a40b69bb95a3)
                check_type(argname="argument local_navigation_configuration", value=local_navigation_configuration, expected_type=type_hints["local_navigation_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if local_navigation_configuration is not None:
                self._values["local_navigation_configuration"] = local_navigation_configuration

        @builtins.property
        def local_navigation_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LocalNavigationConfigurationProperty"]]:
            '''The configuration that chooses the navigation target.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionnavigationoperation.html#cfn-quicksight-analysis-customactionnavigationoperation-localnavigationconfiguration
            '''
            result = self._values.get("local_navigation_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LocalNavigationConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionNavigationOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_value_configurations": "parameterValueConfigurations",
        },
    )
    class CustomActionSetParametersOperationProperty:
        def __init__(
            self,
            *,
            parameter_value_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SetParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The set parameter operation that sets parameters in custom action.

            :param parameter_value_configurations: The parameter that determines the value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionsetparametersoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_action_set_parameters_operation_property = quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                        destination_parameter_name="destinationParameterName",
                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                    date_time_values=["dateTimeValues"],
                                    decimal_values=[123],
                                    integer_values=[123],
                                    string_values=["stringValues"]
                                ),
                
                                # the properties below are optional
                                include_null_value=False
                            ),
                            select_all_value_options="selectAllValueOptions",
                            source_field="sourceField",
                            source_parameter_name="sourceParameterName"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee373cb01707f3cb449bb37361a9c3f6c2ee6d75139a887ac86cce7500a6a171)
                check_type(argname="argument parameter_value_configurations", value=parameter_value_configurations, expected_type=type_hints["parameter_value_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_value_configurations": parameter_value_configurations,
            }

        @builtins.property
        def parameter_value_configurations(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SetParameterValueConfigurationProperty"]]]:
            '''The parameter that determines the value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionsetparametersoperation.html#cfn-quicksight-analysis-customactionsetparametersoperation-parametervalueconfigurations
            '''
            result = self._values.get("parameter_value_configurations")
            assert result is not None, "Required property 'parameter_value_configurations' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SetParameterValueConfigurationProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionSetParametersOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CustomActionURLOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"url_target": "urlTarget", "url_template": "urlTemplate"},
    )
    class CustomActionURLOperationProperty:
        def __init__(
            self,
            *,
            url_target: builtins.str,
            url_template: builtins.str,
        ) -> None:
            '''The URL operation that opens a link to another webpage.

            :param url_target: The target of the ``CustomActionURLOperation`` . Valid values are defined as follows: - ``NEW_TAB`` : Opens the target URL in a new browser tab. - ``NEW_WINDOW`` : Opens the target URL in a new browser window. - ``SAME_TAB`` : Opens the target URL in the same browser tab.
            :param url_template: THe URL link of the ``CustomActionURLOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_action_uRLOperation_property = quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                    url_target="urlTarget",
                    url_template="urlTemplate"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4fda0c22f204d0195ce095fdea679dde6f73317c0c55584b093015aff25e19db)
                check_type(argname="argument url_target", value=url_target, expected_type=type_hints["url_target"])
                check_type(argname="argument url_template", value=url_template, expected_type=type_hints["url_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "url_target": url_target,
                "url_template": url_template,
            }

        @builtins.property
        def url_target(self) -> builtins.str:
            '''The target of the ``CustomActionURLOperation`` .

            Valid values are defined as follows:

            - ``NEW_TAB`` : Opens the target URL in a new browser tab.
            - ``NEW_WINDOW`` : Opens the target URL in a new browser window.
            - ``SAME_TAB`` : Opens the target URL in the same browser tab.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html#cfn-quicksight-analysis-customactionurloperation-urltarget
            '''
            result = self._values.get("url_target")
            assert result is not None, "Required property 'url_target' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def url_template(self) -> builtins.str:
            '''THe URL link of the ``CustomActionURLOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html#cfn-quicksight-analysis-customactionurloperation-urltemplate
            '''
            result = self._values.get("url_template")
            assert result is not None, "Required property 'url_template' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionURLOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CustomColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "field_value": "fieldValue",
            "special_value": "specialValue",
        },
    )
    class CustomColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            special_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''
            :param color: ``CfnAnalysis.CustomColorProperty.Color``.
            :param field_value: ``CfnAnalysis.CustomColorProperty.FieldValue``.
            :param special_value: ``CfnAnalysis.CustomColorProperty.SpecialValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_color_property = quicksight.CfnAnalysis.CustomColorProperty(
                    color="color",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    special_value="specialValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1bb45df2554c39d45144c386c6875edfa16540c57cd686a19d6a15c261365c52)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument special_value", value=special_value, expected_type=type_hints["special_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if special_value is not None:
                self._values["special_value"] = special_value

        @builtins.property
        def color(self) -> builtins.str:
            '''``CfnAnalysis.CustomColorProperty.Color``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''``CfnAnalysis.CustomColorProperty.FieldValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def special_value(self) -> typing.Optional[builtins.str]:
            '''``CfnAnalysis.CustomColorProperty.SpecialValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-specialvalue
            '''
            result = self._values.get("special_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CustomContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content_type": "contentType",
            "content_url": "contentUrl",
            "image_scaling": "imageScaling",
        },
    )
    class CustomContentConfigurationProperty:
        def __init__(
            self,
            *,
            content_type: typing.Optional[builtins.str] = None,
            content_url: typing.Optional[builtins.str] = None,
            image_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of a ``CustomContentVisual`` .

            :param content_type: The content type of the custom content visual. You can use this to have the visual render as an image.
            :param content_url: The input URL that links to the custom content that you want in the custom visual.
            :param image_scaling: The sizing options for the size of the custom content visual. This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_content_configuration_property = quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                    content_type="contentType",
                    content_url="contentUrl",
                    image_scaling="imageScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7537d20a06b00fa43f9d82ba07dedbc9bd1112f90d616963e73492b97fcad2e4)
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument content_url", value=content_url, expected_type=type_hints["content_url"])
                check_type(argname="argument image_scaling", value=image_scaling, expected_type=type_hints["image_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if content_type is not None:
                self._values["content_type"] = content_type
            if content_url is not None:
                self._values["content_url"] = content_url
            if image_scaling is not None:
                self._values["image_scaling"] = image_scaling

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The content type of the custom content visual.

            You can use this to have the visual render as an image.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def content_url(self) -> typing.Optional[builtins.str]:
            '''The input URL that links to the custom content that you want in the custom visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-contenturl
            '''
            result = self._values.get("content_url")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def image_scaling(self) -> typing.Optional[builtins.str]:
            '''The sizing options for the size of the custom content visual.

            This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-imagescaling
            '''
            result = self._values.get("image_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CustomContentVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class CustomContentVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CustomContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used to create the custom content visual. You can't create a visual without a dataset.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``CustomContentVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_content_visual_property = quicksight.CfnAnalysis.CustomContentVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                        content_type="contentType",
                        content_url="contentUrl",
                        image_scaling="imageScaling"
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ba251fe521bb6ef5c544604f9854d65bb0c02d0d44626dc7c138c750546bdbdf)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used to create the custom content visual.

            You can't create a visual without a dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomContentConfigurationProperty"]]:
            '''The configuration of a ``CustomContentVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomContentConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CustomFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_value": "categoryValue",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_value: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_value: The category value for the filter. This field is mutually exclusive to ``ParameterName`` .
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``CategoryValue`` .
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_filter_configuration_property = quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_value="categoryValue",
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__808dbf9c453e99b84e61f1c46bcb368ef5a95df893b74bed8ff01f20b1230dcf)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_value", value=category_value, expected_type=type_hints["category_value"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_value is not None:
                self._values["category_value"] = category_value
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_value(self) -> typing.Optional[builtins.str]:
            '''The category value for the filter.

            This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-categoryvalue
            '''
            result = self._values.get("category_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``CategoryValue`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CustomFilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of custom filter values.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_filter_list_configuration_property = quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__145c79c61d99c9dcbb9ade3edcff76f5c4f031d3365ecec2d8d8f4db2fe73792)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CustomNarrativeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"narrative": "narrative"},
    )
    class CustomNarrativeOptionsProperty:
        def __init__(self, *, narrative: builtins.str) -> None:
            '''The custom narrative options.

            :param narrative: The string input of custom narrative.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customnarrativeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_narrative_options_property = quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                    narrative="narrative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b3ead21422cced0b1a03a0eaa3bb2b9569cb1015843ca3a685ff12a07ce41ea4)
                check_type(argname="argument narrative", value=narrative, expected_type=type_hints["narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "narrative": narrative,
            }

        @builtins.property
        def narrative(self) -> builtins.str:
            '''The string input of custom narrative.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customnarrativeoptions.html#cfn-quicksight-analysis-customnarrativeoptions-narrative
            '''
            result = self._values.get("narrative")
            assert result is not None, "Required property 'narrative' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomNarrativeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CustomParameterValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_values": "dateTimeValues",
            "decimal_values": "decimalValues",
            "integer_values": "integerValues",
            "string_values": "stringValues",
        },
    )
    class CustomParameterValuesProperty:
        def __init__(
            self,
            *,
            date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            decimal_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
            integer_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
            string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The customized parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_values: A list of datetime-type parameter values.
            :param decimal_values: A list of decimal-type parameter values.
            :param integer_values: A list of integer-type parameter values.
            :param string_values: A list of string-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_parameter_values_property = quicksight.CfnAnalysis.CustomParameterValuesProperty(
                    date_time_values=["dateTimeValues"],
                    decimal_values=[123],
                    integer_values=[123],
                    string_values=["stringValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96664ad0959f3886c915dd4831f18d0ee49b9c560975962202084734f09d3e51)
                check_type(argname="argument date_time_values", value=date_time_values, expected_type=type_hints["date_time_values"])
                check_type(argname="argument decimal_values", value=decimal_values, expected_type=type_hints["decimal_values"])
                check_type(argname="argument integer_values", value=integer_values, expected_type=type_hints["integer_values"])
                check_type(argname="argument string_values", value=string_values, expected_type=type_hints["string_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_values is not None:
                self._values["date_time_values"] = date_time_values
            if decimal_values is not None:
                self._values["decimal_values"] = decimal_values
            if integer_values is not None:
                self._values["integer_values"] = integer_values
            if string_values is not None:
                self._values["string_values"] = string_values

        @builtins.property
        def date_time_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of datetime-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-datetimevalues
            '''
            result = self._values.get("date_time_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def decimal_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]]:
            '''A list of decimal-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-decimalvalues
            '''
            result = self._values.get("decimal_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]], result)

        @builtins.property
        def integer_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]]:
            '''A list of integer-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-integervalues
            '''
            result = self._values.get("integer_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]], result)

        @builtins.property
        def string_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of string-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-stringvalues
            '''
            result = self._values.get("string_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomParameterValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.CustomValuesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values": "customValues",
            "include_null_value": "includeNullValue",
        },
    )
    class CustomValuesConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CustomParameterValuesProperty", typing.Dict[builtins.str, typing.Any]]],
            include_null_value: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
        ) -> None:
            '''The configuration of custom values for the destination parameter in ``DestinationParameterValueConfiguration`` .

            :param custom_values: ``CfnAnalysis.CustomValuesConfigurationProperty.CustomValues``.
            :param include_null_value: Includes the null value in custom action parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_values_configuration_property = quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                        date_time_values=["dateTimeValues"],
                        decimal_values=[123],
                        integer_values=[123],
                        string_values=["stringValues"]
                    ),
                
                    # the properties below are optional
                    include_null_value=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c29742ab23d9d662a54c4ebbf9fd50e2a0a3808296e4ea0ecf2b79d2b8e6183)
                check_type(argname="argument custom_values", value=custom_values, expected_type=type_hints["custom_values"])
                check_type(argname="argument include_null_value", value=include_null_value, expected_type=type_hints["include_null_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_values": custom_values,
            }
            if include_null_value is not None:
                self._values["include_null_value"] = include_null_value

        @builtins.property
        def custom_values(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomParameterValuesProperty"]:
            '''``CfnAnalysis.CustomValuesConfigurationProperty.CustomValues``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html#cfn-quicksight-analysis-customvaluesconfiguration-customvalues
            '''
            result = self._values.get("custom_values")
            assert result is not None, "Required property 'custom_values' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomParameterValuesProperty"], result)

        @builtins.property
        def include_null_value(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Includes the null value in custom action parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html#cfn-quicksight-analysis-customvaluesconfiguration-includenullvalue
            '''
            result = self._values.get("include_null_value")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomValuesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DataBarsOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "negative_color": "negativeColor",
            "positive_color": "positiveColor",
        },
    )
    class DataBarsOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            negative_color: typing.Optional[builtins.str] = None,
            positive_color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for data bars.

            :param field_id: The field ID for the data bars options.
            :param negative_color: The color of the negative data bar.
            :param positive_color: The color of the positive data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_bars_options_property = quicksight.CfnAnalysis.DataBarsOptionsProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    negative_color="negativeColor",
                    positive_color="positiveColor"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a634a2b7fdf8c250265c56efe23fa5a44f87e57436b9f0138962742460464d10)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument negative_color", value=negative_color, expected_type=type_hints["negative_color"])
                check_type(argname="argument positive_color", value=positive_color, expected_type=type_hints["positive_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if negative_color is not None:
                self._values["negative_color"] = negative_color
            if positive_color is not None:
                self._values["positive_color"] = positive_color

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the data bars options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def negative_color(self) -> typing.Optional[builtins.str]:
            '''The color of the negative data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-negativecolor
            '''
            result = self._values.get("negative_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def positive_color(self) -> typing.Optional[builtins.str]:
            '''The color of the positive data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-positivecolor
            '''
            result = self._values.get("positive_color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataBarsOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DataColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "data_value": "dataValue"},
    )
    class DataColorProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the color that is applied to a particular data value.

            :param color: The color that is applied to the data value.
            :param data_value: The data value that the color is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_color_property = quicksight.CfnAnalysis.DataColorProperty(
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aa9d7aa155725c69b84b58dcaee043c97d0c1fd57aa0185b2ca98772398cc705)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color that is applied to the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html#cfn-quicksight-analysis-datacolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''The data value that the color is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html#cfn-quicksight-analysis-datacolor-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DataFieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "settings": "settings",
        },
    )
    class DataFieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field that you are setting the axis binding to.
            :param field_value: The field value of the field that you are setting the axis binding to.
            :param settings: The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_field_series_item_property = quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55e555b80af260a17978917a49d90afc102a3aa84a78aecd4ed75f172a196d3b)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that you are setting the axis binding to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The field value of the field that you are setting the axis binding to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartSeriesSettingsProperty"]]:
            '''The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartSeriesSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataFieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "data_label_types": "dataLabelTypes",
            "label_color": "labelColor",
            "label_content": "labelContent",
            "label_font_configuration": "labelFontConfiguration",
            "measure_label_visibility": "measureLabelVisibility",
            "overlap": "overlap",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class DataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            data_label_types: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_content: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            overlap: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: Determines the visibility of the category field labels.
            :param data_label_types: The option that determines the data label type.
            :param label_color: Determines the color of the data labels.
            :param label_content: Determines the content of the data labels.
            :param label_font_configuration: Determines the font configuration of the data labels.
            :param measure_label_visibility: Determines the visibility of the measure field labels.
            :param overlap: Determines whether overlap is enabled or disabled for the data labels.
            :param position: Determines the position of the data labels.
            :param visibility: Determines the visibility of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_label_options_property = quicksight.CfnAnalysis.DataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                            field_id="fieldId",
                            field_value="fieldValue",
                            visibility="visibility"
                        ),
                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                            field_id="fieldId",
                            visibility="visibility"
                        ),
                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                            visibility="visibility"
                        )
                    )],
                    label_color="labelColor",
                    label_content="labelContent",
                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_label_visibility="measureLabelVisibility",
                    overlap="overlap",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__30846b324fab7c7007ab706b72cc63e3b9f627f0dfda422f92fb9359e0a61d48)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument data_label_types", value=data_label_types, expected_type=type_hints["data_label_types"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_content", value=label_content, expected_type=type_hints["label_content"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument overlap", value=overlap, expected_type=type_hints["overlap"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if data_label_types is not None:
                self._values["data_label_types"] = data_label_types
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_content is not None:
                self._values["label_content"] = label_content
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if overlap is not None:
                self._values["overlap"] = overlap
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the category field labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_label_types(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelTypeProperty"]]]]:
            '''The option that determines the data label type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-datalabeltypes
            '''
            result = self._values.get("data_label_types")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelTypeProperty"]]]], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_content(self) -> typing.Optional[builtins.str]:
            '''Determines the content of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelcontent
            '''
            result = self._values.get("label_content")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]]:
            '''Determines the font configuration of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the measure field labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def overlap(self) -> typing.Optional[builtins.str]:
            '''Determines whether overlap is enabled or disabled for the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-overlap
            '''
            result = self._values.get("overlap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the position of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DataLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_label_type": "dataPathLabelType",
            "field_label_type": "fieldLabelType",
            "maximum_label_type": "maximumLabelType",
            "minimum_label_type": "minimumLabelType",
            "range_ends_label_type": "rangeEndsLabelType",
        },
    )
    class DataLabelTypeProperty:
        def __init__(
            self,
            *,
            data_path_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataPathLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maximum_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MaximumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            minimum_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MinimumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_ends_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RangeEndsLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The option that determines the data label type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_path_label_type: The option that specifies individual data values for labels.
            :param field_label_type: Determines the label configuration for the entire field.
            :param maximum_label_type: Determines the label configuration for the maximum value in a visual.
            :param minimum_label_type: Determines the label configuration for the minimum value in a visual.
            :param range_ends_label_type: Determines the label configuration for range end value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_label_type_property = quicksight.CfnAnalysis.DataLabelTypeProperty(
                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                        field_id="fieldId",
                        field_value="fieldValue",
                        visibility="visibility"
                    ),
                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                        field_id="fieldId",
                        visibility="visibility"
                    ),
                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__285c7ed12c69bb42c3d8086ee39dfd12bab8ad21679a5c44de3498eabaac8ab3)
                check_type(argname="argument data_path_label_type", value=data_path_label_type, expected_type=type_hints["data_path_label_type"])
                check_type(argname="argument field_label_type", value=field_label_type, expected_type=type_hints["field_label_type"])
                check_type(argname="argument maximum_label_type", value=maximum_label_type, expected_type=type_hints["maximum_label_type"])
                check_type(argname="argument minimum_label_type", value=minimum_label_type, expected_type=type_hints["minimum_label_type"])
                check_type(argname="argument range_ends_label_type", value=range_ends_label_type, expected_type=type_hints["range_ends_label_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_label_type is not None:
                self._values["data_path_label_type"] = data_path_label_type
            if field_label_type is not None:
                self._values["field_label_type"] = field_label_type
            if maximum_label_type is not None:
                self._values["maximum_label_type"] = maximum_label_type
            if minimum_label_type is not None:
                self._values["minimum_label_type"] = minimum_label_type
            if range_ends_label_type is not None:
                self._values["range_ends_label_type"] = range_ends_label_type

        @builtins.property
        def data_path_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataPathLabelTypeProperty"]]:
            '''The option that specifies individual data values for labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-datapathlabeltype
            '''
            result = self._values.get("data_path_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataPathLabelTypeProperty"]], result)

        @builtins.property
        def field_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldLabelTypeProperty"]]:
            '''Determines the label configuration for the entire field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-fieldlabeltype
            '''
            result = self._values.get("field_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldLabelTypeProperty"]], result)

        @builtins.property
        def maximum_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MaximumLabelTypeProperty"]]:
            '''Determines the label configuration for the maximum value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-maximumlabeltype
            '''
            result = self._values.get("maximum_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MaximumLabelTypeProperty"]], result)

        @builtins.property
        def minimum_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MinimumLabelTypeProperty"]]:
            '''Determines the label configuration for the minimum value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-minimumlabeltype
            '''
            result = self._values.get("minimum_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MinimumLabelTypeProperty"]], result)

        @builtins.property
        def range_ends_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RangeEndsLabelTypeProperty"]]:
            '''Determines the label configuration for range end value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-rangeendslabeltype
            '''
            result = self._values.get("range_ends_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RangeEndsLabelTypeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DataPathColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "element": "element",
            "time_granularity": "timeGranularity",
        },
    )
    class DataPathColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            element: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]],
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The color map that determines the color options for a particular element.

            :param color: The color that needs to be applied to the element.
            :param element: The element that the color needs to be applied to.
            :param time_granularity: The time granularity of the field that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_path_color_property = quicksight.CfnAnalysis.DataPathColorProperty(
                    color="color",
                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    ),
                
                    # the properties below are optional
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__64605ef50ff11a438be355c78f064240a72f9930186e16615c9ca2337b413842)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument element", value=element, expected_type=type_hints["element"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "element": element,
            }
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def color(self) -> builtins.str:
            '''The color that needs to be applied to the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataPathValueProperty"]:
            '''The element that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-element
            '''
            result = self._values.get("element")
            assert result is not None, "Required property 'element' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataPathValueProperty"], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity of the field that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DataPathLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "visibility": "visibility",
        },
    )
    class DataPathLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            field_value: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The option that specifies individual data values for labels.

            :param field_id: The field ID of the field that the data label needs to be applied to.
            :param field_value: The actual value of the field that is labeled.
            :param visibility: The visibility of the data label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_path_label_type_property = quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                    field_id="fieldId",
                    field_value="fieldValue",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b984bf6be29aee3b30d4c6c8881e7b4e315ce92304ab12648fefb74b7b10cda5)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if field_value is not None:
                self._values["field_value"] = field_value
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the field that the data label needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The actual value of the field that is labeled.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DataPathSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "sort_paths": "sortPaths"},
    )
    class DataPathSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_paths: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''Allows data paths to be sorted by a specific data value.

            :param direction: Determines the sort direction.
            :param sort_paths: The list of data paths that need to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_path_sort_property = quicksight.CfnAnalysis.DataPathSortProperty(
                    direction="direction",
                    sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__265ffd5292373519b930408f500c2482a77c27a8984456bd4380edcdbdef9ec6)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_paths", value=sort_paths, expected_type=type_hints["sort_paths"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_paths": sort_paths,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''Determines the sort direction.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html#cfn-quicksight-analysis-datapathsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_paths(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataPathValueProperty"]]]:
            '''The list of data paths that need to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html#cfn-quicksight-analysis-datapathsort-sortpaths
            '''
            result = self._values.get("sort_paths")
            assert result is not None, "Required property 'sort_paths' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataPathValueProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DataPathValueProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "field_value": "fieldValue"},
    )
    class DataPathValueProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            field_value: builtins.str,
        ) -> None:
            '''The data path that needs to be sorted.

            :param field_id: The field ID of the field that needs to be sorted.
            :param field_value: The actual value of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_path_value_property = quicksight.CfnAnalysis.DataPathValueProperty(
                    field_id="fieldId",
                    field_value="fieldValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93daddfe245ffc26fd833e1e61598b37bb41119644b0c352fe5019bb3e71da43)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "field_value": field_value,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html#cfn-quicksight-analysis-datapathvalue-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> builtins.str:
            '''The actual value of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html#cfn-quicksight-analysis-datapathvalue-fieldvalue
            '''
            result = self._values.get("field_value")
            assert result is not None, "Required property 'field_value' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DataSetIdentifierDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_set_arn": "dataSetArn", "identifier": "identifier"},
    )
    class DataSetIdentifierDeclarationProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            identifier: builtins.str,
        ) -> None:
            '''A data set.

            :param data_set_arn: The Amazon Resource Name (ARN) of the data set.
            :param identifier: The identifier of the data set, typically the data set's name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_set_identifier_declaration_property = quicksight.CfnAnalysis.DataSetIdentifierDeclarationProperty(
                    data_set_arn="dataSetArn",
                    identifier="identifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1f2c95d256b8519b80bd0fc84d8e221f3562ef2a2cca517e1667bb949e903c0b)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "identifier": identifier,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the data set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html#cfn-quicksight-analysis-datasetidentifierdeclaration-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def identifier(self) -> builtins.str:
            '''The identifier of the data set, typically the data set's name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html#cfn-quicksight-analysis-datasetidentifierdeclaration-identifier
            '''
            result = self._values.get("identifier")
            assert result is not None, "Required property 'identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetIdentifierDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DataSetReferenceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_arn": "dataSetArn",
            "data_set_placeholder": "dataSetPlaceholder",
        },
    )
    class DataSetReferenceProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            data_set_placeholder: builtins.str,
        ) -> None:
            '''Dataset reference.

            :param data_set_arn: Dataset Amazon Resource Name (ARN).
            :param data_set_placeholder: Dataset placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_set_reference_property = quicksight.CfnAnalysis.DataSetReferenceProperty(
                    data_set_arn="dataSetArn",
                    data_set_placeholder="dataSetPlaceholder"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__97a1e22446bf7e842cf7c445e4ee5196ee64f4aabe24431bdbf9d3cfdf71e925)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument data_set_placeholder", value=data_set_placeholder, expected_type=type_hints["data_set_placeholder"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "data_set_placeholder": data_set_placeholder,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''Dataset Amazon Resource Name (ARN).

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html#cfn-quicksight-analysis-datasetreference-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_placeholder(self) -> builtins.str:
            '''Dataset placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html#cfn-quicksight-analysis-datasetreference-datasetplaceholder
            '''
            result = self._values.get("data_set_placeholder")
            assert result is not None, "Required property 'data_set_placeholder' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetReferenceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DateAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"missing_date_visibility": "missingDateVisibility"},
    )
    class DateAxisOptionsProperty:
        def __init__(
            self,
            *,
            missing_date_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine how a date axis is displayed.

            :param missing_date_visibility: Determines whether or not missing dates are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dateaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_axis_options_property = quicksight.CfnAnalysis.DateAxisOptionsProperty(
                    missing_date_visibility="missingDateVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__73cc97b99e55442c1f754227cead311d0556c742eaca61e1c9916f5859d6257e)
                check_type(argname="argument missing_date_visibility", value=missing_date_visibility, expected_type=type_hints["missing_date_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if missing_date_visibility is not None:
                self._values["missing_date_visibility"] = missing_date_visibility

        @builtins.property
        def missing_date_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not missing dates are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dateaxisoptions.html#cfn-quicksight-analysis-dateaxisoptions-missingdatevisibility
            '''
            result = self._values.get("missing_date_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DateDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "date_granularity": "dateGranularity",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class DateDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            date_granularity: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with date type columns.

            :param column: The column that is used in the ``DateDimensionField`` .
            :param field_id: The custom field ID.
            :param date_granularity: The date granularity of the ``DateDimensionField`` . Choose one of the following options:. - ``YEAR`` - ``QUARTER`` - ``MONTH`` - ``WEEK`` - ``DAY`` - ``HOUR`` - ``MINUTE`` - ``SECOND`` - ``MILLISECOND``
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_dimension_field_property = quicksight.CfnAnalysis.DateDimensionFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    date_granularity="dateGranularity",
                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__368673b331cfc0a41eecb2753b9540c5811dc31b061f92ab6ab281539f3d451c)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument date_granularity", value=date_granularity, expected_type=type_hints["date_granularity"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if date_granularity is not None:
                self._values["date_granularity"] = date_granularity
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``DateDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def date_granularity(self) -> typing.Optional[builtins.str]:
            '''The date granularity of the ``DateDimensionField`` . Choose one of the following options:.

            - ``YEAR``
            - ``QUARTER``
            - ``MONTH``
            - ``WEEK``
            - ``DAY``
            - ``HOUR``
            - ``MINUTE``
            - ``SECOND``
            - ``MILLISECOND``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-dategranularity
            '''
            result = self._values.get("date_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DateMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class DateMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with date type columns.

            :param column: The column that is used in the ``DateMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_measure_field_property = quicksight.CfnAnalysis.DateMeasureFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9faa30e6df5398b455b5878b2730cb5fc3eeb097f878cd1a6a471ccab38597cf)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``DateMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DateTimeDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "rolling_date": "rollingDate",
            "static_values": "staticValues",
        },
    )
    class DateTimeDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rolling_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``DateTimeParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DataTimeDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param rolling_date: The rolling date of the ``DataTimeDefaultValues`` . The date is determined from the dataset based on input expression.
            :param static_values: The static values of the ``DataTimeDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_default_values_property = quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                    dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b0414717de43368a6a15960678d0a887f0396f4d14f2c72d1c3c1ed0cae6006a)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``DataTimeDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RollingDateConfigurationProperty"]]:
            '''The rolling date of the ``DataTimeDefaultValues`` .

            The date is determined from the dataset based on input expression.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DataTimeDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class DateTimeFormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for ``DateTime`` fields.

            :param date_time_format: Determines the ``DateTime`` format.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_format_configuration_property = quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                    date_time_format="dateTimeFormat",
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__24b520cb5315f4bdce10f3c8bdc8240990b875d40e2a62d8a6f4c48bafb7659c)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Determines the ``DateTime`` format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericFormatConfigurationProperty"]]:
            '''The formatting configuration for numeric ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DateTimeHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class DateTimeHierarchyProperty:
        def __init__(
            self,
            *,
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :param hierarchy_id: The hierarchy ID of the ``DateTime`` hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_hierarchy_property = quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fb7578bab90885b258b37c73f38fcc4cc77e5aa1b189aa224d293d1c25930cd8)
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html#cfn-quicksight-analysis-datetimehierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html#cfn-quicksight-analysis-datetimehierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "time_granularity": "timeGranularity",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DateTimeParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DateTimeDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``DateTime`` data type.

            :param name: The name of the parameter that is being declared.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnAnalysis.DateTimeParameterDeclarationProperty.MappedDataSetParameters``.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value_when_unset: The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_parameter_declaration_property = quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty(
                    name="name",
                
                    # the properties below are optional
                    default_values=quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                        dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    time_granularity="timeGranularity",
                    value_when_unset=quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6ae8017dec7b15901dee198ac9a6ce58af8e78d966525f68ed91becf48d35877)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MappedDataSetParameterProperty"]]]]:
            '''``CfnAnalysis.DateTimeParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DateTimeParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class DateTimeParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Sequence[builtins.str],
        ) -> None:
            '''A date-time parameter.

            :param name: A display name for the date-time parameter.
            :param values: The values for the date-time parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_parameter_property = quicksight.CfnAnalysis.DateTimeParameterProperty(
                    name="name",
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec2020e76f9a9a61304ff0bd088086e8608b84f4983dc17f7d27905d04a72b98)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the date-time parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html#cfn-quicksight-analysis-datetimeparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(self) -> typing.List[builtins.str]:
            '''The values for the date-time parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html#cfn-quicksight-analysis-datetimeparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "title_options": "titleOptions",
        },
    )
    class DateTimePickerControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_picker_control_display_options_property = quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62065e00bf524d21667869a7420f8f554fa5f53412ac1471245d0d2c9a322b42)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html#cfn-quicksight-analysis-datetimepickercontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html#cfn-quicksight-analysis-datetimepickercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimePickerControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DateTimeValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_value_when_unset_configuration_property = quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eb62e964d10797b2dc1d06b1c37f990c54f9e8fc5e6890112f1ace51c954d1a2)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-analysis-datetimevaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-analysis-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DecimalDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class DecimalDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``DecimalParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DecimalDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_default_values_property = quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                    dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__98074d18c17769e85607b77d873b7efe2af1607ad7b1fefc2d679daee7b9642e)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``DecimalDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html#cfn-quicksight-analysis-decimaldefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html#cfn-quicksight-analysis-decimaldefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DecimalParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DecimalParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DecimalDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``Decimal`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnAnalysis.DecimalParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_parameter_declaration_property = quicksight.CfnAnalysis.DecimalParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                        dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ad20dd62db1f0042d9126362c1679cd8bb34d489392941fafb04e74ff48a7096)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MappedDataSetParameterProperty"]]]]:
            '''``CfnAnalysis.DecimalParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DecimalParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class DecimalParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]],
        ) -> None:
            '''A decimal parameter.

            :param name: A display name for the decimal parameter.
            :param values: The values for the decimal parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_parameter_property = quicksight.CfnAnalysis.DecimalParameterProperty(
                    name="name",
                    values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__51d1023ee96861d6d11966d42e6b472cb3862086f93771e9fbc2304a4bd61802)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the decimal parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html#cfn-quicksight-analysis-decimalparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]:
            '''The values for the decimal parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html#cfn-quicksight-analysis-decimalparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"decimal_places": "decimalPlaces"},
    )
    class DecimalPlacesConfigurationProperty:
        def __init__(self, *, decimal_places: jsii.Number) -> None:
            '''The option that determines the decimal places configuration.

            :param decimal_places: The values of the decimal places.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalplacesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_places_configuration_property = quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                    decimal_places=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4edfb6e5285422f53f03985556e201a0872e1e95b156db016ca14623d2a505bf)
                check_type(argname="argument decimal_places", value=decimal_places, expected_type=type_hints["decimal_places"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "decimal_places": decimal_places,
            }

        @builtins.property
        def decimal_places(self) -> jsii.Number:
            '''The values of the decimal places.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalplacesconfiguration.html#cfn-quicksight-analysis-decimalplacesconfiguration-decimalplaces
            '''
            result = self._values.get("decimal_places")
            assert result is not None, "Required property 'decimal_places' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalPlacesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DecimalValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_value_when_unset_configuration_property = quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e8262ee575ea5807ed1c2462f179d833b2b0a8977c84db55abb681edac9c726f)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-decimalvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultFreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings of a free-form layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultfreeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_free_form_layout_configuration_property = quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e01d702867bc9b2f7222a9eceafb62455079c69d90af647b4b97820a98bc2003)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultfreeformlayoutconfiguration.html#cfn-quicksight-analysis-defaultfreeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultFreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultGridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings for a grid layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultgridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_grid_layout_configuration_property = quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2a5138d0a4e8f3ac6c8a3008d50fe8aa4cf997d1232f3bca4a98a804ddcb1d93)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GridLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultgridlayoutconfiguration.html#cfn-quicksight-analysis-defaultgridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GridLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultGridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form": "freeForm", "grid": "grid"},
    )
    class DefaultInteractiveLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DefaultGridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default settings for interactive layout configuration.

            :param free_form: The options that determine the default settings of a free-form layout configuration.
            :param grid: The options that determine the default settings for a grid layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_interactive_layout_configuration_property = quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                    free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4e6855c164d33b8ef8b0ef91501ba1046011d9210f39ecef658d137e17f215cb)
                check_type(argname="argument free_form", value=free_form, expected_type=type_hints["free_form"])
                check_type(argname="argument grid", value=grid, expected_type=type_hints["grid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form is not None:
                self._values["free_form"] = free_form
            if grid is not None:
                self._values["grid"] = grid

        @builtins.property
        def free_form(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty"]]:
            '''The options that determine the default settings of a free-form layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html#cfn-quicksight-analysis-defaultinteractivelayoutconfiguration-freeform
            '''
            result = self._values.get("free_form")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty"]], result)

        @builtins.property
        def grid(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DefaultGridLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a grid layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html#cfn-quicksight-analysis-defaultinteractivelayoutconfiguration-grid
            '''
            result = self._values.get("grid")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DefaultGridLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultInteractiveLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "interactive_layout_configuration": "interactiveLayoutConfiguration",
            "paginated_layout_configuration": "paginatedLayoutConfiguration",
            "sheet_content_type": "sheetContentType",
        },
    )
    class DefaultNewSheetConfigurationProperty:
        def __init__(
            self,
            *,
            interactive_layout_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_layout_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sheet_content_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration for default new sheet settings.

            :param interactive_layout_configuration: The options that determine the default settings for interactive layout configuration.
            :param paginated_layout_configuration: The options that determine the default settings for a paginated layout configuration.
            :param sheet_content_type: The option that determines the sheet content type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_new_sheet_configuration_property = quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty(
                    interactive_layout_configuration=quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                        free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    ),
                    paginated_layout_configuration=quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                        section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            )
                        )
                    ),
                    sheet_content_type="sheetContentType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d2b2ea58a80c10603566646da501dac3f0a7e3f5dc367fb49a0a594578bd26ca)
                check_type(argname="argument interactive_layout_configuration", value=interactive_layout_configuration, expected_type=type_hints["interactive_layout_configuration"])
                check_type(argname="argument paginated_layout_configuration", value=paginated_layout_configuration, expected_type=type_hints["paginated_layout_configuration"])
                check_type(argname="argument sheet_content_type", value=sheet_content_type, expected_type=type_hints["sheet_content_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if interactive_layout_configuration is not None:
                self._values["interactive_layout_configuration"] = interactive_layout_configuration
            if paginated_layout_configuration is not None:
                self._values["paginated_layout_configuration"] = paginated_layout_configuration
            if sheet_content_type is not None:
                self._values["sheet_content_type"] = sheet_content_type

        @builtins.property
        def interactive_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for interactive layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-interactivelayoutconfiguration
            '''
            result = self._values.get("interactive_layout_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty"]], result)

        @builtins.property
        def paginated_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a paginated layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-paginatedlayoutconfiguration
            '''
            result = self._values.get("paginated_layout_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty"]], result)

        @builtins.property
        def sheet_content_type(self) -> typing.Optional[builtins.str]:
            '''The option that determines the sheet content type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-sheetcontenttype
            '''
            result = self._values.get("sheet_content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultNewSheetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"section_based": "sectionBased"},
    )
    class DefaultPaginatedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            section_based: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default settings for a paginated layout configuration.

            :param section_based: The options that determine the default settings for a section-based layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultpaginatedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_paginated_layout_configuration_property = quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                    section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5f1947a24af61814d6c4beca40199a6f7935844fe88b2254cc18ab07de42b2ca)
                check_type(argname="argument section_based", value=section_based, expected_type=type_hints["section_based"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if section_based is not None:
                self._values["section_based"] = section_based

        @builtins.property
        def section_based(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a section-based layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-analysis-defaultpaginatedlayoutconfiguration-sectionbased
            '''
            result = self._values.get("section_based")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultPaginatedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultSectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings for a section-based layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultsectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_section_based_layout_configuration_property = quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e4288a6186ceac72c67614b248b364d5a62e547ab78c2e5ed74b830961d52df0)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-defaultsectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultSectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values_configuration": "customValuesConfiguration",
            "select_all_value_options": "selectAllValueOptions",
            "source_field": "sourceField",
            "source_parameter_name": "sourceParameterName",
        },
    )
    class DestinationParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CustomValuesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_value_options: typing.Optional[builtins.str] = None,
            source_field: typing.Optional[builtins.str] = None,
            source_parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of destination parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_values_configuration: The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .
            :param select_all_value_options: The configuration that selects all options.
            :param source_field: The source field ID of the destination parameter.
            :param source_parameter_name: The source parameter name of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                destination_parameter_value_configuration_property = quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                            date_time_values=["dateTimeValues"],
                            decimal_values=[123],
                            integer_values=[123],
                            string_values=["stringValues"]
                        ),
                
                        # the properties below are optional
                        include_null_value=False
                    ),
                    select_all_value_options="selectAllValueOptions",
                    source_field="sourceField",
                    source_parameter_name="sourceParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5df858c5b6db2b527a4212369479236b1d170464c817a447f9393bf8237a8a44)
                check_type(argname="argument custom_values_configuration", value=custom_values_configuration, expected_type=type_hints["custom_values_configuration"])
                check_type(argname="argument select_all_value_options", value=select_all_value_options, expected_type=type_hints["select_all_value_options"])
                check_type(argname="argument source_field", value=source_field, expected_type=type_hints["source_field"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_values_configuration is not None:
                self._values["custom_values_configuration"] = custom_values_configuration
            if select_all_value_options is not None:
                self._values["select_all_value_options"] = select_all_value_options
            if source_field is not None:
                self._values["source_field"] = source_field
            if source_parameter_name is not None:
                self._values["source_parameter_name"] = source_parameter_name

        @builtins.property
        def custom_values_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomValuesConfigurationProperty"]]:
            '''The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-customvaluesconfiguration
            '''
            result = self._values.get("custom_values_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomValuesConfigurationProperty"]], result)

        @builtins.property
        def select_all_value_options(self) -> typing.Optional[builtins.str]:
            '''The configuration that selects all options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-selectallvalueoptions
            '''
            result = self._values.get("select_all_value_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_field(self) -> typing.Optional[builtins.str]:
            '''The source field ID of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-sourcefield
            '''
            result = self._values.get("source_field")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_parameter_name(self) -> typing.Optional[builtins.str]:
            '''The source parameter name of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DestinationParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_dimension_field": "categoricalDimensionField",
            "date_dimension_field": "dateDimensionField",
            "numerical_dimension_field": "numericalDimensionField",
        },
    )
    class DimensionFieldProperty:
        def __init__(
            self,
            *,
            categorical_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CategoricalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            date_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DateDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numerical_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The dimension type field.

            :param categorical_dimension_field: The dimension type field with categorical type columns.
            :param date_dimension_field: The dimension type field with date type columns.
            :param numerical_dimension_field: The dimension type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                dimension_field_property = quicksight.CfnAnalysis.DimensionFieldProperty(
                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        date_granularity="dateGranularity",
                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__98bcfd07e1cb2003129c43e21934d53b78fc5a3c156410f0ec48dd1a478907b9)
                check_type(argname="argument categorical_dimension_field", value=categorical_dimension_field, expected_type=type_hints["categorical_dimension_field"])
                check_type(argname="argument date_dimension_field", value=date_dimension_field, expected_type=type_hints["date_dimension_field"])
                check_type(argname="argument numerical_dimension_field", value=numerical_dimension_field, expected_type=type_hints["numerical_dimension_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_dimension_field is not None:
                self._values["categorical_dimension_field"] = categorical_dimension_field
            if date_dimension_field is not None:
                self._values["date_dimension_field"] = date_dimension_field
            if numerical_dimension_field is not None:
                self._values["numerical_dimension_field"] = numerical_dimension_field

        @builtins.property
        def categorical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CategoricalDimensionFieldProperty"]]:
            '''The dimension type field with categorical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-categoricaldimensionfield
            '''
            result = self._values.get("categorical_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CategoricalDimensionFieldProperty"]], result)

        @builtins.property
        def date_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateDimensionFieldProperty"]]:
            '''The dimension type field with date type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-datedimensionfield
            '''
            result = self._values.get("date_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateDimensionFieldProperty"]], result)

        @builtins.property
        def numerical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericalDimensionFieldProperty"]]:
            '''The dimension type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-numericaldimensionfield
            '''
            result = self._values.get("numerical_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericalDimensionFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DonutCenterOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"label_visibility": "labelVisibility"},
    )
    class DonutCenterOptionsProperty:
        def __init__(
            self,
            *,
            label_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :param label_visibility: Determines the visibility of the label in a donut chart. In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutcenteroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                donut_center_options_property = quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                    label_visibility="labelVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75c3848586b04f225f99735404b088e093e76b75630a8c69cf6f923db9fa951a)
                check_type(argname="argument label_visibility", value=label_visibility, expected_type=type_hints["label_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_visibility is not None:
                self._values["label_visibility"] = label_visibility

        @builtins.property
        def label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the label in a donut chart.

            In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutcenteroptions.html#cfn-quicksight-analysis-donutcenteroptions-labelvisibility
            '''
            result = self._values.get("label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutCenterOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DonutOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc_options": "arcOptions",
            "donut_center_options": "donutCenterOptions",
        },
    )
    class DonutOptionsProperty:
        def __init__(
            self,
            *,
            arc_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ArcOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            donut_center_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DonutCenterOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for configuring a donut chart or pie chart.

            :param arc_options: The option for define the arc of the chart shape. Valid values are as follows:. - ``WHOLE`` - A pie chart - ``SMALL`` - A small-sized donut chart - ``MEDIUM`` - A medium-sized donut chart - ``LARGE`` - A large-sized donut chart
            :param donut_center_options: The label options of the label that is displayed in the center of a donut chart. This option isn't available for pie charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                donut_options_property = quicksight.CfnAnalysis.DonutOptionsProperty(
                    arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                        arc_thickness="arcThickness"
                    ),
                    donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                        label_visibility="labelVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f1eb716ff3ece23bab9e2fb8df996ff7bcc1ec244a1636a67ba80b0cda14ecc3)
                check_type(argname="argument arc_options", value=arc_options, expected_type=type_hints["arc_options"])
                check_type(argname="argument donut_center_options", value=donut_center_options, expected_type=type_hints["donut_center_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_options is not None:
                self._values["arc_options"] = arc_options
            if donut_center_options is not None:
                self._values["donut_center_options"] = donut_center_options

        @builtins.property
        def arc_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ArcOptionsProperty"]]:
            '''The option for define the arc of the chart shape. Valid values are as follows:.

            - ``WHOLE`` - A pie chart
            - ``SMALL`` - A small-sized donut chart
            - ``MEDIUM`` - A medium-sized donut chart
            - ``LARGE`` - A large-sized donut chart

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html#cfn-quicksight-analysis-donutoptions-arcoptions
            '''
            result = self._values.get("arc_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ArcOptionsProperty"]], result)

        @builtins.property
        def donut_center_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DonutCenterOptionsProperty"]]:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html#cfn-quicksight-analysis-donutoptions-donutcenteroptions
            '''
            result = self._values.get("donut_center_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DonutCenterOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "time_range_filter": "timeRangeFilter",
        },
    )
    class DrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CategoryDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericEqualityDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TimeRangeDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The drill down filter for the column hierarchies.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: The category type drill down filter. This filter is used for string type columns.
            :param numeric_equality_filter: The numeric equality type drill down filter. This filter is used for number type columns.
            :param time_range_filter: The time range drill down filter. This filter is used for date time columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                drill_down_filter_property = quicksight.CfnAnalysis.DrillDownFilterProperty(
                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                        category_values=["categoryValues"],
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        value=123
                    ),
                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        range_maximum="rangeMaximum",
                        range_minimum="rangeMinimum",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2b639bfd8b9b57cb0d216556557c58599e957084741c42a421498bb4109e0619)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CategoryDrillDownFilterProperty"]]:
            '''The category type drill down filter.

            This filter is used for string type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CategoryDrillDownFilterProperty"]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericEqualityDrillDownFilterProperty"]]:
            '''The numeric equality type drill down filter.

            This filter is used for number type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericEqualityDrillDownFilterProperty"]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TimeRangeDrillDownFilterProperty"]]:
            '''The time range drill down filter.

            This filter is used for date time columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TimeRangeDrillDownFilterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class DropDownControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            select_all_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param select_all_options: The configuration of the ``Select all`` options in a dropdown control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                drop_down_control_display_options_property = quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee1df67367854f2b715534d7caefd1aa8aa78d135164147b1fb8e6489f5c5f90)
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ListControlSelectAllOptionsProperty"]]:
            '''The configuration of the ``Select all`` options in a dropdown control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html#cfn-quicksight-analysis-dropdowncontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ListControlSelectAllOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html#cfn-quicksight-analysis-dropdowncontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DropDownControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.DynamicDefaultValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_value_column": "defaultValueColumn",
            "group_name_column": "groupNameColumn",
            "user_name_column": "userNameColumn",
        },
    )
    class DynamicDefaultValueProperty:
        def __init__(
            self,
            *,
            default_value_column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            group_name_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            user_name_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Defines different defaults to the users or groups based on mapping.

            :param default_value_column: The column that contains the default value of each user or group.
            :param group_name_column: The column that contains the group name.
            :param user_name_column: The column that contains the username.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                dynamic_default_value_property = quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4f5605de45adb38224161831639d47ee50e6c6f79801f8e9b906263a78273609)
                check_type(argname="argument default_value_column", value=default_value_column, expected_type=type_hints["default_value_column"])
                check_type(argname="argument group_name_column", value=group_name_column, expected_type=type_hints["group_name_column"])
                check_type(argname="argument user_name_column", value=user_name_column, expected_type=type_hints["user_name_column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_value_column": default_value_column,
            }
            if group_name_column is not None:
                self._values["group_name_column"] = group_name_column
            if user_name_column is not None:
                self._values["user_name_column"] = user_name_column

        @builtins.property
        def default_value_column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that contains the default value of each user or group.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-defaultvaluecolumn
            '''
            result = self._values.get("default_value_column")
            assert result is not None, "Required property 'default_value_column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def group_name_column(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]]:
            '''The column that contains the group name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-groupnamecolumn
            '''
            result = self._values.get("group_name_column")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]], result)

        @builtins.property
        def user_name_column(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]]:
            '''The column that contains the username.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-usernamecolumn
            '''
            result = self._values.get("user_name_column")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DynamicDefaultValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.EmptyVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
        },
    )
    class EmptyVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''An empty visual.

            Empty visuals are used in layouts but have not been configured to show any data. A new visual created in the Amazon QuickSight console is considered an ``EmptyVisual`` until a visual type is selected.

            :param data_set_identifier: The data set that is used in the empty visual. Every visual requires a dataset to render.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                empty_visual_property = quicksight.CfnAnalysis.EmptyVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__698f9e46bbc2415ac2162ea79e3668640d0fa8910595468c2d06184bdebe7835)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in the empty visual.

            Every visual requires a dataset to render.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EmptyVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.EntityProperty",
        jsii_struct_bases=[],
        name_mapping={"path": "path"},
    )
    class EntityProperty:
        def __init__(self, *, path: typing.Optional[builtins.str] = None) -> None:
            '''An object, structure, or sub-structure of an analysis, template, or dashboard.

            :param path: The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-entity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                entity_property = quicksight.CfnAnalysis.EntityProperty(
                    path="path"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d995a51c799426dc474f7c849d042aed921a34440873d1a2e669f9e32beacc32)
                check_type(argname="argument path", value=path, expected_type=type_hints["path"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if path is not None:
                self._values["path"] = path

        @builtins.property
        def path(self) -> typing.Optional[builtins.str]:
            '''The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-entity.html#cfn-quicksight-analysis-entity-path
            '''
            result = self._values.get("path")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "amount": "amount",
            "granularity": "granularity",
            "status": "status",
        },
    )
    class ExcludePeriodConfigurationProperty:
        def __init__(
            self,
            *,
            amount: jsii.Number,
            granularity: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The exclude period of ``TimeRangeFilter`` or ``RelativeDatesFilter`` .

            :param amount: The amount or number of the exclude period.
            :param granularity: The granularity or unit (day, month, year) of the exclude period.
            :param status: The status of the exclude period. Choose from the following options:. - ``ENABLED`` - ``DISABLED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                exclude_period_configuration_property = quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                    amount=123,
                    granularity="granularity",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__114a0cb3e4c23a7c145d2fa26b4433ade594d4960c89f6c5251a91093cc5aa15)
                check_type(argname="argument amount", value=amount, expected_type=type_hints["amount"])
                check_type(argname="argument granularity", value=granularity, expected_type=type_hints["granularity"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "amount": amount,
                "granularity": granularity,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def amount(self) -> jsii.Number:
            '''The amount or number of the exclude period.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-amount
            '''
            result = self._values.get("amount")
            assert result is not None, "Required property 'amount' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def granularity(self) -> builtins.str:
            '''The granularity or unit (day, month, year) of the exclude period.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-granularity
            '''
            result = self._values.get("granularity")
            assert result is not None, "Required property 'granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the exclude period. Choose from the following options:.

            - ``ENABLED``
            - ``DISABLED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExcludePeriodConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ExplicitHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class ExplicitHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :param columns: The list of columns that define the explicit hierarchy.
            :param hierarchy_id: The hierarchy ID of the explicit hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                explicit_hierarchy_property = quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__587fe3812ef51ed8b5f6c323d5997dd56553bbbe7edebcc9c837d21b89c57c16)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]]]:
            '''The list of columns that define the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExplicitHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FieldBasedTooltipProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_visibility": "aggregationVisibility",
            "tooltip_fields": "tooltipFields",
            "tooltip_title_type": "tooltipTitleType",
        },
    )
    class FieldBasedTooltipProperty:
        def __init__(
            self,
            *,
            aggregation_visibility: typing.Optional[builtins.str] = None,
            tooltip_fields: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            tooltip_title_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The setup for the detailed tooltip.

            :param aggregation_visibility: The visibility of ``Show aggregations`` .
            :param tooltip_fields: The fields configuration in the tooltip.
            :param tooltip_title_type: The type for the >tooltip title. Choose one of the following options:. - ``NONE`` : Doesn't use the primary value as the title. - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_based_tooltip_property = quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                    aggregation_visibility="aggregationVisibility",
                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            label="label",
                            visibility="visibility"
                        ),
                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            label="label",
                            visibility="visibility"
                        )
                    )],
                    tooltip_title_type="tooltipTitleType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__48b0b2e74afd936e1d9b8859ae38ad59d6b366cb7087b94422ada68e32dd81a3)
                check_type(argname="argument aggregation_visibility", value=aggregation_visibility, expected_type=type_hints["aggregation_visibility"])
                check_type(argname="argument tooltip_fields", value=tooltip_fields, expected_type=type_hints["tooltip_fields"])
                check_type(argname="argument tooltip_title_type", value=tooltip_title_type, expected_type=type_hints["tooltip_title_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if aggregation_visibility is not None:
                self._values["aggregation_visibility"] = aggregation_visibility
            if tooltip_fields is not None:
                self._values["tooltip_fields"] = tooltip_fields
            if tooltip_title_type is not None:
                self._values["tooltip_title_type"] = tooltip_title_type

        @builtins.property
        def aggregation_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of ``Show aggregations`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-aggregationvisibility
            '''
            result = self._values.get("aggregation_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_fields(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipItemProperty"]]]]:
            '''The fields configuration in the tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-tooltipfields
            '''
            result = self._values.get("tooltip_fields")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipItemProperty"]]]], result)

        @builtins.property
        def tooltip_title_type(self) -> typing.Optional[builtins.str]:
            '''The type for the >tooltip title. Choose one of the following options:.

            - ``NONE`` : Doesn't use the primary value as the title.
            - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-tooltiptitletype
            '''
            result = self._values.get("tooltip_title_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldBasedTooltipProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FieldLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "visibility": "visibility"},
    )
    class FieldLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The field label type.

            :param field_id: Indicates the field that is targeted by the field label.
            :param visibility: The visibility of the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_label_type_property = quicksight.CfnAnalysis.FieldLabelTypeProperty(
                    field_id="fieldId",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7d3a82390280b1a887fc0e8e8db34ae22b712f05dcae2850827c8911c9fc79ed)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''Indicates the field that is targeted by the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html#cfn-quicksight-analysis-fieldlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html#cfn-quicksight-analysis-fieldlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "settings": "settings",
        },
    )
    class FieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field for which you are setting the axis binding.
            :param settings: The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_series_item_property = quicksight.CfnAnalysis.FieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__076f6a76377debe6af1703c95f9245dde25a45091c7d49c14b0aec5255dd2bb6)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field for which you are setting the axis binding.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartSeriesSettingsProperty"]]:
            '''The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartSeriesSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column_sort": "columnSort", "field_sort": "fieldSort"},
    )
    class FieldSortOptionsProperty:
        def __init__(
            self,
            *,
            column_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field sort options in a chart configuration.

            :param column_sort: The sort configuration for a column that is not used in a field well.
            :param field_sort: The sort configuration for a field in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_sort_options_property = quicksight.CfnAnalysis.FieldSortOptionsProperty(
                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__673f684b8e027caca313ca74061d31a2831ede70c8f4a93b24b81c1889db8cda)
                check_type(argname="argument column_sort", value=column_sort, expected_type=type_hints["column_sort"])
                check_type(argname="argument field_sort", value=field_sort, expected_type=type_hints["field_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_sort is not None:
                self._values["column_sort"] = column_sort
            if field_sort is not None:
                self._values["field_sort"] = field_sort

        @builtins.property
        def column_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnSortProperty"]]:
            '''The sort configuration for a column that is not used in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html#cfn-quicksight-analysis-fieldsortoptions-columnsort
            '''
            result = self._values.get("column_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnSortProperty"]], result)

        @builtins.property
        def field_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortProperty"]]:
            '''The sort configuration for a field in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html#cfn-quicksight-analysis-fieldsortoptions-fieldsort
            '''
            result = self._values.get("field_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FieldSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "field_id": "fieldId"},
    )
    class FieldSortProperty:
        def __init__(self, *, direction: builtins.str, field_id: builtins.str) -> None:
            '''The sort configuration for a field in a field well.

            :param direction: The sort direction. Choose one of the following options:. - ``ASC`` : Ascending - ``DESC`` : Descending
            :param field_id: The sort configuration target field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_sort_property = quicksight.CfnAnalysis.FieldSortProperty(
                    direction="direction",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3fdb955818c91fd914646f08f145a1a047ead96005cebce79bce3ff97496f165)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "field_id": field_id,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction. Choose one of the following options:.

            - ``ASC`` : Ascending
            - ``DESC`` : Descending

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html#cfn-quicksight-analysis-fieldsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The sort configuration target field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html#cfn-quicksight-analysis-fieldsort-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FieldTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class FieldTooltipItemProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the fields.

            :param field_id: The unique ID of the field that is targeted by the tooltip.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_tooltip_item_property = quicksight.CfnAnalysis.FieldTooltipItemProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ccec3a4c7920019c1961572a212685070d153da04a08388cfa7a59b7b33259b3)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The unique ID of the field that is targeted by the tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"geospatial": "geospatial", "values": "values"},
    )
    class FilledMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well of the filled map.

            :param geospatial: The aggregated location field well of the filled map. Values are grouped by location fields.
            :param values: The aggregated color field well of a filled map. Values are aggregated based on location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_aggregated_field_wells_property = quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                    geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c00d3dee7c6f5f11389ad5a8ba6f993e0418b9d49537ec2e9704eb34ae4a431)
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The aggregated location field well of the filled map.

            Values are grouped by location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html#cfn-quicksight-analysis-filledmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The aggregated color field well of a filled map.

            Values are aggregated based on location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html#cfn-quicksight-analysis-filledmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"shape": "shape"},
    )
    class FilledMapConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            shape: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilledMapShapeConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :param shape: The conditional formatting that determines the shape of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_conditional_formatting_option_property = quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                    shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__560a02368e15f242f23e251e66070b6151756a6246570f6f49cc44d654821173)
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "shape": shape,
            }

        @builtins.property
        def shape(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapShapeConditionalFormattingProperty"]:
            '''The conditional formatting that determines the shape of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformattingoption.html#cfn-quicksight-analysis-filledmapconditionalformattingoption-shape
            '''
            result = self._values.get("shape")
            assert result is not None, "Required property 'shape' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapShapeConditionalFormattingProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class FilledMapConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilledMapConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_conditional_formatting_property = quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                        shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a006c84813344f46ea831c454e7a27466aa316ed2895d7e2f8f72450a426c71b)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "conditional_formatting_options": conditional_formatting_options,
            }

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapConditionalFormattingOptionProperty"]]]:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformatting.html#cfn-quicksight-analysis-filledmapconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            assert result is not None, "Required property 'conditional_formatting_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapConditionalFormattingOptionProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilledMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "window_options": "windowOptions",
        },
    )
    class FilledMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilledMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilledMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            window_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``FilledMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the filled map visual.
            :param sort_configuration: The sort configuration of a ``FilledMapVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param window_options: The window options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_configuration_property = quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                    field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                        filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                            geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                        base_map_style="baseMapStyle"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                        bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                            east=123,
                            north=123,
                            south=123,
                            west=123
                        ),
                        map_zoom_mode="mapZoomMode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a34bc05a8ebbeafa76f6f1976fa9c6c4dc18c69c684ea72da7420bd79f56bf53)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialMapStyleOptionsProperty"]]:
            '''The map style options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialMapStyleOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapSortConfigurationProperty"]]:
            '''The sort configuration of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialWindowOptionsProperty"]]:
            '''The window options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialWindowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilledMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filled_map_aggregated_field_wells": "filledMapAggregatedFieldWells",
        },
    )
    class FilledMapFieldWellsProperty:
        def __init__(
            self,
            *,
            filled_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilledMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``FilledMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filled_map_aggregated_field_wells: The aggregated field well of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_field_wells_property = quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                    filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                        geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__673197faa4eb12b64ba870528053501791129c84297aa9603db12a60bc1ecadd)
                check_type(argname="argument filled_map_aggregated_field_wells", value=filled_map_aggregated_field_wells, expected_type=type_hints["filled_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filled_map_aggregated_field_wells is not None:
                self._values["filled_map_aggregated_field_wells"] = filled_map_aggregated_field_wells

        @builtins.property
        def filled_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field well of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapfieldwells.html#cfn-quicksight-analysis-filledmapfieldwells-filledmapaggregatedfieldwells
            '''
            result = self._values.get("filled_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "format": "format"},
    )
    class FilledMapShapeConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ShapeConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting that determines the shape of the filled map.

            :param field_id: The field ID of the filled map shape.
            :param format: The conditional formatting that determines the background color of a filled map's shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_shape_conditional_formatting_property = quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7df3629402bf9812659649b12aa48699497c908f60b723fb8f1f38f2a54bc171)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if format is not None:
                self._values["format"] = format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the filled map shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html#cfn-quicksight-analysis-filledmapshapeconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ShapeConditionalFormatProperty"]]:
            '''The conditional formatting that determines the background color of a filled map's shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html#cfn-quicksight-analysis-filledmapshapeconditionalformatting-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ShapeConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapShapeConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilledMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"category_sort": "categorySort"},
    )
    class FilledMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FilledMapVisual`` .

            :param category_sort: The sort configuration of the location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_sort_configuration_property = quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__13c1b55f379a96e3f7a7b0573bc2be5f5f3fdc0b941dcb1f1e7baf5655545487)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapsortconfiguration.html#cfn-quicksight-analysis-filledmapsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilledMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FilledMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilledMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilledMapConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a ``FilledMapVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_visual_property = quicksight.CfnAnalysis.FilledMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                        field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                            filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                                geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                            base_map_style="baseMapStyle"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                            bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                east=123,
                                north=123,
                                south=123,
                                west=123
                            ),
                            map_zoom_mode="mapZoomMode"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    conditional_formatting=quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                            shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f2940e4c7076a403888593e877f50191e6206fa294d2e7d5d664fe94165ef16f)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapConditionalFormattingProperty"]]:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "relative_date_time": "relativeDateTime",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class FilterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            dropdown: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterListControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_date_time: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterRelativeDateTimeControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            slider: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterSliderControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_area: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The control of a filter that is used to interact with a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date filter that is used to specify date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list of buttons or boxes. This is used to select either a single value or multiple values.
            :param relative_date_time: A control from a date filter that is used to specify the relative date.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_control_property = quicksight.CfnAnalysis.FilterControlProperty(
                    date_time_picker=quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    dropdown=quicksight.CfnAnalysis.FilterDropDownControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                            select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnAnalysis.FilterListControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                            search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    relative_date_time=quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    slider=quicksight.CfnAnalysis.FilterSliderControlProperty(
                        filter_control_id="filterControlId",
                        maximum_value=123,
                        minimum_value=123,
                        source_filter_id="sourceFilterId",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    text_area=quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4c3cb232d24478e529b1aa9686a7c03ba6878982de21acf61b80372f32096f42)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument relative_date_time", value=relative_date_time, expected_type=type_hints["relative_date_time"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if relative_date_time is not None:
                self._values["relative_date_time"] = relative_date_time
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterDateTimePickerControlProperty"]]:
            '''A control from a date filter that is used to specify date and time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterDateTimePickerControlProperty"]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterDropDownControlProperty"]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterDropDownControlProperty"]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterListControlProperty"]]:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterListControlProperty"]], result)

        @builtins.property
        def relative_date_time(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterRelativeDateTimeControlProperty"]]:
            '''A control from a date filter that is used to specify the relative date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-relativedatetime
            '''
            result = self._values.get("relative_date_time")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterRelativeDateTimeControlProperty"]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterSliderControlProperty"]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterSliderControlProperty"]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterTextAreaControlProperty"]]:
            '''A control to display a text box that is used to enter multiple entries.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterTextAreaControlProperty"]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterTextFieldControlProperty"]]:
            '''A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterTextFieldControlProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control from a date filter that is used to specify date and time.

            :param filter_control_id: The ID of the ``FilterDateTimePickerControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDateTimePickerControl`` .
            :param title: The title of the ``FilterDateTimePickerControl`` .
            :param display_options: The display options of a control.
            :param type: The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:. - ``SINGLE_VALUED`` : The filter condition is a fixed date. - ``DATE_RANGE`` : The filter condition is a date time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_date_time_picker_control_property = quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a768003dd7461f8e6c87239cee01d530f48d535af623615d4cb349073cbaf151)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimePickerControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimePickerControlDisplayOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:.

            - ``SINGLE_VALUED`` : The filter condition is a fixed date.
            - ``DATE_RANGE`` : The filter condition is a date time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterDropDownControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param filter_control_id: The ID of the ``FilterDropDownControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDropDownControl`` .
            :param title: The title of the ``FilterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of the ``FilterDropDownControl`` .
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of the ``FilterDropDownControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu. - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_drop_down_control_property = quicksight.CfnAnalysis.FilterDropDownControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                        select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__67c7003271fe6e4f386ed5c2d4eaddee92eb91778f7903d26fe4323c9f1ba288)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DropDownControlDisplayOptionsProperty"]]:
            '''The display options of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DropDownControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of the ``FilterDropDownControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu.
            - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterGroupProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cross_dataset": "crossDataset",
            "filter_group_id": "filterGroupId",
            "filters": "filters",
            "scope_configuration": "scopeConfiguration",
            "status": "status",
        },
    )
    class FilterGroupProperty:
        def __init__(
            self,
            *,
            cross_dataset: builtins.str,
            filter_group_id: builtins.str,
            filters: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterProperty", typing.Dict[builtins.str, typing.Any]]]]],
            scope_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A grouping of individual filters. Filter groups are applied to the same group of visuals.

            For more information, see `Adding filter conditions (group filters) with AND and OR operators <https://docs.aws.amazon.com/quicksight/latest/user/add-a-compound-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :param cross_dataset: The filter new feature which can apply filter group to all data sets. Choose one of the following options:. - ``ALL_DATASETS`` - ``SINGLE_DATASET``
            :param filter_group_id: The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.
            :param filters: The list of filters that are present in a ``FilterGroup`` .
            :param scope_configuration: The configuration that specifies what scope to apply to a ``FilterGroup`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param status: The status of the ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_group_property = quicksight.CfnAnalysis.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnAnalysis.FilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnAnalysis.NumericRangeFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            parameter_name="parameterName",
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnAnalysis.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection"
                            )],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnAnalysis.FilterScopeConfigurationProperty(
                        selected_sheets=quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
                
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1013761feb5d36c4bbdbaebdac32aa77153fbece03a2db25453e0fe2e7ee6e02)
                check_type(argname="argument cross_dataset", value=cross_dataset, expected_type=type_hints["cross_dataset"])
                check_type(argname="argument filter_group_id", value=filter_group_id, expected_type=type_hints["filter_group_id"])
                check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
                check_type(argname="argument scope_configuration", value=scope_configuration, expected_type=type_hints["scope_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "cross_dataset": cross_dataset,
                "filter_group_id": filter_group_id,
                "filters": filters,
                "scope_configuration": scope_configuration,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def cross_dataset(self) -> builtins.str:
            '''The filter new feature which can apply filter group to all data sets. Choose one of the following options:.

            - ``ALL_DATASETS``
            - ``SINGLE_DATASET``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-crossdataset
            '''
            result = self._values.get("cross_dataset")
            assert result is not None, "Required property 'cross_dataset' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filter_group_id(self) -> builtins.str:
            '''The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-filtergroupid
            '''
            result = self._values.get("filter_group_id")
            assert result is not None, "Required property 'filter_group_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filters(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterProperty"]]]:
            '''The list of filters that are present in a ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-filters
            '''
            result = self._values.get("filters")
            assert result is not None, "Required property 'filters' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterProperty"]]], result)

        @builtins.property
        def scope_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterScopeConfigurationProperty"]:
            '''The configuration that specifies what scope to apply to a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-scopeconfiguration
            '''
            result = self._values.get("scope_configuration")
            assert result is not None, "Required property 'scope_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterScopeConfigurationProperty"], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class FilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of filter configurations.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_list_configuration_property = quicksight.CfnAnalysis.FilterListConfigurationProperty(
                    match_operator="matchOperator",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__972ab0882c9219fc5173a68a22ff040c9e5a5528557675015edc78c235aedf1a)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterListControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :param filter_control_id: The ID of the ``FilterListControl`` .
            :param source_filter_id: The source filter ID of the ``FilterListControl`` .
            :param title: The title of the ``FilterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``FilterListControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from the list. - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_list_control_property = quicksight.CfnAnalysis.FilterListControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                        search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c1a527c0bcc66567021b2a208b50ff883a8c6951a7229e7b849f3ff67ce95c22)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ListControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ListControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterListControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from the list.
            - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_field_options": "selectedFieldOptions",
            "selected_fields": "selectedFields",
        },
    )
    class FilterOperationSelectedFieldsConfigurationProperty:
        def __init__(
            self,
            *,
            selected_field_options: typing.Optional[builtins.str] = None,
            selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of selected fields in the ``CustomActionFilterOperation`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_field_options: A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` . Valid values are defined as follows: - ``ALL_FIELDS`` : Applies the filter operation to all fields.
            :param selected_fields: Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_operation_selected_fields_configuration_property = quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                    selected_field_options="selectedFieldOptions",
                    selected_fields=["selectedFields"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__caa129f04fc5d531b76e0b33dd594ea54720adfff44a723c483877e96298b33a)
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
                check_type(argname="argument selected_fields", value=selected_fields, expected_type=type_hints["selected_fields"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options
            if selected_fields is not None:
                self._values["selected_fields"] = selected_fields

        @builtins.property
        def selected_field_options(self) -> typing.Optional[builtins.str]:
            '''A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` .

            Valid values are defined as follows:

            - ``ALL_FIELDS`` : Applies the filter operation to all fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-analysis-filteroperationselectedfieldsconfiguration-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def selected_fields(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-analysis-filteroperationselectedfieldsconfiguration-selectedfields
            '''
            result = self._values.get("selected_fields")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationSelectedFieldsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "same_sheet_target_visual_configuration": "sameSheetTargetVisualConfiguration",
        },
    )
    class FilterOperationTargetVisualsConfigurationProperty:
        def __init__(
            self,
            *,
            same_sheet_target_visual_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SameSheetTargetVisualConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param same_sheet_target_visual_configuration: The configuration of the same-sheet target visuals that you want to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationtargetvisualsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_operation_target_visuals_configuration_property = quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                        target_visual_options="targetVisualOptions",
                        target_visuals=["targetVisuals"]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8b729ca4f3b90a9cd369347f0f6be0c621174493d13ecc544a235dce81ea561b)
                check_type(argname="argument same_sheet_target_visual_configuration", value=same_sheet_target_visual_configuration, expected_type=type_hints["same_sheet_target_visual_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if same_sheet_target_visual_configuration is not None:
                self._values["same_sheet_target_visual_configuration"] = same_sheet_target_visual_configuration

        @builtins.property
        def same_sheet_target_visual_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SameSheetTargetVisualConfigurationProperty"]]:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-analysis-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
            '''
            result = self._values.get("same_sheet_target_visual_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SameSheetTargetVisualConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationTargetVisualsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "numeric_range_filter": "numericRangeFilter",
            "relative_dates_filter": "relativeDatesFilter",
            "time_equality_filter": "timeEqualityFilter",
            "time_range_filter": "timeRangeFilter",
            "top_bottom_filter": "topBottomFilter",
        },
    )
    class FilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CategoryFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_dates_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RelativeDatesFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TimeEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TimeRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TopBottomFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''With a ``Filter`` , you can remove portions of data from a particular visual or view.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: A ``CategoryFilter`` filters text values. For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .
            :param numeric_equality_filter: A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.
            :param numeric_range_filter: A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.
            :param relative_dates_filter: A ``RelativeDatesFilter`` filters date values that are relative to a given date.
            :param time_equality_filter: A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.
            :param time_range_filter: A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.
            :param top_bottom_filter: A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_property = quicksight.CfnAnalysis.FilterProperty(
                    category_filter=quicksight.CfnAnalysis.CategoryFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                            custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_value="categoryValue",
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions"
                            ),
                            custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            ),
                            filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                                match_operator="matchOperator",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            )
                        ),
                        filter_id="filterId"
                    ),
                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions",
                        value=123
                    ),
                    numeric_range_filter=quicksight.CfnAnalysis.NumericRangeFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        select_all_options="selectAllOptions"
                    ),
                    relative_dates_filter=quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                        anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                            anchor_option="anchorOption",
                            parameter_name="parameterName"
                        ),
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                        relative_date_type="relativeDateType",
                        time_granularity="timeGranularity",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        minimum_granularity="minimumGranularity",
                        parameter_name="parameterName",
                        relative_date_value=123
                    ),
                    time_equality_filter=quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        parameter_name="parameterName",
                        time_granularity="timeGranularity",
                        value="value"
                    ),
                    time_range_filter=quicksight.CfnAnalysis.TimeRangeFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        time_granularity="timeGranularity"
                    ),
                    top_bottom_filter=quicksight.CfnAnalysis.TopBottomFilterProperty(
                        aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            sort_direction="sortDirection"
                        )],
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        limit=123,
                        parameter_name="parameterName",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__59c5ea895762382a2c6066a58d8fe59e210f46c3f423e058706ce9309167e265)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument numeric_range_filter", value=numeric_range_filter, expected_type=type_hints["numeric_range_filter"])
                check_type(argname="argument relative_dates_filter", value=relative_dates_filter, expected_type=type_hints["relative_dates_filter"])
                check_type(argname="argument time_equality_filter", value=time_equality_filter, expected_type=type_hints["time_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
                check_type(argname="argument top_bottom_filter", value=top_bottom_filter, expected_type=type_hints["top_bottom_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if numeric_range_filter is not None:
                self._values["numeric_range_filter"] = numeric_range_filter
            if relative_dates_filter is not None:
                self._values["relative_dates_filter"] = relative_dates_filter
            if time_equality_filter is not None:
                self._values["time_equality_filter"] = time_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter
            if top_bottom_filter is not None:
                self._values["top_bottom_filter"] = top_bottom_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CategoryFilterProperty"]]:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CategoryFilterProperty"]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericEqualityFilterProperty"]]:
            '''A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericEqualityFilterProperty"]], result)

        @builtins.property
        def numeric_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericRangeFilterProperty"]]:
            '''A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-numericrangefilter
            '''
            result = self._values.get("numeric_range_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericRangeFilterProperty"]], result)

        @builtins.property
        def relative_dates_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RelativeDatesFilterProperty"]]:
            '''A ``RelativeDatesFilter`` filters date values that are relative to a given date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-relativedatesfilter
            '''
            result = self._values.get("relative_dates_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RelativeDatesFilterProperty"]], result)

        @builtins.property
        def time_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TimeEqualityFilterProperty"]]:
            '''A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-timeequalityfilter
            '''
            result = self._values.get("time_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TimeEqualityFilterProperty"]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TimeRangeFilterProperty"]]:
            '''A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TimeRangeFilterProperty"]], result)

        @builtins.property
        def top_bottom_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TopBottomFilterProperty"]]:
            '''A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-topbottomfilter
            '''
            result = self._values.get("top_bottom_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TopBottomFilterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterRelativeDateTimeControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control from a date filter that is used to specify the relative date.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_relative_date_time_control_property = quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b3d3c00aca1ced0c42c779d64205335ecd63c001c37e7ed55c39995179428443)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterRelativeDateTimeControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"selected_sheets": "selectedSheets"},
    )
    class FilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            selected_sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The scope configuration for a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_sheets: The configuration for applying a filter to specific sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_scope_configuration_property = quicksight.CfnAnalysis.FilterScopeConfigurationProperty(
                    selected_sheets=quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                        sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                            scope="scope",
                            sheet_id="sheetId",
                
                            # the properties below are optional
                            visual_ids=["visualIds"]
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__15a4d07c882611479f6dc77f59df63d1b9565cebfe918c6ac0bfd0d1c6da9738)
                check_type(argname="argument selected_sheets", value=selected_sheets, expected_type=type_hints["selected_sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_sheets is not None:
                self._values["selected_sheets"] = selected_sheets

        @builtins.property
        def selected_sheets(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty"]]:
            '''The configuration for applying a filter to specific sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterscopeconfiguration.html#cfn-quicksight-analysis-filterscopeconfiguration-selectedsheets
            '''
            result = self._values.get("selected_sheets")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class FilterSelectableValuesProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param values: The values that are used in the ``FilterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_selectable_values_property = quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5645326b212216a40604f5df4b00d1ab022267df9114375d3e64a2c45c311a87)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in the ``FilterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterselectablevalues.html#cfn-quicksight-analysis-filterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "source_filter_id": "sourceFilterId",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterSliderControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            source_filter_id: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param filter_control_id: The ID of the ``FilterSliderControl`` .
            :param maximum_value: The smaller value that is displayed at the left of the slider.
            :param minimum_value: The larger value that is displayed at the right of the slider.
            :param source_filter_id: The source filter ID of the ``FilterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into.
            :param title: The title of the ``FilterSliderControl`` .
            :param display_options: The display options of a control.
            :param type: The type of ``FilterSliderControl`` . Choose one of the following options:. - ``SINGLE_POINT`` : Filter against(equals) a single data point. - ``RANGE`` : Filter data that is in a specified range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_slider_control_property = quicksight.CfnAnalysis.FilterSliderControlProperty(
                    filter_control_id="filterControlId",
                    maximum_value=123,
                    minimum_value=123,
                    source_filter_id="sourceFilterId",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__44dd41f0c24cc4dafa4990db41f8e214b6707201bbd6c0b6e8dc724ffd02180e)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "source_filter_id": source_filter_id,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SliderControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SliderControlDisplayOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterSliderControl`` . Choose one of the following options:.

            - ``SINGLE_POINT`` : Filter against(equals) a single data point.
            - ``RANGE`` : Filter data that is in a specified range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class FilterTextAreaControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_text_area_control_property = quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0737648eb751a23589646bee2cc24d67dd2bfa8996fe13e6022e400c15b22166)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextAreaControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextAreaControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FilterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterTextFieldControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param filter_control_id: The ID of the ``FilterTextFieldControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextFieldControl`` .
            :param title: The title of the ``FilterTextFieldControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_text_field_control_property = quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__161b073d73e90502973780845bb9cd211f77a6e3ace7fc09a1eada5d9c664c8c)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextFieldControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextFieldControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FontConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_color": "fontColor",
            "font_decoration": "fontDecoration",
            "font_size": "fontSize",
            "font_style": "fontStyle",
            "font_weight": "fontWeight",
        },
    )
    class FontConfigurationProperty:
        def __init__(
            self,
            *,
            font_color: typing.Optional[builtins.str] = None,
            font_decoration: typing.Optional[builtins.str] = None,
            font_size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FontSizeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_style: typing.Optional[builtins.str] = None,
            font_weight: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FontWeightProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configures the display properties of the given text.

            :param font_color: Determines the color of the text.
            :param font_decoration: Determines the appearance of decorative lines on the text.
            :param font_size: The option that determines the text display size.
            :param font_style: Determines the text display face that is inherited by the given font family.
            :param font_weight: The option that determines the text display weight, or boldness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                font_configuration_property = quicksight.CfnAnalysis.FontConfigurationProperty(
                    font_color="fontColor",
                    font_decoration="fontDecoration",
                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                        relative="relative"
                    ),
                    font_style="fontStyle",
                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eca0537099b1f6da5447f52742252f25f5ed7839c045973575d88ce9e7f55134)
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_decoration", value=font_decoration, expected_type=type_hints["font_decoration"])
                check_type(argname="argument font_size", value=font_size, expected_type=type_hints["font_size"])
                check_type(argname="argument font_style", value=font_style, expected_type=type_hints["font_style"])
                check_type(argname="argument font_weight", value=font_weight, expected_type=type_hints["font_weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_decoration is not None:
                self._values["font_decoration"] = font_decoration
            if font_size is not None:
                self._values["font_size"] = font_size
            if font_style is not None:
                self._values["font_style"] = font_style
            if font_weight is not None:
                self._values["font_weight"] = font_weight

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_decoration(self) -> typing.Optional[builtins.str]:
            '''Determines the appearance of decorative lines on the text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontdecoration
            '''
            result = self._values.get("font_decoration")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_size(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontSizeProperty"]]:
            '''The option that determines the text display size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontsize
            '''
            result = self._values.get("font_size")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontSizeProperty"]], result)

        @builtins.property
        def font_style(self) -> typing.Optional[builtins.str]:
            '''Determines the text display face that is inherited by the given font family.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontstyle
            '''
            result = self._values.get("font_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_weight(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontWeightProperty"]]:
            '''The option that determines the text display weight, or boldness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontweight
            '''
            result = self._values.get("font_weight")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontWeightProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FontSizeProperty",
        jsii_struct_bases=[],
        name_mapping={"relative": "relative"},
    )
    class FontSizeProperty:
        def __init__(self, *, relative: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display size.

            :param relative: The lexical name for the text size, proportional to its surrounding context.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontsize.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                font_size_property = quicksight.CfnAnalysis.FontSizeProperty(
                    relative="relative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0970831d8ef4f7f4cbd43a9c305e917fa21d40aa3831e3c36f020d5ddbb4235a)
                check_type(argname="argument relative", value=relative, expected_type=type_hints["relative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if relative is not None:
                self._values["relative"] = relative

        @builtins.property
        def relative(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the text size, proportional to its surrounding context.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontsize.html#cfn-quicksight-analysis-fontsize-relative
            '''
            result = self._values.get("relative")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontSizeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FontWeightProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name"},
    )
    class FontWeightProperty:
        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display weight, or boldness.

            :param name: The lexical name for the level of boldness of the text display.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontweight.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                font_weight_property = quicksight.CfnAnalysis.FontWeightProperty(
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__21060d642c9ff1fa67e4e935741dfef4ccf59927b6527e0c51065b1bd3722fab)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the level of boldness of the text display.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontweight.html#cfn-quicksight-analysis-fontweight-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontWeightProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ForecastComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "custom_seasonality_value": "customSeasonalityValue",
            "lower_boundary": "lowerBoundary",
            "name": "name",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
            "value": "value",
        },
    )
    class ForecastComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            custom_seasonality_value: typing.Optional[jsii.Number] = None,
            lower_boundary: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[builtins.str] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param custom_seasonality_value: The custom seasonality value setup of a forecast computation.
            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param name: The name of a computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``AUTOMATIC`` - ``CUSTOM`` : Checks the custom seasonality value.
            :param upper_boundary: The upper boundary setup of a forecast computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                forecast_computation_property = quicksight.CfnAnalysis.ForecastComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    custom_seasonality_value=123,
                    lower_boundary=123,
                    name="name",
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality="seasonality",
                    upper_boundary=123,
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f3fbc6fee55f7858148a11713f5af8fc48d974f8d9b2481386a82f9c51a44430)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument custom_seasonality_value", value=custom_seasonality_value, expected_type=type_hints["custom_seasonality_value"])
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if custom_seasonality_value is not None:
                self._values["custom_seasonality_value"] = custom_seasonality_value
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if name is not None:
                self._values["name"] = name
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"], result)

        @builtins.property
        def custom_seasonality_value(self) -> typing.Optional[jsii.Number]:
            '''The custom seasonality value setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-customseasonalityvalue
            '''
            result = self._values.get("custom_seasonality_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[builtins.str]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``AUTOMATIC``
            - ``CUSTOM`` : Checks the custom seasonality value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ForecastConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast_properties": "forecastProperties",
            "scenario": "scenario",
        },
    )
    class ForecastConfigurationProperty:
        def __init__(
            self,
            *,
            forecast_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TimeBasedForecastPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ForecastScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast configuration that is used in a line chart's display properties.

            :param forecast_properties: The forecast properties setup of a forecast in the line chart.
            :param scenario: The forecast scenario of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                forecast_configuration_property = quicksight.CfnAnalysis.ForecastConfigurationProperty(
                    forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                        lower_boundary=123,
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality=123,
                        upper_boundary=123
                    ),
                    scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                        what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                            date="date",
                            value=123
                        ),
                        what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                            end_date="endDate",
                            start_date="startDate",
                            value=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e2f9fafe39d2a4d10b7fc7fb52d3bc976349cc1d859d2cc8e3d7d35be12ab4e)
                check_type(argname="argument forecast_properties", value=forecast_properties, expected_type=type_hints["forecast_properties"])
                check_type(argname="argument scenario", value=scenario, expected_type=type_hints["scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast_properties is not None:
                self._values["forecast_properties"] = forecast_properties
            if scenario is not None:
                self._values["scenario"] = scenario

        @builtins.property
        def forecast_properties(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TimeBasedForecastPropertiesProperty"]]:
            '''The forecast properties setup of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html#cfn-quicksight-analysis-forecastconfiguration-forecastproperties
            '''
            result = self._values.get("forecast_properties")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TimeBasedForecastPropertiesProperty"]], result)

        @builtins.property
        def scenario(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ForecastScenarioProperty"]]:
            '''The forecast scenario of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html#cfn-quicksight-analysis-forecastconfiguration-scenario
            '''
            result = self._values.get("scenario")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ForecastScenarioProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ForecastScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "what_if_point_scenario": "whatIfPointScenario",
            "what_if_range_scenario": "whatIfRangeScenario",
        },
    )
    class ForecastScenarioProperty:
        def __init__(
            self,
            *,
            what_if_point_scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WhatIfPointScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            what_if_range_scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WhatIfRangeScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast scenario of a forecast in the line chart.

            :param what_if_point_scenario: The what-if analysis forecast setup with the target date.
            :param what_if_range_scenario: The what-if analysis forecast setup with the date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                forecast_scenario_property = quicksight.CfnAnalysis.ForecastScenarioProperty(
                    what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                        date="date",
                        value=123
                    ),
                    what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                        end_date="endDate",
                        start_date="startDate",
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__326187016a2f3707ec229cbe9b61b7400c935cd851e54347be58ad4bda2449ee)
                check_type(argname="argument what_if_point_scenario", value=what_if_point_scenario, expected_type=type_hints["what_if_point_scenario"])
                check_type(argname="argument what_if_range_scenario", value=what_if_range_scenario, expected_type=type_hints["what_if_range_scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if what_if_point_scenario is not None:
                self._values["what_if_point_scenario"] = what_if_point_scenario
            if what_if_range_scenario is not None:
                self._values["what_if_range_scenario"] = what_if_range_scenario

        @builtins.property
        def what_if_point_scenario(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WhatIfPointScenarioProperty"]]:
            '''The what-if analysis forecast setup with the target date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html#cfn-quicksight-analysis-forecastscenario-whatifpointscenario
            '''
            result = self._values.get("what_if_point_scenario")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WhatIfPointScenarioProperty"]], result)

        @builtins.property
        def what_if_range_scenario(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WhatIfRangeScenarioProperty"]]:
            '''The what-if analysis forecast setup with the date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html#cfn-quicksight-analysis-forecastscenario-whatifrangescenario
            '''
            result = self._values.get("what_if_range_scenario")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WhatIfRangeScenarioProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format_configuration": "dateTimeFormatConfiguration",
            "number_format_configuration": "numberFormatConfiguration",
            "string_format_configuration": "stringFormatConfiguration",
        },
    )
    class FormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            string_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for all types of field.

            :param date_time_format_configuration: Formatting configuration for ``DateTime`` fields.
            :param number_format_configuration: Formatting configuration for number fields.
            :param string_format_configuration: Formatting configuration for string fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                format_configuration_property = quicksight.CfnAnalysis.FormatConfigurationProperty(
                    date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec245ad43450ee63f8e0cb2df971854f14eb5c180b253df2f0cbb03f743ccd49)
                check_type(argname="argument date_time_format_configuration", value=date_time_format_configuration, expected_type=type_hints["date_time_format_configuration"])
                check_type(argname="argument number_format_configuration", value=number_format_configuration, expected_type=type_hints["number_format_configuration"])
                check_type(argname="argument string_format_configuration", value=string_format_configuration, expected_type=type_hints["string_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format_configuration is not None:
                self._values["date_time_format_configuration"] = date_time_format_configuration
            if number_format_configuration is not None:
                self._values["number_format_configuration"] = number_format_configuration
            if string_format_configuration is not None:
                self._values["string_format_configuration"] = string_format_configuration

        @builtins.property
        def date_time_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeFormatConfigurationProperty"]]:
            '''Formatting configuration for ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-datetimeformatconfiguration
            '''
            result = self._values.get("date_time_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeFormatConfigurationProperty"]], result)

        @builtins.property
        def number_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumberFormatConfigurationProperty"]]:
            '''Formatting configuration for number fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-numberformatconfiguration
            '''
            result = self._values.get("number_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumberFormatConfigurationProperty"]], result)

        @builtins.property
        def string_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringFormatConfigurationProperty"]]:
            '''Formatting configuration for string fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-stringformatconfiguration
            '''
            result = self._values.get("string_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class FreeFormLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configuration options for the canvas of a free-form layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_canvas_size_options_property = quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f39e28bd8b351299a6f873cb62804157ed1cd4e353fbae6211d912edbbfe6784)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty"]]:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutcanvassizeoptions.html#cfn-quicksight-analysis-freeformlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class FreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a free-form layout.

            :param elements: The elements that are included in a free-form layout.
            :param canvas_size_options: ``CfnAnalysis.FreeFormLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_configuration_property = quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0820d819c37605ff214519777bf51c00a41824121315b9ad5901d8ab2fe6b117)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutElementProperty"]]]:
            '''The elements that are included in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html#cfn-quicksight-analysis-freeformlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutElementProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty"]]:
            '''``CfnAnalysis.FreeFormLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html#cfn-quicksight-analysis-freeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBackgroundStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The background color of a free-form layout element.
            :param visibility: The background visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_element_background_style_property = quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__14247388c2e38abd374d6cd6ba7357b3316c8c1f769110415a3052006580fc9e)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The background color of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-analysis-freeformlayoutelementbackgroundstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The background visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-analysis-freeformlayoutelementbackgroundstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBackgroundStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBorderStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The border color of a free-form layout element.
            :param visibility: The border visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_element_border_style_property = quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__32722560d57b817821a628637559ec1961494aed9cad7106e19506430140cf93)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The border color of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html#cfn-quicksight-analysis-freeformlayoutelementborderstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The border visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html#cfn-quicksight-analysis-freeformlayoutelementborderstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBorderStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FreeFormLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "element_id": "elementId",
            "element_type": "elementType",
            "height": "height",
            "width": "width",
            "x_axis_location": "xAxisLocation",
            "y_axis_location": "yAxisLocation",
            "background_style": "backgroundStyle",
            "border_style": "borderStyle",
            "loading_animation": "loadingAnimation",
            "rendering_rules": "renderingRules",
            "selected_border_style": "selectedBorderStyle",
            "visibility": "visibility",
        },
    )
    class FreeFormLayoutElementProperty:
        def __init__(
            self,
            *,
            element_id: builtins.str,
            element_type: builtins.str,
            height: builtins.str,
            width: builtins.str,
            x_axis_location: builtins.str,
            y_axis_location: builtins.str,
            background_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            border_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            loading_animation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LoadingAnimationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rendering_rules: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SheetElementRenderingRuleProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_border_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An element within a free-form layout.

            :param element_id: A unique identifier for an element within a free-form layout.
            :param element_type: The type of element.
            :param height: The height of an element within a free-form layout.
            :param width: The width of an element within a free-form layout.
            :param x_axis_location: The x-axis coordinate of the element.
            :param y_axis_location: The y-axis coordinate of the element.
            :param background_style: The background style configuration of a free-form layout element.
            :param border_style: The border style configuration of a free-form layout element.
            :param loading_animation: The loading animation configuration of a free-form layout element.
            :param rendering_rules: The rendering rules that determine when an element should be displayed within a free-form layout.
            :param selected_border_style: The border style configuration of a free-form layout element. This border style is used when the element is selected.
            :param visibility: The visibility of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_element_property = quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                    element_id="elementId",
                    element_type="elementType",
                    height="height",
                    width="width",
                    x_axis_location="xAxisLocation",
                    y_axis_location="yAxisLocation",
                
                    # the properties below are optional
                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                        visibility="visibility"
                    ),
                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                            visibility="visibility"
                        ),
                        expression="expression"
                    )],
                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75f2de2fedaf2faed6b09ab588962c611cc5333909395bdb6e59ed58fba7cb8b)
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
                check_type(argname="argument x_axis_location", value=x_axis_location, expected_type=type_hints["x_axis_location"])
                check_type(argname="argument y_axis_location", value=y_axis_location, expected_type=type_hints["y_axis_location"])
                check_type(argname="argument background_style", value=background_style, expected_type=type_hints["background_style"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument loading_animation", value=loading_animation, expected_type=type_hints["loading_animation"])
                check_type(argname="argument rendering_rules", value=rendering_rules, expected_type=type_hints["rendering_rules"])
                check_type(argname="argument selected_border_style", value=selected_border_style, expected_type=type_hints["selected_border_style"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "element_id": element_id,
                "element_type": element_type,
                "height": height,
                "width": width,
                "x_axis_location": x_axis_location,
                "y_axis_location": y_axis_location,
            }
            if background_style is not None:
                self._values["background_style"] = background_style
            if border_style is not None:
                self._values["border_style"] = border_style
            if loading_animation is not None:
                self._values["loading_animation"] = loading_animation
            if rendering_rules is not None:
                self._values["rendering_rules"] = rendering_rules
            if selected_border_style is not None:
                self._values["selected_border_style"] = selected_border_style
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def height(self) -> builtins.str:
            '''The height of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-height
            '''
            result = self._values.get("height")
            assert result is not None, "Required property 'height' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def width(self) -> builtins.str:
            '''The width of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-width
            '''
            result = self._values.get("width")
            assert result is not None, "Required property 'width' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def x_axis_location(self) -> builtins.str:
            '''The x-axis coordinate of the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-xaxislocation
            '''
            result = self._values.get("x_axis_location")
            assert result is not None, "Required property 'x_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def y_axis_location(self) -> builtins.str:
            '''The y-axis coordinate of the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-yaxislocation
            '''
            result = self._values.get("y_axis_location")
            assert result is not None, "Required property 'y_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def background_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty"]]:
            '''The background style configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-backgroundstyle
            '''
            result = self._values.get("background_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty"]], result)

        @builtins.property
        def border_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutElementBorderStyleProperty"]]:
            '''The border style configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutElementBorderStyleProperty"]], result)

        @builtins.property
        def loading_animation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LoadingAnimationProperty"]]:
            '''The loading animation configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-loadinganimation
            '''
            result = self._values.get("loading_animation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LoadingAnimationProperty"]], result)

        @builtins.property
        def rendering_rules(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetElementRenderingRuleProperty"]]]]:
            '''The rendering rules that determine when an element should be displayed within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-renderingrules
            '''
            result = self._values.get("rendering_rules")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetElementRenderingRuleProperty"]]]], result)

        @builtins.property
        def selected_border_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutElementBorderStyleProperty"]]:
            '''The border style configuration of a free-form layout element.

            This border style is used when the element is selected.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-selectedborderstyle
            '''
            result = self._values.get("selected_border_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutElementBorderStyleProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"optimized_view_port_width": "optimizedViewPortWidth"},
    )
    class FreeFormLayoutScreenCanvasSizeOptionsProperty:
        def __init__(self, *, optimized_view_port_width: builtins.str) -> None:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_screen_canvas_size_options_property = quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__64329f3129161ae065a9e56b66f5070fb3ba6e6635b21cb2d3d1ae3ce4d4a7b5)
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "optimized_view_port_width": optimized_view_port_width,
            }

        @builtins.property
        def optimized_view_port_width(self) -> builtins.str:
            '''The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            assert result is not None, "Required property 'optimized_view_port_width' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"elements": "elements"},
    )
    class FreeFormSectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The free-form layout configuration of a section.

            :param elements: The elements that are included in the free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformsectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_section_layout_configuration_property = quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4c415f365825039e9a786921c64e912006ae7c59f0a229ec10215ab563607ebc)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutElementProperty"]]]:
            '''The elements that are included in the free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformsectionlayoutconfiguration.html#cfn-quicksight-analysis-freeformsectionlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutElementProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormSectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "values": "values"},
    )
    class FunnelChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :param category: The category field wells of a funnel chart. Values are grouped by category fields.
            :param values: The value field wells of a funnel chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3d3badd12a5e54bc129074eb33e6bcd605f6c49e871a3b36c54d393381db8202)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The category field wells of a funnel chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html#cfn-quicksight-analysis-funnelchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a funnel chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html#cfn-quicksight-analysis-funnelchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FunnelChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "data_label_options": "dataLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class FunnelChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FunnelChartDataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FunnelChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FunnelChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``FunnelChartVisual`` .

            :param category_label_options: The label options of the categories that are displayed in a ``FunnelChartVisual`` .
            :param data_label_options: The options that determine the presentation of the data labels.
            :param field_wells: The field well configuration of a ``FunnelChartVisual`` .
            :param sort_configuration: The sort configuration of a ``FunnelChartVisual`` .
            :param tooltip: The tooltip configuration of a ``FunnelChartVisual`` .
            :param value_label_options: The label options for the values that are displayed in a ``FunnelChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_configuration_property = quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        label_color="labelColor",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_data_label_style="measureDataLabelStyle",
                        measure_label_visibility="measureLabelVisibility",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                        funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0586bd91f4fc22e17d331e79dab71d3ee8daebc8bb9d49ec9da27dd196626af1)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument data_label_options", value=data_label_options, expected_type=type_hints["data_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if data_label_options is not None:
                self._values["data_label_options"] = data_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the categories that are displayed in a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FunnelChartDataLabelOptionsProperty"]]:
            '''The options that determine the presentation of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-datalabeloptions
            '''
            result = self._values.get("data_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FunnelChartDataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FunnelChartFieldWellsProperty"]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FunnelChartFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FunnelChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FunnelChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options for the values that are displayed in a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The visual palette configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "label_color": "labelColor",
            "label_font_configuration": "labelFontConfiguration",
            "measure_data_label_style": "measureDataLabelStyle",
            "measure_label_visibility": "measureLabelVisibility",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class FunnelChartDataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            measure_data_label_style: typing.Optional[builtins.str] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: The visibility of the category labels within the data labels.
            :param label_color: The color of the data label text.
            :param label_font_configuration: The font configuration for the data labels. Only the ``FontSize`` attribute of the font configuration is used for data labels.
            :param measure_data_label_style: Determines the style of the metric labels.
            :param measure_label_visibility: The visibility of the measure labels within the data labels.
            :param position: Determines the positioning of the data label relative to a section of the funnel.
            :param visibility: The visibility option that determines if data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_data_label_options_property = quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    label_color="labelColor",
                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_data_label_style="measureDataLabelStyle",
                    measure_label_visibility="measureLabelVisibility",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e376186a38e2ee7f52d43bdd38de16d9604a099e845a2dfd0a66d0860f5768fc)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_data_label_style", value=measure_data_label_style, expected_type=type_hints["measure_data_label_style"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_data_label_style is not None:
                self._values["measure_data_label_style"] = measure_data_label_style
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the category labels within the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''The color of the data label text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The font configuration for the data labels.

            Only the ``FontSize`` attribute of the font configuration is used for data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def measure_data_label_style(self) -> typing.Optional[builtins.str]:
            '''Determines the style of the metric labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-measuredatalabelstyle
            '''
            result = self._values.get("measure_data_label_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the measure labels within the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the positioning of the data label relative to a section of the funnel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility option that determines if data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartDataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FunnelChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "funnel_chart_aggregated_field_wells": "funnelChartAggregatedFieldWells",
        },
    )
    class FunnelChartFieldWellsProperty:
        def __init__(
            self,
            *,
            funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FunnelChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param funnel_chart_aggregated_field_wells: The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_field_wells_property = quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                    funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__883e5cfe3c4de46ec83e6073bc7512fc214b9cf8c7a175db885fdfd07ce4c1c0)
                check_type(argname="argument funnel_chart_aggregated_field_wells", value=funnel_chart_aggregated_field_wells, expected_type=type_hints["funnel_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if funnel_chart_aggregated_field_wells is not None:
                self._values["funnel_chart_aggregated_field_wells"] = funnel_chart_aggregated_field_wells

        @builtins.property
        def funnel_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FunnelChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartfieldwells.html#cfn-quicksight-analysis-funnelchartfieldwells-funnelchartaggregatedfieldwells
            '''
            result = self._values.get("funnel_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FunnelChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class FunnelChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :param category_items_limit: The limit on the number of categories displayed.
            :param category_sort: The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_sort_configuration_property = quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ddb48523ec08b07a9d42bbd7c00cd21ca4233d19a76b2ad2cc2209bd46235119)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html#cfn-quicksight-analysis-funnelchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html#cfn-quicksight-analysis-funnelchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.FunnelChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FunnelChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FunnelChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``FunnelChartVisual`` .
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_visual_property = quicksight.CfnAnalysis.FunnelChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            label_color="labelColor",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_data_label_style="measureDataLabelStyle",
                            measure_label_visibility="measureLabelVisibility",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                            funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__314f45fa1deac54c231e26c2220b95807d52217fc36eea8407228458c0bd6f23)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FunnelChartConfigurationProperty"]]:
            '''The configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FunnelChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class GaugeChartArcConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :param foreground_color: The conditional formatting of the arc foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartarcconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_arc_conditional_formatting_property = quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                    foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a6b905d0cf4d9ffd025d354470b906536e4720a00955efd28e0d199e3511175)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the arc foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartarcconditionalformatting.html#cfn-quicksight-analysis-gaugechartarcconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartArcConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"arc": "arc", "primary_value": "primaryValue"},
    )
    class GaugeChartConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GaugeChartArcConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :param arc: The options that determine the presentation of the arc of a ``GaugeChartVisual`` .
            :param primary_value: The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_option_property = quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                    arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2681bbcfe145fb50345dd461958c68ff8bfa32b20618d0a64772d09e3c8920e0)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if primary_value is not None:
                self._values["primary_value"] = primary_value

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartArcConditionalFormattingProperty"]]:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html#cfn-quicksight-analysis-gaugechartconditionalformattingoption-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartArcConditionalFormattingProperty"]], result)

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html#cfn-quicksight-analysis-gaugechartconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class GaugeChartConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GaugeChartConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_property = quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                        arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93630b36e8e6739721b8874d939377bb2ed1c85ac6a2677c372f0bc413587e60)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformatting.html#cfn-quicksight-analysis-gaugechartconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GaugeChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "gauge_chart_options": "gaugeChartOptions",
            "tooltip_options": "tooltipOptions",
            "visual_palette": "visualPalette",
        },
    )
    class GaugeChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GaugeChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            gauge_chart_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GaugeChartOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``GaugeChartVisual`` .

            :param data_labels: The data label configuration of a ``GaugeChartVisual`` .
            :param field_wells: The field well configuration of a ``GaugeChartVisual`` .
            :param gauge_chart_options: The options that determine the presentation of the ``GaugeChartVisual`` .
            :param tooltip_options: The tooltip configuration of a ``GaugeChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_configuration_property = quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                        target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                        arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                            arc_angle=123,
                            arc_thickness="arcThickness"
                        ),
                        arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                            range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                max=123,
                                min=123
                            ),
                            reserve_range=123
                        ),
                        comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                            comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            comparison_method="comparisonMethod"
                        ),
                        primary_value_display_type="primaryValueDisplayType",
                        primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        )
                    ),
                    tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8c59390b9cdcc21e75744c281692f4a777da13eefe12ec5da69fa80ea7c3649c)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument gauge_chart_options", value=gauge_chart_options, expected_type=type_hints["gauge_chart_options"])
                check_type(argname="argument tooltip_options", value=tooltip_options, expected_type=type_hints["tooltip_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if gauge_chart_options is not None:
                self._values["gauge_chart_options"] = gauge_chart_options
            if tooltip_options is not None:
                self._values["tooltip_options"] = tooltip_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The data label configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartFieldWellsProperty"]]:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartFieldWellsProperty"]], result)

        @builtins.property
        def gauge_chart_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartOptionsProperty"]]:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-gaugechartoptions
            '''
            result = self._values.get("gauge_chart_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartOptionsProperty"]], result)

        @builtins.property
        def tooltip_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-tooltipoptions
            '''
            result = self._values.get("tooltip_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The visual palette configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GaugeChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"target_values": "targetValues", "values": "values"},
    )
    class GaugeChartFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :param target_values: The target value field wells of a ``GaugeChartVisual`` .
            :param values: The value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_field_wells_property = quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                    target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__002086b355f5af5981f2ae5bf929891b1460936b0b21975a3972b5bb392a1b32)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The target value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html#cfn-quicksight-analysis-gaugechartfieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html#cfn-quicksight-analysis-gaugechartfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GaugeChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc": "arc",
            "arc_axis": "arcAxis",
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
        },
    )
    class GaugeChartOptionsProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ArcConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            arc_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ArcAxisConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :param arc: The arc configuration of a ``GaugeChartVisual`` .
            :param arc_axis: The arc axis configuration of a ``GaugeChartVisual`` .
            :param comparison: The comparison configuration of a ``GaugeChartVisual`` .
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_options_property = quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                    arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                        arc_angle=123,
                        arc_thickness="arcThickness"
                    ),
                    arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                        range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                            max=123,
                            min=123
                        ),
                        reserve_range=123
                    ),
                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a0ca8583765488a67b3a55c263069d4f8f20355710c960edb620781b20ed2e75)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument arc_axis", value=arc_axis, expected_type=type_hints["arc_axis"])
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if arc_axis is not None:
                self._values["arc_axis"] = arc_axis
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ArcConfigurationProperty"]]:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ArcConfigurationProperty"]], result)

        @builtins.property
        def arc_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ArcAxisConfigurationProperty"]]:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-arcaxis
            '''
            result = self._values.get("arc_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ArcAxisConfigurationProperty"]], result)

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComparisonConfigurationProperty"]]:
            '''The comparison configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComparisonConfigurationProperty"]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class GaugeChartPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :param icon: The conditional formatting of the primary value icon.
            :param text_color: The conditional formatting of the primary value text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_primary_value_conditional_formatting_property = quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d5d61d11872c7eed0dda0dc1fe74d5cac23cd0217db8fb222fb6df251d3c3265)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the primary value icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-gaugechartprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the primary value text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-gaugechartprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GaugeChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GaugeChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GaugeChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GaugeChartConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``GaugeChartVisual`` .
            :param conditional_formatting: The conditional formatting of a ``GaugeChartVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_visual_property = quicksight.CfnAnalysis.GaugeChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                            target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                            arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                                arc_angle=123,
                                arc_thickness="arcThickness"
                            ),
                            arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                                range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                    max=123,
                                    min=123
                                ),
                                reserve_range=123
                            ),
                            comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                comparison_method="comparisonMethod"
                            ),
                            primary_value_display_type="primaryValueDisplayType",
                            primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        ),
                        tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    conditional_formatting=quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                            arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                                foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            ),
                            primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb38428db864170ab45f2443933efc8de15f36e633302edfd75afd8e62a1bab9)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartConfigurationProperty"]]:
            '''The configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartConditionalFormattingProperty"]]:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "east": "east",
            "north": "north",
            "south": "south",
            "west": "west",
        },
    )
    class GeospatialCoordinateBoundsProperty:
        def __init__(
            self,
            *,
            east: jsii.Number,
            north: jsii.Number,
            south: jsii.Number,
            west: jsii.Number,
        ) -> None:
            '''The bound options (north, south, west, east) of the geospatial window options.

            :param east: The longitude of the east bound of the geospatial coordinate bounds.
            :param north: The latitude of the north bound of the geospatial coordinate bounds.
            :param south: The latitude of the south bound of the geospatial coordinate bounds.
            :param west: The longitude of the west bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_coordinate_bounds_property = quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                    east=123,
                    north=123,
                    south=123,
                    west=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__27ffc0c98eac9d7f20dcc7ea41f37a3a168ebf734685d6d902c061ca9e53fc7f)
                check_type(argname="argument east", value=east, expected_type=type_hints["east"])
                check_type(argname="argument north", value=north, expected_type=type_hints["north"])
                check_type(argname="argument south", value=south, expected_type=type_hints["south"])
                check_type(argname="argument west", value=west, expected_type=type_hints["west"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "east": east,
                "north": north,
                "south": south,
                "west": west,
            }

        @builtins.property
        def east(self) -> jsii.Number:
            '''The longitude of the east bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-east
            '''
            result = self._values.get("east")
            assert result is not None, "Required property 'east' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def north(self) -> jsii.Number:
            '''The latitude of the north bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-north
            '''
            result = self._values.get("north")
            assert result is not None, "Required property 'north' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def south(self) -> jsii.Number:
            '''The latitude of the south bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-south
            '''
            result = self._values.get("south")
            assert result is not None, "Required property 'south' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def west(self) -> jsii.Number:
            '''The longitude of the west bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-west
            '''
            result = self._values.get("west")
            assert result is not None, "Required property 'west' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialCoordinateBoundsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "colors": "colors",
            "geospatial": "geospatial",
            "values": "values",
        },
    )
    class GeospatialMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            geospatial: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells for a geospatial map.

            :param colors: The color field wells of a geospatial map.
            :param geospatial: The geospatial field wells of a geospatial map. Values are grouped by geospatial fields.
            :param values: The size field wells of a geospatial map. Values are aggregated based on geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_aggregated_field_wells_property = quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6c78704a4ed2ca7f3a6dad28ee6964648f14cbe5af079d5cd2004aca50beb09d)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The color field wells of a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The geospatial field wells of a geospatial map.

            Values are grouped by geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The size field wells of a geospatial map.

            Values are aggregated based on geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GeospatialMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "point_style_options": "pointStyleOptions",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "window_options": "windowOptions",
        },
    )
    class GeospatialMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GeospatialMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            point_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GeospatialPointStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            window_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``GeospatialMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the geospatial map.
            :param point_style_options: The point style options of the geospatial map.
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: ``CfnAnalysis.GeospatialMapConfigurationProperty.VisualPalette``.
            :param window_options: The window options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_configuration_property = quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                    field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                        geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                        base_map_style="baseMapStyle"
                    ),
                    point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                        cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                            cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                    color="color"
                                )
                            )
                        ),
                        selected_point_style="selectedPointStyle"
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                        bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                            east=123,
                            north=123,
                            south=123,
                            west=123
                        ),
                        map_zoom_mode="mapZoomMode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__69f4dabd531c5f794ed173dffbbfa2587d458c6726c05e1cf451684f3ffd11b8)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument point_style_options", value=point_style_options, expected_type=type_hints["point_style_options"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if point_style_options is not None:
                self._values["point_style_options"] = point_style_options
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialMapStyleOptionsProperty"]]:
            '''The map style options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialMapStyleOptionsProperty"]], result)

        @builtins.property
        def point_style_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialPointStyleOptionsProperty"]]:
            '''The point style options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-pointstyleoptions
            '''
            result = self._values.get("point_style_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialPointStyleOptionsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]]:
            '''``CfnAnalysis.GeospatialMapConfigurationProperty.VisualPalette``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialWindowOptionsProperty"]]:
            '''The window options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialWindowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "geospatial_map_aggregated_field_wells": "geospatialMapAggregatedFieldWells",
        },
    )
    class GeospatialMapFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``GeospatialMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param geospatial_map_aggregated_field_wells: The aggregated field well for a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_field_wells_property = quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                    geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c5af8487c0d8ceec96aef31a5af621f585f12bf318af1d68a5c1792f2e069ed)
                check_type(argname="argument geospatial_map_aggregated_field_wells", value=geospatial_map_aggregated_field_wells, expected_type=type_hints["geospatial_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial_map_aggregated_field_wells is not None:
                self._values["geospatial_map_aggregated_field_wells"] = geospatial_map_aggregated_field_wells

        @builtins.property
        def geospatial_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapfieldwells.html#cfn-quicksight-analysis-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
            '''
            result = self._values.get("geospatial_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"base_map_style": "baseMapStyle"},
    )
    class GeospatialMapStyleOptionsProperty:
        def __init__(
            self,
            *,
            base_map_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The map style options of the geospatial map.

            :param base_map_style: The base map style of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_style_options_property = quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                    base_map_style="baseMapStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__306691ad91eb9a55909ccee2a2ac9424dd1ee504b93fe4443dc4a1084c6f7dd9)
                check_type(argname="argument base_map_style", value=base_map_style, expected_type=type_hints["base_map_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base_map_style is not None:
                self._values["base_map_style"] = base_map_style

        @builtins.property
        def base_map_style(self) -> typing.Optional[builtins.str]:
            '''The base map style of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapstyleoptions.html#cfn-quicksight-analysis-geospatialmapstyleoptions-basemapstyle
            '''
            result = self._values.get("base_map_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GeospatialMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GeospatialMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GeospatialMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_visual_property = quicksight.CfnAnalysis.GeospatialMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                        field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                            geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                                colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                            base_map_style="baseMapStyle"
                        ),
                        point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                            cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                                cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                    simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                        color="color"
                                    )
                                )
                            ),
                            selected_point_style="selectedPointStyle"
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                            bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                east=123,
                                north=123,
                                south=123,
                                west=123
                            ),
                            map_zoom_mode="mapZoomMode"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c0d69358867e18cdb2416ec54480efa24a61d2bd20ec4d0a48e15d58deed5e5e)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cluster_marker_configuration": "clusterMarkerConfiguration",
            "selected_point_style": "selectedPointStyle",
        },
    )
    class GeospatialPointStyleOptionsProperty:
        def __init__(
            self,
            *,
            cluster_marker_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ClusterMarkerConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_point_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The point style of the geospatial map.

            :param cluster_marker_configuration: The cluster marker configuration of the geospatial point style.
            :param selected_point_style: The selected point styles (point, cluster) of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_point_style_options_property = quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                    cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                        cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                            simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                color="color"
                            )
                        )
                    ),
                    selected_point_style="selectedPointStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c8152a8ab4db7145f5c03d68e727c3cbc8f5673272e3e36bcf82d430e2bfca08)
                check_type(argname="argument cluster_marker_configuration", value=cluster_marker_configuration, expected_type=type_hints["cluster_marker_configuration"])
                check_type(argname="argument selected_point_style", value=selected_point_style, expected_type=type_hints["selected_point_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker_configuration is not None:
                self._values["cluster_marker_configuration"] = cluster_marker_configuration
            if selected_point_style is not None:
                self._values["selected_point_style"] = selected_point_style

        @builtins.property
        def cluster_marker_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ClusterMarkerConfigurationProperty"]]:
            '''The cluster marker configuration of the geospatial point style.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html#cfn-quicksight-analysis-geospatialpointstyleoptions-clustermarkerconfiguration
            '''
            result = self._values.get("cluster_marker_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ClusterMarkerConfigurationProperty"]], result)

        @builtins.property
        def selected_point_style(self) -> typing.Optional[builtins.str]:
            '''The selected point styles (point, cluster) of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html#cfn-quicksight-analysis-geospatialpointstyleoptions-selectedpointstyle
            '''
            result = self._values.get("selected_point_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialPointStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GeospatialWindowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bounds": "bounds", "map_zoom_mode": "mapZoomMode"},
    )
    class GeospatialWindowOptionsProperty:
        def __init__(
            self,
            *,
            bounds: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GeospatialCoordinateBoundsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_zoom_mode: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The window options of the geospatial map visual.

            :param bounds: The bounds options (north, south, west, east) of the geospatial window options.
            :param map_zoom_mode: The map zoom modes (manual, auto) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_window_options_property = quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                    bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                        east=123,
                        north=123,
                        south=123,
                        west=123
                    ),
                    map_zoom_mode="mapZoomMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4de86cf39a37dd88d52632aa1c5305cd60e0933a432ebbd769de16e935e7e5f7)
                check_type(argname="argument bounds", value=bounds, expected_type=type_hints["bounds"])
                check_type(argname="argument map_zoom_mode", value=map_zoom_mode, expected_type=type_hints["map_zoom_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bounds is not None:
                self._values["bounds"] = bounds
            if map_zoom_mode is not None:
                self._values["map_zoom_mode"] = map_zoom_mode

        @builtins.property
        def bounds(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialCoordinateBoundsProperty"]]:
            '''The bounds options (north, south, west, east) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html#cfn-quicksight-analysis-geospatialwindowoptions-bounds
            '''
            result = self._values.get("bounds")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialCoordinateBoundsProperty"]], result)

        @builtins.property
        def map_zoom_mode(self) -> typing.Optional[builtins.str]:
            '''The map zoom modes (manual, auto) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html#cfn-quicksight-analysis-geospatialwindowoptions-mapzoommode
            '''
            result = self._values.get("map_zoom_mode")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialWindowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "side_specific_border": "sideSpecificBorder",
            "uniform_border": "uniformBorder",
        },
    )
    class GlobalTableBorderOptionsProperty:
        def __init__(
            self,
            *,
            side_specific_border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableSideBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            uniform_border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the border options for a table visual.

            :param side_specific_border: Determines the options for side specific border.
            :param uniform_border: Determines the options for uniform border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                global_table_border_options_property = quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c151864ab238f9d21c50d92971d5989faa254580d56ab1ed6db05754789f28b0)
                check_type(argname="argument side_specific_border", value=side_specific_border, expected_type=type_hints["side_specific_border"])
                check_type(argname="argument uniform_border", value=uniform_border, expected_type=type_hints["uniform_border"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if side_specific_border is not None:
                self._values["side_specific_border"] = side_specific_border
            if uniform_border is not None:
                self._values["uniform_border"] = uniform_border

        @builtins.property
        def side_specific_border(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableSideBorderOptionsProperty"]]:
            '''Determines the options for side specific border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html#cfn-quicksight-analysis-globaltableborderoptions-sidespecificborder
            '''
            result = self._values.get("side_specific_border")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableSideBorderOptionsProperty"]], result)

        @builtins.property
        def uniform_border(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''Determines the options for uniform border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html#cfn-quicksight-analysis-globaltableborderoptions-uniformborder
            '''
            result = self._values.get("uniform_border")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GlobalTableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"stops": "stops"},
    )
    class GradientColorProperty:
        def __init__(
            self,
            *,
            stops: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GradientStopProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Determines the gradient color settings.

            :param stops: The list of gradient color stops.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gradient_color_property = quicksight.CfnAnalysis.GradientColorProperty(
                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                        gradient_offset=123,
                
                        # the properties below are optional
                        color="color",
                        data_value=123
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__54688eb7726636f8a3496d5055f62071dee64879fd621b2e1f1033263e7dc46f)
                check_type(argname="argument stops", value=stops, expected_type=type_hints["stops"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if stops is not None:
                self._values["stops"] = stops

        @builtins.property
        def stops(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GradientStopProperty"]]]]:
            '''The list of gradient color stops.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientcolor.html#cfn-quicksight-analysis-gradientcolor-stops
            '''
            result = self._values.get("stops")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GradientStopProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GradientStopProperty",
        jsii_struct_bases=[],
        name_mapping={
            "gradient_offset": "gradientOffset",
            "color": "color",
            "data_value": "dataValue",
        },
    )
    class GradientStopProperty:
        def __init__(
            self,
            *,
            gradient_offset: jsii.Number,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the gradient stop configuration.

            :param gradient_offset: Determines gradient offset value.
            :param color: Determines the color.
            :param data_value: Determines the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gradient_stop_property = quicksight.CfnAnalysis.GradientStopProperty(
                    gradient_offset=123,
                
                    # the properties below are optional
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__730f317073242438eedef9a1faeec28c5cec6b9a17a031704d6eacd3a637e8a7)
                check_type(argname="argument gradient_offset", value=gradient_offset, expected_type=type_hints["gradient_offset"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "gradient_offset": gradient_offset,
            }
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def gradient_offset(self) -> jsii.Number:
            '''Determines gradient offset value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-gradientoffset
            '''
            result = self._values.get("gradient_offset")
            assert result is not None, "Required property 'gradient_offset' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''Determines the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientStopProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class GridLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configuration options for the canvas of a grid layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                grid_layout_canvas_size_options_property = quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                        resize_option="resizeOption",
                
                        # the properties below are optional
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3cc300f8d0d723f1340709c4d7993d81970c7cf1f683cd26192975c578250350)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty"]]:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutcanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class GridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GridLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a grid layout. Also called a tiled layout.

            Visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size.

            :param elements: The elements that are included in a grid layout.
            :param canvas_size_options: ``CfnAnalysis.GridLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                grid_layout_configuration_property = quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                    elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                        column_span=123,
                        element_id="elementId",
                        element_type="elementType",
                        row_span=123,
                
                        # the properties below are optional
                        column_index=123,
                        row_index=123
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33b188af7622727512e0e9188423378c37b59993eb4f4036078b32ea2641cb70)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GridLayoutElementProperty"]]]:
            '''The elements that are included in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html#cfn-quicksight-analysis-gridlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GridLayoutElementProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GridLayoutCanvasSizeOptionsProperty"]]:
            '''``CfnAnalysis.GridLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html#cfn-quicksight-analysis-gridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GridLayoutCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GridLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_span": "columnSpan",
            "element_id": "elementId",
            "element_type": "elementType",
            "row_span": "rowSpan",
            "column_index": "columnIndex",
            "row_index": "rowIndex",
        },
    )
    class GridLayoutElementProperty:
        def __init__(
            self,
            *,
            column_span: jsii.Number,
            element_id: builtins.str,
            element_type: builtins.str,
            row_span: jsii.Number,
            column_index: typing.Optional[jsii.Number] = None,
            row_index: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An element within a grid layout.

            :param column_span: The width of a grid element expressed as a number of grid columns.
            :param element_id: A unique identifier for an element within a grid layout.
            :param element_type: The type of element.
            :param row_span: The height of a grid element expressed as a number of grid rows.
            :param column_index: The column index for the upper left corner of an element.
            :param row_index: The row index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                grid_layout_element_property = quicksight.CfnAnalysis.GridLayoutElementProperty(
                    column_span=123,
                    element_id="elementId",
                    element_type="elementType",
                    row_span=123,
                
                    # the properties below are optional
                    column_index=123,
                    row_index=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cb14f471c1d9a14dfd55d168301a6d1eb164f86bf179ec43547dc4cfa7e94afc)
                check_type(argname="argument column_span", value=column_span, expected_type=type_hints["column_span"])
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument row_span", value=row_span, expected_type=type_hints["row_span"])
                check_type(argname="argument column_index", value=column_index, expected_type=type_hints["column_index"])
                check_type(argname="argument row_index", value=row_index, expected_type=type_hints["row_index"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_span": column_span,
                "element_id": element_id,
                "element_type": element_type,
                "row_span": row_span,
            }
            if column_index is not None:
                self._values["column_index"] = column_index
            if row_index is not None:
                self._values["row_index"] = row_index

        @builtins.property
        def column_span(self) -> jsii.Number:
            '''The width of a grid element expressed as a number of grid columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-columnspan
            '''
            result = self._values.get("column_span")
            assert result is not None, "Required property 'column_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def row_span(self) -> jsii.Number:
            '''The height of a grid element expressed as a number of grid rows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-rowspan
            '''
            result = self._values.get("row_span")
            assert result is not None, "Required property 'row_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def column_index(self) -> typing.Optional[jsii.Number]:
            '''The column index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-columnindex
            '''
            result = self._values.get("column_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def row_index(self) -> typing.Optional[jsii.Number]:
            '''The row index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-rowindex
            '''
            result = self._values.get("row_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "resize_option": "resizeOption",
            "optimized_view_port_width": "optimizedViewPortWidth",
        },
    )
    class GridLayoutScreenCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            resize_option: builtins.str,
            optimized_view_port_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :param resize_option: This value determines the layout behavior when the viewport is resized. - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` . - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .
            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                grid_layout_screen_canvas_size_options_property = quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                    resize_option="resizeOption",
                
                    # the properties below are optional
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4d41beec12bbf93191adfc6eaf36b32c0fa3b59f3487492c999b2906e086b6d0)
                check_type(argname="argument resize_option", value=resize_option, expected_type=type_hints["resize_option"])
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "resize_option": resize_option,
            }
            if optimized_view_port_width is not None:
                self._values["optimized_view_port_width"] = optimized_view_port_width

        @builtins.property
        def resize_option(self) -> builtins.str:
            '''This value determines the layout behavior when the viewport is resized.

            - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` .
            - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutscreencanvassizeoptions-resizeoption
            '''
            result = self._values.get("resize_option")
            assert result is not None, "Required property 'resize_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def optimized_view_port_width(self) -> typing.Optional[builtins.str]:
            '''The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.GrowthRateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "period_size": "periodSize",
            "value": "value",
        },
    )
    class GrowthRateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
            period_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The growth rate computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param period_size: The period size setup of a growth rate computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                growth_rate_computation_property = quicksight.CfnAnalysis.GrowthRateComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    period_size=123,
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__54fcf216f414f0f8b8c989053aff5845f1954bcffc1456347582749b1c16fdde)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_size", value=period_size, expected_type=type_hints["period_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if period_size is not None:
                self._values["period_size"] = period_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_size(self) -> typing.Optional[jsii.Number]:
            '''The period size setup of a growth rate computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-periodsize
            '''
            result = self._values.get("period_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GrowthRateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout", "section_id": "sectionId", "style": "style"},
    )
    class HeaderFooterSectionConfigurationProperty:
        def __init__(
            self,
            *,
            layout: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            section_id: builtins.str,
            style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a header or footer section.

            :param layout: The layout configuration of the header or footer section.
            :param section_id: The unique identifier of the header or footer section.
            :param style: The style options of a header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                header_footer_section_configuration_property = quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnAnalysis.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3eded328741f753c3eb9218eb9760066736c6e724e96313d02d90d7db504e120)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "layout": layout,
                "section_id": section_id,
            }
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def layout(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionLayoutConfigurationProperty"]:
            '''The layout configuration of the header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-layout
            '''
            result = self._values.get("layout")
            assert result is not None, "Required property 'layout' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionLayoutConfigurationProperty"], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of the header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionStyleProperty"]]:
            '''The style options of a header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeaderFooterSectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class HeatMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            rows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a heat map.

            :param columns: The columns field well of a heat map.
            :param rows: The rows field well of a heat map.
            :param values: The values field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_aggregated_field_wells_property = quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                    columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__214ac7b660406f84c19804acca2fcdf584b95781e46646ed6cdcc03cf1523fa5)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The columns field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The rows field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The values field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.HeatMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_scale": "colorScale",
            "column_label_options": "columnLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "row_label_options": "rowLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class HeatMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.HeatMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.HeatMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a heat map.

            :param color_scale: The color options (gradient color, point of divergence) in a heat map.
            :param column_label_options: The label options of the column that is displayed in a heat map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param row_label_options: The label options of the row that is displayed in a ``heat map`` .
            :param sort_configuration: The sort configuration of a heat map.
            :param tooltip: The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_configuration_property = quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                    color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                        color_fill_type="colorFillType",
                        colors=[quicksight.CfnAnalysis.DataColorProperty(
                            color="color",
                            data_value=123
                        )],
                
                        # the properties below are optional
                        null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                            color="color",
                            data_value=123
                        )
                    ),
                    column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                        heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                            columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                        heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4aa98212828e5fe93271307814ccae743cd3b57c393e8e93c35b42a0648f6abe)
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument column_label_options", value=column_label_options, expected_type=type_hints["column_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument row_label_options", value=row_label_options, expected_type=type_hints["row_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if column_label_options is not None:
                self._values["column_label_options"] = column_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if row_label_options is not None:
                self._values["row_label_options"] = row_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColorScaleProperty"]]:
            '''The color options (gradient color, point of divergence) in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColorScaleProperty"]], result)

        @builtins.property
        def column_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the column that is displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-columnlabeloptions
            '''
            result = self._values.get("column_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeatMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeatMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def row_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the row that is displayed in a ``heat map`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-rowlabeloptions
            '''
            result = self._values.get("row_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeatMapSortConfigurationProperty"]]:
            '''The sort configuration of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeatMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.HeatMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_aggregated_field_wells": "heatMapAggregatedFieldWells",
        },
    )
    class HeatMapFieldWellsProperty:
        def __init__(
            self,
            *,
            heat_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.HeatMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a heat map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param heat_map_aggregated_field_wells: The aggregated field wells of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_field_wells_property = quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                    heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                        columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__183e3f6fc016060954b0f5610689e4b1ad3c1c63a6f5cfe7d020119510f17811)
                check_type(argname="argument heat_map_aggregated_field_wells", value=heat_map_aggregated_field_wells, expected_type=type_hints["heat_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_aggregated_field_wells is not None:
                self._values["heat_map_aggregated_field_wells"] = heat_map_aggregated_field_wells

        @builtins.property
        def heat_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeatMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapfieldwells.html#cfn-quicksight-analysis-heatmapfieldwells-heatmapaggregatedfieldwells
            '''
            result = self._values.get("heat_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeatMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.HeatMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_column_items_limit_configuration": "heatMapColumnItemsLimitConfiguration",
            "heat_map_column_sort": "heatMapColumnSort",
            "heat_map_row_items_limit_configuration": "heatMapRowItemsLimitConfiguration",
            "heat_map_row_sort": "heatMapRowSort",
        },
    )
    class HeatMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            heat_map_column_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_column_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            heat_map_row_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_row_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a heat map.

            :param heat_map_column_items_limit_configuration: The limit on the number of columns that are displayed in a heat map.
            :param heat_map_column_sort: The column sort configuration for heat map for columns that aren't a part of a field well.
            :param heat_map_row_items_limit_configuration: The limit on the number of rows that are displayed in a heat map.
            :param heat_map_row_sort: The field sort configuration of the rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_sort_configuration_property = quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                    heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__24b97c1cba5bb97f333c75e5d0a823c079c5b70851f4de6136f5f8830da6547e)
                check_type(argname="argument heat_map_column_items_limit_configuration", value=heat_map_column_items_limit_configuration, expected_type=type_hints["heat_map_column_items_limit_configuration"])
                check_type(argname="argument heat_map_column_sort", value=heat_map_column_sort, expected_type=type_hints["heat_map_column_sort"])
                check_type(argname="argument heat_map_row_items_limit_configuration", value=heat_map_row_items_limit_configuration, expected_type=type_hints["heat_map_row_items_limit_configuration"])
                check_type(argname="argument heat_map_row_sort", value=heat_map_row_sort, expected_type=type_hints["heat_map_row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_column_items_limit_configuration is not None:
                self._values["heat_map_column_items_limit_configuration"] = heat_map_column_items_limit_configuration
            if heat_map_column_sort is not None:
                self._values["heat_map_column_sort"] = heat_map_column_sort
            if heat_map_row_items_limit_configuration is not None:
                self._values["heat_map_row_items_limit_configuration"] = heat_map_row_items_limit_configuration
            if heat_map_row_sort is not None:
                self._values["heat_map_row_sort"] = heat_map_row_sort

        @builtins.property
        def heat_map_column_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of columns that are displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
            '''
            result = self._values.get("heat_map_column_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def heat_map_column_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The column sort configuration for heat map for columns that aren't a part of a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmapcolumnsort
            '''
            result = self._values.get("heat_map_column_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def heat_map_row_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of rows that are displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
            '''
            result = self._values.get("heat_map_row_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def heat_map_row_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The field sort configuration of the rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmaprowsort
            '''
            result = self._values.get("heat_map_row_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.HeatMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HeatMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.HeatMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a heat map.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_visual_property = quicksight.CfnAnalysis.HeatMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                        color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                            color_fill_type="colorFillType",
                            colors=[quicksight.CfnAnalysis.DataColorProperty(
                                color="color",
                                data_value=123
                            )],
                
                            # the properties below are optional
                            null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                color="color",
                                data_value=123
                            )
                        ),
                        column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                            heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                                columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                            heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4684ba09a7cb65bff1fcbdce69e44e3c2d2b846d97f21f1a453b88c0e185ad1f)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeatMapConfigurationProperty"]]:
            '''The configuration of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeatMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class HistogramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param values: The value field wells of a histogram. Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                histogram_aggregated_field_wells_property = quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22442f0144435e00120f9cfb6ab2662364e816d6bf115a85d69cf4d66584613c)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a histogram.

            Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramaggregatedfieldwells.html#cfn-quicksight-analysis-histogramaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.HistogramBinOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_count": "binCount",
            "bin_width": "binWidth",
            "selected_bin_type": "selectedBinType",
            "start_value": "startValue",
        },
    )
    class HistogramBinOptionsProperty:
        def __init__(
            self,
            *,
            bin_count: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BinCountOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            bin_width: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BinWidthOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_bin_type: typing.Optional[builtins.str] = None,
            start_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the presentation of histogram bins.

            :param bin_count: The options that determine the bin count of a histogram.
            :param bin_width: The options that determine the bin width of a histogram.
            :param selected_bin_type: The options that determine the selected bin type.
            :param start_value: The options that determine the bin start value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                histogram_bin_options_property = quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                    bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                        value=123
                    ),
                    bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                        bin_count_limit=123,
                        value=123
                    ),
                    selected_bin_type="selectedBinType",
                    start_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3aef72c83f3be75e2b3a37d74c1a50d03b0cbf5a4609da7cbf8b4e0afa8dfa3e)
                check_type(argname="argument bin_count", value=bin_count, expected_type=type_hints["bin_count"])
                check_type(argname="argument bin_width", value=bin_width, expected_type=type_hints["bin_width"])
                check_type(argname="argument selected_bin_type", value=selected_bin_type, expected_type=type_hints["selected_bin_type"])
                check_type(argname="argument start_value", value=start_value, expected_type=type_hints["start_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count is not None:
                self._values["bin_count"] = bin_count
            if bin_width is not None:
                self._values["bin_width"] = bin_width
            if selected_bin_type is not None:
                self._values["selected_bin_type"] = selected_bin_type
            if start_value is not None:
                self._values["start_value"] = start_value

        @builtins.property
        def bin_count(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BinCountOptionsProperty"]]:
            '''The options that determine the bin count of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-bincount
            '''
            result = self._values.get("bin_count")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BinCountOptionsProperty"]], result)

        @builtins.property
        def bin_width(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BinWidthOptionsProperty"]]:
            '''The options that determine the bin width of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-binwidth
            '''
            result = self._values.get("bin_width")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BinWidthOptionsProperty"]], result)

        @builtins.property
        def selected_bin_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the selected bin type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-selectedbintype
            '''
            result = self._values.get("selected_bin_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin start value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-startvalue
            '''
            result = self._values.get("start_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramBinOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.HistogramConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_options": "binOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
        },
    )
    class HistogramConfigurationProperty:
        def __init__(
            self,
            *,
            bin_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.HistogramBinOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.HistogramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``HistogramVisual`` .

            :param bin_options: The options that determine the presentation of histogram bins.
            :param data_labels: The data label configuration of a histogram.
            :param field_wells: The field well configuration of a histogram.
            :param tooltip: The tooltip configuration of a histogram.
            :param visual_palette: The visual palette configuration of a histogram.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.
            :param y_axis_display_options: The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                histogram_configuration_property = quicksight.CfnAnalysis.HistogramConfigurationProperty(
                    bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                        bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                            value=123
                        ),
                        bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                            bin_count_limit=123,
                            value=123
                        ),
                        selected_bin_type="selectedBinType",
                        start_value=123
                    ),
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                        histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a6982125c80102028b29d52d919137a054b3db65308d26d6a2314e8c9a693b9f)
                check_type(argname="argument bin_options", value=bin_options, expected_type=type_hints["bin_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_options is not None:
                self._values["bin_options"] = bin_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options

        @builtins.property
        def bin_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HistogramBinOptionsProperty"]]:
            '''The options that determine the presentation of histogram bins.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-binoptions
            '''
            result = self._values.get("bin_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HistogramBinOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The data label configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HistogramFieldWellsProperty"]]:
            '''The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HistogramFieldWellsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The visual palette configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.HistogramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "histogram_aggregated_field_wells": "histogramAggregatedFieldWells",
        },
    )
    class HistogramFieldWellsProperty:
        def __init__(
            self,
            *,
            histogram_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.HistogramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param histogram_aggregated_field_wells: The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                histogram_field_wells_property = quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                    histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__52315d3d7447f31788d736a570a57a233f08e5011691d864628fe43731862650)
                check_type(argname="argument histogram_aggregated_field_wells", value=histogram_aggregated_field_wells, expected_type=type_hints["histogram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if histogram_aggregated_field_wells is not None:
                self._values["histogram_aggregated_field_wells"] = histogram_aggregated_field_wells

        @builtins.property
        def histogram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HistogramAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramfieldwells.html#cfn-quicksight-analysis-histogramfieldwells-histogramaggregatedfieldwells
            '''
            result = self._values.get("histogram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HistogramAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.HistogramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HistogramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.HistogramConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a ``HistogramVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                histogram_visual_property = quicksight.CfnAnalysis.HistogramVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.HistogramConfigurationProperty(
                        bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                            bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                                value=123
                            ),
                            bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                                bin_count_limit=123,
                                value=123
                            ),
                            selected_bin_type="selectedBinType",
                            start_value=123
                        ),
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                            histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        )
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75648e239edb4a60374d591c8c1718907c546ad755907f8a95b3a28f447eb78f)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HistogramConfigurationProperty"]]:
            '''The configuration for a ``HistogramVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HistogramConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.InsightConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computations": "computations",
            "custom_narrative": "customNarrative",
        },
    )
    class InsightConfigurationProperty:
        def __init__(
            self,
            *,
            computations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ComputationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            custom_narrative: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CustomNarrativeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of an insight visual.

            :param computations: The computations configurations of the insight visual.
            :param custom_narrative: The custom narrative of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                insight_configuration_property = quicksight.CfnAnalysis.InsightConfigurationProperty(
                    computations=[quicksight.CfnAnalysis.ComputationProperty(
                        forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            custom_seasonality_value=123,
                            lower_boundary=123,
                            name="name",
                            periods_backward=123,
                            periods_forward=123,
                            prediction_interval=123,
                            seasonality="seasonality",
                            upper_boundary=123,
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            period_size=123,
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            type="type",
                
                            # the properties below are optional
                            name="name",
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                            computation_id="computationId",
                            from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                            target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name"
                        ),
                        period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            period_time_granularity="periodTimeGranularity",
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            type="type",
                
                            # the properties below are optional
                            mover_size=123,
                            name="name",
                            sort_order="sortOrder",
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                            type="type",
                
                            # the properties below are optional
                            name="name",
                            result_size=123,
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                            computation_id="computationId",
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                
                            # the properties below are optional
                            name="name"
                        ),
                        unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                
                            # the properties below are optional
                            name="name"
                        )
                    )],
                    custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                        narrative="narrative"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__439763f99773df32868c3697ede2a75a0ee59f27819ec220e22cdaaa9edc6446)
                check_type(argname="argument computations", value=computations, expected_type=type_hints["computations"])
                check_type(argname="argument custom_narrative", value=custom_narrative, expected_type=type_hints["custom_narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if computations is not None:
                self._values["computations"] = computations
            if custom_narrative is not None:
                self._values["custom_narrative"] = custom_narrative

        @builtins.property
        def computations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComputationProperty"]]]]:
            '''The computations configurations of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html#cfn-quicksight-analysis-insightconfiguration-computations
            '''
            result = self._values.get("computations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComputationProperty"]]]], result)

        @builtins.property
        def custom_narrative(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomNarrativeOptionsProperty"]]:
            '''The custom narrative of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html#cfn-quicksight-analysis-insightconfiguration-customnarrative
            '''
            result = self._values.get("custom_narrative")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomNarrativeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.InsightVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "insight_configuration": "insightConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class InsightVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            insight_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.InsightConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used in the insight visual.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param insight_configuration: The configuration of an insight visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                insight_visual_property = quicksight.CfnAnalysis.InsightVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    insight_configuration=quicksight.CfnAnalysis.InsightConfigurationProperty(
                        computations=[quicksight.CfnAnalysis.ComputationProperty(
                            forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                custom_seasonality_value=123,
                                lower_boundary=123,
                                name="name",
                                periods_backward=123,
                                periods_forward=123,
                                prediction_interval=123,
                                seasonality="seasonality",
                                upper_boundary=123,
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                period_size=123,
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                type="type",
                
                                # the properties below are optional
                                name="name",
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                                computation_id="computationId",
                                from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                                target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name"
                            ),
                            period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                period_time_granularity="periodTimeGranularity",
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                                category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                type="type",
                
                                # the properties below are optional
                                mover_size=123,
                                name="name",
                                sort_order="sortOrder",
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                                category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                                type="type",
                
                                # the properties below are optional
                                name="name",
                                result_size=123,
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                                computation_id="computationId",
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                
                                # the properties below are optional
                                name="name"
                            ),
                            unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                                category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                
                                # the properties below are optional
                                name="name"
                            )
                        )],
                        custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                            narrative="narrative"
                        )
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8e73025ad4780a9eda72ac3f5d98ab788721dd40195e40a06c6c993e945d2608)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument insight_configuration", value=insight_configuration, expected_type=type_hints["insight_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if insight_configuration is not None:
                self._values["insight_configuration"] = insight_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used in the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def insight_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.InsightConfigurationProperty"]]:
            '''The configuration of an insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-insightconfiguration
            '''
            result = self._values.get("insight_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.InsightConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.IntegerDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class IntegerDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``IntegerParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``IntegerDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``IntegerDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                integer_default_values_property = quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                    dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9acb5f2f95d1a97cd587e5bfc698de1343921670c22cf781d81df9ced9554e4)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``IntegerDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html#cfn-quicksight-analysis-integerdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]]:
            '''The static values of the ``IntegerDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html#cfn-quicksight-analysis-integerdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.IntegerParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class IntegerParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.IntegerDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnAnalysis.IntegerParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                integer_parameter_declaration_property = quicksight.CfnAnalysis.IntegerParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                        dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1c0e4f74ddaad567ae53a74954434aefa0cca0759a3226f518dfb3ff6f1efae6)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.IntegerDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.IntegerDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MappedDataSetParameterProperty"]]]]:
            '''``CfnAnalysis.IntegerParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty"]]:
            '''A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.IntegerParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class IntegerParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]],
        ) -> None:
            '''An integer parameter.

            :param name: The name of the integer parameter.
            :param values: The values for the integer parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                integer_parameter_property = quicksight.CfnAnalysis.IntegerParameterProperty(
                    name="name",
                    values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__44992c5a6ba079cce6c8b604db9e9530e5686fe70839ad2e00347e761e20de8a)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the integer parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html#cfn-quicksight-analysis-integerparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]:
            '''The values for the integer parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html#cfn-quicksight-analysis-integerparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class IntegerValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                integer_value_when_unset_configuration_property = quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__879b4634cb2b8c14f51cc6404f82e152c86faf9eb98f6e000039e39588108a5d)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html#cfn-quicksight-analysis-integervaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html#cfn-quicksight-analysis-integervaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ItemsLimitConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "items_limit": "itemsLimit",
            "other_categories": "otherCategories",
        },
    )
    class ItemsLimitConfigurationProperty:
        def __init__(
            self,
            *,
            items_limit: typing.Optional[jsii.Number] = None,
            other_categories: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The limit configuration of the visual display for an axis.

            :param items_limit: The limit on how many items of a field are showed in the chart. For example, the number of slices that are displayed in a pie chart.
            :param other_categories: The ``Show other`` of an axis in the chart. Choose one of the following options:. - ``INCLUDE`` - ``EXCLUDE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                items_limit_configuration_property = quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                    items_limit=123,
                    other_categories="otherCategories"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e3b7021caad18bdfd19e7370979ae3fb199c86dcc328f2228faec8c39a4d87f)
                check_type(argname="argument items_limit", value=items_limit, expected_type=type_hints["items_limit"])
                check_type(argname="argument other_categories", value=other_categories, expected_type=type_hints["other_categories"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if items_limit is not None:
                self._values["items_limit"] = items_limit
            if other_categories is not None:
                self._values["other_categories"] = other_categories

        @builtins.property
        def items_limit(self) -> typing.Optional[jsii.Number]:
            '''The limit on how many items of a field are showed in the chart.

            For example, the number of slices that are displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html#cfn-quicksight-analysis-itemslimitconfiguration-itemslimit
            '''
            result = self._values.get("items_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def other_categories(self) -> typing.Optional[builtins.str]:
            '''The ``Show other`` of an axis in the chart. Choose one of the following options:.

            - ``INCLUDE``
            - ``EXCLUDE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html#cfn-quicksight-analysis-itemslimitconfiguration-othercategories
            '''
            result = self._values.get("other_categories")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ItemsLimitConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"primary_value": "primaryValue", "progress_bar": "progressBar"},
    )
    class KPIConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            primary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            progress_bar: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.KPIProgressBarConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting options of a KPI visual.

            :param primary_value: The conditional formatting for the primary value of a KPI visual.
            :param progress_bar: The conditional formatting for the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIConditional_formatting_option_property = quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                    primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9f00849897ed59a8520e884a8bd35f87d82bd5fa4e5090f32d59c59bb17a7731)
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if primary_value is not None:
                self._values["primary_value"] = primary_value
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the primary value of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty"]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIProgressBarConditionalFormattingProperty"]]:
            '''The conditional formatting for the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIProgressBarConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.KPIConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class KPIConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.KPIConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting of a KPI visual.

            :param conditional_formatting_options: The conditional formatting options of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIConditional_formatting_property = quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                        primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__abebb1dc633c2e758a6b46ad00787854ad6e97283794058f063efa67856933cf)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIConditionalFormattingOptionProperty"]]]]:
            '''The conditional formatting options of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformatting.html#cfn-quicksight-analysis-kpiconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.KPIConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "kpi_options": "kpiOptions",
            "sort_configuration": "sortConfiguration",
        },
    )
    class KPIConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.KPIFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            kpi_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.KPIOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.KPISortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a KPI visual.

            :param field_wells: The field well configuration of a KPI visual.
            :param kpi_options: The options that determine the presentation of a KPI visual.
            :param sort_configuration: The sort configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIConfiguration_property = quicksight.CfnAnalysis.KPIConfigurationProperty(
                    field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                        target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                        comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                            comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            comparison_method="comparisonMethod"
                        ),
                        primary_value_display_type="primaryValueDisplayType",
                        primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                            visibility="visibility"
                        ),
                        secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                            visibility="visibility"
                        ),
                        secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                            visibility="visibility"
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                        trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6f41e9054cfb2e23f2d771425fa6f107eb6a8fb2a204e2c90b56a8db62624121)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument kpi_options", value=kpi_options, expected_type=type_hints["kpi_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if kpi_options is not None:
                self._values["kpi_options"] = kpi_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIFieldWellsProperty"]]:
            '''The field well configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIFieldWellsProperty"]], result)

        @builtins.property
        def kpi_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIOptionsProperty"]]:
            '''The options that determine the presentation of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-kpioptions
            '''
            result = self._values.get("kpi_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPISortConfigurationProperty"]]:
            '''The sort configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPISortConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.KPIFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_values": "targetValues",
            "trend_groups": "trendGroups",
            "values": "values",
        },
    )
    class KPIFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            trend_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a KPI visual.

            :param target_values: The target value field wells of a KPI visual.
            :param trend_groups: The trend group field wells of a KPI visual.
            :param values: The value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIField_wells_property = quicksight.CfnAnalysis.KPIFieldWellsProperty(
                    target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__363f918b3e4b7a3f89ba268a01c1906c5b3d70fd4b673cb94879e545fbe0ae80)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument trend_groups", value=trend_groups, expected_type=type_hints["trend_groups"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if trend_groups is not None:
                self._values["trend_groups"] = trend_groups
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The target value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def trend_groups(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The trend group field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-trendgroups
            '''
            result = self._values.get("trend_groups")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.KPIOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
            "progress_bar": "progressBar",
            "secondary_value": "secondaryValue",
            "secondary_value_font_configuration": "secondaryValueFontConfiguration",
            "trend_arrows": "trendArrows",
        },
    )
    class KPIOptionsProperty:
        def __init__(
            self,
            *,
            comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            progress_bar: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ProgressBarOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SecondaryValueOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            trend_arrows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TrendArrowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of a KPI visual.

            :param comparison: The comparison configuration of a KPI visual.
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.
            :param progress_bar: The options that determine the presentation of the progress bar of a KPI visual.
            :param secondary_value: The options that determine the presentation of the secondary value of a KPI visual.
            :param secondary_value_font_configuration: The options that determine the secondary value font configuration.
            :param trend_arrows: The options that determine the presentation of trend arrows in a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIOptions_property = quicksight.CfnAnalysis.KPIOptionsProperty(
                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__365f59cd3f79093fc29ed88d5ee960ff604bd96cf3c550170165a03c879e8b00)
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
                check_type(argname="argument secondary_value", value=secondary_value, expected_type=type_hints["secondary_value"])
                check_type(argname="argument secondary_value_font_configuration", value=secondary_value_font_configuration, expected_type=type_hints["secondary_value_font_configuration"])
                check_type(argname="argument trend_arrows", value=trend_arrows, expected_type=type_hints["trend_arrows"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar
            if secondary_value is not None:
                self._values["secondary_value"] = secondary_value
            if secondary_value_font_configuration is not None:
                self._values["secondary_value_font_configuration"] = secondary_value_font_configuration
            if trend_arrows is not None:
                self._values["trend_arrows"] = trend_arrows

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComparisonConfigurationProperty"]]:
            '''The comparison configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComparisonConfigurationProperty"]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ProgressBarOptionsProperty"]]:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ProgressBarOptionsProperty"]], result)

        @builtins.property
        def secondary_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SecondaryValueOptionsProperty"]]:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-secondaryvalue
            '''
            result = self._values.get("secondary_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SecondaryValueOptionsProperty"]], result)

        @builtins.property
        def secondary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The options that determine the secondary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-secondaryvaluefontconfiguration
            '''
            result = self._values.get("secondary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def trend_arrows(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TrendArrowOptionsProperty"]]:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-trendarrows
            '''
            result = self._values.get("trend_arrows")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TrendArrowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a KPI visual.

            :param icon: The conditional formatting of the primary value's icon.
            :param text_color: The conditional formatting of the primary value's text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIPrimary_value_conditional_formatting_property = quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7aae78bc4c11a1f09436745a9a7b03bb98ce5c1b2523a9a0b10870965b29c42b)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the primary value's icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-kpiprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the primary value's text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-kpiprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class KPIProgressBarConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the progress bar of a KPI visual.

            :param foreground_color: The conditional formatting of the progress bar's foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprogressbarconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIProgress_bar_conditional_formatting_property = quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                    foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e4588470a5d3553d9e6978e5a0b774a81fb8944d96098ad284b9ffe3e11c0b73)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the progress bar's foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprogressbarconditionalformatting.html#cfn-quicksight-analysis-kpiprogressbarconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIProgressBarConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.KPISortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"trend_group_sort": "trendGroupSort"},
    )
    class KPISortConfigurationProperty:
        def __init__(
            self,
            *,
            trend_group_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a KPI visual.

            :param trend_group_sort: The sort configuration of the trend group fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pISort_configuration_property = quicksight.CfnAnalysis.KPISortConfigurationProperty(
                    trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0353982f894d4c9532f4f327e8540522be9adfa28818ecb1a9f6c36f1da7d441)
                check_type(argname="argument trend_group_sort", value=trend_group_sort, expected_type=type_hints["trend_group_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if trend_group_sort is not None:
                self._values["trend_group_sort"] = trend_group_sort

        @builtins.property
        def trend_group_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the trend group fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisortconfiguration.html#cfn-quicksight-analysis-kpisortconfiguration-trendgroupsort
            '''
            result = self._values.get("trend_group_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPISortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.KPIVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class KPIVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.KPIConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.KPIConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a KPI visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a KPI visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIVisual_property = quicksight.CfnAnalysis.KPIVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.KPIConfigurationProperty(
                        field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                            target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                            comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                comparison_method="comparisonMethod"
                            ),
                            primary_value_display_type="primaryValueDisplayType",
                            primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                                visibility="visibility"
                            ),
                            secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                                visibility="visibility"
                            ),
                            secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                                visibility="visibility"
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                            trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    conditional_formatting=quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                            primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            ),
                            progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                                foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee47410f1b05e1f6f62441e6060f5263f9e1061c66ddfad21be56f33ad3fbca0)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIConfigurationProperty"]]:
            '''The configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIConditionalFormattingProperty"]]:
            '''The conditional formatting of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
            "visibility": "visibility",
        },
    )
    class LabelOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The share label options for the labels.

            :param custom_label: The text for the label.
            :param font_configuration: The font configuration of the label.
            :param visibility: Determines whether or not the label is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                label_options_property = quicksight.CfnAnalysis.LabelOptionsProperty(
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d8a63305b387dc9e3e5222c5cdd1aecb7fb534a5618b37603f82aacb325b69ea)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The font configuration of the label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the label is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "free_form_layout": "freeFormLayout",
            "grid_layout": "gridLayout",
            "section_based_layout": "sectionBasedLayout",
        },
    )
    class LayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            section_based_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration that determines what the type of layout will be used on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param free_form_layout: A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
            :param grid_layout: A type of layout that can be used on a sheet. In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .
            :param section_based_layout: A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                layout_configuration_property = quicksight.CfnAnalysis.LayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                        body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                            content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                    status="status"
                                )
                            ),
                            style=quicksight.CfnAnalysis.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        ),
                        footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnAnalysis.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnAnalysis.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f6e3829019b028b8203125c77b7d9dc209e438b260c4e227c2706bac74e892f5)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
                check_type(argname="argument section_based_layout", value=section_based_layout, expected_type=type_hints["section_based_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form_layout is not None:
                self._values["free_form_layout"] = free_form_layout
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout
            if section_based_layout is not None:
                self._values["section_based_layout"] = section_based_layout

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutConfigurationProperty"]]:
            '''A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormLayoutConfigurationProperty"]], result)

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GridLayoutConfigurationProperty"]]:
            '''A type of layout that can be used on a sheet.

            In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GridLayoutConfigurationProperty"]], result)

        @builtins.property
        def section_based_layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionBasedLayoutConfigurationProperty"]]:
            '''A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-sectionbasedlayout
            '''
            result = self._values.get("section_based_layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionBasedLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class LayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A ``Layout`` defines the placement of elements within a sheet.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param configuration: The configuration that determines what the type of layout for a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                layout_property = quicksight.CfnAnalysis.LayoutProperty(
                    configuration=quicksight.CfnAnalysis.LayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                            body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                                content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                    after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                        status="status"
                                    )
                                ),
                                style=quicksight.CfnAnalysis.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            ),
                            footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnAnalysis.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnAnalysis.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1617046f061dcc7641e84455035f8426eaa1a7b3c0ea98a34f81688cee694f2d)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LayoutConfigurationProperty"]:
            '''The configuration that determines what the type of layout for a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layout.html#cfn-quicksight-analysis-layout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LegendOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "height": "height",
            "position": "position",
            "title": "title",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class LegendOptionsProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for the legend setup of a visual.

            :param height: The height of the legend. If this value is omitted, a default height is used when rendering.
            :param position: The positions for the legend. Choose one of the following options:. - ``AUTO`` - ``RIGHT`` - ``BOTTOM`` - ``LEFT``
            :param title: The custom title for the legend.
            :param visibility: Determines whether or not the legend is visible.
            :param width: The width of the legend. If this value is omitted, a default width is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                legend_options_property = quicksight.CfnAnalysis.LegendOptionsProperty(
                    height="height",
                    position="position",
                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__39a540a0a94a346c833d7916f311441254474464b2c6fd7cabdaea13edb4f3a1)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if position is not None:
                self._values["position"] = position
            if title is not None:
                self._values["title"] = title
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of the legend.

            If this value is omitted, a default height is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''The positions for the legend. Choose one of the following options:.

            - ``AUTO``
            - ``RIGHT``
            - ``BOTTOM``
            - ``LEFT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The custom title for the legend.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the legend is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the legend.

            If this value is omitted, a default width is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LegendOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class LineChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param category: The category field wells of a line chart. Values are grouped by category fields.
            :param colors: The color field wells of a line chart. Values are grouped by category fields.
            :param small_multiples: The small multiples field well of a line chart.
            :param values: The value field wells of a line chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__12052e7450234480b9d49028f99b1c0591e1bc9fc7c0a3104a91188988231ba9)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The category field wells of a line chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The color field wells of a line chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a line chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LineChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "default_series_settings": "defaultSeriesSettings",
            "field_wells": "fieldWells",
            "forecast_configurations": "forecastConfigurations",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "series": "series",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "type": "type",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
        },
    )
    class LineChartConfigurationProperty:
        def __init__(
            self,
            *,
            contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            default_series_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineChartDefaultSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            forecast_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ForecastConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            series: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a line chart.

            :param contribution_analysis_defaults: The default configuration of a line chart's contribution analysis.
            :param data_labels: The data label configuration of a line chart.
            :param default_series_settings: The options that determine the default presentation of all line series in ``LineChartVisual`` .
            :param field_wells: The field well configuration of a line chart.
            :param forecast_configurations: The forecast configuration of a line chart.
            :param legend: The legend configuration of a line chart.
            :param primary_y_axis_display_options: The series axis configuration of a line chart.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param reference_lines: The reference lines configuration of a line chart.
            :param secondary_y_axis_display_options: The series axis configuration of a line chart.
            :param secondary_y_axis_label_options: The options that determine the presentation of the secondary y-axis label.
            :param series: The series item configuration of a line chart.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a line chart.
            :param tooltip: The tooltip configuration of a line chart.
            :param type: Determines the type of the line chart.
            :param visual_palette: The visual palette configuration of a line chart.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_chart_configuration_property = quicksight.CfnAnalysis.LineChartConfigurationProperty(
                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                        axis_binding="axisBinding",
                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    ),
                    field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                        line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                        forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                            lower_boundary=123,
                            periods_backward=123,
                            periods_forward=123,
                            prediction_interval=123,
                            seasonality=123,
                            upper_boundary=123
                        ),
                        scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                            what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                date="date",
                                value=123
                            ),
                            what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                end_date="endDate",
                                start_date="startDate",
                                value=123
                            )
                        )
                    )],
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                        axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                            treatment_option="treatmentOption"
                        )]
                    ),
                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                        axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                            treatment_option="treatmentOption"
                        )]
                    ),
                    secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    series=[quicksight.CfnAnalysis.SeriesItemProperty(
                        data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                            axis_binding="axisBinding",
                            field_id="fieldId",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            )
                        ),
                        field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                            axis_binding="axisBinding",
                            field_id="fieldId",
                
                            # the properties below are optional
                            settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            )
                        )
                    )],
                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                        category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    type="type",
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8783ad51034c90ab63639beb8d9f674a44fc140a1f365ab4f90ed8634bccc604)
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument default_series_settings", value=default_series_settings, expected_type=type_hints["default_series_settings"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument forecast_configurations", value=forecast_configurations, expected_type=type_hints["forecast_configurations"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument series", value=series, expected_type=type_hints["series"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if default_series_settings is not None:
                self._values["default_series_settings"] = default_series_settings
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if forecast_configurations is not None:
                self._values["forecast_configurations"] = forecast_configurations
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if series is not None:
                self._values["series"] = series
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if type is not None:
                self._values["type"] = type
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ContributionAnalysisDefaultProperty"]]]]:
            '''The default configuration of a line chart's contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The data label configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def default_series_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartDefaultSeriesSettingsProperty"]]:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-defaultseriessettings
            '''
            result = self._values.get("default_series_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartDefaultSeriesSettingsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartFieldWellsProperty"]]:
            '''The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartFieldWellsProperty"]], result)

        @builtins.property
        def forecast_configurations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ForecastConfigurationProperty"]]]]:
            '''The forecast configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-forecastconfigurations
            '''
            result = self._values.get("forecast_configurations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ForecastConfigurationProperty"]]]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineSeriesAxisDisplayOptionsProperty"]]:
            '''The series axis configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineSeriesAxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineProperty"]]]]:
            '''The reference lines configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineProperty"]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineSeriesAxisDisplayOptionsProperty"]]:
            '''The series axis configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineSeriesAxisDisplayOptionsProperty"]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the secondary y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def series(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SeriesItemProperty"]]]]:
            '''The series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-series
            '''
            result = self._values.get("series")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SeriesItemProperty"]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartSortConfigurationProperty"]]:
            '''The sort configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Determines the type of the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The visual palette configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartDefaultSeriesSettingsProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            line_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            marker_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :param axis_binding: The axis to which you are binding all line series to.
            :param line_style_settings: Line styles options for all line series in the visual.
            :param marker_style_settings: Marker styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_default_series_settings_property = quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                    axis_binding="axisBinding",
                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__712a9cec0180817cc2e5fd5018c9b7463dfb8825394f0abbff651ac76c37e63f)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis to which you are binding all line series to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartLineStyleSettingsProperty"]]:
            '''Line styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartLineStyleSettingsProperty"]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartMarkerStyleSettingsProperty"]]:
            '''Marker styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartMarkerStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartDefaultSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LineChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_chart_aggregated_field_wells": "lineChartAggregatedFieldWells",
        },
    )
    class LineChartFieldWellsProperty:
        def __init__(
            self,
            *,
            line_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param line_chart_aggregated_field_wells: The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_field_wells_property = quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                    line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9961d37a6696334c9f4c5e36bfc61631d3b8b30ed42f71a18bdcec19e46a746)
                check_type(argname="argument line_chart_aggregated_field_wells", value=line_chart_aggregated_field_wells, expected_type=type_hints["line_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_chart_aggregated_field_wells is not None:
                self._values["line_chart_aggregated_field_wells"] = line_chart_aggregated_field_wells

        @builtins.property
        def line_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartfieldwells.html#cfn-quicksight-analysis-linechartfieldwells-linechartaggregatedfieldwells
            '''
            result = self._values.get("line_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_interpolation": "lineInterpolation",
            "line_style": "lineStyle",
            "line_visibility": "lineVisibility",
            "line_width": "lineWidth",
        },
    )
    class LineChartLineStyleSettingsProperty:
        def __init__(
            self,
            *,
            line_interpolation: typing.Optional[builtins.str] = None,
            line_style: typing.Optional[builtins.str] = None,
            line_visibility: typing.Optional[builtins.str] = None,
            line_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :param line_interpolation: Interpolation style for line series. - ``LINEAR`` : Show as default, linear style. - ``SMOOTH`` : Show as a smooth curve. - ``STEPPED`` : Show steps in line.
            :param line_style: Line style for line series. - ``SOLID`` : Show as a solid line. - ``DOTTED`` : Show as a dotted line. - ``DASHED`` : Show as a dashed line.
            :param line_visibility: Configuration option that determines whether to show the line for the series.
            :param line_width: Width that determines the line thickness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_line_style_settings_property = quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                    line_interpolation="lineInterpolation",
                    line_style="lineStyle",
                    line_visibility="lineVisibility",
                    line_width="lineWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d48987524f10706d67bcea9c455673a6e9595c9bdddca32eb41238a594c60009)
                check_type(argname="argument line_interpolation", value=line_interpolation, expected_type=type_hints["line_interpolation"])
                check_type(argname="argument line_style", value=line_style, expected_type=type_hints["line_style"])
                check_type(argname="argument line_visibility", value=line_visibility, expected_type=type_hints["line_visibility"])
                check_type(argname="argument line_width", value=line_width, expected_type=type_hints["line_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_interpolation is not None:
                self._values["line_interpolation"] = line_interpolation
            if line_style is not None:
                self._values["line_style"] = line_style
            if line_visibility is not None:
                self._values["line_visibility"] = line_visibility
            if line_width is not None:
                self._values["line_width"] = line_width

        @builtins.property
        def line_interpolation(self) -> typing.Optional[builtins.str]:
            '''Interpolation style for line series.

            - ``LINEAR`` : Show as default, linear style.
            - ``SMOOTH`` : Show as a smooth curve.
            - ``STEPPED`` : Show steps in line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-lineinterpolation
            '''
            result = self._values.get("line_interpolation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style(self) -> typing.Optional[builtins.str]:
            '''Line style for line series.

            - ``SOLID`` : Show as a solid line.
            - ``DOTTED`` : Show as a dotted line.
            - ``DASHED`` : Show as a dashed line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linestyle
            '''
            result = self._values.get("line_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the line for the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linevisibility
            '''
            result = self._values.get("line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_width(self) -> typing.Optional[builtins.str]:
            '''Width that determines the line thickness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linewidth
            '''
            result = self._values.get("line_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartLineStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "marker_color": "markerColor",
            "marker_shape": "markerShape",
            "marker_size": "markerSize",
            "marker_visibility": "markerVisibility",
        },
    )
    class LineChartMarkerStyleSettingsProperty:
        def __init__(
            self,
            *,
            marker_color: typing.Optional[builtins.str] = None,
            marker_shape: typing.Optional[builtins.str] = None,
            marker_size: typing.Optional[builtins.str] = None,
            marker_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :param marker_color: Color of marker in the series.
            :param marker_shape: Shape option for markers in the series. - ``CIRCLE`` : Show marker as a circle. - ``TRIANGLE`` : Show marker as a triangle. - ``SQUARE`` : Show marker as a square. - ``DIAMOND`` : Show marker as a diamond. - ``ROUNDED_SQUARE`` : Show marker as a rounded square.
            :param marker_size: Size of marker in the series.
            :param marker_visibility: Configuration option that determines whether to show the markers in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_marker_style_settings_property = quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                    marker_color="markerColor",
                    marker_shape="markerShape",
                    marker_size="markerSize",
                    marker_visibility="markerVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__40644dd10170cfd872b3cdf3ad2171913338fffe97b2ed6f6668308f0883a389)
                check_type(argname="argument marker_color", value=marker_color, expected_type=type_hints["marker_color"])
                check_type(argname="argument marker_shape", value=marker_shape, expected_type=type_hints["marker_shape"])
                check_type(argname="argument marker_size", value=marker_size, expected_type=type_hints["marker_size"])
                check_type(argname="argument marker_visibility", value=marker_visibility, expected_type=type_hints["marker_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if marker_color is not None:
                self._values["marker_color"] = marker_color
            if marker_shape is not None:
                self._values["marker_shape"] = marker_shape
            if marker_size is not None:
                self._values["marker_size"] = marker_size
            if marker_visibility is not None:
                self._values["marker_visibility"] = marker_visibility

        @builtins.property
        def marker_color(self) -> typing.Optional[builtins.str]:
            '''Color of marker in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markercolor
            '''
            result = self._values.get("marker_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_shape(self) -> typing.Optional[builtins.str]:
            '''Shape option for markers in the series.

            - ``CIRCLE`` : Show marker as a circle.
            - ``TRIANGLE`` : Show marker as a triangle.
            - ``SQUARE`` : Show marker as a square.
            - ``DIAMOND`` : Show marker as a diamond.
            - ``ROUNDED_SQUARE`` : Show marker as a rounded square.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markershape
            '''
            result = self._values.get("marker_shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_size(self) -> typing.Optional[builtins.str]:
            '''Size of marker in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markersize
            '''
            result = self._values.get("marker_size")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the markers in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markervisibility
            '''
            result = self._values.get("marker_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartMarkerStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LineChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            line_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            marker_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of a line series in the visual.

            :param line_style_settings: Line styles options for a line series in ``LineChartVisual`` .
            :param marker_style_settings: Marker styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_series_settings_property = quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ffc7133f3f4106f26713ea7e63592136a91f7c6edf1a0c6041221b5f5091873c)
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartLineStyleSettingsProperty"]]:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html#cfn-quicksight-analysis-linechartseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartLineStyleSettingsProperty"]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartMarkerStyleSettingsProperty"]]:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html#cfn-quicksight-analysis-linechartseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartMarkerStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LineChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit_configuration": "categoryItemsLimitConfiguration",
            "category_sort": "categorySort",
            "color_items_limit_configuration": "colorItemsLimitConfiguration",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class LineChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a line chart.

            :param category_items_limit_configuration: The limit on the number of categories that are displayed in a line chart.
            :param category_sort: The sort configuration of the category fields.
            :param color_items_limit_configuration: The limit on the number of lines that are displayed in a line chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_sort_configuration_property = quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                    category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7dbd6ce87bc54c6447b1a2b1ed0268afd76988d72455e9e3df22380e0ae5066f)
                check_type(argname="argument category_items_limit_configuration", value=category_items_limit_configuration, expected_type=type_hints["category_items_limit_configuration"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit_configuration", value=color_items_limit_configuration, expected_type=type_hints["color_items_limit_configuration"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit_configuration is not None:
                self._values["category_items_limit_configuration"] = category_items_limit_configuration
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit_configuration is not None:
                self._values["color_items_limit_configuration"] = color_items_limit_configuration
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories that are displayed in a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-categoryitemslimitconfiguration
            '''
            result = self._values.get("category_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of lines that are displayed in a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-coloritemslimitconfiguration
            '''
            result = self._values.get("color_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LineChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class LineChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a line chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_chart_visual_property = quicksight.CfnAnalysis.LineChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.LineChartConfigurationProperty(
                        contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                            axis_binding="axisBinding",
                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        ),
                        field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                            line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                            forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                                lower_boundary=123,
                                periods_backward=123,
                                periods_forward=123,
                                prediction_interval=123,
                                seasonality=123,
                                upper_boundary=123
                            ),
                            scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                                what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                    date="date",
                                    value=123
                                ),
                                what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                    end_date="endDate",
                                    start_date="startDate",
                                    value=123
                                )
                            )
                        )],
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                            axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                treatment_option="treatmentOption"
                            )]
                        ),
                        primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                            data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                            axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                treatment_option="treatmentOption"
                            )]
                        ),
                        secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        series=[quicksight.CfnAnalysis.SeriesItemProperty(
                            data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                                axis_binding="axisBinding",
                                field_id="fieldId",
                
                                # the properties below are optional
                                field_value="fieldValue",
                                settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                )
                            ),
                            field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                                axis_binding="axisBinding",
                                field_id="fieldId",
                
                                # the properties below are optional
                                settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                )
                            )
                        )],
                        small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                            category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        type="type",
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e5284f9b25fc45cd57b681aaf71fe392497852dbd890bfdb18384e426b9414db)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartConfigurationProperty"]]:
            '''The configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_options": "axisOptions",
            "missing_data_configurations": "missingDataConfigurations",
        },
    )
    class LineSeriesAxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            missing_data_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MissingDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The series axis configuration of a line chart.

            :param axis_options: The options that determine the presentation of the line series axis.
            :param missing_data_configurations: The configuration options that determine how missing data is treated during the rendering of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_series_axis_display_options_property = quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                    axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                        treatment_option="treatmentOption"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__148c1a4ce871ab113950a9a5b24c4b59eefdbab388f4ae40ddf6334475395d43)
                check_type(argname="argument axis_options", value=axis_options, expected_type=type_hints["axis_options"])
                check_type(argname="argument missing_data_configurations", value=missing_data_configurations, expected_type=type_hints["missing_data_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_options is not None:
                self._values["axis_options"] = axis_options
            if missing_data_configurations is not None:
                self._values["missing_data_configurations"] = missing_data_configurations

        @builtins.property
        def axis_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the line series axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html#cfn-quicksight-analysis-lineseriesaxisdisplayoptions-axisoptions
            '''
            result = self._values.get("axis_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def missing_data_configurations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MissingDataConfigurationProperty"]]]]:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html#cfn-quicksight-analysis-lineseriesaxisdisplayoptions-missingdataconfigurations
            '''
            result = self._values.get("missing_data_configurations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MissingDataConfigurationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineSeriesAxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ListControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "search_options": "searchOptions",
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class ListControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            search_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ListControlSearchOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param search_options: The configuration of the search options in a list control.
            :param select_all_options: The configuration of the ``Select all`` options in a list control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                list_control_display_options_property = quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                    search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                        visibility="visibility"
                    ),
                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e15b3daa8a4eb17bbf585641affb51d65a81c4382f500d0f01869311df1c752d)
                check_type(argname="argument search_options", value=search_options, expected_type=type_hints["search_options"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if search_options is not None:
                self._values["search_options"] = search_options
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def search_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ListControlSearchOptionsProperty"]]:
            '''The configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-searchoptions
            '''
            result = self._values.get("search_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ListControlSearchOptionsProperty"]], result)

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ListControlSelectAllOptionsProperty"]]:
            '''The configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ListControlSelectAllOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ListControlSearchOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSearchOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the search options in a list control.

            :param visibility: The visibility configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolsearchoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                list_control_search_options_property = quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f2a2b999c175fd2f9fc4668e116879dadb6929a09f8d1f4b90b34bb82addd270)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolsearchoptions.html#cfn-quicksight-analysis-listcontrolsearchoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSearchOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSelectAllOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the ``Select all`` options in a list control.

            :param visibility: The visibility configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolselectalloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                list_control_select_all_options_property = quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__745d8b3603dca6bb47bafd4b6a572500ea846f3b8c92f3a78d41181d03473853)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolselectalloptions.html#cfn-quicksight-analysis-listcontrolselectalloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSelectAllOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LoadingAnimationProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class LoadingAnimationProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of loading animation in free-form layout.

            :param visibility: The visibility configuration of ``LoadingAnimation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-loadinganimation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                loading_animation_property = quicksight.CfnAnalysis.LoadingAnimationProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__117cbdb7cd88c7d99a0fc27406b855af7f3291663cf0e5a9664fa47919f2dc7d)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of ``LoadingAnimation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-loadinganimation.html#cfn-quicksight-analysis-loadinganimation-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LoadingAnimationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LocalNavigationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"target_sheet_id": "targetSheetId"},
    )
    class LocalNavigationConfigurationProperty:
        def __init__(self, *, target_sheet_id: builtins.str) -> None:
            '''The navigation configuration for ``CustomActionNavigationOperation`` .

            :param target_sheet_id: The sheet that is targeted for navigation in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-localnavigationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                local_navigation_configuration_property = quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                    target_sheet_id="targetSheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8edd40e5c665390e851ec533fade8e1de0b7a881891695931eae142a128e034b)
                check_type(argname="argument target_sheet_id", value=target_sheet_id, expected_type=type_hints["target_sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "target_sheet_id": target_sheet_id,
            }

        @builtins.property
        def target_sheet_id(self) -> builtins.str:
            '''The sheet that is targeted for navigation in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-localnavigationconfiguration.html#cfn-quicksight-analysis-localnavigationconfiguration-targetsheetid
            '''
            result = self._values.get("target_sheet_id")
            assert result is not None, "Required property 'target_sheet_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LocalNavigationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.LongFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class LongFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for a subtitle.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                long_format_text_property = quicksight.CfnAnalysis.LongFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0ad7d8a04e1fea3fdf86b7d3de91e884f5864d8e3975fdee554e8f3c1fff48f2)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html#cfn-quicksight-analysis-longformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html#cfn-quicksight-analysis-longformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LongFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.MappedDataSetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "data_set_parameter_name": "dataSetParameterName",
        },
    )
    class MappedDataSetParameterProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            data_set_parameter_name: builtins.str,
        ) -> None:
            '''
            :param data_set_identifier: ``CfnAnalysis.MappedDataSetParameterProperty.DataSetIdentifier``.
            :param data_set_parameter_name: ``CfnAnalysis.MappedDataSetParameterProperty.DataSetParameterName``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                mapped_data_set_parameter_property = quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                    data_set_identifier="dataSetIdentifier",
                    data_set_parameter_name="dataSetParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9722426542715bb43b3c698c9d611350dd0f863e952977f0943c5c0559707160)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument data_set_parameter_name", value=data_set_parameter_name, expected_type=type_hints["data_set_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "data_set_parameter_name": data_set_parameter_name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''``CfnAnalysis.MappedDataSetParameterProperty.DataSetIdentifier``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html#cfn-quicksight-analysis-mappeddatasetparameter-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_parameter_name(self) -> builtins.str:
            '''``CfnAnalysis.MappedDataSetParameterProperty.DataSetParameterName``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html#cfn-quicksight-analysis-mappeddatasetparameter-datasetparametername
            '''
            result = self._values.get("data_set_parameter_name")
            assert result is not None, "Required property 'data_set_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MappedDataSetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.MaximumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MaximumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The maximum label of a data path label.

            :param visibility: The visibility of the maximum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                maximum_label_type_property = quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__132fda3fc2952925abdac70d31244274ec63918ac462e9bf5e4e769050394039)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the maximum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumlabeltype.html#cfn-quicksight-analysis-maximumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.MaximumMinimumComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "type": "type",
            "name": "name",
            "value": "value",
        },
    )
    class MaximumMinimumComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The maximum and minimum computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param type: The type of computation. Choose one of the following options:. - MAXIMUM: A maximum computation. - MINIMUM: A minimum computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                maximum_minimum_computation_property = quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__189a36ce054f57c902106eaa08ffe5dfbff5bcbcdfc89e8d7789e88b94dd6145)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"], result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of computation. Choose one of the following options:.

            - MAXIMUM: A maximum computation.
            - MINIMUM: A minimum computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumMinimumComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.MeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculated_measure_field": "calculatedMeasureField",
            "categorical_measure_field": "categoricalMeasureField",
            "date_measure_field": "dateMeasureField",
            "numerical_measure_field": "numericalMeasureField",
        },
    )
    class MeasureFieldProperty:
        def __init__(
            self,
            *,
            calculated_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CalculatedMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            categorical_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CategoricalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            date_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DateMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numerical_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure (metric) type field.

            :param calculated_measure_field: The calculated measure field only used in pivot tables.
            :param categorical_measure_field: The measure type field with categorical type columns.
            :param date_measure_field: The measure type field with date type columns.
            :param numerical_measure_field: The measure type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                measure_field_property = quicksight.CfnAnalysis.MeasureFieldProperty(
                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                        expression="expression",
                        field_id="fieldId"
                    ),
                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b2dd402a512e779923f0cba4b24087e39e2767a91bbd44697e671950c130af66)
                check_type(argname="argument calculated_measure_field", value=calculated_measure_field, expected_type=type_hints["calculated_measure_field"])
                check_type(argname="argument categorical_measure_field", value=categorical_measure_field, expected_type=type_hints["categorical_measure_field"])
                check_type(argname="argument date_measure_field", value=date_measure_field, expected_type=type_hints["date_measure_field"])
                check_type(argname="argument numerical_measure_field", value=numerical_measure_field, expected_type=type_hints["numerical_measure_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if calculated_measure_field is not None:
                self._values["calculated_measure_field"] = calculated_measure_field
            if categorical_measure_field is not None:
                self._values["categorical_measure_field"] = categorical_measure_field
            if date_measure_field is not None:
                self._values["date_measure_field"] = date_measure_field
            if numerical_measure_field is not None:
                self._values["numerical_measure_field"] = numerical_measure_field

        @builtins.property
        def calculated_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CalculatedMeasureFieldProperty"]]:
            '''The calculated measure field only used in pivot tables.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-calculatedmeasurefield
            '''
            result = self._values.get("calculated_measure_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CalculatedMeasureFieldProperty"]], result)

        @builtins.property
        def categorical_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CategoricalMeasureFieldProperty"]]:
            '''The measure type field with categorical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-categoricalmeasurefield
            '''
            result = self._values.get("categorical_measure_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CategoricalMeasureFieldProperty"]], result)

        @builtins.property
        def date_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateMeasureFieldProperty"]]:
            '''The measure type field with date type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-datemeasurefield
            '''
            result = self._values.get("date_measure_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateMeasureFieldProperty"]], result)

        @builtins.property
        def numerical_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericalMeasureFieldProperty"]]:
            '''The measure type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-numericalmeasurefield
            '''
            result = self._values.get("numerical_measure_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericalMeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.MetricComparisonComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "from_value": "fromValue",
            "target_value": "targetValue",
            "time": "time",
            "name": "name",
        },
    )
    class MetricComparisonComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            from_value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            target_value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The metric comparison computation configuration.

            :param computation_id: The ID for a computation.
            :param from_value: The field that is used in a metric comparison from value setup.
            :param target_value: The field that is used in a metric comparison to value setup.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                metric_comparison_computation_property = quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                    computation_id="computationId",
                    from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                    target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a91fa342e53ed6f91bead5f9636c2211b37caf97a6e55463c5c9853db8eae27b)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument from_value", value=from_value, expected_type=type_hints["from_value"])
                check_type(argname="argument target_value", value=target_value, expected_type=type_hints["target_value"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "from_value": from_value,
                "target_value": target_value,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def from_value(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]:
            '''The field that is used in a metric comparison from value setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-fromvalue
            '''
            result = self._values.get("from_value")
            assert result is not None, "Required property 'from_value' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"], result)

        @builtins.property
        def target_value(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]:
            '''The field that is used in a metric comparison to value setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-targetvalue
            '''
            result = self._values.get("target_value")
            assert result is not None, "Required property 'target_value' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MetricComparisonComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.MinimumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MinimumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The minimum label of a data path label.

            :param visibility: The visibility of the minimum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-minimumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                minimum_label_type_property = quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b24e44009415a6c6718a11bbbb682734dcf9321b444f906e26a340d9a0af4af9)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the minimum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-minimumlabeltype.html#cfn-quicksight-analysis-minimumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MinimumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.MissingDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"treatment_option": "treatmentOption"},
    )
    class MissingDataConfigurationProperty:
        def __init__(
            self,
            *,
            treatment_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :param treatment_option: The treatment option that determines how missing data should be rendered. Choose from the following options:. - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value. - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` . - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-missingdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                missing_data_configuration_property = quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                    treatment_option="treatmentOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__938fb9dbf52790acc7ec1e50594d516345571c5c5ea382de808cbaebe61da3fd)
                check_type(argname="argument treatment_option", value=treatment_option, expected_type=type_hints["treatment_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if treatment_option is not None:
                self._values["treatment_option"] = treatment_option

        @builtins.property
        def treatment_option(self) -> typing.Optional[builtins.str]:
            '''The treatment option that determines how missing data should be rendered. Choose from the following options:.

            - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value.
            - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` .
            - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-missingdataconfiguration.html#cfn-quicksight-analysis-missingdataconfiguration-treatmentoption
            '''
            result = self._values.get("treatment_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MissingDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NegativeValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"display_mode": "displayMode"},
    )
    class NegativeValueConfigurationProperty:
        def __init__(self, *, display_mode: builtins.str) -> None:
            '''The options that determine the negative value configuration.

            :param display_mode: Determines the display mode of the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-negativevalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                negative_value_configuration_property = quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                    display_mode="displayMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f43be72a6bdd1b6d36b53f1edcd1c145ecf9833e0be86b18c483e2c655e84836)
                check_type(argname="argument display_mode", value=display_mode, expected_type=type_hints["display_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "display_mode": display_mode,
            }

        @builtins.property
        def display_mode(self) -> builtins.str:
            '''Determines the display mode of the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-negativevalueconfiguration.html#cfn-quicksight-analysis-negativevalueconfiguration-displaymode
            '''
            result = self._values.get("display_mode")
            assert result is not None, "Required property 'display_mode' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NegativeValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NullValueFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"null_string": "nullString"},
    )
    class NullValueFormatConfigurationProperty:
        def __init__(self, *, null_string: builtins.str) -> None:
            '''The options that determine the null value format configuration.

            :param null_string: Determines the null string of null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-nullvalueformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                null_value_format_configuration_property = quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                    null_string="nullString"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__35f31368b328ad250a5f6529200843a8c2eed2f5011aba82464dd02fd785a61a)
                check_type(argname="argument null_string", value=null_string, expected_type=type_hints["null_string"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "null_string": null_string,
            }

        @builtins.property
        def null_string(self) -> builtins.str:
            '''Determines the null string of null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-nullvalueformatconfiguration.html#cfn-quicksight-analysis-nullvalueformatconfiguration-nullstring
            '''
            result = self._values.get("null_string")
            assert result is not None, "Required property 'null_string' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NullValueFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class NumberDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the number display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value of the number format.
            :param prefix: Determines the prefix value of the number format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                number_display_format_configuration_property = quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__980fea01022173c154c7296e9fcc1ca025eca5a3c05156180a7b6cf30b459802)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NumberFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"format_configuration": "formatConfiguration"},
    )
    class NumberFormatConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for number fields.

            :param format_configuration: The options that determine the numeric format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                number_format_configuration_property = quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__652da5db56ba367f63dcc3e09d5016acdc536de052bcc8bab2c345c4381f16ed)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericFormatConfigurationProperty"]]:
            '''The options that determine the numeric format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberformatconfiguration.html#cfn-quicksight-analysis-numberformatconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NumericAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "scale": "scale"},
    )
    class NumericAxisOptionsProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for an axis with a numeric field.

            :param range: The range setup of a numeric axis.
            :param scale: The scale setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                numeric_axis_options_property = quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                        data_driven=data_driven,
                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                            maximum=123,
                            minimum=123
                        )
                    ),
                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                            step_count=123,
                            step_size=123
                        ),
                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                            base=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3d8c460bf6f32b91c04167889ed22b358eeb73516b712762ef78a82474a9e835)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if scale is not None:
                self._values["scale"] = scale

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayRangeProperty"]]:
            '''The range setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html#cfn-quicksight-analysis-numericaxisoptions-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayRangeProperty"]], result)

        @builtins.property
        def scale(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisScaleProperty"]]:
            '''The scale setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html#cfn-quicksight-analysis-numericaxisoptions-scale
            '''
            result = self._values.get("scale")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "value": "value"},
    )
    class NumericEqualityDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            value: jsii.Number,
        ) -> None:
            '''The category drill down filter.

            :param column: The column that the filter is applied to.
            :param value: The value of the double input numeric drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_equality_drill_down_filter_property = quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__acf738e889bc0618003fa78595f3cb7eee8d6851e6bad68a9265ccfefeceef1b)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "value": value,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html#cfn-quicksight-analysis-numericequalitydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The value of the double input numeric drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html#cfn-quicksight-analysis-numericequalitydrilldownfilter-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NumericEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
            "value": "value",
        },
    )
    class NumericEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            match_operator: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``NumericEqualityFilter`` filters values that are equal to the specified value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``
            :param value: The input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_equality_filter_property = quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1c75e5bbe1238a201f85a94c16b095a983a84cb43fc8af4cd6ced86059f5a47d)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationFunctionProperty"]]:
            '''The aggregation function of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationFunctionProperty"]], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NumericFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "currency_display_format_configuration": "currencyDisplayFormatConfiguration",
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class NumericFormatConfigurationProperty:
        def __init__(
            self,
            *,
            currency_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CurrencyDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the numeric format configuration.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param currency_display_format_configuration: The options that determine the currency display format configuration.
            :param number_display_format_configuration: The options that determine the number display format configuration.
            :param percentage_display_format_configuration: The options that determine the percentage display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_format_configuration_property = quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix",
                        symbol="symbol"
                    ),
                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__566edeedca4ed20e48a4eda6f9af40c82aab81756e987c45265aa5fda0682404)
                check_type(argname="argument currency_display_format_configuration", value=currency_display_format_configuration, expected_type=type_hints["currency_display_format_configuration"])
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if currency_display_format_configuration is not None:
                self._values["currency_display_format_configuration"] = currency_display_format_configuration
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def currency_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CurrencyDisplayFormatConfigurationProperty"]]:
            '''The options that determine the currency display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-currencydisplayformatconfiguration
            '''
            result = self._values.get("currency_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CurrencyDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumberDisplayFormatConfigurationProperty"]]:
            '''The options that determine the number display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumberDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PercentageDisplayFormatConfigurationProperty"]]:
            '''The options that determine the percentage display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PercentageDisplayFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NumericRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "select_all_options": "selectAllOptions",
        },
    )
    class NumericRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            range_maximum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_minimum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``NumericRangeFilter`` filters values that are within the value range.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_range_filter_property = quicksight.CfnAnalysis.NumericRangeFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__88bd9d150ae96de667a1e3b25b5cc65409cf063cb33f0d0e5fba674800209944)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum is not None:
                self._values["range_maximum"] = range_maximum
            if range_minimum is not None:
                self._values["range_minimum"] = range_minimum
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationFunctionProperty"]]:
            '''The aggregation function of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationFunctionProperty"]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def range_maximum(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericRangeFilterValueProperty"]]:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericRangeFilterValueProperty"]], result)

        @builtins.property
        def range_minimum(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericRangeFilterValueProperty"]]:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericRangeFilterValueProperty"]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NumericRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={"parameter": "parameter", "static_value": "staticValue"},
    )
    class NumericRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            static_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The value input pf the numeric range filter.

            :param parameter: The parameter that is used in the numeric range.
            :param static_value: The static value of the numeric range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_range_filter_value_property = quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                    parameter="parameter",
                    static_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2403c508bca5ca082eeee8dbd225a008db08c3a639d0117b47d89267ad9bb404)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter that is used in the numeric range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html#cfn-quicksight-analysis-numericrangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def static_value(self) -> typing.Optional[jsii.Number]:
            '''The static value of the numeric range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html#cfn-quicksight-analysis-numericrangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_separator": "decimalSeparator",
            "thousands_separator": "thousandsSeparator",
        },
    )
    class NumericSeparatorConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_separator: typing.Optional[builtins.str] = None,
            thousands_separator: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ThousandSeparatorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the numeric separator configuration.

            :param decimal_separator: Determines the decimal separator.
            :param thousands_separator: The options that determine the thousands separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_separator_configuration_property = quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                    decimal_separator="decimalSeparator",
                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                        symbol="symbol",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45872501ea91ccc71a58d845f546dcba4d6912689c3be5feb9b13359e1f085de)
                check_type(argname="argument decimal_separator", value=decimal_separator, expected_type=type_hints["decimal_separator"])
                check_type(argname="argument thousands_separator", value=thousands_separator, expected_type=type_hints["thousands_separator"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_separator is not None:
                self._values["decimal_separator"] = decimal_separator
            if thousands_separator is not None:
                self._values["thousands_separator"] = thousands_separator

        @builtins.property
        def decimal_separator(self) -> typing.Optional[builtins.str]:
            '''Determines the decimal separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html#cfn-quicksight-analysis-numericseparatorconfiguration-decimalseparator
            '''
            result = self._values.get("decimal_separator")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thousands_separator(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ThousandSeparatorOptionsProperty"]]:
            '''The options that determine the thousands separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html#cfn-quicksight-analysis-numericseparatorconfiguration-thousandsseparator
            '''
            result = self._values.get("thousands_separator")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ThousandSeparatorOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericSeparatorConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NumericalAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "percentile_aggregation": "percentileAggregation",
            "simple_numerical_aggregation": "simpleNumericalAggregation",
        },
    )
    class NumericalAggregationFunctionProperty:
        def __init__(
            self,
            *,
            percentile_aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PercentileAggregationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            simple_numerical_aggregation: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Aggregation for numerical values.

            :param percentile_aggregation: An aggregation based on the percentile of values in a dimension or measure.
            :param simple_numerical_aggregation: Built-in aggregation functions for numerical values. - ``SUM`` : The sum of a dimension or measure. - ``AVERAGE`` : The average of a dimension or measure. - ``MIN`` : The minimum value of a dimension or measure. - ``MAX`` : The maximum value of a dimension or measure. - ``COUNT`` : The count of a dimension or measure. - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure. - ``VAR`` : The variance of a dimension or measure. - ``VARP`` : The partitioned variance of a dimension or measure. - ``STDEV`` : The standard deviation of a dimension or measure. - ``STDEVP`` : The partitioned standard deviation of a dimension or measure. - ``MEDIAN`` : The median value of a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numerical_aggregation_function_property = quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                        percentile_value=123
                    ),
                    simple_numerical_aggregation="simpleNumericalAggregation"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__836d306506e53962d3152fea384f453641eda78620b24ba606c883f3b88d217a)
                check_type(argname="argument percentile_aggregation", value=percentile_aggregation, expected_type=type_hints["percentile_aggregation"])
                check_type(argname="argument simple_numerical_aggregation", value=simple_numerical_aggregation, expected_type=type_hints["simple_numerical_aggregation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_aggregation is not None:
                self._values["percentile_aggregation"] = percentile_aggregation
            if simple_numerical_aggregation is not None:
                self._values["simple_numerical_aggregation"] = simple_numerical_aggregation

        @builtins.property
        def percentile_aggregation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PercentileAggregationProperty"]]:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html#cfn-quicksight-analysis-numericalaggregationfunction-percentileaggregation
            '''
            result = self._values.get("percentile_aggregation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PercentileAggregationProperty"]], result)

        @builtins.property
        def simple_numerical_aggregation(self) -> typing.Optional[builtins.str]:
            '''Built-in aggregation functions for numerical values.

            - ``SUM`` : The sum of a dimension or measure.
            - ``AVERAGE`` : The average of a dimension or measure.
            - ``MIN`` : The minimum value of a dimension or measure.
            - ``MAX`` : The maximum value of a dimension or measure.
            - ``COUNT`` : The count of a dimension or measure.
            - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure.
            - ``VAR`` : The variance of a dimension or measure.
            - ``VARP`` : The partitioned variance of a dimension or measure.
            - ``STDEV`` : The standard deviation of a dimension or measure.
            - ``STDEVP`` : The partitioned standard deviation of a dimension or measure.
            - ``MEDIAN`` : The median value of a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html#cfn-quicksight-analysis-numericalaggregationfunction-simplenumericalaggregation
            '''
            result = self._values.get("simple_numerical_aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NumericalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class NumericalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with numerical type columns.

            :param column: The column that is used in the ``NumericalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numerical_dimension_field_property = quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4222fc469387ac060d5618bf1b9c7de8502a43277c2ce2baba824cd18e066f41)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``NumericalDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumberFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumberFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.NumericalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class NumericalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with numerical type columns.

            :param column: The column that is used in the ``NumericalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numerical_measure_field_property = quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__09b09786ee329d00a9f13af2d5fdf09f422fa0081717548856e45146c9a17da0)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``NumericalMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericalAggregationFunctionProperty"]]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericalAggregationFunctionProperty"]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumberFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumberFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PaginationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"page_number": "pageNumber", "page_size": "pageSize"},
    )
    class PaginationConfigurationProperty:
        def __init__(self, *, page_number: jsii.Number, page_size: jsii.Number) -> None:
            '''The pagination configuration for a table visual or boxplot.

            :param page_number: Indicates the page number.
            :param page_size: Indicates how many items render in one page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pagination_configuration_property = quicksight.CfnAnalysis.PaginationConfigurationProperty(
                    page_number=123,
                    page_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d834e2877f486e3e7cdd49135fd5fd5eea42910a47519792cbc9566bb0e558f3)
                check_type(argname="argument page_number", value=page_number, expected_type=type_hints["page_number"])
                check_type(argname="argument page_size", value=page_size, expected_type=type_hints["page_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "page_number": page_number,
                "page_size": page_size,
            }

        @builtins.property
        def page_number(self) -> jsii.Number:
            '''Indicates the page number.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html#cfn-quicksight-analysis-paginationconfiguration-pagenumber
            '''
            result = self._values.get("page_number")
            assert result is not None, "Required property 'page_number' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def page_size(self) -> jsii.Number:
            '''Indicates how many items render in one page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html#cfn-quicksight-analysis-paginationconfiguration-pagesize
            '''
            result = self._values.get("page_size")
            assert result is not None, "Required property 'page_size' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PaginationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PanelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "background_visibility": "backgroundVisibility",
            "border_color": "borderColor",
            "border_style": "borderStyle",
            "border_thickness": "borderThickness",
            "border_visibility": "borderVisibility",
            "gutter_spacing": "gutterSpacing",
            "gutter_visibility": "gutterVisibility",
            "title": "title",
        },
    )
    class PanelConfigurationProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            background_visibility: typing.Optional[builtins.str] = None,
            border_color: typing.Optional[builtins.str] = None,
            border_style: typing.Optional[builtins.str] = None,
            border_thickness: typing.Optional[builtins.str] = None,
            border_visibility: typing.Optional[builtins.str] = None,
            gutter_spacing: typing.Optional[builtins.str] = None,
            gutter_visibility: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PanelTitleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A collection of options that configure how each panel displays in a small multiples chart.

            :param background_color: Sets the background color for each panel.
            :param background_visibility: Determines whether or not a background for each small multiples panel is rendered.
            :param border_color: Sets the line color of panel borders.
            :param border_style: Sets the line style of panel borders.
            :param border_thickness: Sets the line thickness of panel borders.
            :param border_visibility: Determines whether or not each panel displays a border.
            :param gutter_spacing: Sets the total amount of negative space to display between sibling panels.
            :param gutter_visibility: Determines whether or not negative space between sibling panels is rendered.
            :param title: Configures the title display within each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                panel_configuration_property = quicksight.CfnAnalysis.PanelConfigurationProperty(
                    background_color="backgroundColor",
                    background_visibility="backgroundVisibility",
                    border_color="borderColor",
                    border_style="borderStyle",
                    border_thickness="borderThickness",
                    border_visibility="borderVisibility",
                    gutter_spacing="gutterSpacing",
                    gutter_visibility="gutterVisibility",
                    title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_text_alignment="horizontalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7fcdde6144405e8734ededa49ed9bb6578d64cdcd90c6f7e51acde8330a711b9)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument background_visibility", value=background_visibility, expected_type=type_hints["background_visibility"])
                check_type(argname="argument border_color", value=border_color, expected_type=type_hints["border_color"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument border_thickness", value=border_thickness, expected_type=type_hints["border_thickness"])
                check_type(argname="argument border_visibility", value=border_visibility, expected_type=type_hints["border_visibility"])
                check_type(argname="argument gutter_spacing", value=gutter_spacing, expected_type=type_hints["gutter_spacing"])
                check_type(argname="argument gutter_visibility", value=gutter_visibility, expected_type=type_hints["gutter_visibility"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if background_visibility is not None:
                self._values["background_visibility"] = background_visibility
            if border_color is not None:
                self._values["border_color"] = border_color
            if border_style is not None:
                self._values["border_style"] = border_style
            if border_thickness is not None:
                self._values["border_thickness"] = border_thickness
            if border_visibility is not None:
                self._values["border_visibility"] = border_visibility
            if gutter_spacing is not None:
                self._values["gutter_spacing"] = gutter_spacing
            if gutter_visibility is not None:
                self._values["gutter_visibility"] = gutter_visibility
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''Sets the background color for each panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def background_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not a background for each small multiples panel is rendered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-backgroundvisibility
            '''
            result = self._values.get("background_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_color(self) -> typing.Optional[builtins.str]:
            '''Sets the line color of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-bordercolor
            '''
            result = self._values.get("border_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_style(self) -> typing.Optional[builtins.str]:
            '''Sets the line style of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_thickness(self) -> typing.Optional[builtins.str]:
            '''Sets the line thickness of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-borderthickness
            '''
            result = self._values.get("border_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not each panel displays a border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-bordervisibility
            '''
            result = self._values.get("border_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_spacing(self) -> typing.Optional[builtins.str]:
            '''Sets the total amount of negative space to display between sibling panels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-gutterspacing
            '''
            result = self._values.get("gutter_spacing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not negative space between sibling panels is rendered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-guttervisibility
            '''
            result = self._values.get("gutter_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PanelTitleOptionsProperty"]]:
            '''Configures the title display within each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PanelTitleOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PanelTitleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_configuration": "fontConfiguration",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "visibility": "visibility",
        },
    )
    class PanelTitleOptionsProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the title styles for each small multiples panel.

            :param font_configuration: ``CfnAnalysis.PanelTitleOptionsProperty.FontConfiguration``.
            :param horizontal_text_alignment: Sets the horizontal text alignment of the title within each panel.
            :param visibility: Determines whether or not panel titles are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                panel_title_options_property = quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_text_alignment="horizontalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__27efbfcc0fe34c45438d91e8063fd44d74e5bdd69a0ebca420f3bdf4e42b6593)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]]:
            '''``CfnAnalysis.PanelTitleOptionsProperty.FontConfiguration``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''Sets the horizontal text alignment of the title within each panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not panel titles are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelTitleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ParameterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class ParameterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ParameterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            dropdown: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ParameterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ParameterListControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            slider: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ParameterSliderControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_area: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ParameterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ParameterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The control of a parameter that users can interact with in a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date parameter that specifies date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_control_property = quicksight.CfnAnalysis.ParameterControlProperty(
                    date_time_picker=quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    dropdown=quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                            select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnAnalysis.ParameterListControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                            search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    slider=quicksight.CfnAnalysis.ParameterSliderControlProperty(
                        maximum_value=123,
                        minimum_value=123,
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_area=quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0207c2eeb4659b3f8ca769c11ec58ffa9972229f41b4bd0d903496369bd8086d)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterDateTimePickerControlProperty"]]:
            '''A control from a date parameter that specifies date and time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterDateTimePickerControlProperty"]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterDropDownControlProperty"]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterDropDownControlProperty"]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterListControlProperty"]]:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterListControlProperty"]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterSliderControlProperty"]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterSliderControlProperty"]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterTextAreaControlProperty"]]:
            '''A control to display a text box that is used to enter multiple entries.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterTextAreaControlProperty"]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterTextFieldControlProperty"]]:
            '''A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterTextFieldControlProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control from a date parameter that specifies date and time.

            :param parameter_control_id: The ID of the ``ParameterDateTimePickerControl`` .
            :param source_parameter_name: The name of the ``ParameterDateTimePickerControl`` .
            :param title: The title of the ``ParameterDateTimePickerControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_date_time_picker_control_property = quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__59215a2d615284549d970abe550d8fe9ff7ffd15eb3bc9ce24519fe550e96fbc)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The name of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimePickerControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimePickerControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameter_declaration": "dateTimeParameterDeclaration",
            "decimal_parameter_declaration": "decimalParameterDeclaration",
            "integer_parameter_declaration": "integerParameterDeclaration",
            "string_parameter_declaration": "stringParameterDeclaration",
        },
    )
    class ParameterDeclarationProperty:
        def __init__(
            self,
            *,
            date_time_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DateTimeParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            decimal_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DecimalParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            integer_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.IntegerParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            string_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.StringParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The declaration definition of a parameter.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_parameter_declaration: A parameter declaration for the ``DateTime`` data type.
            :param decimal_parameter_declaration: A parameter declaration for the ``Decimal`` data type.
            :param integer_parameter_declaration: A parameter declaration for the ``Integer`` data type.
            :param string_parameter_declaration: A parameter declaration for the ``String`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_declaration_property = quicksight.CfnAnalysis.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty(
                        name="name",
                
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnAnalysis.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnAnalysis.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnAnalysis.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dce6d181f4a61644f72b81f973882283fdb06e8e57ce1c4117e6b052bad6e918)
                check_type(argname="argument date_time_parameter_declaration", value=date_time_parameter_declaration, expected_type=type_hints["date_time_parameter_declaration"])
                check_type(argname="argument decimal_parameter_declaration", value=decimal_parameter_declaration, expected_type=type_hints["decimal_parameter_declaration"])
                check_type(argname="argument integer_parameter_declaration", value=integer_parameter_declaration, expected_type=type_hints["integer_parameter_declaration"])
                check_type(argname="argument string_parameter_declaration", value=string_parameter_declaration, expected_type=type_hints["string_parameter_declaration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameter_declaration is not None:
                self._values["date_time_parameter_declaration"] = date_time_parameter_declaration
            if decimal_parameter_declaration is not None:
                self._values["decimal_parameter_declaration"] = decimal_parameter_declaration
            if integer_parameter_declaration is not None:
                self._values["integer_parameter_declaration"] = integer_parameter_declaration
            if string_parameter_declaration is not None:
                self._values["string_parameter_declaration"] = string_parameter_declaration

        @builtins.property
        def date_time_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``DateTime`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-datetimeparameterdeclaration
            '''
            result = self._values.get("date_time_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeParameterDeclarationProperty"]], result)

        @builtins.property
        def decimal_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``Decimal`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-decimalparameterdeclaration
            '''
            result = self._values.get("decimal_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalParameterDeclarationProperty"]], result)

        @builtins.property
        def integer_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.IntegerParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-integerparameterdeclaration
            '''
            result = self._values.get("integer_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.IntegerParameterDeclarationProperty"]], result)

        @builtins.property
        def string_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``String`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-stringparameterdeclaration
            '''
            result = self._values.get("string_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringParameterDeclarationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ParameterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterDropDownControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param parameter_control_id: The ID of the ``ParameterDropDownControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterDropDownControl`` .
            :param title: The title of the ``ParameterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_drop_down_control_property = quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                        select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__db1e7b8eb24fd854321bd154d83042a96f338bc32ad3c58bff6055654d6ea9ee)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DropDownControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DropDownControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ParameterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterListControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :param parameter_control_id: The ID of the ``ParameterListControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterListControl`` .
            :param title: The title of the ``ParameterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_list_control_property = quicksight.CfnAnalysis.ParameterListControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                        search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a9c59738cb53da3762254f4572d873727eaa0a1c3e3a795b386b44151270aa95)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ListControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ListControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ParameterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "link_to_data_set_column": "linkToDataSetColumn",
            "values": "values",
        },
    )
    class ParameterSelectableValuesProperty:
        def __init__(
            self,
            *,
            link_to_data_set_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param link_to_data_set_column: The column identifier that fetches values from the data set.
            :param values: The values that are used in ``ParameterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_selectable_values_property = quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                    link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__806e2a821d889e6a1f2e9d0892ce06143ad353221f168c569ce8ed79cc1d3a8e)
                check_type(argname="argument link_to_data_set_column", value=link_to_data_set_column, expected_type=type_hints["link_to_data_set_column"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if link_to_data_set_column is not None:
                self._values["link_to_data_set_column"] = link_to_data_set_column
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def link_to_data_set_column(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]]:
            '''The column identifier that fetches values from the data set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html#cfn-quicksight-analysis-parameterselectablevalues-linktodatasetcolumn
            '''
            result = self._values.get("link_to_data_set_column")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]], result)

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in ``ParameterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html#cfn-quicksight-analysis-parameterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ParameterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterSliderControlProperty:
        def __init__(
            self,
            *,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param maximum_value: The smaller value that is displayed at the left of the slider.
            :param minimum_value: The larger value that is displayed at the right of the slider.
            :param parameter_control_id: The ID of the ``ParameterSliderControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into.
            :param title: The title of the ``ParameterSliderControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_slider_control_property = quicksight.CfnAnalysis.ParameterSliderControlProperty(
                    maximum_value=123,
                    minimum_value=123,
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75af37a6e6766837f77d5d48d2fc848b5ea5b9decd51ba041f9e0109bf65cd08)
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SliderControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SliderControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ParameterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextAreaControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param parameter_control_id: The ID of the ``ParameterTextAreaControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextAreaControl`` .
            :param title: The title of the ``ParameterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_text_area_control_property = quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0572813bf25289af88d9bad0046e7d2a8adbac96e42dd5a003ea1f7929d1bc81)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextAreaControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextAreaControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ParameterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextFieldControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param parameter_control_id: The ID of the ``ParameterTextFieldControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextFieldControl`` .
            :param title: The title of the ``ParameterTextFieldControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_text_field_control_property = quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a3140a60f08d07b18a886fe7ad1e0357eb993968bbf79ad92d445dc0eb5d0559)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextFieldControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextFieldControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameters": "dateTimeParameters",
            "decimal_parameters": "decimalParameters",
            "integer_parameters": "integerParameters",
            "string_parameters": "stringParameters",
        },
    )
    class ParametersProperty:
        def __init__(
            self,
            *,
            date_time_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DateTimeParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            decimal_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DecimalParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            integer_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.IntegerParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            string_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.StringParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A list of Amazon QuickSight parameters and the list's override values.

            :param date_time_parameters: The parameters that have a data type of date-time.
            :param decimal_parameters: The parameters that have a data type of decimal.
            :param integer_parameters: The parameters that have a data type of integer.
            :param string_parameters: The parameters that have a data type of string.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameters_property = quicksight.CfnAnalysis.ParametersProperty(
                    date_time_parameters=[quicksight.CfnAnalysis.DateTimeParameterProperty(
                        name="name",
                        values=["values"]
                    )],
                    decimal_parameters=[quicksight.CfnAnalysis.DecimalParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    integer_parameters=[quicksight.CfnAnalysis.IntegerParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    string_parameters=[quicksight.CfnAnalysis.StringParameterProperty(
                        name="name",
                        values=["values"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__032a4e49690d1db651d95576aadd9028dc207b92af93eb7fef0c92564bb3d444)
                check_type(argname="argument date_time_parameters", value=date_time_parameters, expected_type=type_hints["date_time_parameters"])
                check_type(argname="argument decimal_parameters", value=decimal_parameters, expected_type=type_hints["decimal_parameters"])
                check_type(argname="argument integer_parameters", value=integer_parameters, expected_type=type_hints["integer_parameters"])
                check_type(argname="argument string_parameters", value=string_parameters, expected_type=type_hints["string_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameters is not None:
                self._values["date_time_parameters"] = date_time_parameters
            if decimal_parameters is not None:
                self._values["decimal_parameters"] = decimal_parameters
            if integer_parameters is not None:
                self._values["integer_parameters"] = integer_parameters
            if string_parameters is not None:
                self._values["string_parameters"] = string_parameters

        @builtins.property
        def date_time_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeParameterProperty"]]]]:
            '''The parameters that have a data type of date-time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-datetimeparameters
            '''
            result = self._values.get("date_time_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DateTimeParameterProperty"]]]], result)

        @builtins.property
        def decimal_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalParameterProperty"]]]]:
            '''The parameters that have a data type of decimal.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-decimalparameters
            '''
            result = self._values.get("decimal_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalParameterProperty"]]]], result)

        @builtins.property
        def integer_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.IntegerParameterProperty"]]]]:
            '''The parameters that have a data type of integer.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-integerparameters
            '''
            result = self._values.get("integer_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.IntegerParameterProperty"]]]], result)

        @builtins.property
        def string_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringParameterProperty"]]]]:
            '''The parameters that have a data type of string.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-stringparameters
            '''
            result = self._values.get("string_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringParameterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PercentVisibleRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"from_": "from", "to": "to"},
    )
    class PercentVisibleRangeProperty:
        def __init__(
            self,
            *,
            from_: typing.Optional[jsii.Number] = None,
            to: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The percent range in the visible range.

            :param from_: The lower bound of the range.
            :param to: The top bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                percent_visible_range_property = quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                    from=123,
                    to=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__017b904cc8ba58f6f8bd9c71c01f137c8afc07e48b57becfc5a3dbbc716ad35e)
                check_type(argname="argument from_", value=from_, expected_type=type_hints["from_"])
                check_type(argname="argument to", value=to, expected_type=type_hints["to"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if from_ is not None:
                self._values["from_"] = from_
            if to is not None:
                self._values["to"] = to

        @builtins.property
        def from_(self) -> typing.Optional[jsii.Number]:
            '''The lower bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html#cfn-quicksight-analysis-percentvisiblerange-from
            '''
            result = self._values.get("from_")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def to(self) -> typing.Optional[jsii.Number]:
            '''The top bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html#cfn-quicksight-analysis-percentvisiblerange-to
            '''
            result = self._values.get("to")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentVisibleRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class PercentageDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the percentage display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param prefix: Determines the prefix value of the percentage format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                percentage_display_format_configuration_property = quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    prefix="prefix",
                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__70094d6e08ded9d6e9351191895a3f63c3ef8c01a388f01a0eb29a0ee71fdfdd)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentageDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PercentileAggregationProperty",
        jsii_struct_bases=[],
        name_mapping={"percentile_value": "percentileValue"},
    )
    class PercentileAggregationProperty:
        def __init__(
            self,
            *,
            percentile_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :param percentile_value: The percentile value. This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentileaggregation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                percentile_aggregation_property = quicksight.CfnAnalysis.PercentileAggregationProperty(
                    percentile_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__97849670dfceea4f015c9a258e2fd8fdb60f8fe4b9f3887b47311e282cea78d5)
                check_type(argname="argument percentile_value", value=percentile_value, expected_type=type_hints["percentile_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_value is not None:
                self._values["percentile_value"] = percentile_value

        @builtins.property
        def percentile_value(self) -> typing.Optional[jsii.Number]:
            '''The percentile value.

            This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentileaggregation.html#cfn-quicksight-analysis-percentileaggregation-percentilevalue
            '''
            result = self._values.get("percentile_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentileAggregationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "value": "value",
        },
    )
    class PeriodOverPeriodComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The period over period computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                period_over_period_computation_property = quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec1e71bacd5f64473b3510a5db1d62484a15be232580485c1f854d37f6b8df9b)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodOverPeriodComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PeriodToDateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "period_time_granularity": "periodTimeGranularity",
            "value": "value",
        },
    )
    class PeriodToDateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
            period_time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The period to date computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param period_time_granularity: The time granularity setup of period to date computation. Choose from the following options:. - YEAR: Year to date. - MONTH: Month to date.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                period_to_date_computation_property = quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    period_time_granularity="periodTimeGranularity",
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b44278fe5cfe71c7aa5c35ac19790767f96988ebf71a8b31870c1584c06e97b4)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_time_granularity", value=period_time_granularity, expected_type=type_hints["period_time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if period_time_granularity is not None:
                self._values["period_time_granularity"] = period_time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity setup of period to date computation. Choose from the following options:.

            - YEAR: Year to date.
            - MONTH: Month to date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-periodtimegranularity
            '''
            result = self._values.get("period_time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodToDateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class PieChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            :param category: The category (group/color) field wells of a pie chart.
            :param small_multiples: The small multiples field well of a pie chart.
            :param values: The value field wells of a pie chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b0210b27e3bc3834c56989f3fa34f59c5c0fcb66fb964fdc96fdfcc9766851c8)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The category (group/color) field wells of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a pie chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PieChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "donut_options": "donutOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class PieChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            donut_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DonutOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PieChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PieChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a pie chart.

            :param category_label_options: The label options of the group/color that is displayed in a pie chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param donut_options: The options that determine the shape of the chart. This option determines whether the chart is a pie chart or a donut chart.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a pie chart.
            :param tooltip: The tooltip display setup of the visual.
            :param value_label_options: The label options for the value that is displayed in a pie chart.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_configuration_property = quicksight.CfnAnalysis.PieChartConfigurationProperty(
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                        arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                            arc_thickness="arcThickness"
                        ),
                        donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                            label_visibility="labelVisibility"
                        )
                    ),
                    field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                        pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__44a7f8083afe17f7068f541cf73c6f0a0b414a6bd6c7bc9ffc83873d4cd09a8c)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument donut_options", value=donut_options, expected_type=type_hints["donut_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if donut_options is not None:
                self._values["donut_options"] = donut_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the group/color that is displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ContributionAnalysisDefaultProperty"]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def donut_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DonutOptionsProperty"]]:
            '''The options that determine the shape of the chart.

            This option determines whether the chart is a pie chart or a donut chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-donutoptions
            '''
            result = self._values.get("donut_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DonutOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PieChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PieChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PieChartSortConfigurationProperty"]]:
            '''The sort configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PieChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options for the value that is displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PieChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pie_chart_aggregated_field_wells": "pieChartAggregatedFieldWells",
        },
    )
    class PieChartFieldWellsProperty:
        def __init__(
            self,
            *,
            pie_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PieChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pie_chart_aggregated_field_wells: The field well configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_field_wells_property = quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                    pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d290cd7ba219d3a0da8b96be2229d45784fa3993a05e6c0fefd44457a6f729ed)
                check_type(argname="argument pie_chart_aggregated_field_wells", value=pie_chart_aggregated_field_wells, expected_type=type_hints["pie_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pie_chart_aggregated_field_wells is not None:
                self._values["pie_chart_aggregated_field_wells"] = pie_chart_aggregated_field_wells

        @builtins.property
        def pie_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PieChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartfieldwells.html#cfn-quicksight-analysis-piechartfieldwells-piechartaggregatedfieldwells
            '''
            result = self._values.get("pie_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PieChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PieChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class PieChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a pie chart.

            :param category_items_limit: The limit on the number of categories that are displayed in a pie chart.
            :param category_sort: The sort configuration of the category fields.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_sort_configuration_property = quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__66df0545014d697ad4125e09d2ec4abc2b4291bd932eda8879039a99dac03f1e)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories that are displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PieChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PieChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PieChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A pie or donut chart.

            The ``PieChartVisual`` structure describes a visual that is a member of the pie chart family.

            The following charts can be described by using this structure:

            - Pie charts
            - Donut charts

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            For more information, see `Using donut charts <https://docs.aws.amazon.com/quicksight/latest/user/donut-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a pie chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_visual_property = quicksight.CfnAnalysis.PieChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.PieChartConfigurationProperty(
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                            arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                                arc_thickness="arcThickness"
                            ),
                            donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                                label_visibility="labelVisibility"
                            )
                        ),
                        field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                            pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__73888a6d84575760d41ca9b5ffb6728ac74ce5a9d3b9473ebc3ab5d28bad7fdc)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PieChartConfigurationProperty"]]:
            '''The configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PieChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotFieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "sort_by": "sortBy"},
    )
    class PivotFieldSortOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            sort_by: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableSortByProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The field sort options for a pivot table sort configuration.

            :param field_id: The field ID for the field sort options.
            :param sort_by: The sort by field for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_field_sort_options_property = quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                    field_id="fieldId",
                    sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                        column=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                            direction="direction",
                            sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            )]
                        ),
                        field=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9f7805e890b1545fc6630d9d88081d7aa49fc2cf8d497c7446f0939e1e56be13)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "sort_by": sort_by,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html#cfn-quicksight-analysis-pivotfieldsortoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableSortByProperty"]:
            '''The sort by field for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html#cfn-quicksight-analysis-pivotfieldsortoptions-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableSortByProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotFieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class PivotTableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            rows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for the pivot table.

            :param columns: The columns field well for a pivot table. Values are grouped by columns fields.
            :param rows: The rows field well for a pivot table. Values are grouped by rows fields.
            :param values: The values field well for a pivot table. Values are aggregated based on rows and columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_aggregated_field_wells_property = quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                    columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8751491bdbc701c4449cf53a79d73fef5f57db715048727c87126a8644f5b671)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The columns field well for a pivot table.

            Values are grouped by columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The rows field well for a pivot table.

            Values are grouped by rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on rows and columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "scope": "scope",
            "text_format": "textFormat",
        },
    )
    class PivotTableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            scope: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableConditionalFormattingScopeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cell conditional formatting option for a pivot table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param scope: The scope of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_cell_conditional_formatting_property = quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                        role="role"
                    ),
                    text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a0ab532acfdfb2170b5f0f6cb1689b2675b265c3c7e81e95104850b17bc04fce)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if scope is not None:
                self._values["scope"] = scope
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def scope(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableConditionalFormattingScopeProperty"]]:
            '''The scope of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-scope
            '''
            result = self._values.get("scope")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableConditionalFormattingScopeProperty"]], result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextConditionalFormatProperty"]]:
            '''The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell"},
    )
    class PivotTableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_option_property = quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                            role="role"
                        ),
                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__043da837bcca55e21d88a6cde72bbb384e08451c1ebde5efd83f319fc2953225)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableCellConditionalFormattingProperty"]]:
            '''The cell conditional formatting option for a pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingoption.html#cfn-quicksight-analysis-pivottableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableCellConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class PivotTableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_property = quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                role="role"
                            ),
                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__666391e85a7dfaf1065018136067fc9d7e27028ec8f375b1e6dad68e92de8d09)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformatting.html#cfn-quicksight-analysis-pivottableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty",
        jsii_struct_bases=[],
        name_mapping={"role": "role"},
    )
    class PivotTableConditionalFormattingScopeProperty:
        def __init__(self, *, role: typing.Optional[builtins.str] = None) -> None:
            '''The scope of the cell for conditional formatting.

            :param role: The role (field, field total, grand total) of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingscope.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_scope_property = quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9a3daa44473bad29ce892b452a5880ea59a91dd3e6f46c71180e5752be9c860d)
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role (field, field total, grand total) of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingscope.html#cfn-quicksight-analysis-pivottableconditionalformattingscope-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingScopeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class PivotTableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_report_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``PivotTableVisual`` .

            :param field_options: The field options for a pivot table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a pivot table visual.
            :param sort_configuration: The sort configuration for a ``PivotTableVisual`` .
            :param table_options: The table options for a pivot table visual.
            :param total_options: The total options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_configuration_property = quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                    field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                        data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                            data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            )],
                
                            # the properties below are optional
                            width="width"
                        )],
                        selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            custom_label="customLabel",
                            visibility="visibility"
                        )]
                    ),
                    field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                        pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                            columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                        vertical_overflow_visibility="verticalOverflowVisibility"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                        field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                            field_id="fieldId",
                            sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                column=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                    direction="direction",
                                    sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    )]
                                ),
                                field=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )
                        )]
                    ),
                    table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                        cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        column_names_visibility="columnNamesVisibility",
                        metric_placement="metricPlacement",
                        row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                            row_alternate_colors=["rowAlternateColors"],
                            status="status"
                        ),
                        row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        single_metric_visibility="singleMetricVisibility",
                        toggle_buttons_visibility="toggleButtonsVisibility"
                    ),
                    total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                        column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                            custom_label="customLabel",
                            field_level="fieldLevel",
                            field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                field_id="fieldId"
                            )],
                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                            custom_label="customLabel",
                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                            custom_label="customLabel",
                            field_level="fieldLevel",
                            field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                field_id="fieldId"
                            )],
                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                            custom_label="customLabel",
                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e83bc604f673b90aa59968ab9b4bf98d8b9836285b7c7812aa528ddbd38609fc)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableFieldOptionsProperty"]]:
            '''The field options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableFieldOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableFieldWellsProperty"]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTablePaginatedReportOptionsProperty"]]:
            '''The paginated report options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTablePaginatedReportOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableSortConfigurationProperty"]]:
            '''The sort configuration for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableSortConfigurationProperty"]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableOptionsProperty"]]:
            '''The table options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableOptionsProperty"]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableTotalOptionsProperty"]]:
            '''The total options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableTotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableDataPathOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"data_path_list": "dataPathList", "width": "width"},
    )
    class PivotTableDataPathOptionProperty:
        def __init__(
            self,
            *,
            data_path_list: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]],
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data path options for the pivot table field options.

            :param data_path_list: The list of data path values for the data path options.
            :param width: The width of the data path option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_data_path_option_property = quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                    data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    )],
                
                    # the properties below are optional
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__94f23d64d32e10cd21faac9d6a8f7b6605ccc1e55503ac81ade15b3873974b0b)
                check_type(argname="argument data_path_list", value=data_path_list, expected_type=type_hints["data_path_list"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_path_list": data_path_list,
            }
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def data_path_list(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataPathValueProperty"]]]:
            '''The list of data path values for the data path options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html#cfn-quicksight-analysis-pivottabledatapathoption-datapathlist
            '''
            result = self._values.get("data_path_list")
            assert result is not None, "Required property 'data_path_list' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataPathValueProperty"]]], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the data path option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html#cfn-quicksight-analysis-pivottabledatapathoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableDataPathOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "visibility": "visibility",
        },
    )
    class PivotTableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The selected field options for the pivot table field options.

            :param field_id: The field ID of the pivot table field.
            :param custom_label: The custom label of the pivot table field.
            :param visibility: The visibility of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_field_option_property = quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__83ffacd0157b8fa3f52b4546be6342d61af4c880713d12370032afe968f46e0a)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_options": "dataPathOptions",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class PivotTableFieldOptionsProperty:
        def __init__(
            self,
            *,
            data_path_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableDataPathOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field options for a pivot table visual.

            :param data_path_options: The data path options for the pivot table field options.
            :param selected_field_options: The selected field options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_field_options_property = quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                    data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                        data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        )],
                
                        # the properties below are optional
                        width="width"
                    )],
                    selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__15682275c2340ea593e9910ab2f7f207e38d0cf93e87b80e5c1abab07f082b04)
                check_type(argname="argument data_path_options", value=data_path_options, expected_type=type_hints["data_path_options"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_options is not None:
                self._values["data_path_options"] = data_path_options
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def data_path_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableDataPathOptionProperty"]]]]:
            '''The data path options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html#cfn-quicksight-analysis-pivottablefieldoptions-datapathoptions
            '''
            result = self._values.get("data_path_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableDataPathOptionProperty"]]]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableFieldOptionProperty"]]]]:
            '''The selected field options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html#cfn-quicksight-analysis-pivottablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableFieldOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId"},
    )
    class PivotTableFieldSubtotalOptionsProperty:
        def __init__(self, *, field_id: typing.Optional[builtins.str] = None) -> None:
            '''The optional configuration of subtotals cells.

            :param field_id: The field ID of the subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldsubtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_field_subtotal_options_property = quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0bdc8c5da21a87f88e359286ad309da4b005492bb55e4e7cd379c70f0abf63b2)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldsubtotaloptions.html#cfn-quicksight-analysis-pivottablefieldsubtotaloptions-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldSubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pivot_table_aggregated_field_wells": "pivotTableAggregatedFieldWells",
        },
    )
    class PivotTableFieldWellsProperty:
        def __init__(
            self,
            *,
            pivot_table_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells for a pivot table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pivot_table_aggregated_field_wells: The aggregated field well for the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_field_wells_property = quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                    pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                        columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__26daf32220c6657273e4786dcba48ae3aee997a08fb55d1b7e1f90cdf9dde073)
                check_type(argname="argument pivot_table_aggregated_field_wells", value=pivot_table_aggregated_field_wells, expected_type=type_hints["pivot_table_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pivot_table_aggregated_field_wells is not None:
                self._values["pivot_table_aggregated_field_wells"] = pivot_table_aggregated_field_wells

        @builtins.property
        def pivot_table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldwells.html#cfn-quicksight-analysis-pivottablefieldwells-pivottableaggregatedfieldwells
            '''
            result = self._values.get("pivot_table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "column_header_style": "columnHeaderStyle",
            "column_names_visibility": "columnNamesVisibility",
            "metric_placement": "metricPlacement",
            "row_alternate_color_options": "rowAlternateColorOptions",
            "row_field_names_style": "rowFieldNamesStyle",
            "row_header_style": "rowHeaderStyle",
            "single_metric_visibility": "singleMetricVisibility",
            "toggle_buttons_visibility": "toggleButtonsVisibility",
        },
    )
    class PivotTableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_names_visibility: typing.Optional[builtins.str] = None,
            metric_placement: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_field_names_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            single_metric_visibility: typing.Optional[builtins.str] = None,
            toggle_buttons_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table options for a pivot table visual.

            :param cell_style: The table cell style of cells.
            :param column_header_style: The table cell style of the column header.
            :param column_names_visibility: The visibility of the column names.
            :param metric_placement: The metric placement (row, column) options.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors).
            :param row_field_names_style: The table cell style of row field names.
            :param row_header_style: The table cell style of the row headers.
            :param single_metric_visibility: The visibility of the single metric options.
            :param toggle_buttons_visibility: Determines the visibility of the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_options_property = quicksight.CfnAnalysis.PivotTableOptionsProperty(
                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_names_visibility="columnNamesVisibility",
                    metric_placement="metricPlacement",
                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status"
                    ),
                    row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    single_metric_visibility="singleMetricVisibility",
                    toggle_buttons_visibility="toggleButtonsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d7f187aa0bb094cf69c2aea68ae3475ccf5dcfd425239093b7897cd15be05b8e)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument column_header_style", value=column_header_style, expected_type=type_hints["column_header_style"])
                check_type(argname="argument column_names_visibility", value=column_names_visibility, expected_type=type_hints["column_names_visibility"])
                check_type(argname="argument metric_placement", value=metric_placement, expected_type=type_hints["metric_placement"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
                check_type(argname="argument row_field_names_style", value=row_field_names_style, expected_type=type_hints["row_field_names_style"])
                check_type(argname="argument row_header_style", value=row_header_style, expected_type=type_hints["row_header_style"])
                check_type(argname="argument single_metric_visibility", value=single_metric_visibility, expected_type=type_hints["single_metric_visibility"])
                check_type(argname="argument toggle_buttons_visibility", value=toggle_buttons_visibility, expected_type=type_hints["toggle_buttons_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if column_header_style is not None:
                self._values["column_header_style"] = column_header_style
            if column_names_visibility is not None:
                self._values["column_names_visibility"] = column_names_visibility
            if metric_placement is not None:
                self._values["metric_placement"] = metric_placement
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options
            if row_field_names_style is not None:
                self._values["row_field_names_style"] = row_field_names_style
            if row_header_style is not None:
                self._values["row_header_style"] = row_header_style
            if single_metric_visibility is not None:
                self._values["single_metric_visibility"] = single_metric_visibility
            if toggle_buttons_visibility is not None:
                self._values["toggle_buttons_visibility"] = toggle_buttons_visibility

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The table cell style of cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def column_header_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The table cell style of the column header.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-columnheaderstyle
            '''
            result = self._values.get("column_header_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def column_names_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the column names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-columnnamesvisibility
            '''
            result = self._values.get("column_names_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_placement(self) -> typing.Optional[builtins.str]:
            '''The metric placement (row, column) options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-metricplacement
            '''
            result = self._values.get("metric_placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RowAlternateColorOptionsProperty"]]:
            '''The row alternate color options (widget status, row alternate colors).

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RowAlternateColorOptionsProperty"]], result)

        @builtins.property
        def row_field_names_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The table cell style of row field names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowfieldnamesstyle
            '''
            result = self._values.get("row_field_names_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def row_header_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The table cell style of the row headers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowheaderstyle
            '''
            result = self._values.get("row_header_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def single_metric_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the single metric options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-singlemetricvisibility
            '''
            result = self._values.get("single_metric_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def toggle_buttons_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-togglebuttonsvisibility
            '''
            result = self._values.get("toggle_buttons_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class PivotTablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a pivot table visual.

            :param overflow_column_header_visibility: The visibility of the repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of the printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_paginated_report_options_property = quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a108d3adddb21e02a89aecd62d0228977f03983c2e9e4740aaa235c675743922)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the repeating header rows on each page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html#cfn-quicksight-analysis-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html#cfn-quicksight-analysis-pivottablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableSortByProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "data_path": "dataPath", "field": "field"},
    )
    class PivotTableSortByProperty:
        def __init__(
            self,
            *,
            column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_path: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataPathSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort by field for the field sort options.

            :param column: The column sort (field id, direction) for the pivot table sort by options.
            :param data_path: The data path sort (data path value, direction) for the pivot table sort by options.
            :param field: The field sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_sort_by_property = quicksight.CfnAnalysis.PivotTableSortByProperty(
                    column=quicksight.CfnAnalysis.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                        direction="direction",
                        sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        )]
                    ),
                    field=quicksight.CfnAnalysis.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4d6323fc5e8a6de6993b07b805f24d0d831af53bb4fd59acc47f1c2ecb04b6d7)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument data_path", value=data_path, expected_type=type_hints["data_path"])
                check_type(argname="argument field", value=field, expected_type=type_hints["field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column is not None:
                self._values["column"] = column
            if data_path is not None:
                self._values["data_path"] = data_path
            if field is not None:
                self._values["field"] = field

        @builtins.property
        def column(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnSortProperty"]]:
            '''The column sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-column
            '''
            result = self._values.get("column")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnSortProperty"]], result)

        @builtins.property
        def data_path(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataPathSortProperty"]]:
            '''The data path sort (data path value, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-datapath
            '''
            result = self._values.get("data_path")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataPathSortProperty"]], result)

        @builtins.property
        def field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortProperty"]]:
            '''The field sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-field
            '''
            result = self._values.get("field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortByProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"field_sort_options": "fieldSortOptions"},
    )
    class PivotTableSortConfigurationProperty:
        def __init__(
            self,
            *,
            field_sort_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotFieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration for a ``PivotTableVisual`` .

            :param field_sort_options: The field sort options for a pivot table sort configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_sort_configuration_property = quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                    field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                        field_id="fieldId",
                        sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                            column=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                direction="direction",
                                sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )]
                            ),
                            field=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fec1f52c3f162b8315c5dc6ce7f80f0bed9de6e2d629b63bff56483410feb583)
                check_type(argname="argument field_sort_options", value=field_sort_options, expected_type=type_hints["field_sort_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_sort_options is not None:
                self._values["field_sort_options"] = field_sort_options

        @builtins.property
        def field_sort_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotFieldSortOptionsProperty"]]]]:
            '''The field sort options for a pivot table sort configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortconfiguration.html#cfn-quicksight-analysis-pivottablesortconfiguration-fieldsortoptions
            '''
            result = self._values.get("field_sort_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotFieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_subtotal_options": "columnSubtotalOptions",
            "column_total_options": "columnTotalOptions",
            "row_subtotal_options": "rowSubtotalOptions",
            "row_total_options": "rowTotalOptions",
        },
    )
    class PivotTableTotalOptionsProperty:
        def __init__(
            self,
            *,
            column_subtotal_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_subtotal_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The total options for a pivot table visual.

            :param column_subtotal_options: The column subtotal options.
            :param column_total_options: The column total options.
            :param row_subtotal_options: The row subtotal options.
            :param row_total_options: The row total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_total_options_property = quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                    column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                        custom_label="customLabel",
                        field_level="fieldLevel",
                        field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                            field_id="fieldId"
                        )],
                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                        custom_label="customLabel",
                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                        custom_label="customLabel",
                        field_level="fieldLevel",
                        field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                            field_id="fieldId"
                        )],
                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                        custom_label="customLabel",
                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e50d5623a12e1bdc639165cb630a2657dc4f94bbb34aeaaebf69d5f051b35cbe)
                check_type(argname="argument column_subtotal_options", value=column_subtotal_options, expected_type=type_hints["column_subtotal_options"])
                check_type(argname="argument column_total_options", value=column_total_options, expected_type=type_hints["column_total_options"])
                check_type(argname="argument row_subtotal_options", value=row_subtotal_options, expected_type=type_hints["row_subtotal_options"])
                check_type(argname="argument row_total_options", value=row_total_options, expected_type=type_hints["row_total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_subtotal_options is not None:
                self._values["column_subtotal_options"] = column_subtotal_options
            if column_total_options is not None:
                self._values["column_total_options"] = column_total_options
            if row_subtotal_options is not None:
                self._values["row_subtotal_options"] = row_subtotal_options
            if row_total_options is not None:
                self._values["row_total_options"] = row_total_options

        @builtins.property
        def column_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SubtotalOptionsProperty"]]:
            '''The column subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-columnsubtotaloptions
            '''
            result = self._values.get("column_subtotal_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SubtotalOptionsProperty"]], result)

        @builtins.property
        def column_total_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTotalOptionsProperty"]]:
            '''The column total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-columntotaloptions
            '''
            result = self._values.get("column_total_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTotalOptionsProperty"]], result)

        @builtins.property
        def row_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SubtotalOptionsProperty"]]:
            '''The row subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-rowsubtotaloptions
            '''
            result = self._values.get("row_subtotal_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SubtotalOptionsProperty"]], result)

        @builtins.property
        def row_total_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTotalOptionsProperty"]]:
            '''The row total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-rowtotaloptions
            '''
            result = self._values.get("row_total_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PivotTableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_visual_property = quicksight.CfnAnalysis.PivotTableVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                        field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                            data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                                data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )],
                
                                # the properties below are optional
                                width="width"
                            )],
                            selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                custom_label="customLabel",
                                visibility="visibility"
                            )]
                        ),
                        field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                            pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                                columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                            overflow_column_header_visibility="overflowColumnHeaderVisibility",
                            vertical_overflow_visibility="verticalOverflowVisibility"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                            field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                                field_id="fieldId",
                                sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                    column=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                        direction="direction",
                                        sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )]
                                    ),
                                    field=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )
                            )]
                        ),
                        table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                            cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            column_names_visibility="columnNamesVisibility",
                            metric_placement="metricPlacement",
                            row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                row_alternate_colors=["rowAlternateColors"],
                                status="status"
                            ),
                            row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            single_metric_visibility="singleMetricVisibility",
                            toggle_buttons_visibility="toggleButtonsVisibility"
                        ),
                        total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                            column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                custom_label="customLabel",
                                field_level="fieldLevel",
                                field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                    field_id="fieldId"
                                )],
                                metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                custom_label="customLabel",
                                metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                custom_label="customLabel",
                                field_level="fieldLevel",
                                field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                    field_id="fieldId"
                                )],
                                metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                custom_label="customLabel",
                                metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        )
                    ),
                    conditional_formatting=quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                            cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                    role="role"
                                ),
                                text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d76d528a5f2d81251656b21c316cae0c17f678378927d2c7fceab68e34347223)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableConditionalFormattingProperty"]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PivotTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class PivotTotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            metric_header_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The optional configuration of totals cells in a ``PivotTableVisual`` .

            :param custom_label: The custom label string for the total cells.
            :param metric_header_cell_style: The cell styling options for the total of header cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_cell_style: The cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.
            :param value_cell_style: The cell styling options for the totals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_total_options_property = quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                    custom_label="customLabel",
                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f04bd4866cb33e84b67c97b202a6aa0e026bddb8ce0608a934b57701d4e0e994)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The cell styling options for the total of header cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The cell styling options for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The cell styling options for the totals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.PredefinedHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class PredefinedHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :param columns: The list of columns that define the predefined hierarchy.
            :param hierarchy_id: The hierarchy ID of the predefined hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                predefined_hierarchy_property = quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__98f1beba4baf0c2b1acb54cfb02acee714cdef11d1f44312d39fe80d86418ce9)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]]]:
            '''The list of columns that define the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PredefinedHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ProgressBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ProgressBarOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :param visibility: The visibility of the progress bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-progressbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                progress_bar_options_property = quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5cd05f980784e71c4b835ccae301c08346781e95ec20c5c6d4fab5d5acf4ffe1)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the progress bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-progressbaroptions.html#cfn-quicksight-analysis-progressbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ProgressBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "color": "color", "values": "values"},
    )
    class RadarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well configuration of a ``RadarChartVisual`` .

            :param category: The aggregated field well categories of a radar chart.
            :param color: The color that are assigned to the aggregated field wells of a radar chart.
            :param values: The values that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0c75740defed28866f2ba79fb3b2a135b48a7ab23aaf2005ed3a1d02e5bae1d)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if color is not None:
                self._values["color"] = color
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The aggregated field well categories of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The color that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The values that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RadarChartAreaStyleSettingsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configured style settings of a radar chart.

            :param visibility: The visibility settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartareastylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_area_style_settings_property = quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5d9bd7296105c868ad9035195c6f90c2827f5a79e93d58be6a54953dffa90316)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartareastylesettings.html#cfn-quicksight-analysis-radarchartareastylesettings-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAreaStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.RadarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "alternate_band_colors_visibility": "alternateBandColorsVisibility",
            "alternate_band_even_color": "alternateBandEvenColor",
            "alternate_band_odd_color": "alternateBandOddColor",
            "base_series_settings": "baseSeriesSettings",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_axis": "colorAxis",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "shape": "shape",
            "sort_configuration": "sortConfiguration",
            "start_angle": "startAngle",
            "visual_palette": "visualPalette",
        },
    )
    class RadarChartConfigurationProperty:
        def __init__(
            self,
            *,
            alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
            alternate_band_even_color: typing.Optional[builtins.str] = None,
            alternate_band_odd_color: typing.Optional[builtins.str] = None,
            base_series_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RadarChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RadarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            shape: typing.Optional[builtins.str] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RadarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            start_angle: typing.Optional[jsii.Number] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``RadarChartVisual`` .

            :param alternate_band_colors_visibility: Determines the visibility of the colors of alternatign bands in a radar chart.
            :param alternate_band_even_color: The color of the even-numbered alternate bands of a radar chart.
            :param alternate_band_odd_color: The color of the odd-numbered alternate bands of a radar chart.
            :param base_series_settings: The base sreies settings of a radar chart.
            :param category_axis: The category axis of a radar chart.
            :param category_label_options: The category label options of a radar chart.
            :param color_axis: The color axis of a radar chart.
            :param color_label_options: The color label options of a radar chart.
            :param field_wells: The field well configuration of a ``RadarChartVisual`` .
            :param legend: The legend display setup of the visual.
            :param shape: The shape of the radar chart.
            :param sort_configuration: The sort configuration of a ``RadarChartVisual`` .
            :param start_angle: The start angle of a radar chart's axis.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                radar_chart_configuration_property = quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                    alternate_band_even_color="alternateBandEvenColor",
                    alternate_band_odd_color="alternateBandOddColor",
                    base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                        area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                            visibility="visibility"
                        )
                    ),
                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                        radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    shape="shape",
                    sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    start_angle=123,
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9563dd83c7592d684615d31a1298063109fd11a2bb03a631672aaf4adf20917)
                check_type(argname="argument alternate_band_colors_visibility", value=alternate_band_colors_visibility, expected_type=type_hints["alternate_band_colors_visibility"])
                check_type(argname="argument alternate_band_even_color", value=alternate_band_even_color, expected_type=type_hints["alternate_band_even_color"])
                check_type(argname="argument alternate_band_odd_color", value=alternate_band_odd_color, expected_type=type_hints["alternate_band_odd_color"])
                check_type(argname="argument base_series_settings", value=base_series_settings, expected_type=type_hints["base_series_settings"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_axis", value=color_axis, expected_type=type_hints["color_axis"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument start_angle", value=start_angle, expected_type=type_hints["start_angle"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if alternate_band_colors_visibility is not None:
                self._values["alternate_band_colors_visibility"] = alternate_band_colors_visibility
            if alternate_band_even_color is not None:
                self._values["alternate_band_even_color"] = alternate_band_even_color
            if alternate_band_odd_color is not None:
                self._values["alternate_band_odd_color"] = alternate_band_odd_color
            if base_series_settings is not None:
                self._values["base_series_settings"] = base_series_settings
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_axis is not None:
                self._values["color_axis"] = color_axis
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if shape is not None:
                self._values["shape"] = shape
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if start_angle is not None:
                self._values["start_angle"] = start_angle
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def alternate_band_colors_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the colors of alternatign bands in a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandcolorsvisibility
            '''
            result = self._values.get("alternate_band_colors_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_even_color(self) -> typing.Optional[builtins.str]:
            '''The color of the even-numbered alternate bands of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandevencolor
            '''
            result = self._values.get("alternate_band_even_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_odd_color(self) -> typing.Optional[builtins.str]:
            '''The color of the odd-numbered alternate bands of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandoddcolor
            '''
            result = self._values.get("alternate_band_odd_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def base_series_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartSeriesSettingsProperty"]]:
            '''The base sreies settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-baseseriessettings
            '''
            result = self._values.get("base_series_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartSeriesSettingsProperty"]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The category axis of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The category label options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The color axis of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-coloraxis
            '''
            result = self._values.get("color_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The color label options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartFieldWellsProperty"]]:
            '''The field well configuration of a ``RadarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def shape(self) -> typing.Optional[builtins.str]:
            '''The shape of the radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-shape
            '''
            result = self._values.get("shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``RadarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartSortConfigurationProperty"]], result)

        @builtins.property
        def start_angle(self) -> typing.Optional[jsii.Number]:
            '''The start angle of a radar chart's axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-startangle
            '''
            result = self._values.get("start_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.RadarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "radar_chart_aggregated_field_wells": "radarChartAggregatedFieldWells",
        },
    )
    class RadarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            radar_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RadarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a radar chart visual.

            :param radar_chart_aggregated_field_wells: The aggregated field wells of a radar chart visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_field_wells_property = quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                    radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__10c3a482b06092ee6d22abf27afa04deb532b6c26d98f29f4c57f4f94cf55b43)
                check_type(argname="argument radar_chart_aggregated_field_wells", value=radar_chart_aggregated_field_wells, expected_type=type_hints["radar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if radar_chart_aggregated_field_wells is not None:
                self._values["radar_chart_aggregated_field_wells"] = radar_chart_aggregated_field_wells

        @builtins.property
        def radar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a radar chart visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartfieldwells.html#cfn-quicksight-analysis-radarchartfieldwells-radarchartaggregatedfieldwells
            '''
            result = self._values.get("radar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"area_style_settings": "areaStyleSettings"},
    )
    class RadarChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            area_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RadarChartAreaStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The series settings of a radar chart.

            :param area_style_settings: The area style settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_series_settings_property = quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                    area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__52f5ef626ddf42fb5e38bae8a7ac8554b68be4a32e925cf64fa98abc88930c55)
                check_type(argname="argument area_style_settings", value=area_style_settings, expected_type=type_hints["area_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if area_style_settings is not None:
                self._values["area_style_settings"] = area_style_settings

        @builtins.property
        def area_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartAreaStyleSettingsProperty"]]:
            '''The area style settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartseriessettings.html#cfn-quicksight-analysis-radarchartseriessettings-areastylesettings
            '''
            result = self._values.get("area_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartAreaStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.RadarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class RadarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``RadarChartVisual`` .

            :param category_items_limit: The category items limit for a radar chart.
            :param category_sort: The category sort options of a radar chart.
            :param color_items_limit: The color items limit of a radar chart.
            :param color_sort: The color sort configuration of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_sort_configuration_property = quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ef4f687b0aa2ad42f562a7827b4ed3eda0108e71a56e2a11ddc19e10a5cfbcf5)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The category items limit for a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The category sort options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The color items limit of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The color sort configuration of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.RadarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class RadarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RadarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A radar chart visual.

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                radar_chart_visual_property = quicksight.CfnAnalysis.RadarChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                        alternate_band_colors_visibility="alternateBandColorsVisibility",
                        alternate_band_even_color="alternateBandEvenColor",
                        alternate_band_odd_color="alternateBandOddColor",
                        base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                            area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                                visibility="visibility"
                            )
                        ),
                        category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                            radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        shape="shape",
                        sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        start_angle=123,
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9fada9aa73703fa429403118726326b68bf29fe4d8ae482fa8978dabad896cdf)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.RangeEndsLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RangeEndsLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The range ends label type of a data path label.

            :param visibility: The visibility of the range ends label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rangeendslabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                range_ends_label_type_property = quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7a1425a883f06e5fbfa3c04083db8c3d1d1f4cb17b8c0b95e15de65844f9c345)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the range ends label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rangeendslabeltype.html#cfn-quicksight-analysis-rangeendslabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RangeEndsLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_label": "customLabel"},
    )
    class ReferenceLineCustomLabelConfigurationProperty:
        def __init__(self, *, custom_label: builtins.str) -> None:
            '''The configuration for a custom label on a ``ReferenceLine`` .

            :param custom_label: The string text of the custom label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinecustomlabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_custom_label_configuration_property = quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                    custom_label="customLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b4bf9558d7ba1c8eb0bcc09f5ebc61af2e451c94524b5501f54df4653265aab8)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_label": custom_label,
            }

        @builtins.property
        def custom_label(self) -> builtins.str:
            '''The string text of the custom label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinecustomlabelconfiguration.html#cfn-quicksight-analysis-referencelinecustomlabelconfiguration-customlabel
            '''
            result = self._values.get("custom_label")
            assert result is not None, "Required property 'custom_label' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineCustomLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "dynamic_configuration": "dynamicConfiguration",
            "static_configuration": "staticConfiguration",
        },
    )
    class ReferenceLineDataConfigurationProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            dynamic_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ReferenceLineStaticDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data configuration of the reference line.

            :param axis_binding: The axis binding type of the reference line. Choose one of the following options:. - PrimaryY - SecondaryY
            :param dynamic_configuration: The dynamic configuration of the reference line data configuration.
            :param static_configuration: The static data configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_data_configuration_property = quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                    axis_binding="axisBinding",
                    dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                        calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4954b807fa9737eaac9037abc36a5a95c2cd8bbed82a780e8ba21a2fa48e2547)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument dynamic_configuration", value=dynamic_configuration, expected_type=type_hints["dynamic_configuration"])
                check_type(argname="argument static_configuration", value=static_configuration, expected_type=type_hints["static_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if dynamic_configuration is not None:
                self._values["dynamic_configuration"] = dynamic_configuration
            if static_configuration is not None:
                self._values["static_configuration"] = static_configuration

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis binding type of the reference line. Choose one of the following options:.

            - PrimaryY
            - SecondaryY

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dynamic_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty"]]:
            '''The dynamic configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-dynamicconfiguration
            '''
            result = self._values.get("dynamic_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty"]], result)

        @builtins.property
        def static_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineStaticDataConfigurationProperty"]]:
            '''The static data configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-staticconfiguration
            '''
            result = self._values.get("static_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineStaticDataConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculation": "calculation",
            "column": "column",
            "measure_aggregation_function": "measureAggregationFunction",
        },
    )
    class ReferenceLineDynamicDataConfigurationProperty:
        def __init__(
            self,
            *,
            calculation: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            measure_aggregation_function: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The dynamic configuration of the reference line data configuration.

            :param calculation: The calculation that is used in the dynamic data.
            :param column: The column that the dynamic data targets.
            :param measure_aggregation_function: The aggregation function that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_dynamic_data_configuration_property = quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                    calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ecb636f5a7ffd4f5b7e7df94a6e9939a8d36607a5b16d03769699a2b89307531)
                check_type(argname="argument calculation", value=calculation, expected_type=type_hints["calculation"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument measure_aggregation_function", value=measure_aggregation_function, expected_type=type_hints["measure_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "calculation": calculation,
                "column": column,
                "measure_aggregation_function": measure_aggregation_function,
            }

        @builtins.property
        def calculation(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericalAggregationFunctionProperty"]:
            '''The calculation that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-calculation
            '''
            result = self._values.get("calculation")
            assert result is not None, "Required property 'calculation' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericalAggregationFunctionProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the dynamic data targets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def measure_aggregation_function(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationFunctionProperty"]:
            '''The aggregation function that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-measureaggregationfunction
            '''
            result = self._values.get("measure_aggregation_function")
            assert result is not None, "Required property 'measure_aggregation_function' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationFunctionProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDynamicDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label_configuration": "customLabelConfiguration",
            "font_color": "fontColor",
            "font_configuration": "fontConfiguration",
            "horizontal_position": "horizontalPosition",
            "value_label_configuration": "valueLabelConfiguration",
            "vertical_position": "verticalPosition",
        },
    )
    class ReferenceLineLabelConfigurationProperty:
        def __init__(
            self,
            *,
            custom_label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_color: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            horizontal_position: typing.Optional[builtins.str] = None,
            value_label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ReferenceLineValueLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            vertical_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label configuration of a reference line.

            :param custom_label_configuration: The custom label configuration of the label in a reference line.
            :param font_color: The font color configuration of the label in a reference line.
            :param font_configuration: The font configuration of the label in a reference line.
            :param horizontal_position: The horizontal position configuration of the label in a reference line. Choose one of the following options:. - ``LEFT`` - ``CENTER`` - ``RIGHT``
            :param value_label_configuration: The value label configuration of the label in a reference line.
            :param vertical_position: The vertical position configuration of the label in a reference line. Choose one of the following options:. - ``ABOVE`` - ``BELOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_label_configuration_property = quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                    custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                        custom_label="customLabel"
                    ),
                    font_color="fontColor",
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_position="horizontalPosition",
                    value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        relative_position="relativePosition"
                    ),
                    vertical_position="verticalPosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__46f10aed1478303f43309fd5f20a01d373f13d96f23ccfdca1ccb26bdbd46200)
                check_type(argname="argument custom_label_configuration", value=custom_label_configuration, expected_type=type_hints["custom_label_configuration"])
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_position", value=horizontal_position, expected_type=type_hints["horizontal_position"])
                check_type(argname="argument value_label_configuration", value=value_label_configuration, expected_type=type_hints["value_label_configuration"])
                check_type(argname="argument vertical_position", value=vertical_position, expected_type=type_hints["vertical_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label_configuration is not None:
                self._values["custom_label_configuration"] = custom_label_configuration
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_position is not None:
                self._values["horizontal_position"] = horizontal_position
            if value_label_configuration is not None:
                self._values["value_label_configuration"] = value_label_configuration
            if vertical_position is not None:
                self._values["vertical_position"] = vertical_position

        @builtins.property
        def custom_label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty"]]:
            '''The custom label configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-customlabelconfiguration
            '''
            result = self._values.get("custom_label_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty"]], result)

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''The font color configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The font configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def horizontal_position(self) -> typing.Optional[builtins.str]:
            '''The horizontal position configuration of the label in a reference line. Choose one of the following options:.

            - ``LEFT``
            - ``CENTER``
            - ``RIGHT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-horizontalposition
            '''
            result = self._values.get("horizontal_position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineValueLabelConfigurationProperty"]]:
            '''The value label configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-valuelabelconfiguration
            '''
            result = self._values.get("value_label_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineValueLabelConfigurationProperty"]], result)

        @builtins.property
        def vertical_position(self) -> typing.Optional[builtins.str]:
            '''The vertical position configuration of the label in a reference line. Choose one of the following options:.

            - ``ABOVE``
            - ``BELOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-verticalposition
            '''
            result = self._values.get("vertical_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ReferenceLineProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_configuration": "dataConfiguration",
            "label_configuration": "labelConfiguration",
            "status": "status",
            "style_configuration": "styleConfiguration",
        },
    )
    class ReferenceLineProperty:
        def __init__(
            self,
            *,
            data_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ReferenceLineDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ReferenceLineLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            status: typing.Optional[builtins.str] = None,
            style_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ReferenceLineStyleConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The reference line visual display options.

            :param data_configuration: The data configuration of the reference line.
            :param label_configuration: The label configuration of the reference line.
            :param status: The status of the reference line. Choose one of the following options:. - ``ENABLE`` - ``DISABLE``
            :param style_configuration: The style configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_property = quicksight.CfnAnalysis.ReferenceLineProperty(
                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                        axis_binding="axisBinding",
                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                            value=123
                        )
                    ),
                
                    # the properties below are optional
                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                            custom_label="customLabel"
                        ),
                        font_color="fontColor",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_position="horizontalPosition",
                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            relative_position="relativePosition"
                        ),
                        vertical_position="verticalPosition"
                    ),
                    status="status",
                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                        color="color",
                        pattern="pattern"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f44f1caf1d5838fa52083901d0048bf9a5b1f1e8d776f909f8ccf495b639610f)
                check_type(argname="argument data_configuration", value=data_configuration, expected_type=type_hints["data_configuration"])
                check_type(argname="argument label_configuration", value=label_configuration, expected_type=type_hints["label_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument style_configuration", value=style_configuration, expected_type=type_hints["style_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_configuration": data_configuration,
            }
            if label_configuration is not None:
                self._values["label_configuration"] = label_configuration
            if status is not None:
                self._values["status"] = status
            if style_configuration is not None:
                self._values["style_configuration"] = style_configuration

        @builtins.property
        def data_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineDataConfigurationProperty"]:
            '''The data configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-dataconfiguration
            '''
            result = self._values.get("data_configuration")
            assert result is not None, "Required property 'data_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineDataConfigurationProperty"], result)

        @builtins.property
        def label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineLabelConfigurationProperty"]]:
            '''The label configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-labelconfiguration
            '''
            result = self._values.get("label_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineLabelConfigurationProperty"]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the reference line. Choose one of the following options:.

            - ``ENABLE``
            - ``DISABLE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineStyleConfigurationProperty"]]:
            '''The style configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-styleconfiguration
            '''
            result = self._values.get("style_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ReferenceLineStyleConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class ReferenceLineStaticDataConfigurationProperty:
        def __init__(self, *, value: jsii.Number) -> None:
            '''The static data configuration of the reference line data configuration.

            :param value: The double input of the static data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestaticdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_static_data_configuration_property = quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e9ac78245776d8f23111800bfef25fb654ef215154e0470a2be1653c2154769f)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "value": value,
            }

        @builtins.property
        def value(self) -> jsii.Number:
            '''The double input of the static data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestaticdataconfiguration.html#cfn-quicksight-analysis-referencelinestaticdataconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStaticDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "pattern": "pattern"},
    )
    class ReferenceLineStyleConfigurationProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            pattern: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The style configuration of the reference line.

            :param color: The hex color of the reference line.
            :param pattern: The pattern type of the line style. Choose one of the following options:. - ``SOLID`` - ``DASHED`` - ``DOTTED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_style_configuration_property = quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                    color="color",
                    pattern="pattern"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e05dc0f16bc3f29378a74ae9891083d7ee6081b734733be871e8ffe193495c2)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if pattern is not None:
                self._values["pattern"] = pattern

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The hex color of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html#cfn-quicksight-analysis-referencelinestyleconfiguration-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def pattern(self) -> typing.Optional[builtins.str]:
            '''The pattern type of the line style. Choose one of the following options:.

            - ``SOLID``
            - ``DASHED``
            - ``DOTTED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html#cfn-quicksight-analysis-referencelinestyleconfiguration-pattern
            '''
            result = self._values.get("pattern")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStyleConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "format_configuration": "formatConfiguration",
            "relative_position": "relativePosition",
        },
    )
    class ReferenceLineValueLabelConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value label configuration of the label in a reference line.

            :param format_configuration: The format configuration of the value label.
            :param relative_position: The relative position of the value label. Choose one of the following options:. - ``BEFORE_CUSTOM_LABEL`` - ``AFTER_CUSTOM_LABEL``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_value_label_configuration_property = quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    relative_position="relativePosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__578d36c213d8ae577e4a303eca3c6c868bdd32ec997a196f314c1318c5f61817)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument relative_position", value=relative_position, expected_type=type_hints["relative_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if relative_position is not None:
                self._values["relative_position"] = relative_position

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericFormatConfigurationProperty"]]:
            '''The format configuration of the value label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html#cfn-quicksight-analysis-referencelinevaluelabelconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericFormatConfigurationProperty"]], result)

        @builtins.property
        def relative_position(self) -> typing.Optional[builtins.str]:
            '''The relative position of the value label. Choose one of the following options:.

            - ``BEFORE_CUSTOM_LABEL``
            - ``AFTER_CUSTOM_LABEL``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html#cfn-quicksight-analysis-referencelinevaluelabelconfiguration-relativeposition
            '''
            result = self._values.get("relative_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineValueLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "title_options": "titleOptions",
        },
    )
    class RelativeDateTimeControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                relative_date_time_control_display_options_property = quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__47a63cfeda2b07c1c69a139367a9a351974a56a1f88b4620d5b8632a918f0eab)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html#cfn-quicksight-analysis-relativedatetimecontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html#cfn-quicksight-analysis-relativedatetimecontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDateTimeControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.RelativeDatesFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_date_configuration": "anchorDateConfiguration",
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "relative_date_type": "relativeDateType",
            "time_granularity": "timeGranularity",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "minimum_granularity": "minimumGranularity",
            "parameter_name": "parameterName",
            "relative_date_value": "relativeDateValue",
        },
    )
    class RelativeDatesFilterProperty:
        def __init__(
            self,
            *,
            anchor_date_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AnchorDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            relative_date_type: builtins.str,
            time_granularity: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            minimum_granularity: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            relative_date_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``RelativeDatesFilter`` filters relative dates values.

            :param anchor_date_configuration: The date configuration of the filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param relative_date_type: The range date type of the filter. Choose one of the options below:. - ``PREVIOUS`` - ``THIS`` - ``LAST`` - ``NOW`` - ``NEXT``
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param exclude_period_configuration: The configuration for the exclude period of the filter.
            :param minimum_granularity: The minimum granularity (period granularity) of the relative dates filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param relative_date_value: The date value of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                relative_dates_filter_property = quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                    anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                        anchor_option="anchorOption",
                        parameter_name="parameterName"
                    ),
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                    relative_date_type="relativeDateType",
                    time_granularity="timeGranularity",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    minimum_granularity="minimumGranularity",
                    parameter_name="parameterName",
                    relative_date_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dc66a0688d049a9b7a75208a246026f4108ee71438dc04d08df4e47d54d9bcaa)
                check_type(argname="argument anchor_date_configuration", value=anchor_date_configuration, expected_type=type_hints["anchor_date_configuration"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument relative_date_type", value=relative_date_type, expected_type=type_hints["relative_date_type"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument minimum_granularity", value=minimum_granularity, expected_type=type_hints["minimum_granularity"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument relative_date_value", value=relative_date_value, expected_type=type_hints["relative_date_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "anchor_date_configuration": anchor_date_configuration,
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
                "relative_date_type": relative_date_type,
                "time_granularity": time_granularity,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if minimum_granularity is not None:
                self._values["minimum_granularity"] = minimum_granularity
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if relative_date_value is not None:
                self._values["relative_date_value"] = relative_date_value

        @builtins.property
        def anchor_date_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AnchorDateConfigurationProperty"]:
            '''The date configuration of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-anchordateconfiguration
            '''
            result = self._values.get("anchor_date_configuration")
            assert result is not None, "Required property 'anchor_date_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AnchorDateConfigurationProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def relative_date_type(self) -> builtins.str:
            '''The range date type of the filter. Choose one of the options below:.

            - ``PREVIOUS``
            - ``THIS``
            - ``LAST``
            - ``NOW``
            - ``NEXT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-relativedatetype
            '''
            result = self._values.get("relative_date_type")
            assert result is not None, "Required property 'relative_date_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ExcludePeriodConfigurationProperty"]]:
            '''The configuration for the exclude period of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ExcludePeriodConfigurationProperty"]], result)

        @builtins.property
        def minimum_granularity(self) -> typing.Optional[builtins.str]:
            '''The minimum granularity (period granularity) of the relative dates filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-minimumgranularity
            '''
            result = self._values.get("minimum_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def relative_date_value(self) -> typing.Optional[jsii.Number]:
            '''The date value of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-relativedatevalue
            '''
            result = self._values.get("relative_date_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDatesFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "actions": "actions",
            "principal": "principal",
            "resource": "resource",
        },
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
            resource: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
            :param resource: ``CfnAnalysis.ResourcePermissionProperty.Resource``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnAnalysis.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
                
                    # the properties below are optional
                    resource="resource"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd013d72a5cb83e308fffaa5e209dcc9a26655891997dcb7c495c5688501fc23)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
                check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }
            if resource is not None:
                self._values["resource"] = resource

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def resource(self) -> typing.Optional[builtins.str]:
            '''``CfnAnalysis.ResourcePermissionProperty.Resource``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-resource
            '''
            result = self._values.get("resource")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.RollingDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class RollingDateConfigurationProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            data_set_identifier: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The rolling date configuration of a date time filter.

            :param expression: The expression of the rolling date configuration.
            :param data_set_identifier: The data set that is used in the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                rolling_date_configuration_property = quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                    expression="expression",
                
                    # the properties below are optional
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ed461bd3defdf64a18b9ff37c102c6a50396d406e655af5a3143c59be03b021b)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if data_set_identifier is not None:
                self._values["data_set_identifier"] = data_set_identifier

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html#cfn-quicksight-analysis-rollingdateconfiguration-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> typing.Optional[builtins.str]:
            '''The data set that is used in the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html#cfn-quicksight-analysis-rollingdateconfiguration-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RollingDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.RowAlternateColorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "row_alternate_colors": "rowAlternateColors",
            "status": "status",
        },
    )
    class RowAlternateColorOptionsProperty:
        def __init__(
            self,
            *,
            row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the row alternate color options.

            :param row_alternate_colors: Determines the list of row alternate colors.
            :param status: Determines the widget status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                row_alternate_color_options_property = quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                    row_alternate_colors=["rowAlternateColors"],
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__87f650fad11a3c6318594304970065d92f1d9560f3b3414f90300e2053dc54a6)
                check_type(argname="argument row_alternate_colors", value=row_alternate_colors, expected_type=type_hints["row_alternate_colors"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if row_alternate_colors is not None:
                self._values["row_alternate_colors"] = row_alternate_colors
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def row_alternate_colors(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Determines the list of row alternate colors.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html#cfn-quicksight-analysis-rowalternatecoloroptions-rowalternatecolors
            '''
            result = self._values.get("row_alternate_colors")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''Determines the widget status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html#cfn-quicksight-analysis-rowalternatecoloroptions-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowAlternateColorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_visual_options": "targetVisualOptions",
            "target_visuals": "targetVisuals",
        },
    )
    class SameSheetTargetVisualConfigurationProperty:
        def __init__(
            self,
            *,
            target_visual_options: typing.Optional[builtins.str] = None,
            target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param target_visual_options: The options that choose the target visual in the same sheet. Valid values are defined as follows: - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.
            :param target_visuals: A list of the target visual IDs that are located in the same sheet of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                same_sheet_target_visual_configuration_property = quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                    target_visual_options="targetVisualOptions",
                    target_visuals=["targetVisuals"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a7cc2ea40377d4dc3d7090647fd4576458e949bd798b775ccf15a013b9c39795)
                check_type(argname="argument target_visual_options", value=target_visual_options, expected_type=type_hints["target_visual_options"])
                check_type(argname="argument target_visuals", value=target_visuals, expected_type=type_hints["target_visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_visual_options is not None:
                self._values["target_visual_options"] = target_visual_options
            if target_visuals is not None:
                self._values["target_visuals"] = target_visuals

        @builtins.property
        def target_visual_options(self) -> typing.Optional[builtins.str]:
            '''The options that choose the target visual in the same sheet.

            Valid values are defined as follows:

            - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html#cfn-quicksight-analysis-samesheettargetvisualconfiguration-targetvisualoptions
            '''
            result = self._values.get("target_visual_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def target_visuals(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of the target visual IDs that are located in the same sheet of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html#cfn-quicksight-analysis-samesheettargetvisualconfiguration-targetvisuals
            '''
            result = self._values.get("target_visuals")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SameSheetTargetVisualConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination": "destination",
            "source": "source",
            "weight": "weight",
        },
    )
    class SankeyDiagramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            destination: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            source: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            weight: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param destination: The destination field wells of a sankey diagram.
            :param source: The source field wells of a sankey diagram.
            :param weight: The weight field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_aggregated_field_wells_property = quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                    destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c23876552bb23894cad869a1bfea6688b1f1bf0b6e32febd287dd0c24a185f4)
                check_type(argname="argument destination", value=destination, expected_type=type_hints["destination"])
                check_type(argname="argument source", value=source, expected_type=type_hints["source"])
                check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination is not None:
                self._values["destination"] = destination
            if source is not None:
                self._values["source"] = source
            if weight is not None:
                self._values["weight"] = weight

        @builtins.property
        def destination(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The destination field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-destination
            '''
            result = self._values.get("destination")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def source(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The source field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-source
            '''
            result = self._values.get("source")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def weight(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The weight field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-weight
            '''
            result = self._values.get("weight")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
        },
    )
    class SankeyDiagramChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SankeyDiagramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SankeyDiagramSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a sankey diagram.

            :param data_labels: The data label configuration of a sankey diagram.
            :param field_wells: The field well configuration of a sankey diagram.
            :param sort_configuration: The sort configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_chart_configuration_property = quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                        sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                            destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                        destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a94cac8d18c7d9fa78eb53c155379779eb52f09e7d27fd2c40e700716c7f8e1)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The data label configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SankeyDiagramFieldWellsProperty"]]:
            '''The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SankeyDiagramFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SankeyDiagramSortConfigurationProperty"]]:
            '''The sort configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SankeyDiagramSortConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sankey_diagram_aggregated_field_wells": "sankeyDiagramAggregatedFieldWells",
        },
    )
    class SankeyDiagramFieldWellsProperty:
        def __init__(
            self,
            *,
            sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param sankey_diagram_aggregated_field_wells: The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_field_wells_property = quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                    sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                        destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__346b9e514948d61427f9754ed52de80f326d3a06ae36d514b26badb87c1af33a)
                check_type(argname="argument sankey_diagram_aggregated_field_wells", value=sankey_diagram_aggregated_field_wells, expected_type=type_hints["sankey_diagram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sankey_diagram_aggregated_field_wells is not None:
                self._values["sankey_diagram_aggregated_field_wells"] = sankey_diagram_aggregated_field_wells

        @builtins.property
        def sankey_diagram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramfieldwells.html#cfn-quicksight-analysis-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
            '''
            result = self._values.get("sankey_diagram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_items_limit": "destinationItemsLimit",
            "source_items_limit": "sourceItemsLimit",
            "weight_sort": "weightSort",
        },
    )
    class SankeyDiagramSortConfigurationProperty:
        def __init__(
            self,
            *,
            destination_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            weight_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a sankey diagram.

            :param destination_items_limit: The limit on the number of destination nodes that are displayed in a sankey diagram.
            :param source_items_limit: The limit on the number of source nodes that are displayed in a sankey diagram.
            :param weight_sort: The sort configuration of the weight fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_sort_configuration_property = quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                    destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6c9bbf2241d81aaf412f2bb97d1d6ab72bf5161a4c387c47afbd296598daab3f)
                check_type(argname="argument destination_items_limit", value=destination_items_limit, expected_type=type_hints["destination_items_limit"])
                check_type(argname="argument source_items_limit", value=source_items_limit, expected_type=type_hints["source_items_limit"])
                check_type(argname="argument weight_sort", value=weight_sort, expected_type=type_hints["weight_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination_items_limit is not None:
                self._values["destination_items_limit"] = destination_items_limit
            if source_items_limit is not None:
                self._values["source_items_limit"] = source_items_limit
            if weight_sort is not None:
                self._values["weight_sort"] = weight_sort

        @builtins.property
        def destination_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of destination nodes that are displayed in a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-destinationitemslimit
            '''
            result = self._values.get("destination_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def source_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of source nodes that are displayed in a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-sourceitemslimit
            '''
            result = self._values.get("source_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def weight_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the weight fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-weightsort
            '''
            result = self._values.get("weight_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SankeyDiagramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class SankeyDiagramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SankeyDiagramChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a sankey diagram.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_visual_property = quicksight.CfnAnalysis.SankeyDiagramVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                            sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                                destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                            destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        )
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__99465037c7f19cee5402c8a8cc201aec41e09330c089ec3ba0bfecd38224aa35)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SankeyDiagramChartConfigurationProperty"]]:
            '''The configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SankeyDiagramChartConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "size": "size",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class ScatterPlotCategoricallyAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            x_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            y_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well of a scatter plot.

            :param category: The category field well of a scatter plot.
            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is aggregated by category.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                scatter_plot_categorically_aggregated_field_wells_property = quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e90833c17bd4c7e53b2a44dc1631d9705b98cf5d7ba4e75c45eafa82f8b3c7b8)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The category field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The size field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotCategoricallyAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ScatterPlotConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
            "y_axis_label_options": "yAxisLabelOptions",
        },
    )
    class ScatterPlotConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ScatterPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a scatter plot.

            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.
            :param x_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
            :param x_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
            :param y_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
            :param y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                scatter_plot_configuration_property = quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2e035ae883757344f1da3b230708374fa7fcbbe893ec4e266aa9df728ce9da8a)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
                check_type(argname="argument y_axis_label_options", value=y_axis_label_options, expected_type=type_hints["y_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options
            if y_axis_label_options is not None:
                self._values["y_axis_label_options"] = y_axis_label_options

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ScatterPlotFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ScatterPlotFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-yaxislabeloptions
            '''
            result = self._values.get("y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scatter_plot_categorically_aggregated_field_wells": "scatterPlotCategoricallyAggregatedFieldWells",
            "scatter_plot_unaggregated_field_wells": "scatterPlotUnaggregatedFieldWells",
        },
    )
    class ScatterPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a scatter plot.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param scatter_plot_categorically_aggregated_field_wells: The aggregated field wells of a scatter plot. Scatter plots that have a field in the category (group/color) field will have aggregated field wells. The x and y-axes of these scatter plots are aggregated by category.
            :param scatter_plot_unaggregated_field_wells: The unaggregated field wells of a scatter plot. Scatter plots without a category field well have unaggregated field wells. The x and y-axes of these scatter plots are unaggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                scatter_plot_field_wells_property = quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d76e517d6cac60b685140447e422c1bc0ecfa35403a4b61f62225ac21e30917b)
                check_type(argname="argument scatter_plot_categorically_aggregated_field_wells", value=scatter_plot_categorically_aggregated_field_wells, expected_type=type_hints["scatter_plot_categorically_aggregated_field_wells"])
                check_type(argname="argument scatter_plot_unaggregated_field_wells", value=scatter_plot_unaggregated_field_wells, expected_type=type_hints["scatter_plot_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if scatter_plot_categorically_aggregated_field_wells is not None:
                self._values["scatter_plot_categorically_aggregated_field_wells"] = scatter_plot_categorically_aggregated_field_wells
            if scatter_plot_unaggregated_field_wells is not None:
                self._values["scatter_plot_unaggregated_field_wells"] = scatter_plot_unaggregated_field_wells

        @builtins.property
        def scatter_plot_categorically_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a scatter plot.

            Scatter plots that have a field in the category (group/color) field will have aggregated field wells. The x and y-axes of these scatter plots are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html#cfn-quicksight-analysis-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_categorically_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty"]], result)

        @builtins.property
        def scatter_plot_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty"]]:
            '''The unaggregated field wells of a scatter plot.

            Scatter plots without a category field well have unaggregated field wells. The x and y-axes of these scatter plots are unaggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html#cfn-quicksight-analysis-scatterplotfieldwells-scatterplotunaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"size": "size", "x_axis": "xAxis", "y_axis": "yAxis"},
    )
    class ScatterPlotUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            x_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            y_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The unaggregated field wells of a scatter plot.

            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is a dimension field and cannot be aggregated.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                scatter_plot_unaggregated_field_wells_property = quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                    size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f7e6574784eb86d41e397fd728a9233ff88c370a5fc4e6353d471396853bbdbb)
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The size field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ScatterPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ScatterPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ScatterPlotConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                scatter_plot_visual_property = quicksight.CfnAnalysis.ScatterPlotVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                            scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                                size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9f466e97da2ae9406a8f785bea04069ac951fa520616e0d8f2ace8bcfc21293)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ScatterPlotConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ScatterPlotConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ScrollBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility", "visible_range": "visibleRange"},
    )
    class ScrollBarOptionsProperty:
        def __init__(
            self,
            *,
            visibility: typing.Optional[builtins.str] = None,
            visible_range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisibleRangeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The visual display options for a data zoom scroll bar.

            :param visibility: The visibility of the data zoom scroll bar.
            :param visible_range: The visibility range for the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                scroll_bar_options_property = quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                    visibility="visibility",
                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                            from=123,
                            to=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a75c97a8c8a2a8c78d9aae9d336b1ebff0b2662f95f7b3d77c5522267497cf5e)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument visible_range", value=visible_range, expected_type=type_hints["visible_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility
            if visible_range is not None:
                self._values["visible_range"] = visible_range

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html#cfn-quicksight-analysis-scrollbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visible_range(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisibleRangeOptionsProperty"]]:
            '''The visibility range for the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html#cfn-quicksight-analysis-scrollbaroptions-visiblerange
            '''
            result = self._values.get("visible_range")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisibleRangeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScrollBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SecondaryValueOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SecondaryValueOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :param visibility: Determines the visibility of the secondary value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-secondaryvalueoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                secondary_value_options_property = quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__006808d2638dbf353af0d085a31825fa28e966371bc10350cb000d77ed4f7255)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the secondary value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-secondaryvalueoptions.html#cfn-quicksight-analysis-secondaryvalueoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SecondaryValueOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SectionAfterPageBreakProperty",
        jsii_struct_bases=[],
        name_mapping={"status": "status"},
    )
    class SectionAfterPageBreakProperty:
        def __init__(self, *, status: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of a page break after a section.

            :param status: The option that enables or disables a page break at the end of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionafterpagebreak.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_after_page_break_property = quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ddd38899348373bfe78c28250e06a87f797a5bde9bec531a361c23064093cb5f)
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The option that enables or disables a page break at the end of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionafterpagebreak.html#cfn-quicksight-analysis-sectionafterpagebreak-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionAfterPageBreakProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"paper_canvas_size_options": "paperCanvasSizeOptions"},
    )
    class SectionBasedLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for the canvas of a section-based layout.

            :param paper_canvas_size_options: The options for a paper canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_based_layout_canvas_size_options_property = quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                    paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                        paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        ),
                        paper_orientation="paperOrientation",
                        paper_size="paperSize"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__05dcf44a0b008853c5f7981982bade77af7a5573bb84cdf933605279c3600c6c)
                check_type(argname="argument paper_canvas_size_options", value=paper_canvas_size_options, expected_type=type_hints["paper_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_canvas_size_options is not None:
                self._values["paper_canvas_size_options"] = paper_canvas_size_options

        @builtins.property
        def paper_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty"]]:
            '''The options for a paper canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
            '''
            result = self._values.get("paper_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "body_sections": "bodySections",
            "canvas_size_options": "canvasSizeOptions",
            "footer_sections": "footerSections",
            "header_sections": "headerSections",
        },
    )
    class SectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            body_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BodySectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
            footer_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            header_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The configuration for a section-based layout.

            :param body_sections: A list of body section configurations.
            :param canvas_size_options: The options for the canvas of a section-based layout.
            :param footer_sections: A list of footer section configurations.
            :param header_sections: A list of header section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_based_layout_configuration_property = quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                    body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                        content=quicksight.CfnAnalysis.BodySectionContentProperty(
                            layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                            after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                status="status"
                            )
                        ),
                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    ),
                    footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f9c3bc810320e00a0d2c6185852b65d4e0a322a1d79b30fab0f528c8071ecfc)
                check_type(argname="argument body_sections", value=body_sections, expected_type=type_hints["body_sections"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
                check_type(argname="argument footer_sections", value=footer_sections, expected_type=type_hints["footer_sections"])
                check_type(argname="argument header_sections", value=header_sections, expected_type=type_hints["header_sections"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "body_sections": body_sections,
                "canvas_size_options": canvas_size_options,
                "footer_sections": footer_sections,
                "header_sections": header_sections,
            }

        @builtins.property
        def body_sections(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BodySectionConfigurationProperty"]]]:
            '''A list of body section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-bodysections
            '''
            result = self._values.get("body_sections")
            assert result is not None, "Required property 'body_sections' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BodySectionConfigurationProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty"]:
            '''The options for the canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty"], result)

        @builtins.property
        def footer_sections(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeaderFooterSectionConfigurationProperty"]]]:
            '''A list of footer section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-footersections
            '''
            result = self._values.get("footer_sections")
            assert result is not None, "Required property 'footer_sections' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeaderFooterSectionConfigurationProperty"]]], result)

        @builtins.property
        def header_sections(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeaderFooterSectionConfigurationProperty"]]]:
            '''A list of header section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-headersections
            '''
            result = self._values.get("header_sections")
            assert result is not None, "Required property 'header_sections' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeaderFooterSectionConfigurationProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "paper_margin": "paperMargin",
            "paper_orientation": "paperOrientation",
            "paper_size": "paperSize",
        },
    )
    class SectionBasedLayoutPaperCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_margin: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SpacingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paper_orientation: typing.Optional[builtins.str] = None,
            paper_size: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a paper canvas of a section-based layout.

            :param paper_margin: Defines the spacing between the canvas content and the top, bottom, left, and right edges.
            :param paper_orientation: The paper orientation that is used to define canvas dimensions. Choose one of the following options:. - PORTRAIT - LANDSCAPE
            :param paper_size: The paper size that is used to define canvas dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_based_layout_paper_canvas_size_options_property = quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                    paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    ),
                    paper_orientation="paperOrientation",
                    paper_size="paperSize"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a050d65a95b1d7d0662d3ef7f5a94c0a5caaf626bfbbf593ab499595cc0d0723)
                check_type(argname="argument paper_margin", value=paper_margin, expected_type=type_hints["paper_margin"])
                check_type(argname="argument paper_orientation", value=paper_orientation, expected_type=type_hints["paper_orientation"])
                check_type(argname="argument paper_size", value=paper_size, expected_type=type_hints["paper_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_margin is not None:
                self._values["paper_margin"] = paper_margin
            if paper_orientation is not None:
                self._values["paper_orientation"] = paper_orientation
            if paper_size is not None:
                self._values["paper_size"] = paper_size

        @builtins.property
        def paper_margin(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SpacingProperty"]]:
            '''Defines the spacing between the canvas content and the top, bottom, left, and right edges.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-papermargin
            '''
            result = self._values.get("paper_margin")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SpacingProperty"]], result)

        @builtins.property
        def paper_orientation(self) -> typing.Optional[builtins.str]:
            '''The paper orientation that is used to define canvas dimensions. Choose one of the following options:.

            - PORTRAIT
            - LANDSCAPE

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-paperorientation
            '''
            result = self._values.get("paper_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def paper_size(self) -> typing.Optional[builtins.str]:
            '''The paper size that is used to define canvas dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-papersize
            '''
            result = self._values.get("paper_size")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutPaperCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form_layout": "freeFormLayout"},
    )
    class SectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FreeFormSectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The layout configuration of a section.

            :param free_form_layout: The free-form layout configuration of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_layout_configuration_property = quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7899424c10370d8394db35506870ff3ebf25b595a7a61ad6c039e5681be45e1f)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "free_form_layout": free_form_layout,
            }

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormSectionLayoutConfigurationProperty"]:
            '''The free-form layout configuration of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionlayoutconfiguration.html#cfn-quicksight-analysis-sectionlayoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            assert result is not None, "Required property 'free_form_layout' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FreeFormSectionLayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"after": "after"},
    )
    class SectionPageBreakConfigurationProperty:
        def __init__(
            self,
            *,
            after: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SectionAfterPageBreakProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a page break for a section.

            :param after: The configuration of a page break after a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionpagebreakconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_page_break_configuration_property = quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                    after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b8cf3ca6b34d6cceb68a26f9e2f51f20ffe4937c933d2c7fbf77750ef0d19fdb)
                check_type(argname="argument after", value=after, expected_type=type_hints["after"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if after is not None:
                self._values["after"] = after

        @builtins.property
        def after(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionAfterPageBreakProperty"]]:
            '''The configuration of a page break after a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionpagebreakconfiguration.html#cfn-quicksight-analysis-sectionpagebreakconfiguration-after
            '''
            result = self._values.get("after")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SectionAfterPageBreakProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionPageBreakConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SectionStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"height": "height", "padding": "padding"},
    )
    class SectionStyleProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            padding: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SpacingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that style a section.

            :param height: The height of a section. Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.
            :param padding: The spacing between section content and its top, bottom, left, and right edges. There is no padding by default.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_style_property = quicksight.CfnAnalysis.SectionStyleProperty(
                    height="height",
                    padding=quicksight.CfnAnalysis.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0735e72e3dfc9dede89030602ecd438f5dfd42c6eb4c7ac9df5c815b943377d6)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument padding", value=padding, expected_type=type_hints["padding"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if padding is not None:
                self._values["padding"] = padding

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of a section.

            Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html#cfn-quicksight-analysis-sectionstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def padding(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SpacingProperty"]]:
            '''The spacing between section content and its top, bottom, left, and right edges.

            There is no padding by default.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html#cfn-quicksight-analysis-sectionstyle-padding
            '''
            result = self._values.get("padding")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SpacingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_visual_scoping_configurations": "sheetVisualScopingConfigurations",
        },
    )
    class SelectedSheetsFilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            sheet_visual_scoping_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SheetVisualScopingConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The configuration for applying a filter to specific sheets or visuals.

            You can apply this filter to multiple visuals that are on one sheet or to all visuals on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param sheet_visual_scoping_configurations: The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-selectedsheetsfilterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                selected_sheets_filter_scope_configuration_property = quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                    sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                        scope="scope",
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        visual_ids=["visualIds"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57d02ef9bcb7f1327be6b53a061aff3c7df02e16c24d32c39cb07d61be5900e1)
                check_type(argname="argument sheet_visual_scoping_configurations", value=sheet_visual_scoping_configurations, expected_type=type_hints["sheet_visual_scoping_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sheet_visual_scoping_configurations is not None:
                self._values["sheet_visual_scoping_configurations"] = sheet_visual_scoping_configurations

        @builtins.property
        def sheet_visual_scoping_configurations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetVisualScopingConfigurationProperty"]]]]:
            '''The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-analysis-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
            '''
            result = self._values.get("sheet_visual_scoping_configurations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetVisualScopingConfigurationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SelectedSheetsFilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_field_series_item": "dataFieldSeriesItem",
            "field_series_item": "fieldSeriesItem",
        },
    )
    class SeriesItemProperty:
        def __init__(
            self,
            *,
            data_field_series_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataFieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_series_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The series item configuration of a line chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_field_series_item: The data field series item configuration of a line chart.
            :param field_series_item: The field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                series_item_property = quicksight.CfnAnalysis.SeriesItemProperty(
                    data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    ),
                    field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7180e0c50dc8a5a8d70d6c0e98f798cd42eb2bc6b1b30e6989c306bb0d9380ec)
                check_type(argname="argument data_field_series_item", value=data_field_series_item, expected_type=type_hints["data_field_series_item"])
                check_type(argname="argument field_series_item", value=field_series_item, expected_type=type_hints["field_series_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_field_series_item is not None:
                self._values["data_field_series_item"] = data_field_series_item
            if field_series_item is not None:
                self._values["field_series_item"] = field_series_item

        @builtins.property
        def data_field_series_item(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataFieldSeriesItemProperty"]]:
            '''The data field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html#cfn-quicksight-analysis-seriesitem-datafieldseriesitem
            '''
            result = self._values.get("data_field_series_item")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataFieldSeriesItemProperty"]], result)

        @builtins.property
        def field_series_item(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSeriesItemProperty"]]:
            '''The field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html#cfn-quicksight-analysis-seriesitem-fieldseriesitem
            '''
            result = self._values.get("field_series_item")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSeriesItemProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SetParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_parameter_name": "destinationParameterName",
            "value": "value",
        },
    )
    class SetParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            destination_parameter_name: builtins.str,
            value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DestinationParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The configuration of adding parameters in action.

            :param destination_parameter_name: The destination parameter name of the ``SetParameterValueConfiguration`` .
            :param value: ``CfnAnalysis.SetParameterValueConfigurationProperty.Value``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                set_parameter_value_configuration_property = quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                    destination_parameter_name="destinationParameterName",
                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                date_time_values=["dateTimeValues"],
                                decimal_values=[123],
                                integer_values=[123],
                                string_values=["stringValues"]
                            ),
                
                            # the properties below are optional
                            include_null_value=False
                        ),
                        select_all_value_options="selectAllValueOptions",
                        source_field="sourceField",
                        source_parameter_name="sourceParameterName"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__98a5a24e118b72b5dc0d8939881bb7dbe56dedb1bc22ade037c8001118d25e7c)
                check_type(argname="argument destination_parameter_name", value=destination_parameter_name, expected_type=type_hints["destination_parameter_name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "destination_parameter_name": destination_parameter_name,
                "value": value,
            }

        @builtins.property
        def destination_parameter_name(self) -> builtins.str:
            '''The destination parameter name of the ``SetParameterValueConfiguration`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html#cfn-quicksight-analysis-setparametervalueconfiguration-destinationparametername
            '''
            result = self._values.get("destination_parameter_name")
            assert result is not None, "Required property 'destination_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DestinationParameterValueConfigurationProperty"]:
            '''``CfnAnalysis.SetParameterValueConfigurationProperty.Value``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html#cfn-quicksight-analysis-setparametervalueconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DestinationParameterValueConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SetParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ShapeConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={"background_color": "backgroundColor"},
    )
    class ShapeConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The shape conditional formatting of a filled map visual.

            :param background_color: The conditional formatting for the shape background color of a filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shapeconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                shape_conditional_format_property = quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ff66c4953527bd851c8f88d154bab079f313d03d1705b825372e6385a8c04b4b)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "background_color": background_color,
            }

        @builtins.property
        def background_color(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]:
            '''The conditional formatting for the shape background color of a filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shapeconditionalformat.html#cfn-quicksight-analysis-shapeconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            assert result is not None, "Required property 'background_color' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShapeConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"grid_layout": "gridLayout"},
    )
    class SheetControlLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            grid_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :param grid_layout: The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_control_layout_configuration_property = quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                    grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f9e75e88096b00fd3b17af9e8d7b559a38db0733ecb86c0fe0b784550e65ca14)
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GridLayoutConfigurationProperty"]]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayoutconfiguration.html#cfn-quicksight-analysis-sheetcontrollayoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GridLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SheetControlLayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class SheetControlLayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SheetControlLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A grid layout to define the placement of sheet control.

            :param configuration: The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_control_layout_property = quicksight.CfnAnalysis.SheetControlLayoutProperty(
                    configuration=quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                        grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__20a2d2d6baff3fa470557e907b4bbbee724a0974cf1795748f33cc8da1efcbcb)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetControlLayoutConfigurationProperty"]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayout.html#cfn-quicksight-analysis-sheetcontrollayout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetControlLayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SheetDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_id": "sheetId",
            "content_type": "contentType",
            "description": "description",
            "filter_controls": "filterControls",
            "layouts": "layouts",
            "name": "name",
            "parameter_controls": "parameterControls",
            "sheet_control_layouts": "sheetControlLayouts",
            "text_boxes": "textBoxes",
            "title": "title",
            "visuals": "visuals",
        },
    )
    class SheetDefinitionProperty:
        def __init__(
            self,
            *,
            sheet_id: builtins.str,
            content_type: typing.Optional[builtins.str] = None,
            description: typing.Optional[builtins.str] = None,
            filter_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilterControlProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            layouts: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LayoutProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            name: typing.Optional[builtins.str] = None,
            parameter_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ParameterControlProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheet_control_layouts: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SheetControlLayoutProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            text_boxes: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SheetTextBoxProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            title: typing.Optional[builtins.str] = None,
            visuals: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A sheet is an object that contains a set of visuals that are viewed together on one page in a paginated report.

            Every analysis and dashboard must contain at least one sheet.

            :param sheet_id: The unique identifier of a sheet.
            :param content_type: The layout content type of the sheet. Choose one of the following options:. - ``PAGINATED`` : Creates a sheet for a paginated report. - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.
            :param description: A description of the sheet.
            :param filter_controls: The list of filter controls that are on a sheet. For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param layouts: Layouts define how the components of a sheet are arranged. For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .
            :param name: The name of the sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param parameter_controls: The list of parameter controls that are on a sheet. For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheet_control_layouts: The control layouts of the sheet.
            :param text_boxes: The text boxes that are on a sheet.
            :param title: The title of the sheet.
            :param visuals: A list of the visuals that are on a sheet. Visual placement is determined by the layout of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                sheet_definition_property = quicksight.CfnAnalysis.SheetDefinitionProperty(
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    content_type="contentType",
                    description="description",
                    filter_controls=[quicksight.CfnAnalysis.FilterControlProperty(
                        date_time_picker=quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        dropdown=quicksight.CfnAnalysis.FilterDropDownControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnAnalysis.FilterListControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        relative_date_time=quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        slider=quicksight.CfnAnalysis.FilterSliderControlProperty(
                            filter_control_id="filterControlId",
                            maximum_value=123,
                            minimum_value=123,
                            source_filter_id="sourceFilterId",
                            step_size=123,
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        text_area=quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    layouts=[quicksight.CfnAnalysis.LayoutProperty(
                        configuration=quicksight.CfnAnalysis.LayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
                
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                                body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                                    content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                        after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                            status="status"
                                        )
                                    ),
                                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                ),
                                footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )]
                            )
                        )
                    )],
                    name="name",
                    parameter_controls=[quicksight.CfnAnalysis.ParameterControlProperty(
                        date_time_picker=quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        dropdown=quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnAnalysis.ParameterListControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        slider=quicksight.CfnAnalysis.ParameterSliderControlProperty(
                            maximum_value=123,
                            minimum_value=123,
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            step_size=123,
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_area=quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    sheet_control_layouts=[quicksight.CfnAnalysis.SheetControlLayoutProperty(
                        configuration=quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                            grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
                
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        )
                    )],
                    text_boxes=[quicksight.CfnAnalysis.SheetTextBoxProperty(
                        sheet_text_box_id="sheetTextBoxId",
                
                        # the properties below are optional
                        content="content"
                    )],
                    title="title",
                    visuals=[quicksight.CfnAnalysis.VisualProperty(
                        bar_chart_visual=quicksight.CfnAnalysis.BarChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.BarChartConfigurationProperty(
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                                    bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                orientation="orientation",
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        box_plot_visual=quicksight.CfnAnalysis.BoxPlotVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                                box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                                    all_data_points_visibility="allDataPointsVisibility",
                                    outlier_visibility="outlierVisibility",
                                    style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                                        fill_style="fillStyle"
                                    )
                                ),
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                                    box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    )
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        combo_chart_visual=quicksight.CfnAnalysis.ComboChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                                bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                                    combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                                        bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        custom_content_visual=quicksight.CfnAnalysis.CustomContentVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                                content_type="contentType",
                                content_url="contentUrl",
                                image_scaling="imageScaling"
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        empty_visual=quicksight.CfnAnalysis.EmptyVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )]
                        ),
                        filled_map_visual=quicksight.CfnAnalysis.FilledMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                                field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                                    filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                                        geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                                    shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        funnel_chart_visual=quicksight.CfnAnalysis.FunnelChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    label_color="labelColor",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_data_label_style="measureDataLabelStyle",
                                    measure_label_visibility="measureLabelVisibility",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                                    funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        gauge_chart_visual=quicksight.CfnAnalysis.GaugeChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                                    target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                                    arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                                        arc_angle=123,
                                        arc_thickness="arcThickness"
                                    ),
                                    arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                                        range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                            max=123,
                                            min=123
                                        ),
                                        reserve_range=123
                                    ),
                                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                ),
                                tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            conditional_formatting=quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                                    arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        geospatial_map_visual=quicksight.CfnAnalysis.GeospatialMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                                field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                                    geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                                    cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                                        cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                            simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                                color="color"
                                            )
                                        )
                                    ),
                                    selected_point_style="selectedPointStyle"
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        heat_map_visual=quicksight.CfnAnalysis.HeatMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                                color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
                
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                                    heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                                    heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        histogram_visual=quicksight.CfnAnalysis.HistogramVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.HistogramConfigurationProperty(
                                bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                                    bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                                        value=123
                                    ),
                                    bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                                        bin_count_limit=123,
                                        value=123
                                    ),
                                    selected_bin_type="selectedBinType",
                                    start_value=123
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                                    histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                )
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        insight_visual=quicksight.CfnAnalysis.InsightVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            insight_configuration=quicksight.CfnAnalysis.InsightConfigurationProperty(
                                computations=[quicksight.CfnAnalysis.ComputationProperty(
                                    forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        custom_seasonality_value=123,
                                        lower_boundary=123,
                                        name="name",
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality="seasonality",
                                        upper_boundary=123,
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        period_size=123,
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
                
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                                        computation_id="computationId",
                                        from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        period_time_granularity="periodTimeGranularity",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
                
                                        # the properties below are optional
                                        mover_size=123,
                                        name="name",
                                        sort_order="sortOrder",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        type="type",
                
                                        # the properties below are optional
                                        name="name",
                                        result_size=123,
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                                        computation_id="computationId",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                
                                        # the properties below are optional
                                        name="name"
                                    )
                                )],
                                custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                                    narrative="narrative"
                                )
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        kpi_visual=quicksight.CfnAnalysis.KPIVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.KPIConfigurationProperty(
                                field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                                    target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                                    trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                                    primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        line_chart_visual=quicksight.CfnAnalysis.LineChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.LineChartConfigurationProperty(
                                contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                                    axis_binding="axisBinding",
                                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                                    line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                                    forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                                        lower_boundary=123,
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality=123,
                                        upper_boundary=123
                                    ),
                                    scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                                        what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                            date="date",
                                            value=123
                                        ),
                                        what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                            end_date="endDate",
                                            start_date="startDate",
                                            value=123
                                        )
                                    )
                                )],
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                series=[quicksight.CfnAnalysis.SeriesItemProperty(
                                    data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        field_value="fieldValue",
                                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    ),
                                    field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    )
                                )],
                                small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                                    category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                type="type",
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pie_chart_visual=quicksight.CfnAnalysis.PieChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.PieChartConfigurationProperty(
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                                    arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                                        arc_thickness="arcThickness"
                                    ),
                                    donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                                        label_visibility="labelVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                                    pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pivot_table_visual=quicksight.CfnAnalysis.PivotTableVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                                field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                                    data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                                        data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )],
                
                                        # the properties below are optional
                                        width="width"
                                    )],
                                    selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        visibility="visibility"
                                    )]
                                ),
                                field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                                    pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                                    field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                                        field_id="fieldId",
                                        sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                            column=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                                direction="direction",
                                                sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                    field_id="fieldId",
                                                    field_value="fieldValue"
                                                )]
                                            ),
                                            field=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )
                                    )]
                                ),
                                table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_names_visibility="columnNamesVisibility",
                                    metric_placement="metricPlacement",
                                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    ),
                                    row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    single_metric_visibility="singleMetricVisibility",
                                    toggle_buttons_visibility="toggleButtonsVisibility"
                                ),
                                total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                                    column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                )
                            ),
                            conditional_formatting=quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                            role="role"
                                        ),
                                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        radar_chart_visual=quicksight.CfnAnalysis.RadarChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                                alternate_band_colors_visibility="alternateBandColorsVisibility",
                                alternate_band_even_color="alternateBandEvenColor",
                                alternate_band_odd_color="alternateBandOddColor",
                                base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                                    area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                                    radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                shape="shape",
                                sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                start_angle=123,
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        sankey_diagram_visual=quicksight.CfnAnalysis.SankeyDiagramVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                                    sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                                        destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                                    destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        scatter_plot_visual=quicksight.CfnAnalysis.ScatterPlotVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        table_visual=quicksight.CfnAnalysis.TableVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.TableConfigurationProperty(
                                field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                                    order=["order"],
                                    selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                            image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                                sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                )
                                            ),
                                            link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                                content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                                    custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                                        icon="icon"
                                                    ),
                                                    custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                            font_color="fontColor",
                                                            font_decoration="fontDecoration",
                                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                                relative="relative"
                                                            ),
                                                            font_style="fontStyle",
                                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                                name="name"
                                                            )
                                                        ),
                
                                                        # the properties below are optional
                                                        value="value"
                                                    )
                                                ),
                                                target="target"
                                            )
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    )]
                                ),
                                field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                                    table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                                        values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                                date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    ),
                                    row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                                    data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        negative_color="negativeColor",
                                        positive_color="positiveColor"
                                    )
                                )],
                                table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    orientation="orientation",
                                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    )
                                ),
                                total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                                    custom_label="customLabel",
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility"
                                )
                            ),
                            conditional_formatting=quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    ),
                                    row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        tree_map_visual=quicksight.CfnAnalysis.TreeMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
                
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                                    tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                                    tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        waterfall_visual=quicksight.CfnAnalysis.WaterfallVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                                category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                                    waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                                        breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                                    breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                                    total_bar_label="totalBarLabel"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        word_cloud_visual=quicksight.CfnAnalysis.WordCloudVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                                    word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                                    cloud_layout="cloudLayout",
                                    maximum_string_length=123,
                                    word_casing="wordCasing",
                                    word_orientation="wordOrientation",
                                    word_padding="wordPadding",
                                    word_scaling="wordScaling"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__98d6f4f0028ae9d6b3145f602f0c88ebc6ee8cdc2a7fd3d72d64d5df71cf5d02)
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument filter_controls", value=filter_controls, expected_type=type_hints["filter_controls"])
                check_type(argname="argument layouts", value=layouts, expected_type=type_hints["layouts"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_controls", value=parameter_controls, expected_type=type_hints["parameter_controls"])
                check_type(argname="argument sheet_control_layouts", value=sheet_control_layouts, expected_type=type_hints["sheet_control_layouts"])
                check_type(argname="argument text_boxes", value=text_boxes, expected_type=type_hints["text_boxes"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visuals", value=visuals, expected_type=type_hints["visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_id": sheet_id,
            }
            if content_type is not None:
                self._values["content_type"] = content_type
            if description is not None:
                self._values["description"] = description
            if filter_controls is not None:
                self._values["filter_controls"] = filter_controls
            if layouts is not None:
                self._values["layouts"] = layouts
            if name is not None:
                self._values["name"] = name
            if parameter_controls is not None:
                self._values["parameter_controls"] = parameter_controls
            if sheet_control_layouts is not None:
                self._values["sheet_control_layouts"] = sheet_control_layouts
            if text_boxes is not None:
                self._values["text_boxes"] = text_boxes
            if title is not None:
                self._values["title"] = title
            if visuals is not None:
                self._values["visuals"] = visuals

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The unique identifier of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The layout content type of the sheet. Choose one of the following options:.

            - ``PAGINATED`` : Creates a sheet for a paginated report.
            - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''A description of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def filter_controls(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterControlProperty"]]]]:
            '''The list of filter controls that are on a sheet.

            For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-filtercontrols
            '''
            result = self._values.get("filter_controls")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilterControlProperty"]]]], result)

        @builtins.property
        def layouts(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LayoutProperty"]]]]:
            '''Layouts define how the components of a sheet are arranged.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-layouts
            '''
            result = self._values.get("layouts")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LayoutProperty"]]]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_controls(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterControlProperty"]]]]:
            '''The list of parameter controls that are on a sheet.

            For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-parametercontrols
            '''
            result = self._values.get("parameter_controls")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ParameterControlProperty"]]]], result)

        @builtins.property
        def sheet_control_layouts(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetControlLayoutProperty"]]]]:
            '''The control layouts of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-sheetcontrollayouts
            '''
            result = self._values.get("sheet_control_layouts")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetControlLayoutProperty"]]]], result)

        @builtins.property
        def text_boxes(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetTextBoxProperty"]]]]:
            '''The text boxes that are on a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-textboxes
            '''
            result = self._values.get("text_boxes")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetTextBoxProperty"]]]], result)

        @builtins.property
        def title(self) -> typing.Optional[builtins.str]:
            '''The title of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visuals(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualProperty"]]]]:
            '''A list of the visuals that are on a sheet.

            Visual placement is determined by the layout of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-visuals
            '''
            result = self._values.get("visuals")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SheetElementConfigurationOverridesProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The override configuration of the rendering rules of a sheet.

            :param visibility: Determines whether or not the overrides are visible. Choose one of the following options:. - ``VISIBLE`` - ``HIDDEN``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementconfigurationoverrides.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_element_configuration_overrides_property = quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f9509da869d74c1a8c070bf0d16312535361f6f146f49a2f608c4b1edaeb37f)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the overrides are visible. Choose one of the following options:.

            - ``VISIBLE``
            - ``HIDDEN``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementconfigurationoverrides.html#cfn-quicksight-analysis-sheetelementconfigurationoverrides-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementConfigurationOverridesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SheetElementRenderingRuleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "configuration_overrides": "configurationOverrides",
            "expression": "expression",
        },
    )
    class SheetElementRenderingRuleProperty:
        def __init__(
            self,
            *,
            configuration_overrides: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SheetElementConfigurationOverridesProperty", typing.Dict[builtins.str, typing.Any]]],
            expression: builtins.str,
        ) -> None:
            '''The rendering rules of a sheet that uses a free-form layout.

            :param configuration_overrides: The override configuration of the rendering rules of a sheet.
            :param expression: The expression of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_element_rendering_rule_property = quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                        visibility="visibility"
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7b18030ef2fa34ac222ba21c5da57678bac1c69488e13f6640311ee0c0fb5f9a)
                check_type(argname="argument configuration_overrides", value=configuration_overrides, expected_type=type_hints["configuration_overrides"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration_overrides": configuration_overrides,
                "expression": expression,
            }

        @builtins.property
        def configuration_overrides(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetElementConfigurationOverridesProperty"]:
            '''The override configuration of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html#cfn-quicksight-analysis-sheetelementrenderingrule-configurationoverrides
            '''
            result = self._values.get("configuration_overrides")
            assert result is not None, "Required property 'configuration_overrides' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SheetElementConfigurationOverridesProperty"], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html#cfn-quicksight-analysis-sheetelementrenderingrule-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementRenderingRuleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SheetProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "sheet_id": "sheetId"},
    )
    class SheetProperty:
        def __init__(
            self,
            *,
            name: typing.Optional[builtins.str] = None,
            sheet_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight.

            Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.

            :param name: The name of a sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param sheet_id: The unique identifier associated with a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_property = quicksight.CfnAnalysis.SheetProperty(
                    name="name",
                    sheet_id="sheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7cacd0f254449cae9b648689b1208d949b84917047f78fb6cf379d6f1d941582)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name
            if sheet_id is not None:
                self._values["sheet_id"] = sheet_id

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html#cfn-quicksight-analysis-sheet-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sheet_id(self) -> typing.Optional[builtins.str]:
            '''The unique identifier associated with a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html#cfn-quicksight-analysis-sheet-sheetid
            '''
            result = self._values.get("sheet_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SheetTextBoxProperty",
        jsii_struct_bases=[],
        name_mapping={"sheet_text_box_id": "sheetTextBoxId", "content": "content"},
    )
    class SheetTextBoxProperty:
        def __init__(
            self,
            *,
            sheet_text_box_id: builtins.str,
            content: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A text box.

            :param sheet_text_box_id: The unique identifier for a text box. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
            :param content: The content that is displayed in the text box.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_text_box_property = quicksight.CfnAnalysis.SheetTextBoxProperty(
                    sheet_text_box_id="sheetTextBoxId",
                
                    # the properties below are optional
                    content="content"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b9e2cae552e9c723a892ca8af894fb9f71723b6d120addcec8b06bc65a0b0621)
                check_type(argname="argument sheet_text_box_id", value=sheet_text_box_id, expected_type=type_hints["sheet_text_box_id"])
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_text_box_id": sheet_text_box_id,
            }
            if content is not None:
                self._values["content"] = content

        @builtins.property
        def sheet_text_box_id(self) -> builtins.str:
            '''The unique identifier for a text box.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html#cfn-quicksight-analysis-sheettextbox-sheettextboxid
            '''
            result = self._values.get("sheet_text_box_id")
            assert result is not None, "Required property 'sheet_text_box_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content(self) -> typing.Optional[builtins.str]:
            '''The content that is displayed in the text box.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html#cfn-quicksight-analysis-sheettextbox-content
            '''
            result = self._values.get("content")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetTextBoxProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scope": "scope",
            "sheet_id": "sheetId",
            "visual_ids": "visualIds",
        },
    )
    class SheetVisualScopingConfigurationProperty:
        def __init__(
            self,
            *,
            scope: builtins.str,
            sheet_id: builtins.str,
            visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The filter that is applied to the options.

            :param scope: The scope of the applied entities. Choose one of the following options:. - ``ALL_VISUALS`` - ``SELECTED_VISUALS``
            :param sheet_id: The selected sheet that the filter is applied to.
            :param visual_ids: The selected visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_visual_scoping_configuration_property = quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                    scope="scope",
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    visual_ids=["visualIds"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb08203bf42bc95c411ffee09bb2e6ec9c6940033cf7291896304896a28df623)
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument visual_ids", value=visual_ids, expected_type=type_hints["visual_ids"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "scope": scope,
                "sheet_id": sheet_id,
            }
            if visual_ids is not None:
                self._values["visual_ids"] = visual_ids

        @builtins.property
        def scope(self) -> builtins.str:
            '''The scope of the applied entities. Choose one of the following options:.

            - ``ALL_VISUALS``
            - ``SELECTED_VISUALS``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-scope
            '''
            result = self._values.get("scope")
            assert result is not None, "Required property 'scope' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The selected sheet that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_ids(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The selected visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-visualids
            '''
            result = self._values.get("visual_ids")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetVisualScopingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ShortFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class ShortFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for the title.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                short_format_text_property = quicksight.CfnAnalysis.ShortFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a2a0f1eb82d70438008f1f141c8c8674a381d6c01dd4fe59ce4d7737b7adde9)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html#cfn-quicksight-analysis-shortformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html#cfn-quicksight-analysis-shortformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShortFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SimpleClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color"},
    )
    class SimpleClusterMarkerProperty:
        def __init__(self, *, color: typing.Optional[builtins.str] = None) -> None:
            '''The simple cluster marker of the cluster marker.

            :param color: The color of the simple cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-simpleclustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                simple_cluster_marker_property = quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__71e9ec78fe94cf84ad2a41b3a9a1aa6e2304dc7ec18a90e32de70deb4ef5febb)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of the simple cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-simpleclustermarker.html#cfn-quicksight-analysis-simpleclustermarker-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SimpleClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"title_options": "titleOptions"},
    )
    class SliderControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-slidercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                slider_control_display_options_property = quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__67093e452f807d8cc8c13a040e3510ce55243eb17b8b622c4c3095ae9338f826)
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-slidercontroldisplayoptions.html#cfn-quicksight-analysis-slidercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SliderControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SmallMultiplesOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "max_visible_columns": "maxVisibleColumns",
            "max_visible_rows": "maxVisibleRows",
            "panel_configuration": "panelConfiguration",
        },
    )
    class SmallMultiplesOptionsProperty:
        def __init__(
            self,
            *,
            max_visible_columns: typing.Optional[jsii.Number] = None,
            max_visible_rows: typing.Optional[jsii.Number] = None,
            panel_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PanelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Options that determine the layout and display options of a chart's small multiples.

            :param max_visible_columns: Sets the maximum number of visible columns to display in the grid of small multiples panels. The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
            :param max_visible_rows: Sets the maximum number of visible rows to display in the grid of small multiples panels. The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
            :param panel_configuration: Configures the display options for each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                small_multiples_options_property = quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                    max_visible_columns=123,
                    max_visible_rows=123,
                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                        background_color="backgroundColor",
                        background_visibility="backgroundVisibility",
                        border_color="borderColor",
                        border_style="borderStyle",
                        border_thickness="borderThickness",
                        border_visibility="borderVisibility",
                        gutter_spacing="gutterSpacing",
                        gutter_visibility="gutterVisibility",
                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_text_alignment="horizontalTextAlignment",
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b34a8942e8b9336f2d48e06137768358f24af2ebfc5193fa88f0bf5c8642dc93)
                check_type(argname="argument max_visible_columns", value=max_visible_columns, expected_type=type_hints["max_visible_columns"])
                check_type(argname="argument max_visible_rows", value=max_visible_rows, expected_type=type_hints["max_visible_rows"])
                check_type(argname="argument panel_configuration", value=panel_configuration, expected_type=type_hints["panel_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max_visible_columns is not None:
                self._values["max_visible_columns"] = max_visible_columns
            if max_visible_rows is not None:
                self._values["max_visible_rows"] = max_visible_rows
            if panel_configuration is not None:
                self._values["panel_configuration"] = panel_configuration

        @builtins.property
        def max_visible_columns(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible columns to display in the grid of small multiples panels.

            The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-maxvisiblecolumns
            '''
            result = self._values.get("max_visible_columns")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def max_visible_rows(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible rows to display in the grid of small multiples panels.

            The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-maxvisiblerows
            '''
            result = self._values.get("max_visible_rows")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def panel_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PanelConfigurationProperty"]]:
            '''Configures the display options for each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-panelconfiguration
            '''
            result = self._values.get("panel_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PanelConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SmallMultiplesOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SpacingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class SpacingProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[builtins.str] = None,
            left: typing.Optional[builtins.str] = None,
            right: typing.Optional[builtins.str] = None,
            top: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of spacing (often a margin or padding).

            :param bottom: Define the bottom spacing.
            :param left: Define the left spacing.
            :param right: Define the right spacing.
            :param top: Define the top spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                spacing_property = quicksight.CfnAnalysis.SpacingProperty(
                    bottom="bottom",
                    left="left",
                    right="right",
                    top="top"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5b2be0229e5c871b1763885f6535c43424f0762572f2046c9cce5002947c9dd)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(self) -> typing.Optional[builtins.str]:
            '''Define the bottom spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def left(self) -> typing.Optional[builtins.str]:
            '''Define the left spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def right(self) -> typing.Optional[builtins.str]:
            '''Define the right spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def top(self) -> typing.Optional[builtins.str]:
            '''Define the top spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SpacingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.StringDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class StringDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``StringParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``StringDefaultValues`` . Different defaults displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_default_values_property = quicksight.CfnAnalysis.StringDefaultValuesProperty(
                    dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ccc7e0543de2412b5b25d0973329ecdb15ba6486ef62ec2852d046aef8220312)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``StringDefaultValues`` .

            Different defaults displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html#cfn-quicksight-analysis-stringdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html#cfn-quicksight-analysis-stringdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.StringFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class StringFormatConfigurationProperty:
        def __init__(
            self,
            *,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for string fields.

            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric strings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_format_configuration_property = quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5578d43ea0b1a011b59b52c0fe1cabac17a88604a3fcc768325ba1a6dbfc78f6)
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html#cfn-quicksight-analysis-stringformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericFormatConfigurationProperty"]]:
            '''The formatting configuration for numeric strings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html#cfn-quicksight-analysis-stringformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.StringParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class StringParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.StringDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.StringValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``String`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnAnalysis.StringParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_parameter_declaration_property = quicksight.CfnAnalysis.StringParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnAnalysis.StringDefaultValuesProperty(
                        dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a3428456c1d6e6937273bb7bff77e0be099bf226f15b89ba55693a48b702fb06)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MappedDataSetParameterProperty"]]]]:
            '''``CfnAnalysis.StringParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.StringValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.StringParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class StringParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Sequence[builtins.str],
        ) -> None:
            '''A string parameter.

            :param name: A display name for a string parameter.
            :param values: The values of a string parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_parameter_property = quicksight.CfnAnalysis.StringParameterProperty(
                    name="name",
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d8d78fa02ae2aed74712632f744886e36d8560b93267dfae1fe42091a4c8a086)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for a string parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html#cfn-quicksight-analysis-stringparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(self) -> typing.List[builtins.str]:
            '''The values of a string parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html#cfn-quicksight-analysis-stringparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class StringValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_value_when_unset_configuration_property = quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57a1af832712bc853d8861dfdce5b7e9e9c79c6697ec86ab8874aafd27a77bc6)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-stringvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-stringvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.SubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "field_level": "fieldLevel",
            "field_level_options": "fieldLevelOptions",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class SubtotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            field_level: typing.Optional[builtins.str] = None,
            field_level_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableFieldSubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            metric_header_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The subtotal options.

            :param custom_label: The custom label string for the subtotal cells.
            :param field_level: The field level (all, custom, last) for the subtotal cells.
            :param field_level_options: The optional configuration of subtotal cells.
            :param metric_header_cell_style: The cell styling options for the subtotals of header cells.
            :param total_cell_style: The cell styling options for the subtotal cells.
            :param totals_visibility: The visibility configuration for the subtotal cells.
            :param value_cell_style: The cell styling options for the subtotals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                subtotal_options_property = quicksight.CfnAnalysis.SubtotalOptionsProperty(
                    custom_label="customLabel",
                    field_level="fieldLevel",
                    field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                        field_id="fieldId"
                    )],
                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c9a27ac919503c807c54ef3d99f42e3e023f1c38d8e1413a3bbd26fd0847eedd)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument field_level", value=field_level, expected_type=type_hints["field_level"])
                check_type(argname="argument field_level_options", value=field_level_options, expected_type=type_hints["field_level_options"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if field_level is not None:
                self._values["field_level"] = field_level
            if field_level_options is not None:
                self._values["field_level_options"] = field_level_options
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level(self) -> typing.Optional[builtins.str]:
            '''The field level (all, custom, last) for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-fieldlevel
            '''
            result = self._values.get("field_level")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableFieldSubtotalOptionsProperty"]]]]:
            '''The optional configuration of subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-fieldleveloptions
            '''
            result = self._values.get("field_level_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableFieldSubtotalOptionsProperty"]]]], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotals of header cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class TableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for the table.

            :param group_by: The group by field well for a pivot table. Values are grouped by group by fields.
            :param values: The values field well for a pivot table. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_aggregated_field_wells_property = quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f255384b3c126bc08e0710f46935a92fe2225005f55725cd0efe34c9c00f9ca4)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The group by field well for a pivot table.

            Values are grouped by group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html#cfn-quicksight-analysis-tableaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html#cfn-quicksight-analysis-tableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "style": "style", "thickness": "thickness"},
    )
    class TableBorderOptionsProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            style: typing.Optional[builtins.str] = None,
            thickness: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The border options for a table border.

            :param color: The color of a table border.
            :param style: The style (none, solid) of a table border.
            :param thickness: The thickness of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_border_options_property = quicksight.CfnAnalysis.TableBorderOptionsProperty(
                    color="color",
                    style="style",
                    thickness=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f8364f2fe48c0bc0464f363ff5216f5f1063b4cd65dba537c35dc7ce8c18d332)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
                check_type(argname="argument thickness", value=thickness, expected_type=type_hints["thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if style is not None:
                self._values["style"] = style
            if thickness is not None:
                self._values["thickness"] = thickness

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style(self) -> typing.Optional[builtins.str]:
            '''The style (none, solid) of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thickness(self) -> typing.Optional[jsii.Number]:
            '''The thickness of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-thickness
            '''
            result = self._values.get("thickness")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "text_format": "textFormat"},
    )
    class TableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            text_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cell conditional formatting option for a table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_cell_conditional_formatting_property = quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d27b894f1ec0b4cec4cabd1746f88e6040cb88d796dd76291eff4b899d490f50)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html#cfn-quicksight-analysis-tablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextConditionalFormatProperty"]]:
            '''The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html#cfn-quicksight-analysis-tablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_cell_image_scaling_configuration": "tableCellImageScalingConfiguration",
        },
    )
    class TableCellImageSizingConfigurationProperty:
        def __init__(
            self,
            *,
            table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The sizing options for the table image configuration.

            :param table_cell_image_scaling_configuration: The cell scaling configuration of the sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellimagesizingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_cell_image_sizing_configuration_property = quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f89394e28ada923f4869cc0cfa0f42fb2439a4749b2845fdac145cc1d56fc6c4)
                check_type(argname="argument table_cell_image_scaling_configuration", value=table_cell_image_scaling_configuration, expected_type=type_hints["table_cell_image_scaling_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_cell_image_scaling_configuration is not None:
                self._values["table_cell_image_scaling_configuration"] = table_cell_image_scaling_configuration

        @builtins.property
        def table_cell_image_scaling_configuration(
            self,
        ) -> typing.Optional[builtins.str]:
            '''The cell scaling configuration of the sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellimagesizingconfiguration.html#cfn-quicksight-analysis-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
            '''
            result = self._values.get("table_cell_image_scaling_configuration")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellImageSizingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableCellStyleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "border": "border",
            "font_configuration": "fontConfiguration",
            "height": "height",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "text_wrap": "textWrap",
            "vertical_text_alignment": "verticalTextAlignment",
            "visibility": "visibility",
        },
    )
    class TableCellStyleProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GlobalTableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            height: typing.Optional[jsii.Number] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            text_wrap: typing.Optional[builtins.str] = None,
            vertical_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table cell style for a cell in pivot table or table visual.

            :param background_color: The background color for the table cells.
            :param border: The borders for the table cells.
            :param font_configuration: The font configuration of the table cells.
            :param height: The height color for the table cells.
            :param horizontal_text_alignment: The horizontal text alignment (left, center, right, auto) for the table cells.
            :param text_wrap: The text wrap (none, wrap) for the table cells.
            :param vertical_text_alignment: The vertical text alignment (top, middle, bottom) for the table cells.
            :param visibility: The visibility of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_cell_style_property = quicksight.CfnAnalysis.TableCellStyleProperty(
                    background_color="backgroundColor",
                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    height=123,
                    horizontal_text_alignment="horizontalTextAlignment",
                    text_wrap="textWrap",
                    vertical_text_alignment="verticalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__42c2e423baf66d1e7f50ff7efa995d82d30c52c1b20458d69098f2c08d417d35)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument border", value=border, expected_type=type_hints["border"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument text_wrap", value=text_wrap, expected_type=type_hints["text_wrap"])
                check_type(argname="argument vertical_text_alignment", value=vertical_text_alignment, expected_type=type_hints["vertical_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if border is not None:
                self._values["border"] = border
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if height is not None:
                self._values["height"] = height
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if text_wrap is not None:
                self._values["text_wrap"] = text_wrap
            if vertical_text_alignment is not None:
                self._values["vertical_text_alignment"] = vertical_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''The background color for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GlobalTableBorderOptionsProperty"]]:
            '''The borders for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-border
            '''
            result = self._values.get("border")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GlobalTableBorderOptionsProperty"]], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]]:
            '''The font configuration of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]], result)

        @builtins.property
        def height(self) -> typing.Optional[jsii.Number]:
            '''The height color for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The horizontal text alignment (left, center, right, auto) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def text_wrap(self) -> typing.Optional[builtins.str]:
            '''The text wrap (none, wrap) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-textwrap
            '''
            result = self._values.get("text_wrap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The vertical text alignment (top, middle, bottom) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-verticaltextalignment
            '''
            result = self._values.get("vertical_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell", "row": "row"},
    )
    class TableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableRowConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a table.
            :param row: The row conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_conditional_formatting_option_property = quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    ),
                    row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fecfbbe7cc00f7928e348ba95570a7debd025e6adfa6fbf4fe7fd5cd9ebd7cc0)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
                check_type(argname="argument row", value=row, expected_type=type_hints["row"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell
            if row is not None:
                self._values["row"] = row

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellConditionalFormattingProperty"]]:
            '''The cell conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html#cfn-quicksight-analysis-tableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellConditionalFormattingProperty"]], result)

        @builtins.property
        def row(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableRowConditionalFormattingProperty"]]:
            '''The row conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html#cfn-quicksight-analysis-tableconditionalformattingoption-row
            '''
            result = self._values.get("row")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableRowConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class TableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_conditional_formatting_property = quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        ),
                        row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eb58f86dc6c6304bbc6ddc4e5020a60cf25cc8a4ebaea1700e21fe0ecb2dc509)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformatting.html#cfn-quicksight-analysis-tableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_inline_visualizations": "tableInlineVisualizations",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class TableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_report_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_inline_visualizations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableInlineVisualizationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            table_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``TableVisual`` .

            :param field_options: The field options for a table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a table visual.
            :param sort_configuration: The sort configuration for a ``TableVisual`` .
            :param table_inline_visualizations: A collection of inline visualizations to display within a chart.
            :param table_options: The table options for a table visual.
            :param total_options: The total options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_configuration_property = quicksight.CfnAnalysis.TableConfigurationProperty(
                    field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                        order=["order"],
                        selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            custom_label="customLabel",
                            url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                    sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                    )
                                ),
                                link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                    content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                        custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                            icon="icon"
                                        ),
                                        custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            value="value"
                                        )
                                    ),
                                    target="target"
                                )
                            ),
                            visibility="visibility",
                            width="width"
                        )]
                    ),
                    field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                        table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                            values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                    date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                        vertical_overflow_visibility="verticalOverflowVisibility"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                        pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                            page_number=123,
                            page_size=123
                        ),
                        row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                        data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            negative_color="negativeColor",
                            positive_color="positiveColor"
                        )
                    )],
                    table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                        cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        orientation="orientation",
                        row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                            row_alternate_colors=["rowAlternateColors"],
                            status="status"
                        )
                    ),
                    total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                        custom_label="customLabel",
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__461f5fcef3cb75d7112386f1cdbd1159d5de6647f7c7ac8fd1c8d80ca8b99549)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_inline_visualizations", value=table_inline_visualizations, expected_type=type_hints["table_inline_visualizations"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_inline_visualizations is not None:
                self._values["table_inline_visualizations"] = table_inline_visualizations
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldOptionsProperty"]]:
            '''The field options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldWellsProperty"]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TablePaginatedReportOptionsProperty"]]:
            '''The paginated report options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TablePaginatedReportOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableSortConfigurationProperty"]]:
            '''The sort configuration for a ``TableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableSortConfigurationProperty"]], result)

        @builtins.property
        def table_inline_visualizations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableInlineVisualizationProperty"]]]]:
            '''A collection of inline visualizations to display within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-tableinlinevisualizations
            '''
            result = self._values.get("table_inline_visualizations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableInlineVisualizationProperty"]]]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableOptionsProperty"]]:
            '''The table options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableOptionsProperty"]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TotalOptionsProperty"]]:
            '''The total options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableFieldCustomIconContentProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon"},
    )
    class TableFieldCustomIconContentProperty:
        def __init__(self, *, icon: typing.Optional[builtins.str] = None) -> None:
            '''The custom icon content for the table link content configuration.

            :param icon: The icon set type (link) of the custom icon content for table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomiconcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_custom_icon_content_property = quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                    icon="icon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__18d6da966041b103e7dce9a1a3fc25fafcac0d08d2a722ad1c11fdd22e7d3cf2)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''The icon set type (link) of the custom icon content for table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomiconcontent.html#cfn-quicksight-analysis-tablefieldcustomiconcontent-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomIconContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableFieldCustomTextContentProperty",
        jsii_struct_bases=[],
        name_mapping={"font_configuration": "fontConfiguration", "value": "value"},
    )
    class TableFieldCustomTextContentProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :param font_configuration: The font configuration of the custom text content for the table URL link content.
            :param value: The string value of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_custom_text_content_property = quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                
                    # the properties below are optional
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__02e22ec2a18ca267b33fad8df8923023b3c31f723d612c55b32afc8b636d6cab)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "font_configuration": font_configuration,
            }
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"]:
            '''The font configuration of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html#cfn-quicksight-analysis-tablefieldcustomtextcontent-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            assert result is not None, "Required property 'font_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FontConfigurationProperty"], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The string value of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html#cfn-quicksight-analysis-tablefieldcustomtextcontent-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomTextContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableFieldImageConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"sizing_options": "sizingOptions"},
    )
    class TableFieldImageConfigurationProperty:
        def __init__(
            self,
            *,
            sizing_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellImageSizingConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The image configuration of a table field URL.

            :param sizing_options: The sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldimageconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_image_configuration_property = quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                    sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a47a7e09ccdb72246681ca605f217f6041815cc516aeed9016d12e23c8659c7)
                check_type(argname="argument sizing_options", value=sizing_options, expected_type=type_hints["sizing_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sizing_options is not None:
                self._values["sizing_options"] = sizing_options

        @builtins.property
        def sizing_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellImageSizingConfigurationProperty"]]:
            '''The sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldimageconfiguration.html#cfn-quicksight-analysis-tablefieldimageconfiguration-sizingoptions
            '''
            result = self._values.get("sizing_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellImageSizingConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldImageConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"content": "content", "target": "target"},
    )
    class TableFieldLinkConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableFieldLinkContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            target: builtins.str,
        ) -> None:
            '''The link configuration of a table field URL.

            :param content: The URL content (text, icon) for the table link configuration.
            :param target: The URL target (new tab, new window, same tab) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_link_configuration_property = quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                    content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                        custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                            icon="icon"
                        ),
                        custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                
                            # the properties below are optional
                            value="value"
                        )
                    ),
                    target="target"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e5eba622d180f1bcb77b3e83227e5450b49cd30ee67121ac6b6fb0c5ab998428)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument target", value=target, expected_type=type_hints["target"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "target": target,
            }

        @builtins.property
        def content(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldLinkContentConfigurationProperty"]:
            '''The URL content (text, icon) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html#cfn-quicksight-analysis-tablefieldlinkconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldLinkContentConfigurationProperty"], result)

        @builtins.property
        def target(self) -> builtins.str:
            '''The URL target (new tab, new window, same tab) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html#cfn-quicksight-analysis-tablefieldlinkconfiguration-target
            '''
            result = self._values.get("target")
            assert result is not None, "Required property 'target' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_icon_content": "customIconContent",
            "custom_text_content": "customTextContent",
        },
    )
    class TableFieldLinkContentConfigurationProperty:
        def __init__(
            self,
            *,
            custom_icon_content: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableFieldCustomIconContentProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_text_content: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableFieldCustomTextContentProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The URL content (text, icon) for the table link configuration.

            :param custom_icon_content: The custom icon content for the table link content configuration.
            :param custom_text_content: The custom text content (value, font configuration) for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_link_content_configuration_property = quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                    custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                        icon="icon"
                    ),
                    custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                
                        # the properties below are optional
                        value="value"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__99ba4b04bd7fa7922a2ecbe559b207937cfcd0787cc4282972cd273d1023b4ce)
                check_type(argname="argument custom_icon_content", value=custom_icon_content, expected_type=type_hints["custom_icon_content"])
                check_type(argname="argument custom_text_content", value=custom_text_content, expected_type=type_hints["custom_text_content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_icon_content is not None:
                self._values["custom_icon_content"] = custom_icon_content
            if custom_text_content is not None:
                self._values["custom_text_content"] = custom_text_content

        @builtins.property
        def custom_icon_content(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldCustomIconContentProperty"]]:
            '''The custom icon content for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html#cfn-quicksight-analysis-tablefieldlinkcontentconfiguration-customiconcontent
            '''
            result = self._values.get("custom_icon_content")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldCustomIconContentProperty"]], result)

        @builtins.property
        def custom_text_content(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldCustomTextContentProperty"]]:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html#cfn-quicksight-analysis-tablefieldlinkcontentconfiguration-customtextcontent
            '''
            result = self._values.get("custom_text_content")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldCustomTextContentProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "url_styling": "urlStyling",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class TableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            url_styling: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableFieldURLConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a table field.

            :param field_id: The field ID for a table field.
            :param custom_label: The custom label for a table field.
            :param url_styling: The URL configuration for a table field.
            :param visibility: The visibility of a table field.
            :param width: The width for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_option_property = quicksight.CfnAnalysis.TableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                        image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                            sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                            )
                        ),
                        link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                            content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                    icon="icon"
                                ),
                                custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    value="value"
                                )
                            ),
                            target="target"
                        )
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d51dc70f2596619d6a5315b18b50bed1e5d2c74abc26edee57ccaf5c5943f003)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument url_styling", value=url_styling, expected_type=type_hints["url_styling"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if url_styling is not None:
                self._values["url_styling"] = url_styling
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def url_styling(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldURLConfigurationProperty"]]:
            '''The URL configuration for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-urlstyling
            '''
            result = self._values.get("url_styling")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldURLConfigurationProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "order": "order",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class TableFieldOptionsProperty:
        def __init__(
            self,
            *,
            order: typing.Optional[typing.Sequence[builtins.str]] = None,
            selected_field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field options for a table visual.

            :param order: The order of field IDs of the field options for a table visual.
            :param selected_field_options: The selected field options for the table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_options_property = quicksight.CfnAnalysis.TableFieldOptionsProperty(
                    order=["order"],
                    selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                            image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                )
                            ),
                            link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                    custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                        icon="icon"
                                    ),
                                    custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        value="value"
                                    )
                                ),
                                target="target"
                            )
                        ),
                        visibility="visibility",
                        width="width"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7cfa074160e5bafdbf057b1144a0109b2b11c0bfc47698f35e66c8595563b2f2)
                check_type(argname="argument order", value=order, expected_type=type_hints["order"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if order is not None:
                self._values["order"] = order
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def order(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The order of field IDs of the field options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html#cfn-quicksight-analysis-tablefieldoptions-order
            '''
            result = self._values.get("order")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldOptionProperty"]]]]:
            '''The selected field options for the table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html#cfn-quicksight-analysis-tablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableFieldURLConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "image_configuration": "imageConfiguration",
            "link_configuration": "linkConfiguration",
        },
    )
    class TableFieldURLConfigurationProperty:
        def __init__(
            self,
            *,
            image_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableFieldImageConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            link_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableFieldLinkConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The URL configuration for a table field.

            :param image_configuration: The image configuration of a table field URL.
            :param link_configuration: The link configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_uRLConfiguration_property = quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                    image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                        sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                        )
                    ),
                    link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                        content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                            custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                icon="icon"
                            ),
                            custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                
                                # the properties below are optional
                                value="value"
                            )
                        ),
                        target="target"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__05fcaa5bf6c410e2af935f8264b25da0799f2c6d7bf2ed71abe5b59a0e048aef)
                check_type(argname="argument image_configuration", value=image_configuration, expected_type=type_hints["image_configuration"])
                check_type(argname="argument link_configuration", value=link_configuration, expected_type=type_hints["link_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if image_configuration is not None:
                self._values["image_configuration"] = image_configuration
            if link_configuration is not None:
                self._values["link_configuration"] = link_configuration

        @builtins.property
        def image_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldImageConfigurationProperty"]]:
            '''The image configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html#cfn-quicksight-analysis-tablefieldurlconfiguration-imageconfiguration
            '''
            result = self._values.get("image_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldImageConfigurationProperty"]], result)

        @builtins.property
        def link_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldLinkConfigurationProperty"]]:
            '''The link configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html#cfn-quicksight-analysis-tablefieldurlconfiguration-linkconfiguration
            '''
            result = self._values.get("link_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableFieldLinkConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldURLConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_aggregated_field_wells": "tableAggregatedFieldWells",
            "table_unaggregated_field_wells": "tableUnaggregatedFieldWells",
        },
    )
    class TableFieldWellsProperty:
        def __init__(
            self,
            *,
            table_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_unaggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells for a table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param table_aggregated_field_wells: The aggregated field well for the table.
            :param table_unaggregated_field_wells: The unaggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_wells_property = quicksight.CfnAnalysis.TableFieldWellsProperty(
                    table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                        values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5120a99bc0994de264df10390e24adb3b0cebe5817d98e35cd22922c1062fe06)
                check_type(argname="argument table_aggregated_field_wells", value=table_aggregated_field_wells, expected_type=type_hints["table_aggregated_field_wells"])
                check_type(argname="argument table_unaggregated_field_wells", value=table_unaggregated_field_wells, expected_type=type_hints["table_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_aggregated_field_wells is not None:
                self._values["table_aggregated_field_wells"] = table_aggregated_field_wells
            if table_unaggregated_field_wells is not None:
                self._values["table_unaggregated_field_wells"] = table_unaggregated_field_wells

        @builtins.property
        def table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html#cfn-quicksight-analysis-tablefieldwells-tableaggregatedfieldwells
            '''
            result = self._values.get("table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableAggregatedFieldWellsProperty"]], result)

        @builtins.property
        def table_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableUnaggregatedFieldWellsProperty"]]:
            '''The unaggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html#cfn-quicksight-analysis-tablefieldwells-tableunaggregatedfieldwells
            '''
            result = self._values.get("table_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableUnaggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableInlineVisualizationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_bars": "dataBars"},
    )
    class TableInlineVisualizationProperty:
        def __init__(
            self,
            *,
            data_bars: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataBarsOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The inline visualization of a specific type to display within a chart.

            :param data_bars: The configuration of the inline visualization of the data bars within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableinlinevisualization.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_inline_visualization_property = quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                    data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        negative_color="negativeColor",
                        positive_color="positiveColor"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__43ffc5a657c7d8ab71c7e891383e6288b3849d068be01315ba7a92c8eb9b7367)
                check_type(argname="argument data_bars", value=data_bars, expected_type=type_hints["data_bars"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_bars is not None:
                self._values["data_bars"] = data_bars

        @builtins.property
        def data_bars(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataBarsOptionsProperty"]]:
            '''The configuration of the inline visualization of the data bars within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableinlinevisualization.html#cfn-quicksight-analysis-tableinlinevisualization-databars
            '''
            result = self._values.get("data_bars")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataBarsOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableInlineVisualizationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "header_style": "headerStyle",
            "orientation": "orientation",
            "row_alternate_color_options": "rowAlternateColorOptions",
        },
    )
    class TableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            orientation: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The table options for a table visual.

            :param cell_style: The table cell style of table cells.
            :param header_style: The table cell style of a table header.
            :param orientation: The orientation (vertical, horizontal) for a table.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_options_property = quicksight.CfnAnalysis.TableOptionsProperty(
                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    orientation="orientation",
                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c26cb8d60d809746b189a866575550498a87b206d2908f4ecbf51d2c0aca6c25)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument header_style", value=header_style, expected_type=type_hints["header_style"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if header_style is not None:
                self._values["header_style"] = header_style
            if orientation is not None:
                self._values["orientation"] = orientation
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The table cell style of table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def header_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]]:
            '''The table cell style of a table header.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-headerstyle
            '''
            result = self._values.get("header_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation (vertical, horizontal) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RowAlternateColorOptionsProperty"]]:
            '''The row alternate color options (widget status, row alternate colors) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RowAlternateColorOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class TablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a table visual.

            :param overflow_column_header_visibility: The visibility of repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_paginated_report_options_property = quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__400317663776ab4c1f2917b5ca054b98ec329ac4a6b7e74b2fe53c7d05080a71)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of repeating header rows on each page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html#cfn-quicksight-analysis-tablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html#cfn-quicksight-analysis-tablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableRowConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "text_color": "textColor",
        },
    )
    class TableRowConditionalFormattingProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting of a table row.

            :param background_color: The conditional formatting color (solid, gradient) of the background for a table row.
            :param text_color: The conditional formatting color (solid, gradient) of the text for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_row_conditional_formatting_property = quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7029b932d9c112c1fe6ecc02d2e0eb0596638b76476f7b1c906fe92080315f69)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting color (solid, gradient) of the background for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html#cfn-quicksight-analysis-tablerowconditionalformatting-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting color (solid, gradient) of the text for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html#cfn-quicksight-analysis-tablerowconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableRowConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableSideBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "inner_horizontal": "innerHorizontal",
            "inner_vertical": "innerVertical",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class TableSideBorderOptionsProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inner_horizontal: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inner_vertical: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            left: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            right: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The side border options for a table.

            :param bottom: The table border options of the bottom border.
            :param inner_horizontal: The table border options of the inner horizontal border.
            :param inner_vertical: The table border options of the inner vertical border.
            :param left: The table border options of the left border.
            :param right: The table border options of the right border.
            :param top: The table border options of the top border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_side_border_options_property = quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__256be354818f3c513b3d549ce4cdadb421a2b9a44d77b0faf672b7df80033342)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument inner_horizontal", value=inner_horizontal, expected_type=type_hints["inner_horizontal"])
                check_type(argname="argument inner_vertical", value=inner_vertical, expected_type=type_hints["inner_vertical"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if inner_horizontal is not None:
                self._values["inner_horizontal"] = inner_horizontal
            if inner_vertical is not None:
                self._values["inner_vertical"] = inner_vertical
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''The table border options of the bottom border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        @builtins.property
        def inner_horizontal(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''The table border options of the inner horizontal border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-innerhorizontal
            '''
            result = self._values.get("inner_horizontal")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        @builtins.property
        def inner_vertical(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''The table border options of the inner vertical border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-innervertical
            '''
            result = self._values.get("inner_vertical")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        @builtins.property
        def left(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''The table border options of the left border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        @builtins.property
        def right(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''The table border options of the right border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        @builtins.property
        def top(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]]:
            '''The table border options of the top border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableBorderOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSideBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pagination_configuration": "paginationConfiguration",
            "row_sort": "rowSort",
        },
    )
    class TableSortConfigurationProperty:
        def __init__(
            self,
            *,
            pagination_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration for a ``TableVisual`` .

            :param pagination_configuration: The pagination configuration (page size, page number) for the table.
            :param row_sort: The field sort options for rows in the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_sort_configuration_property = quicksight.CfnAnalysis.TableSortConfigurationProperty(
                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    ),
                    row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e9c50c7d74225987a470676333ef9a83392575298cbea8b837ca2a01deed3054)
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
                check_type(argname="argument row_sort", value=row_sort, expected_type=type_hints["row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration
            if row_sort is not None:
                self._values["row_sort"] = row_sort

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PaginationConfigurationProperty"]]:
            '''The pagination configuration (page size, page number) for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html#cfn-quicksight-analysis-tablesortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PaginationConfigurationProperty"]], result)

        @builtins.property
        def row_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The field sort options for rows in the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html#cfn-quicksight-analysis-tablesortconfiguration-rowsort
            '''
            result = self._values.get("row_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class TableUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.UnaggregatedFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The unaggregated field well for the table.

            :param values: The values field well for a pivot table. Values are unaggregated for an unaggregated table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_unaggregated_field_wells_property = quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                    values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6c3e1fee2088d75155f70c29df26844380f91f745827a2efba5b2cf0fd7056df)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.UnaggregatedFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are unaggregated for an unaggregated table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableunaggregatedfieldwells.html#cfn-quicksight-analysis-tableunaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.UnaggregatedFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_visual_property = quicksight.CfnAnalysis.TableVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.TableConfigurationProperty(
                        field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                            order=["order"],
                            selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                custom_label="customLabel",
                                url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                    image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                        sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                        )
                                    ),
                                    link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                        content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                            custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                                icon="icon"
                                            ),
                                            custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                
                                                # the properties below are optional
                                                value="value"
                                            )
                                        ),
                                        target="target"
                                    )
                                ),
                                visibility="visibility",
                                width="width"
                            )]
                        ),
                        field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                            table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                                values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                        date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                            overflow_column_header_visibility="overflowColumnHeaderVisibility",
                            vertical_overflow_visibility="verticalOverflowVisibility"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                            pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                page_number=123,
                                page_size=123
                            ),
                            row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                            data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                negative_color="negativeColor",
                                positive_color="positiveColor"
                            )
                        )],
                        table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                            cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            orientation="orientation",
                            row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                row_alternate_colors=["rowAlternateColors"],
                                status="status"
                            )
                        ),
                        total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                            custom_label="customLabel",
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility"
                        )
                    ),
                    conditional_formatting=quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                            cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            ),
                            row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9913d7f7cd8c81d3ab5a6de937a815f1b501a0b1e766932105ba4d4f42512478)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableConditionalFormattingProperty"]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextAreaControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            placeholder_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param placeholder_options: The configuration of the placeholder options in a text area control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                text_area_control_display_options_property = quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a700ae0be708d4be1258960b8db5b08e2f8ea452e8c97ba2614605a437b54d6d)
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextControlPlaceholderOptionsProperty"]]:
            '''The configuration of the placeholder options in a text area control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html#cfn-quicksight-analysis-textareacontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextControlPlaceholderOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html#cfn-quicksight-analysis-textareacontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextAreaControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TextConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "icon": "icon",
            "text_color": "textColor",
        },
    )
    class TextConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the text.

            :param background_color: The conditional formatting for the text background color.
            :param icon: The conditional formatting for the icon.
            :param text_color: The conditional formatting for the text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                text_conditional_format_property = quicksight.CfnAnalysis.TextConditionalFormatProperty(
                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb55caa13ec433dfb729128dd290212c3647cccc81c5417fe6e8d7f5d16d1f4d)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting for the text background color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting for the icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting for the text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TextControlPlaceholderOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the placeholder options in a text control.

            :param visibility: The visibility configuration of the placeholder options in a text control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textcontrolplaceholderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                text_control_placeholder_options_property = quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__03d070e567fad7d9cd8dca405aa13f96c1333ea18f8cd07f8ea42273349ffa59)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the placeholder options in a text control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textcontrolplaceholderoptions.html#cfn-quicksight-analysis-textcontrolplaceholderoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextControlPlaceholderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextFieldControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            placeholder_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param placeholder_options: The configuration of the placeholder options in a text field control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                text_field_control_display_options_property = quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7d2298d881ad66005671e8e4d1e57f64db9cbbbf85c324e7fe0234ade9967276)
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextControlPlaceholderOptionsProperty"]]:
            '''The configuration of the placeholder options in a text field control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html#cfn-quicksight-analysis-textfieldcontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TextControlPlaceholderOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html#cfn-quicksight-analysis-textfieldcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextFieldControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"symbol": "symbol", "visibility": "visibility"},
    )
    class ThousandSeparatorOptionsProperty:
        def __init__(
            self,
            *,
            symbol: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the thousands separator configuration.

            :param symbol: Determines the thousands separator symbol.
            :param visibility: Determines the visibility of the thousands separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                thousand_separator_options_property = quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                    symbol="symbol",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b67e4caf06894032bfdb6af12762f117b35e8b089b1830b28dc820a218948d1e)
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if symbol is not None:
                self._values["symbol"] = symbol
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the thousands separator symbol.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html#cfn-quicksight-analysis-thousandseparatoroptions-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the thousands separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html#cfn-quicksight-analysis-thousandseparatoroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThousandSeparatorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "lower_boundary": "lowerBoundary",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
        },
    )
    class TimeBasedForecastPropertiesProperty:
        def __init__(
            self,
            *,
            lower_boundary: typing.Optional[jsii.Number] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[jsii.Number] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The forecast properties setup of a forecast in the line chart.

            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``NULL`` : The input is set to ``NULL`` . - ``NON_NULL`` : The input is set to a custom value.
            :param upper_boundary: The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_based_forecast_properties_property = quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                    lower_boundary=123,
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality=123,
                    upper_boundary=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8abba2be8b45aac7c1d103337d7fa70c365d9d91fe1e55fda5f53a67817a7002)
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[jsii.Number]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``NULL`` : The input is set to ``NULL`` .
            - ``NON_NULL`` : The input is set to a custom value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeBasedForecastPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TimeEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
            "value": "value",
        },
    )
    class TimeEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeEqualityFilter`` filters values that are equal to a given value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``Value`` .
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value: The value of a ``TimeEquality`` filter. This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_equality_filter_property = quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    parameter_name="parameterName",
                    time_granularity="timeGranularity",
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ddecb2f8770ff2b3151bb2ac36052865f02fe999bdc5236eb783ac074458694d)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
            }
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``Value`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The value of a ``TimeEquality`` filter.

            This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            range_maximum: builtins.str,
            range_minimum: builtins.str,
            time_granularity: builtins.str,
        ) -> None:
            '''The time range drill down filter.

            :param column: The column that the filter is applied to.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_range_drill_down_filter_property = quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    range_maximum="rangeMaximum",
                    range_minimum="rangeMinimum",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__87fa79e9f14d95f01ee4b2c2b464703520d2d7f06ef83a35ad51dfdd52c7cc19)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "range_maximum": range_maximum,
                "range_minimum": range_minimum,
                "time_granularity": time_granularity,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def range_maximum(self) -> builtins.str:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            assert result is not None, "Required property 'range_maximum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def range_minimum(self) -> builtins.str:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            assert result is not None, "Required property 'range_minimum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TimeRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum_value": "rangeMaximumValue",
            "range_minimum_value": "rangeMinimumValue",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            range_maximum_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_minimum_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeRangeFilter`` filters values that are between two specified values.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param exclude_period_configuration: The exclude period of the time range filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum_value: The maximum value for the filter value range.
            :param range_minimum_value: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_range_filter_property = quicksight.CfnAnalysis.TimeRangeFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__028f35484c126e74a2a828f9819005eeed839c45b2b0c5dc53fa188d1d904140)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum_value", value=range_maximum_value, expected_type=type_hints["range_maximum_value"])
                check_type(argname="argument range_minimum_value", value=range_minimum_value, expected_type=type_hints["range_minimum_value"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum_value is not None:
                self._values["range_maximum_value"] = range_maximum_value
            if range_minimum_value is not None:
                self._values["range_minimum_value"] = range_minimum_value
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ExcludePeriodConfigurationProperty"]]:
            '''The exclude period of the time range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ExcludePeriodConfigurationProperty"]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def range_maximum_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TimeRangeFilterValueProperty"]]:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-rangemaximumvalue
            '''
            result = self._values.get("range_maximum_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TimeRangeFilterValueProperty"]], result)

        @builtins.property
        def range_minimum_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TimeRangeFilterValueProperty"]]:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-rangeminimumvalue
            '''
            result = self._values.get("range_minimum_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TimeRangeFilterValueProperty"]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TimeRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter": "parameter",
            "rolling_date": "rollingDate",
            "static_value": "staticValue",
        },
    )
    class TimeRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            rolling_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value of a time range filter.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param parameter: The parameter type input value.
            :param rolling_date: The rolling date input value.
            :param static_value: The static input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_range_filter_value_property = quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                    parameter="parameter",
                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_value="staticValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c8b5289f98e9b91efd2347c9ff86bccb1689f6fd0a3d0b6db8d1efdeb647a34)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter type input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RollingDateConfigurationProperty"]]:
            '''The rolling date input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def static_value(self) -> typing.Optional[builtins.str]:
            '''The static input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_tooltip_item": "columnTooltipItem",
            "field_tooltip_item": "fieldTooltipItem",
        },
    )
    class TooltipItemProperty:
        def __init__(
            self,
            *,
            column_tooltip_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnTooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_tooltip_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldTooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The tooltip.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param column_tooltip_item: The tooltip item for the columns that are not part of a field well.
            :param field_tooltip_item: The tooltip item for the fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tooltip_item_property = quicksight.CfnAnalysis.TooltipItemProperty(
                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        label="label",
                        visibility="visibility"
                    ),
                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        label="label",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__db99536de276b5db7a33340f4f90179df4bcabea3e247e4317731fff3cf4342c)
                check_type(argname="argument column_tooltip_item", value=column_tooltip_item, expected_type=type_hints["column_tooltip_item"])
                check_type(argname="argument field_tooltip_item", value=field_tooltip_item, expected_type=type_hints["field_tooltip_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_tooltip_item is not None:
                self._values["column_tooltip_item"] = column_tooltip_item
            if field_tooltip_item is not None:
                self._values["field_tooltip_item"] = field_tooltip_item

        @builtins.property
        def column_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnTooltipItemProperty"]]:
            '''The tooltip item for the columns that are not part of a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html#cfn-quicksight-analysis-tooltipitem-columntooltipitem
            '''
            result = self._values.get("column_tooltip_item")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnTooltipItemProperty"]], result)

        @builtins.property
        def field_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldTooltipItemProperty"]]:
            '''The tooltip item for the fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html#cfn-quicksight-analysis-tooltipitem-fieldtooltipitem
            '''
            result = self._values.get("field_tooltip_item")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldTooltipItemProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TooltipOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_based_tooltip": "fieldBasedTooltip",
            "selected_tooltip_type": "selectedTooltipType",
            "tooltip_visibility": "tooltipVisibility",
        },
    )
    class TooltipOptionsProperty:
        def __init__(
            self,
            *,
            field_based_tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldBasedTooltipProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_tooltip_type: typing.Optional[builtins.str] = None,
            tooltip_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The display options for the visual tooltip.

            :param field_based_tooltip: The setup for the detailed tooltip. The tooltip setup is always saved. The display type is decided based on the tooltip type.
            :param selected_tooltip_type: The selected type for the tooltip. Choose one of the following options:. - ``BASIC`` : A basic tooltip. - ``DETAILED`` : A detailed tooltip.
            :param tooltip_visibility: Determines whether or not the tooltip is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tooltip_options_property = quicksight.CfnAnalysis.TooltipOptionsProperty(
                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                        aggregation_visibility="aggregationVisibility",
                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                label="label",
                                visibility="visibility"
                            ),
                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                label="label",
                                visibility="visibility"
                            )
                        )],
                        tooltip_title_type="tooltipTitleType"
                    ),
                    selected_tooltip_type="selectedTooltipType",
                    tooltip_visibility="tooltipVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45773945e1cd18ea20c5839ce54565e0617256f1f06ee7b3dbf129c8eeefdc1a)
                check_type(argname="argument field_based_tooltip", value=field_based_tooltip, expected_type=type_hints["field_based_tooltip"])
                check_type(argname="argument selected_tooltip_type", value=selected_tooltip_type, expected_type=type_hints["selected_tooltip_type"])
                check_type(argname="argument tooltip_visibility", value=tooltip_visibility, expected_type=type_hints["tooltip_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_based_tooltip is not None:
                self._values["field_based_tooltip"] = field_based_tooltip
            if selected_tooltip_type is not None:
                self._values["selected_tooltip_type"] = selected_tooltip_type
            if tooltip_visibility is not None:
                self._values["tooltip_visibility"] = tooltip_visibility

        @builtins.property
        def field_based_tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldBasedTooltipProperty"]]:
            '''The setup for the detailed tooltip.

            The tooltip setup is always saved. The display type is decided based on the tooltip type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-fieldbasedtooltip
            '''
            result = self._values.get("field_based_tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldBasedTooltipProperty"]], result)

        @builtins.property
        def selected_tooltip_type(self) -> typing.Optional[builtins.str]:
            '''The selected type for the tooltip. Choose one of the following options:.

            - ``BASIC`` : A basic tooltip.
            - ``DETAILED`` : A detailed tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-selectedtooltiptype
            '''
            result = self._values.get("selected_tooltip_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the tooltip is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-tooltipvisibility
            '''
            result = self._values.get("tooltip_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TopBottomFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_sort_configurations": "aggregationSortConfigurations",
            "column": "column",
            "filter_id": "filterId",
            "limit": "limit",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
        },
    )
    class TopBottomFilterProperty:
        def __init__(
            self,
            *,
            aggregation_sort_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AggregationSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            limit: typing.Optional[jsii.Number] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TopBottomFilter`` filters values that are at the top or the bottom.

            :param aggregation_sort_configurations: The aggregation and sort configuration of the top bottom filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param limit: The number of items to include in the top bottom filter results.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                top_bottom_filter_property = quicksight.CfnAnalysis.TopBottomFilterProperty(
                    aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        sort_direction="sortDirection"
                    )],
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    limit=123,
                    parameter_name="parameterName",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8465d0d4025300aa1b3f5db081d4f2de56cef87c2606d171932843c886c84266)
                check_type(argname="argument aggregation_sort_configurations", value=aggregation_sort_configurations, expected_type=type_hints["aggregation_sort_configurations"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_sort_configurations": aggregation_sort_configurations,
                "column": column,
                "filter_id": filter_id,
            }
            if limit is not None:
                self._values["limit"] = limit
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def aggregation_sort_configurations(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationSortConfigurationProperty"]]]:
            '''The aggregation and sort configuration of the top bottom filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-aggregationsortconfigurations
            '''
            result = self._values.get("aggregation_sort_configurations")
            assert result is not None, "Required property 'aggregation_sort_configurations' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AggregationSortConfigurationProperty"]]], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def limit(self) -> typing.Optional[jsii.Number]:
            '''The number of items to include in the top bottom filter results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-limit
            '''
            result = self._values.get("limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TopBottomMoversComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "time": "time",
            "type": "type",
            "mover_size": "moverSize",
            "name": "name",
            "sort_order": "sortOrder",
            "value": "value",
        },
    )
    class TopBottomMoversComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            type: builtins.str,
            mover_size: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            sort_order: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The top movers and bottom movers computation setup.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param type: The computation type. Choose from the following options:. - TOP: Top movers computation. - BOTTOM: Bottom movers computation.
            :param mover_size: The mover size setup of the top and bottom movers computation.
            :param name: The name of a computation.
            :param sort_order: The sort order setup of the top and bottom movers computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                top_bottom_movers_computation_property = quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                    category=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    type="type",
                
                    # the properties below are optional
                    mover_size=123,
                    name="name",
                    sort_order="sortOrder",
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__845e823a8ebb22deb0f55b759ee054f53e2ebf7bc57a6dbb57ab8169e2e20727)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument mover_size", value=mover_size, expected_type=type_hints["mover_size"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sort_order", value=sort_order, expected_type=type_hints["sort_order"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
                "time": time,
                "type": type,
            }
            if mover_size is not None:
                self._values["mover_size"] = mover_size
            if name is not None:
                self._values["name"] = name
            if sort_order is not None:
                self._values["sort_order"] = sort_order
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def category(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"], result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose from the following options:.

            - TOP: Top movers computation.
            - BOTTOM: Bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def mover_size(self) -> typing.Optional[jsii.Number]:
            '''The mover size setup of the top and bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-moversize
            '''
            result = self._values.get("mover_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_order(self) -> typing.Optional[builtins.str]:
            '''The sort order setup of the top and bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-sortorder
            '''
            result = self._values.get("sort_order")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomMoversComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TopBottomRankedComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "type": "type",
            "name": "name",
            "result_size": "resultSize",
            "value": "value",
        },
    )
    class TopBottomRankedComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            computation_id: builtins.str,
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            result_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The top ranked and bottom ranked computation configuration.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param type: The computation type. Choose one of the following options:. - TOP: A top ranked computation. - BOTTOM: A bottom ranked computation.
            :param name: The name of a computation.
            :param result_size: The result size of a top and bottom ranked computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                top_bottom_ranked_computation_property = quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                    category=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    result_size=123,
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3d6fd877ff3cc8749f4aa7e9aff8348a33b686f2930f388b3cc377fae58bab65)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument result_size", value=result_size, expected_type=type_hints["result_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if result_size is not None:
                self._values["result_size"] = result_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def category(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose one of the following options:.

            - TOP: A top ranked computation.
            - BOTTOM: A bottom ranked computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def result_size(self) -> typing.Optional[jsii.Number]:
            '''The result size of a top and bottom ranked computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-resultsize
            '''
            result = self._values.get("result_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomRankedComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TotalAggregationComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "value": "value",
            "name": "name",
        },
    )
    class TotalAggregationComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total aggregation computation configuration.

            :param computation_id: The ID for a computation.
            :param value: The value field that is used in a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                total_aggregation_computation_property = quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                    computation_id="computationId",
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e74ec9047e6d0d14baeae685d3635aa13a32c3c92841603a1af15967da84ce64)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "value": value,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
        },
    )
    class TotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total options for a table visual.

            :param custom_label: The custom label string for the total cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_cell_style: Cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                total_options_property = quicksight.CfnAnalysis.TotalOptionsProperty(
                    custom_label="customLabel",
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ae2b09c00d24bf0e485e2b650341ad38f34ecb6dcc928b3b0c88eeb0c86f820f)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]]:
            '''Cell styling options for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"colors": "colors", "groups": "groups", "sizes": "sizes"},
    )
    class TreeMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sizes: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Aggregated field wells of a tree map.

            :param colors: The color field well of a tree map. Values are grouped by aggregations based on group by fields.
            :param groups: The group by field well of a tree map. Values are grouped based on group by fields.
            :param sizes: The size field well of a tree map. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_aggregated_field_wells_property = quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                    colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__40ff2b59a0d9fe5551cdcc7863824c28b845983be8f866f3b455c505b0cb9aa5)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument groups", value=groups, expected_type=type_hints["groups"])
                check_type(argname="argument sizes", value=sizes, expected_type=type_hints["sizes"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if groups is not None:
                self._values["groups"] = groups
            if sizes is not None:
                self._values["sizes"] = sizes

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The color field well of a tree map.

            Values are grouped by aggregations based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        @builtins.property
        def groups(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The group by field well of a tree map.

            Values are grouped based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-groups
            '''
            result = self._values.get("groups")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def sizes(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The size field well of a tree map.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-sizes
            '''
            result = self._values.get("sizes")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TreeMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_label_options": "colorLabelOptions",
            "color_scale": "colorScale",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "group_label_options": "groupLabelOptions",
            "legend": "legend",
            "size_label_options": "sizeLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class TreeMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TreeMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            group_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            size_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TreeMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a tree map.

            :param color_label_options: The label options (label text, label visibility) for the colors displayed in a tree map.
            :param color_scale: The color options (gradient color, point of divergence) of a tree map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param group_label_options: The label options (label text, label visibility) of the groups that are displayed in a tree map.
            :param legend: The legend display setup of the visual.
            :param size_label_options: The label options (label text, label visibility) of the sizes that are displayed in a tree map.
            :param sort_configuration: The sort configuration of a tree map.
            :param tooltip: The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_configuration_property = quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                        color_fill_type="colorFillType",
                        colors=[quicksight.CfnAnalysis.DataColorProperty(
                            color="color",
                            data_value=123
                        )],
                
                        # the properties below are optional
                        null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                            color="color",
                            data_value=123
                        )
                    ),
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                        tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                            colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                        tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8689070099667e6b50fb9d5ca01dc351109d9d5918c710bb8e422e723836d24a)
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument group_label_options", value=group_label_options, expected_type=type_hints["group_label_options"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument size_label_options", value=size_label_options, expected_type=type_hints["size_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if group_label_options is not None:
                self._values["group_label_options"] = group_label_options
            if legend is not None:
                self._values["legend"] = legend
            if size_label_options is not None:
                self._values["size_label_options"] = size_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) for the colors displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColorScaleProperty"]]:
            '''The color options (gradient color, point of divergence) of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColorScaleProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TreeMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TreeMapFieldWellsProperty"]], result)

        @builtins.property
        def group_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) of the groups that are displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-grouplabeloptions
            '''
            result = self._values.get("group_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def size_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) of the sizes that are displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-sizelabeloptions
            '''
            result = self._values.get("size_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TreeMapSortConfigurationProperty"]]:
            '''The sort configuration of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TreeMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TooltipOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TreeMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_aggregated_field_wells": "treeMapAggregatedFieldWells",
        },
    )
    class TreeMapFieldWellsProperty:
        def __init__(
            self,
            *,
            tree_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TreeMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a tree map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param tree_map_aggregated_field_wells: The aggregated field wells of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_field_wells_property = quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                    tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                        colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__20122b4f544ea66e8eb2c9992018066cf8200ede7131282eed1012bd10255f0c)
                check_type(argname="argument tree_map_aggregated_field_wells", value=tree_map_aggregated_field_wells, expected_type=type_hints["tree_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_aggregated_field_wells is not None:
                self._values["tree_map_aggregated_field_wells"] = tree_map_aggregated_field_wells

        @builtins.property
        def tree_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TreeMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapfieldwells.html#cfn-quicksight-analysis-treemapfieldwells-treemapaggregatedfieldwells
            '''
            result = self._values.get("tree_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TreeMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TreeMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_group_items_limit_configuration": "treeMapGroupItemsLimitConfiguration",
            "tree_map_sort": "treeMapSort",
        },
    )
    class TreeMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            tree_map_group_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tree_map_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a tree map.

            :param tree_map_group_items_limit_configuration: The limit on the number of groups that are displayed.
            :param tree_map_sort: The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_sort_configuration_property = quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                    tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b8bdfe1bda8f43d44780355ece78c519b77b8c9b4582a0913836a866278ae540)
                check_type(argname="argument tree_map_group_items_limit_configuration", value=tree_map_group_items_limit_configuration, expected_type=type_hints["tree_map_group_items_limit_configuration"])
                check_type(argname="argument tree_map_sort", value=tree_map_sort, expected_type=type_hints["tree_map_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_group_items_limit_configuration is not None:
                self._values["tree_map_group_items_limit_configuration"] = tree_map_group_items_limit_configuration
            if tree_map_sort is not None:
                self._values["tree_map_sort"] = tree_map_sort

        @builtins.property
        def tree_map_group_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of groups that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html#cfn-quicksight-analysis-treemapsortconfiguration-treemapgroupitemslimitconfiguration
            '''
            result = self._values.get("tree_map_group_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def tree_map_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html#cfn-quicksight-analysis-treemapsortconfiguration-treemapsort
            '''
            result = self._values.get("tree_map_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TreeMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TreeMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TreeMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_visual_property = quicksight.CfnAnalysis.TreeMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                        color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                            color_fill_type="colorFillType",
                            colors=[quicksight.CfnAnalysis.DataColorProperty(
                                color="color",
                                data_value=123
                            )],
                
                            # the properties below are optional
                            null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                color="color",
                                data_value=123
                            )
                        ),
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                            tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                                colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                            tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb0d60efc27654f2e7a10f31bd22a1619e0045153a55817d9d0f5c7c821b9ad5)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TreeMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TreeMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.TrendArrowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TrendArrowOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :param visibility: The visibility of the trend arrows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-trendarrowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                trend_arrow_options_property = quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__086cec46ac780cfd07640896d1ea9300779c6836a4e99d85a858d9907595cd9a)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the trend arrows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-trendarrowoptions.html#cfn-quicksight-analysis-trendarrowoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TrendArrowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.UnaggregatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
        },
    )
    class UnaggregatedFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The unaggregated field for a table.

            :param column: The column that is used in the ``UnaggregatedField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                unaggregated_field_property = quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7cf448941e904391367709ddde2946b89c31dedf08fc5b55d0b279c7be7223f0)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"]:
            '''The column that is used in the ``UnaggregatedField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UnaggregatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.UniqueValuesComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "name": "name",
        },
    )
    class UniqueValuesComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The unique values computation configuration.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                unique_values_computation_property = quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                    category=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5d6a84267ef69ace80812482aaa7dfbf1d324161d3d402744f6c4d22be5e3814)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def category(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UniqueValuesComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.VisibleRangeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"percent_range": "percentRange"},
    )
    class VisibleRangeOptionsProperty:
        def __init__(
            self,
            *,
            percent_range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PercentVisibleRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The range options for the data zoom scroll bar.

            :param percent_range: The percent range in the visible range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visiblerangeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visible_range_options_property = quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                        from=123,
                        to=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2f9c9cd10309e0c8e3a0e4bcf3cefad595c5e7fb8b6639be658daa12f852debe)
                check_type(argname="argument percent_range", value=percent_range, expected_type=type_hints["percent_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percent_range is not None:
                self._values["percent_range"] = percent_range

        @builtins.property
        def percent_range(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PercentVisibleRangeProperty"]]:
            '''The percent range in the visible range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visiblerangeoptions.html#cfn-quicksight-analysis-visiblerangeoptions-percentrange
            '''
            result = self._values.get("percent_range")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PercentVisibleRangeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisibleRangeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.VisualCustomActionOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_operation": "filterOperation",
            "navigation_operation": "navigationOperation",
            "set_parameters_operation": "setParametersOperation",
            "url_operation": "urlOperation",
        },
    )
    class VisualCustomActionOperationProperty:
        def __init__(
            self,
            *,
            filter_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CustomActionFilterOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            navigation_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CustomActionNavigationOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            set_parameters_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CustomActionSetParametersOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            url_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CustomActionURLOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The operation that is defined by the custom action.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filter_operation: The filter operation that filters data included in a visual or in an entire sheet.
            :param navigation_operation: The navigation operation that navigates between different sheets in the same analysis.
            :param set_parameters_operation: The set parameter operation that sets parameters in custom action.
            :param url_operation: The URL operation that opens a link to another webpage.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_custom_action_operation_property = quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                            selected_field_options="selectedFieldOptions",
                            selected_fields=["selectedFields"]
                        ),
                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                target_visual_options="targetVisualOptions",
                                target_visuals=["targetVisuals"]
                            )
                        )
                    ),
                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                            target_sheet_id="targetSheetId"
                        )
                    ),
                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                            destination_parameter_name="destinationParameterName",
                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                        date_time_values=["dateTimeValues"],
                                        decimal_values=[123],
                                        integer_values=[123],
                                        string_values=["stringValues"]
                                    ),
                
                                    # the properties below are optional
                                    include_null_value=False
                                ),
                                select_all_value_options="selectAllValueOptions",
                                source_field="sourceField",
                                source_parameter_name="sourceParameterName"
                            )
                        )]
                    ),
                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                        url_target="urlTarget",
                        url_template="urlTemplate"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__911729a8900b71f464fc360be03b094126550e2902915e99aabd9c56262bbaa9)
                check_type(argname="argument filter_operation", value=filter_operation, expected_type=type_hints["filter_operation"])
                check_type(argname="argument navigation_operation", value=navigation_operation, expected_type=type_hints["navigation_operation"])
                check_type(argname="argument set_parameters_operation", value=set_parameters_operation, expected_type=type_hints["set_parameters_operation"])
                check_type(argname="argument url_operation", value=url_operation, expected_type=type_hints["url_operation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filter_operation is not None:
                self._values["filter_operation"] = filter_operation
            if navigation_operation is not None:
                self._values["navigation_operation"] = navigation_operation
            if set_parameters_operation is not None:
                self._values["set_parameters_operation"] = set_parameters_operation
            if url_operation is not None:
                self._values["url_operation"] = url_operation

        @builtins.property
        def filter_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomActionFilterOperationProperty"]]:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-filteroperation
            '''
            result = self._values.get("filter_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomActionFilterOperationProperty"]], result)

        @builtins.property
        def navigation_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomActionNavigationOperationProperty"]]:
            '''The navigation operation that navigates between different sheets in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-navigationoperation
            '''
            result = self._values.get("navigation_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomActionNavigationOperationProperty"]], result)

        @builtins.property
        def set_parameters_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomActionSetParametersOperationProperty"]]:
            '''The set parameter operation that sets parameters in custom action.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-setparametersoperation
            '''
            result = self._values.get("set_parameters_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomActionSetParametersOperationProperty"]], result)

        @builtins.property
        def url_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomActionURLOperationProperty"]]:
            '''The URL operation that opens a link to another webpage.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-urloperation
            '''
            result = self._values.get("url_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomActionURLOperationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.VisualCustomActionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "action_operations": "actionOperations",
            "custom_action_id": "customActionId",
            "name": "name",
            "trigger": "trigger",
            "status": "status",
        },
    )
    class VisualCustomActionProperty:
        def __init__(
            self,
            *,
            action_operations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionOperationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            custom_action_id: builtins.str,
            name: builtins.str,
            trigger: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom action defined on a visual.

            :param action_operations: A list of ``VisualCustomActionOperations`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param custom_action_id: The ID of the ``VisualCustomAction`` .
            :param name: The name of the ``VisualCustomAction`` .
            :param trigger: The trigger of the ``VisualCustomAction`` . Valid values are defined as follows: - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point. - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.
            :param status: The status of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_custom_action_property = quicksight.CfnAnalysis.VisualCustomActionProperty(
                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                selected_field_options="selectedFieldOptions",
                                selected_fields=["selectedFields"]
                            ),
                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                    target_visual_options="targetVisualOptions",
                                    target_visuals=["targetVisuals"]
                                )
                            )
                        ),
                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                target_sheet_id="targetSheetId"
                            )
                        ),
                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                destination_parameter_name="destinationParameterName",
                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                            date_time_values=["dateTimeValues"],
                                            decimal_values=[123],
                                            integer_values=[123],
                                            string_values=["stringValues"]
                                        ),
                
                                        # the properties below are optional
                                        include_null_value=False
                                    ),
                                    select_all_value_options="selectAllValueOptions",
                                    source_field="sourceField",
                                    source_parameter_name="sourceParameterName"
                                )
                            )]
                        ),
                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                            url_target="urlTarget",
                            url_template="urlTemplate"
                        )
                    )],
                    custom_action_id="customActionId",
                    name="name",
                    trigger="trigger",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__305776f846978e140f2419b7a6fe37c4b1473f864d8736f2ce5b4a7c7dab5b9a)
                check_type(argname="argument action_operations", value=action_operations, expected_type=type_hints["action_operations"])
                check_type(argname="argument custom_action_id", value=custom_action_id, expected_type=type_hints["custom_action_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument trigger", value=trigger, expected_type=type_hints["trigger"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "action_operations": action_operations,
                "custom_action_id": custom_action_id,
                "name": name,
                "trigger": trigger,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def action_operations(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionOperationProperty"]]]:
            '''A list of ``VisualCustomActionOperations`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-actionoperations
            '''
            result = self._values.get("action_operations")
            assert result is not None, "Required property 'action_operations' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionOperationProperty"]]], result)

        @builtins.property
        def custom_action_id(self) -> builtins.str:
            '''The ID of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-customactionid
            '''
            result = self._values.get("custom_action_id")
            assert result is not None, "Required property 'custom_action_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def trigger(self) -> builtins.str:
            '''The trigger of the ``VisualCustomAction`` .

            Valid values are defined as follows:

            - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point.
            - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-trigger
            '''
            result = self._values.get("trigger")
            assert result is not None, "Required property 'trigger' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.VisualPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={"chart_color": "chartColor", "color_map": "colorMap"},
    )
    class VisualPaletteProperty:
        def __init__(
            self,
            *,
            chart_color: typing.Optional[builtins.str] = None,
            color_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataPathColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The visual display options for the visual palette.

            :param chart_color: The chart color options for the visual palette.
            :param color_map: The color map options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_palette_property = quicksight.CfnAnalysis.VisualPaletteProperty(
                    chart_color="chartColor",
                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                        color="color",
                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        ),
                
                        # the properties below are optional
                        time_granularity="timeGranularity"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ca8d48ea3029a97b023077c4b934dfb0a6d1aa32e7a139a67e992050bb49922)
                check_type(argname="argument chart_color", value=chart_color, expected_type=type_hints["chart_color"])
                check_type(argname="argument color_map", value=color_map, expected_type=type_hints["color_map"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if chart_color is not None:
                self._values["chart_color"] = chart_color
            if color_map is not None:
                self._values["color_map"] = color_map

        @builtins.property
        def chart_color(self) -> typing.Optional[builtins.str]:
            '''The chart color options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html#cfn-quicksight-analysis-visualpalette-chartcolor
            '''
            result = self._values.get("chart_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def color_map(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataPathColorProperty"]]]]:
            '''The color map options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html#cfn-quicksight-analysis-visualpalette-colormap
            '''
            result = self._values.get("color_map")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataPathColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.VisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_visual": "barChartVisual",
            "box_plot_visual": "boxPlotVisual",
            "combo_chart_visual": "comboChartVisual",
            "custom_content_visual": "customContentVisual",
            "empty_visual": "emptyVisual",
            "filled_map_visual": "filledMapVisual",
            "funnel_chart_visual": "funnelChartVisual",
            "gauge_chart_visual": "gaugeChartVisual",
            "geospatial_map_visual": "geospatialMapVisual",
            "heat_map_visual": "heatMapVisual",
            "histogram_visual": "histogramVisual",
            "insight_visual": "insightVisual",
            "kpi_visual": "kpiVisual",
            "line_chart_visual": "lineChartVisual",
            "pie_chart_visual": "pieChartVisual",
            "pivot_table_visual": "pivotTableVisual",
            "radar_chart_visual": "radarChartVisual",
            "sankey_diagram_visual": "sankeyDiagramVisual",
            "scatter_plot_visual": "scatterPlotVisual",
            "table_visual": "tableVisual",
            "tree_map_visual": "treeMapVisual",
            "waterfall_visual": "waterfallVisual",
            "word_cloud_visual": "wordCloudVisual",
        },
    )
    class VisualProperty:
        def __init__(
            self,
            *,
            bar_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BarChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            box_plot_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.BoxPlotVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            combo_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ComboChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_content_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.CustomContentVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            empty_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.EmptyVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filled_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FilledMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            funnel_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FunnelChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            gauge_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GaugeChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            geospatial_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.GeospatialMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.HeatMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            histogram_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.HistogramVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            insight_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.InsightVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            kpi_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.KPIVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            line_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LineChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            pie_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PieChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            pivot_table_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.PivotTableVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            radar_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.RadarChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sankey_diagram_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.SankeyDiagramVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scatter_plot_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ScatterPlotVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TableVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tree_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.TreeMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            waterfall_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WaterfallVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            word_cloud_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WordCloudVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A visual displayed on a sheet in an analysis, dashboard, or template.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_visual: A bar chart. For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param box_plot_visual: A box plot. For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .
            :param combo_chart_visual: A combo chart. For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param custom_content_visual: A visual that contains custom content. For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param empty_visual: An empty visual.
            :param filled_map_visual: A filled map. For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param funnel_chart_visual: A funnel chart. For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param gauge_chart_visual: A gauge chart. For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param geospatial_map_visual: A geospatial map or a points on map visual. For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param heat_map_visual: A heat map. For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param histogram_visual: A histogram. For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param insight_visual: An insight visual. For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .
            :param kpi_visual: A key performance indicator (KPI). For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .
            :param line_chart_visual: A line chart. For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param pie_chart_visual: A pie or donut chart. For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param pivot_table_visual: A pivot table. For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .
            :param radar_chart_visual: A radar chart visual. For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param sankey_diagram_visual: A sankey diagram. For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .
            :param scatter_plot_visual: A scatter plot. For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .
            :param table_visual: A table visual. For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .
            :param tree_map_visual: A tree map. For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param waterfall_visual: A waterfall chart. For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param word_cloud_visual: A word cloud. For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                visual_property = quicksight.CfnAnalysis.VisualProperty(
                    bar_chart_visual=quicksight.CfnAnalysis.BarChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.BarChartConfigurationProperty(
                            bars_arrangement="barsArrangement",
                            category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                                bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            orientation="orientation",
                            reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    box_plot_visual=quicksight.CfnAnalysis.BoxPlotVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                            box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                                all_data_points_visibility="allDataPointsVisibility",
                                outlier_visibility="outlierVisibility",
                                style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                                    fill_style="fillStyle"
                                )
                            ),
                            category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                                box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                    page_number=123,
                                    page_size=123
                                )
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    combo_chart_visual=quicksight.CfnAnalysis.ComboChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                            bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            bars_arrangement="barsArrangement",
                            category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                                combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                                    bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    custom_content_visual=quicksight.CfnAnalysis.CustomContentVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                            content_type="contentType",
                            content_url="contentUrl",
                            image_scaling="imageScaling"
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    empty_visual=quicksight.CfnAnalysis.EmptyVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )]
                    ),
                    filled_map_visual=quicksight.CfnAnalysis.FilledMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                            field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                                filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                                    geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                base_map_style="baseMapStyle"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                    east=123,
                                    north=123,
                                    south=123,
                                    west=123
                                ),
                                map_zoom_mode="mapZoomMode"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        conditional_formatting=quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                                shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    funnel_chart_visual=quicksight.CfnAnalysis.FunnelChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                label_color="labelColor",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_data_label_style="measureDataLabelStyle",
                                measure_label_visibility="measureLabelVisibility",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                                funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    gauge_chart_visual=quicksight.CfnAnalysis.GaugeChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                                target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                                arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                                    arc_angle=123,
                                    arc_thickness="arcThickness"
                                ),
                                arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                                    range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                        max=123,
                                        min=123
                                    ),
                                    reserve_range=123
                                ),
                                comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                    comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    comparison_method="comparisonMethod"
                                ),
                                primary_value_display_type="primaryValueDisplayType",
                                primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            ),
                            tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        conditional_formatting=quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                                arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                                    foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                ),
                                primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    geospatial_map_visual=quicksight.CfnAnalysis.GeospatialMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                            field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                                geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                base_map_style="baseMapStyle"
                            ),
                            point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                                cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                                    cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                        simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                            color="color"
                                        )
                                    )
                                ),
                                selected_point_style="selectedPointStyle"
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                    east=123,
                                    north=123,
                                    south=123,
                                    west=123
                                ),
                                map_zoom_mode="mapZoomMode"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    heat_map_visual=quicksight.CfnAnalysis.HeatMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                            color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                color_fill_type="colorFillType",
                                colors=[quicksight.CfnAnalysis.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )],
                
                                # the properties below are optional
                                null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )
                            ),
                            column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                                heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                                    columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                                heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    histogram_visual=quicksight.CfnAnalysis.HistogramVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.HistogramConfigurationProperty(
                            bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                                bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                                    value=123
                                ),
                                bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                                    bin_count_limit=123,
                                    value=123
                                ),
                                selected_bin_type="selectedBinType",
                                start_value=123
                            ),
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                                histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            )
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    insight_visual=quicksight.CfnAnalysis.InsightVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        insight_configuration=quicksight.CfnAnalysis.InsightConfigurationProperty(
                            computations=[quicksight.CfnAnalysis.ComputationProperty(
                                forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    custom_seasonality_value=123,
                                    lower_boundary=123,
                                    name="name",
                                    periods_backward=123,
                                    periods_forward=123,
                                    prediction_interval=123,
                                    seasonality="seasonality",
                                    upper_boundary=123,
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    period_size=123,
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    type="type",
                
                                    # the properties below are optional
                                    name="name",
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                                    computation_id="computationId",
                                    from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name"
                                ),
                                period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    period_time_granularity="periodTimeGranularity",
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                                    category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    type="type",
                
                                    # the properties below are optional
                                    mover_size=123,
                                    name="name",
                                    sort_order="sortOrder",
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                                    category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                                    type="type",
                
                                    # the properties below are optional
                                    name="name",
                                    result_size=123,
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                                    computation_id="computationId",
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name"
                                ),
                                unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                                    category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                
                                    # the properties below are optional
                                    name="name"
                                )
                            )],
                            custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                                narrative="narrative"
                            )
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    kpi_visual=quicksight.CfnAnalysis.KPIVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.KPIConfigurationProperty(
                            field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                                target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                                comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                    comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    comparison_method="comparisonMethod"
                                ),
                                primary_value_display_type="primaryValueDisplayType",
                                primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                                    visibility="visibility"
                                ),
                                secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                                    visibility="visibility"
                                ),
                                secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                                    visibility="visibility"
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                                trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        conditional_formatting=quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                                primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                ),
                                progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                                    foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    line_chart_visual=quicksight.CfnAnalysis.LineChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.LineChartConfigurationProperty(
                            contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                                axis_binding="axisBinding",
                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            ),
                            field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                                line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                                forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                                    lower_boundary=123,
                                    periods_backward=123,
                                    periods_forward=123,
                                    prediction_interval=123,
                                    seasonality=123,
                                    upper_boundary=123
                                ),
                                scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                                    what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                        date="date",
                                        value=123
                                    ),
                                    what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                        end_date="endDate",
                                        start_date="startDate",
                                        value=123
                                    )
                                )
                            )],
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                    treatment_option="treatmentOption"
                                )]
                            ),
                            primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                    treatment_option="treatmentOption"
                                )]
                            ),
                            secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            series=[quicksight.CfnAnalysis.SeriesItemProperty(
                                data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                                    axis_binding="axisBinding",
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    field_value="fieldValue",
                                    settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    )
                                ),
                                field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                                    axis_binding="axisBinding",
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    )
                                )
                            )],
                            small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                                category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            type="type",
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    pie_chart_visual=quicksight.CfnAnalysis.PieChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.PieChartConfigurationProperty(
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                                arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                                    arc_thickness="arcThickness"
                                ),
                                donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                                    label_visibility="labelVisibility"
                                )
                            ),
                            field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                                pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    pivot_table_visual=quicksight.CfnAnalysis.PivotTableVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                            field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                                data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                                    data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    )],
                
                                    # the properties below are optional
                                    width="width"
                                )],
                                selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    custom_label="customLabel",
                                    visibility="visibility"
                                )]
                            ),
                            field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                                pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                                    columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                                overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                vertical_overflow_visibility="verticalOverflowVisibility"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                                field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                                    field_id="fieldId",
                                    sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                        column=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                            direction="direction",
                                            sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )]
                                        ),
                                        field=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )
                                )]
                            ),
                            table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                                cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                column_names_visibility="columnNamesVisibility",
                                metric_placement="metricPlacement",
                                row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                    row_alternate_colors=["rowAlternateColors"],
                                    status="status"
                                ),
                                row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                single_metric_visibility="singleMetricVisibility",
                                toggle_buttons_visibility="toggleButtonsVisibility"
                            ),
                            total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                                column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                    custom_label="customLabel",
                                    field_level="fieldLevel",
                                    field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                        field_id="fieldId"
                                    )],
                                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                    custom_label="customLabel",
                                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                    custom_label="customLabel",
                                    field_level="fieldLevel",
                                    field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                        field_id="fieldId"
                                    )],
                                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                    custom_label="customLabel",
                                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            )
                        ),
                        conditional_formatting=quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                                cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                        role="role"
                                    ),
                                    text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    radar_chart_visual=quicksight.CfnAnalysis.RadarChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                            alternate_band_colors_visibility="alternateBandColorsVisibility",
                            alternate_band_even_color="alternateBandEvenColor",
                            alternate_band_odd_color="alternateBandOddColor",
                            base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                                area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                                    visibility="visibility"
                                )
                            ),
                            category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                                radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            shape="shape",
                            sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            start_angle=123,
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    sankey_diagram_visual=quicksight.CfnAnalysis.SankeyDiagramVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                                sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                                    destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                                destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            )
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    scatter_plot_visual=quicksight.CfnAnalysis.ScatterPlotVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                                scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                                    size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    table_visual=quicksight.CfnAnalysis.TableVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.TableConfigurationProperty(
                            field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                                order=["order"],
                                selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    custom_label="customLabel",
                                    url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                        image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                            sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                            )
                                        ),
                                        link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                            content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                                custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                                    icon="icon"
                                                ),
                                                custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                
                                                    # the properties below are optional
                                                    value="value"
                                                )
                                            ),
                                            target="target"
                                        )
                                    ),
                                    visibility="visibility",
                                    width="width"
                                )]
                            ),
                            field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                                table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                                    values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                            date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                                overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                vertical_overflow_visibility="verticalOverflowVisibility"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                                pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                    page_number=123,
                                    page_size=123
                                ),
                                row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                                data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    negative_color="negativeColor",
                                    positive_color="positiveColor"
                                )
                            )],
                            table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                                cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                orientation="orientation",
                                row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                    row_alternate_colors=["rowAlternateColors"],
                                    status="status"
                                )
                            ),
                            total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                                custom_label="customLabel",
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility"
                            )
                        ),
                        conditional_formatting=quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                                cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                ),
                                row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    tree_map_visual=quicksight.CfnAnalysis.TreeMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                            color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                color_fill_type="colorFillType",
                                colors=[quicksight.CfnAnalysis.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )],
                
                                # the properties below are optional
                                null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )
                            ),
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                                tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                                    colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                                tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    waterfall_visual=quicksight.CfnAnalysis.WaterfallVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                            category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                                waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                                    breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                                breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                                total_bar_label="totalBarLabel"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    word_cloud_visual=quicksight.CfnAnalysis.WordCloudVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                                word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                                category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                                cloud_layout="cloudLayout",
                                maximum_string_length=123,
                                word_casing="wordCasing",
                                word_orientation="wordOrientation",
                                word_padding="wordPadding",
                                word_scaling="wordScaling"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8a17406b75a6d0080bcca17351cc12b3850e11299db5acacf2f53f73fee90a20)
                check_type(argname="argument bar_chart_visual", value=bar_chart_visual, expected_type=type_hints["bar_chart_visual"])
                check_type(argname="argument box_plot_visual", value=box_plot_visual, expected_type=type_hints["box_plot_visual"])
                check_type(argname="argument combo_chart_visual", value=combo_chart_visual, expected_type=type_hints["combo_chart_visual"])
                check_type(argname="argument custom_content_visual", value=custom_content_visual, expected_type=type_hints["custom_content_visual"])
                check_type(argname="argument empty_visual", value=empty_visual, expected_type=type_hints["empty_visual"])
                check_type(argname="argument filled_map_visual", value=filled_map_visual, expected_type=type_hints["filled_map_visual"])
                check_type(argname="argument funnel_chart_visual", value=funnel_chart_visual, expected_type=type_hints["funnel_chart_visual"])
                check_type(argname="argument gauge_chart_visual", value=gauge_chart_visual, expected_type=type_hints["gauge_chart_visual"])
                check_type(argname="argument geospatial_map_visual", value=geospatial_map_visual, expected_type=type_hints["geospatial_map_visual"])
                check_type(argname="argument heat_map_visual", value=heat_map_visual, expected_type=type_hints["heat_map_visual"])
                check_type(argname="argument histogram_visual", value=histogram_visual, expected_type=type_hints["histogram_visual"])
                check_type(argname="argument insight_visual", value=insight_visual, expected_type=type_hints["insight_visual"])
                check_type(argname="argument kpi_visual", value=kpi_visual, expected_type=type_hints["kpi_visual"])
                check_type(argname="argument line_chart_visual", value=line_chart_visual, expected_type=type_hints["line_chart_visual"])
                check_type(argname="argument pie_chart_visual", value=pie_chart_visual, expected_type=type_hints["pie_chart_visual"])
                check_type(argname="argument pivot_table_visual", value=pivot_table_visual, expected_type=type_hints["pivot_table_visual"])
                check_type(argname="argument radar_chart_visual", value=radar_chart_visual, expected_type=type_hints["radar_chart_visual"])
                check_type(argname="argument sankey_diagram_visual", value=sankey_diagram_visual, expected_type=type_hints["sankey_diagram_visual"])
                check_type(argname="argument scatter_plot_visual", value=scatter_plot_visual, expected_type=type_hints["scatter_plot_visual"])
                check_type(argname="argument table_visual", value=table_visual, expected_type=type_hints["table_visual"])
                check_type(argname="argument tree_map_visual", value=tree_map_visual, expected_type=type_hints["tree_map_visual"])
                check_type(argname="argument waterfall_visual", value=waterfall_visual, expected_type=type_hints["waterfall_visual"])
                check_type(argname="argument word_cloud_visual", value=word_cloud_visual, expected_type=type_hints["word_cloud_visual"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_visual is not None:
                self._values["bar_chart_visual"] = bar_chart_visual
            if box_plot_visual is not None:
                self._values["box_plot_visual"] = box_plot_visual
            if combo_chart_visual is not None:
                self._values["combo_chart_visual"] = combo_chart_visual
            if custom_content_visual is not None:
                self._values["custom_content_visual"] = custom_content_visual
            if empty_visual is not None:
                self._values["empty_visual"] = empty_visual
            if filled_map_visual is not None:
                self._values["filled_map_visual"] = filled_map_visual
            if funnel_chart_visual is not None:
                self._values["funnel_chart_visual"] = funnel_chart_visual
            if gauge_chart_visual is not None:
                self._values["gauge_chart_visual"] = gauge_chart_visual
            if geospatial_map_visual is not None:
                self._values["geospatial_map_visual"] = geospatial_map_visual
            if heat_map_visual is not None:
                self._values["heat_map_visual"] = heat_map_visual
            if histogram_visual is not None:
                self._values["histogram_visual"] = histogram_visual
            if insight_visual is not None:
                self._values["insight_visual"] = insight_visual
            if kpi_visual is not None:
                self._values["kpi_visual"] = kpi_visual
            if line_chart_visual is not None:
                self._values["line_chart_visual"] = line_chart_visual
            if pie_chart_visual is not None:
                self._values["pie_chart_visual"] = pie_chart_visual
            if pivot_table_visual is not None:
                self._values["pivot_table_visual"] = pivot_table_visual
            if radar_chart_visual is not None:
                self._values["radar_chart_visual"] = radar_chart_visual
            if sankey_diagram_visual is not None:
                self._values["sankey_diagram_visual"] = sankey_diagram_visual
            if scatter_plot_visual is not None:
                self._values["scatter_plot_visual"] = scatter_plot_visual
            if table_visual is not None:
                self._values["table_visual"] = table_visual
            if tree_map_visual is not None:
                self._values["tree_map_visual"] = tree_map_visual
            if waterfall_visual is not None:
                self._values["waterfall_visual"] = waterfall_visual
            if word_cloud_visual is not None:
                self._values["word_cloud_visual"] = word_cloud_visual

        @builtins.property
        def bar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BarChartVisualProperty"]]:
            '''A bar chart.

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-barchartvisual
            '''
            result = self._values.get("bar_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BarChartVisualProperty"]], result)

        @builtins.property
        def box_plot_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotVisualProperty"]]:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-boxplotvisual
            '''
            result = self._values.get("box_plot_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.BoxPlotVisualProperty"]], result)

        @builtins.property
        def combo_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComboChartVisualProperty"]]:
            '''A combo chart.

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-combochartvisual
            '''
            result = self._values.get("combo_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ComboChartVisualProperty"]], result)

        @builtins.property
        def custom_content_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomContentVisualProperty"]]:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-customcontentvisual
            '''
            result = self._values.get("custom_content_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.CustomContentVisualProperty"]], result)

        @builtins.property
        def empty_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.EmptyVisualProperty"]]:
            '''An empty visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-emptyvisual
            '''
            result = self._values.get("empty_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.EmptyVisualProperty"]], result)

        @builtins.property
        def filled_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapVisualProperty"]]:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-filledmapvisual
            '''
            result = self._values.get("filled_map_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FilledMapVisualProperty"]], result)

        @builtins.property
        def funnel_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FunnelChartVisualProperty"]]:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-funnelchartvisual
            '''
            result = self._values.get("funnel_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FunnelChartVisualProperty"]], result)

        @builtins.property
        def gauge_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartVisualProperty"]]:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-gaugechartvisual
            '''
            result = self._values.get("gauge_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GaugeChartVisualProperty"]], result)

        @builtins.property
        def geospatial_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialMapVisualProperty"]]:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-geospatialmapvisual
            '''
            result = self._values.get("geospatial_map_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.GeospatialMapVisualProperty"]], result)

        @builtins.property
        def heat_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeatMapVisualProperty"]]:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-heatmapvisual
            '''
            result = self._values.get("heat_map_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HeatMapVisualProperty"]], result)

        @builtins.property
        def histogram_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HistogramVisualProperty"]]:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-histogramvisual
            '''
            result = self._values.get("histogram_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.HistogramVisualProperty"]], result)

        @builtins.property
        def insight_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.InsightVisualProperty"]]:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-insightvisual
            '''
            result = self._values.get("insight_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.InsightVisualProperty"]], result)

        @builtins.property
        def kpi_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIVisualProperty"]]:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-kpivisual
            '''
            result = self._values.get("kpi_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.KPIVisualProperty"]], result)

        @builtins.property
        def line_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartVisualProperty"]]:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-linechartvisual
            '''
            result = self._values.get("line_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LineChartVisualProperty"]], result)

        @builtins.property
        def pie_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PieChartVisualProperty"]]:
            '''A pie or donut chart.

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-piechartvisual
            '''
            result = self._values.get("pie_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PieChartVisualProperty"]], result)

        @builtins.property
        def pivot_table_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableVisualProperty"]]:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-pivottablevisual
            '''
            result = self._values.get("pivot_table_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.PivotTableVisualProperty"]], result)

        @builtins.property
        def radar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartVisualProperty"]]:
            '''A radar chart visual.

            For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-radarchartvisual
            '''
            result = self._values.get("radar_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.RadarChartVisualProperty"]], result)

        @builtins.property
        def sankey_diagram_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SankeyDiagramVisualProperty"]]:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-sankeydiagramvisual
            '''
            result = self._values.get("sankey_diagram_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.SankeyDiagramVisualProperty"]], result)

        @builtins.property
        def scatter_plot_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ScatterPlotVisualProperty"]]:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-scatterplotvisual
            '''
            result = self._values.get("scatter_plot_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ScatterPlotVisualProperty"]], result)

        @builtins.property
        def table_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableVisualProperty"]]:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-tablevisual
            '''
            result = self._values.get("table_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TableVisualProperty"]], result)

        @builtins.property
        def tree_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TreeMapVisualProperty"]]:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-treemapvisual
            '''
            result = self._values.get("tree_map_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.TreeMapVisualProperty"]], result)

        @builtins.property
        def waterfall_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WaterfallVisualProperty"]]:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-waterfallvisual
            '''
            result = self._values.get("waterfall_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WaterfallVisualProperty"]], result)

        @builtins.property
        def word_cloud_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WordCloudVisualProperty"]]:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-wordcloudvisual
            '''
            result = self._values.get("word_cloud_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WordCloudVisualProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualSubtitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LongFormatTextProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The subtitle label options for a visual.

            :param format_text: The long text format of the subtitle label, such as plain text or rich text.
            :param visibility: The visibility of the subtitle label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_subtitle_label_options_property = quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__97e7f6e474471c9a94e2f233e41ddbc7d9dadac00d1db66e15f3d4ecf262a51d)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LongFormatTextProperty"]]:
            '''The long text format of the subtitle label, such as plain text or rich text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html#cfn-quicksight-analysis-visualsubtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LongFormatTextProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the subtitle label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html#cfn-quicksight-analysis-visualsubtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualSubtitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualTitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ShortFormatTextProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The title label options for a visual.

            :param format_text: The short text format of the title label, such as plain text or rich text.
            :param visibility: The visibility of the title label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_title_label_options_property = quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__895188dd0f51eb7fddd4996aec4b8caceeeb451df745adfc8d9082dcfdd9733b)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ShortFormatTextProperty"]]:
            '''The short text format of the title label, such as plain text or rich text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html#cfn-quicksight-analysis-visualtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ShortFormatTextProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the title label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html#cfn-quicksight-analysis-visualtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualTitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdowns": "breakdowns",
            "categories": "categories",
            "values": "values",
        },
    )
    class WaterfallChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            breakdowns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            categories: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param breakdowns: The breakdown field wells of a waterfall visual.
            :param categories: The category field wells of a waterfall visual.
            :param values: The value field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                waterfall_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                    breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6a4ce4309fd1e1c5f4cd2cbfe48dede7d90bfffc2a1205b7b6d59ae2599737ec)
                check_type(argname="argument breakdowns", value=breakdowns, expected_type=type_hints["breakdowns"])
                check_type(argname="argument categories", value=categories, expected_type=type_hints["categories"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdowns is not None:
                self._values["breakdowns"] = breakdowns
            if categories is not None:
                self._values["categories"] = categories
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def breakdowns(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The breakdown field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-breakdowns
            '''
            result = self._values.get("breakdowns")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def categories(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The category field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-categories
            '''
            result = self._values.get("categories")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The value field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WaterfallChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_axis_display_options": "categoryAxisDisplayOptions",
            "category_axis_label_options": "categoryAxisLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "visual_palette": "visualPalette",
            "waterfall_chart_options": "waterfallChartOptions",
        },
    )
    class WaterfallChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WaterfallChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WaterfallChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            waterfall_chart_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WaterfallChartOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a waterfall visual.

            :param category_axis_display_options: The options that determine the presentation of the category axis.
            :param category_axis_label_options: The options that determine the presentation of the category axis label.
            :param data_labels: The data label configuration of a waterfall visual.
            :param field_wells: The field well configuration of a waterfall visual.
            :param legend: The legend configuration of a waterfall visual.
            :param primary_y_axis_display_options: The options that determine the presentation of the y-axis.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param sort_configuration: The sort configuration of a waterfall visual.
            :param visual_palette: The visual palette configuration of a waterfall visual.
            :param waterfall_chart_options: The options that determine the presentation of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                waterfall_chart_configuration_property = quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                    category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                        waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                            breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                        breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                        total_bar_label="totalBarLabel"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b5caf47a31b51b862e27a2d8d40e6573a55f6146ef4fcd61b8be5bdb1ab3f640)
                check_type(argname="argument category_axis_display_options", value=category_axis_display_options, expected_type=type_hints["category_axis_display_options"])
                check_type(argname="argument category_axis_label_options", value=category_axis_label_options, expected_type=type_hints["category_axis_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument waterfall_chart_options", value=waterfall_chart_options, expected_type=type_hints["waterfall_chart_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_axis_display_options is not None:
                self._values["category_axis_display_options"] = category_axis_display_options
            if category_axis_label_options is not None:
                self._values["category_axis_label_options"] = category_axis_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if waterfall_chart_options is not None:
                self._values["waterfall_chart_options"] = waterfall_chart_options

        @builtins.property
        def category_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the category axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-categoryaxisdisplayoptions
            '''
            result = self._values.get("category_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the category axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-categoryaxislabeloptions
            '''
            result = self._values.get("category_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]]:
            '''The data label configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WaterfallChartFieldWellsProperty"]]:
            '''The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WaterfallChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]]:
            '''The legend configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WaterfallChartSortConfigurationProperty"]]:
            '''The sort configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WaterfallChartSortConfigurationProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]]:
            '''The visual palette configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualPaletteProperty"]], result)

        @builtins.property
        def waterfall_chart_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WaterfallChartOptionsProperty"]]:
            '''The options that determine the presentation of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-waterfallchartoptions
            '''
            result = self._values.get("waterfall_chart_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WaterfallChartOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "waterfall_chart_aggregated_field_wells": "waterfallChartAggregatedFieldWells",
        },
    )
    class WaterfallChartFieldWellsProperty:
        def __init__(
            self,
            *,
            waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param waterfall_chart_aggregated_field_wells: The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                waterfall_chart_field_wells_property = quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                    waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                        breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e924f32550b5a3aca9849a62366b2e0e3e3798a75767498047ff2bee26af9cc7)
                check_type(argname="argument waterfall_chart_aggregated_field_wells", value=waterfall_chart_aggregated_field_wells, expected_type=type_hints["waterfall_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if waterfall_chart_aggregated_field_wells is not None:
                self._values["waterfall_chart_aggregated_field_wells"] = waterfall_chart_aggregated_field_wells

        @builtins.property
        def waterfall_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartfieldwells.html#cfn-quicksight-analysis-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
            '''
            result = self._values.get("waterfall_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WaterfallChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"total_bar_label": "totalBarLabel"},
    )
    class WaterfallChartOptionsProperty:
        def __init__(
            self,
            *,
            total_bar_label: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of a waterfall visual.

            :param total_bar_label: This option determines the total bar label of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                waterfall_chart_options_property = quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                    total_bar_label="totalBarLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aba08ea7a126148022ac27ece4c7efe54b758e371ebc06701b8a8bef96fd5179)
                check_type(argname="argument total_bar_label", value=total_bar_label, expected_type=type_hints["total_bar_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if total_bar_label is not None:
                self._values["total_bar_label"] = total_bar_label

        @builtins.property
        def total_bar_label(self) -> typing.Optional[builtins.str]:
            '''This option determines the total bar label of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartoptions.html#cfn-quicksight-analysis-waterfallchartoptions-totalbarlabel
            '''
            result = self._values.get("total_bar_label")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdown_items_limit": "breakdownItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WaterfallChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            breakdown_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a waterfall visual.

            :param breakdown_items_limit: The limit on the number of bar groups that are displayed.
            :param category_sort: The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                waterfall_chart_sort_configuration_property = quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                    breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2a7d46c4a6688997c19bc45a3ba348867a890ed493f473f41a191a258e4b9488)
                check_type(argname="argument breakdown_items_limit", value=breakdown_items_limit, expected_type=type_hints["breakdown_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdown_items_limit is not None:
                self._values["breakdown_items_limit"] = breakdown_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def breakdown_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of bar groups that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html#cfn-quicksight-analysis-waterfallchartsortconfiguration-breakdownitemslimit
            '''
            result = self._values.get("breakdown_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html#cfn-quicksight-analysis-waterfallchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WaterfallVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WaterfallVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WaterfallChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a waterfall visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                waterfall_visual_property = quicksight.CfnAnalysis.WaterfallVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                        category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                            waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                                breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                            breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                            total_bar_label="totalBarLabel"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__42b6502b34ccf1acaaf46afd73ddfecadd0411293c44ee48052be33597bf7495)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WaterfallChartConfigurationProperty"]]:
            '''The configuration for a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WaterfallChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WhatIfPointScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={"date": "date", "value": "value"},
    )
    class WhatIfPointScenarioProperty:
        def __init__(self, *, date: builtins.str, value: jsii.Number) -> None:
            '''Provides the forecast to meet the target for a particular date.

            :param date: The date that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                what_if_point_scenario_property = quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                    date="date",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c81c102cc41ab62641d1894a5c11c921912f386a864db21015606ff5f9b0123)
                check_type(argname="argument date", value=date, expected_type=type_hints["date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "date": date,
                "value": value,
            }

        @builtins.property
        def date(self) -> builtins.str:
            '''The date that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html#cfn-quicksight-analysis-whatifpointscenario-date
            '''
            result = self._values.get("date")
            assert result is not None, "Required property 'date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html#cfn-quicksight-analysis-whatifpointscenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfPointScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WhatIfRangeScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "end_date": "endDate",
            "start_date": "startDate",
            "value": "value",
        },
    )
    class WhatIfRangeScenarioProperty:
        def __init__(
            self,
            *,
            end_date: builtins.str,
            start_date: builtins.str,
            value: jsii.Number,
        ) -> None:
            '''Provides the forecast to meet the target for a particular date range.

            :param end_date: The end date in the date range that you need the forecast results for.
            :param start_date: The start date in the date range that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                what_if_range_scenario_property = quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                    end_date="endDate",
                    start_date="startDate",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6efa131bf9fd8eca60340ee9accd6f1638136e6c26a4b9cbdbd4a881c93a956d)
                check_type(argname="argument end_date", value=end_date, expected_type=type_hints["end_date"])
                check_type(argname="argument start_date", value=start_date, expected_type=type_hints["start_date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "end_date": end_date,
                "start_date": start_date,
                "value": value,
            }

        @builtins.property
        def end_date(self) -> builtins.str:
            '''The end date in the date range that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-enddate
            '''
            result = self._values.get("end_date")
            assert result is not None, "Required property 'end_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def start_date(self) -> builtins.str:
            '''The start date in the date range that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-startdate
            '''
            result = self._values.get("start_date")
            assert result is not None, "Required property 'start_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfRangeScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "size": "size"},
    )
    class WordCloudAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a word cloud.

            :param group_by: The group by field well of a word cloud. Values are grouped by group by fields.
            :param size: The size field well of a word cloud. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_aggregated_field_wells_property = quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9144b0f8cfb4ff98e92db4a9f759e9117ff3e44c0fa5c86ac5499774b4957460)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if size is not None:
                self._values["size"] = size

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]]:
            '''The group by field well of a word cloud.

            Values are grouped by group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html#cfn-quicksight-analysis-wordcloudaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]]:
            '''The size field well of a word cloud.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html#cfn-quicksight-analysis-wordcloudaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WordCloudChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "word_cloud_options": "wordCloudOptions",
        },
    )
    class WordCloudChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WordCloudFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WordCloudSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            word_cloud_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WordCloudOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a word cloud visual.

            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
            :param field_wells: The field wells of the visual.
            :param sort_configuration: The sort configuration of a word cloud visual.
            :param word_cloud_options: The options for a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_chart_configuration_property = quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                        word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                        cloud_layout="cloudLayout",
                        maximum_string_length=123,
                        word_casing="wordCasing",
                        word_orientation="wordOrientation",
                        word_padding="wordPadding",
                        word_scaling="wordScaling"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__746fcfa6667f447492eb6876b894351f96777bbe9f8b88bf1ba1f8614c31cea0)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument word_cloud_options", value=word_cloud_options, expected_type=type_hints["word_cloud_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if word_cloud_options is not None:
                self._values["word_cloud_options"] = word_cloud_options

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) for the word cloud category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WordCloudFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WordCloudFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WordCloudSortConfigurationProperty"]]:
            '''The sort configuration of a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WordCloudSortConfigurationProperty"]], result)

        @builtins.property
        def word_cloud_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WordCloudOptionsProperty"]]:
            '''The options for a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-wordcloudoptions
            '''
            result = self._values.get("word_cloud_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WordCloudOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WordCloudFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "word_cloud_aggregated_field_wells": "wordCloudAggregatedFieldWells",
        },
    )
    class WordCloudFieldWellsProperty:
        def __init__(
            self,
            *,
            word_cloud_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WordCloudAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a word cloud visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param word_cloud_aggregated_field_wells: The aggregated field wells of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_field_wells_property = quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                    word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__15e73ef744aa9f7d3e00325b263596ae2cbe5e9332eb721c05527d15827aa4c8)
                check_type(argname="argument word_cloud_aggregated_field_wells", value=word_cloud_aggregated_field_wells, expected_type=type_hints["word_cloud_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if word_cloud_aggregated_field_wells is not None:
                self._values["word_cloud_aggregated_field_wells"] = word_cloud_aggregated_field_wells

        @builtins.property
        def word_cloud_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WordCloudAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudfieldwells.html#cfn-quicksight-analysis-wordcloudfieldwells-wordcloudaggregatedfieldwells
            '''
            result = self._values.get("word_cloud_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WordCloudAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WordCloudOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cloud_layout": "cloudLayout",
            "maximum_string_length": "maximumStringLength",
            "word_casing": "wordCasing",
            "word_orientation": "wordOrientation",
            "word_padding": "wordPadding",
            "word_scaling": "wordScaling",
        },
    )
    class WordCloudOptionsProperty:
        def __init__(
            self,
            *,
            cloud_layout: typing.Optional[builtins.str] = None,
            maximum_string_length: typing.Optional[jsii.Number] = None,
            word_casing: typing.Optional[builtins.str] = None,
            word_orientation: typing.Optional[builtins.str] = None,
            word_padding: typing.Optional[builtins.str] = None,
            word_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The word cloud options for a word cloud visual.

            :param cloud_layout: The cloud layout options (fluid, normal) of a word cloud.
            :param maximum_string_length: The length limit of each word from 1-100.
            :param word_casing: The word casing options (lower_case, existing_case) for the words in a word cloud.
            :param word_orientation: The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
            :param word_padding: The word padding options (none, small, medium, large) for the words in a word cloud.
            :param word_scaling: The word scaling options (emphasize, normal) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_options_property = quicksight.CfnAnalysis.WordCloudOptionsProperty(
                    cloud_layout="cloudLayout",
                    maximum_string_length=123,
                    word_casing="wordCasing",
                    word_orientation="wordOrientation",
                    word_padding="wordPadding",
                    word_scaling="wordScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__af9c886ff923d6370b151e14ee383dc317f92b40dc807cd4fcb0a6a2e8acf708)
                check_type(argname="argument cloud_layout", value=cloud_layout, expected_type=type_hints["cloud_layout"])
                check_type(argname="argument maximum_string_length", value=maximum_string_length, expected_type=type_hints["maximum_string_length"])
                check_type(argname="argument word_casing", value=word_casing, expected_type=type_hints["word_casing"])
                check_type(argname="argument word_orientation", value=word_orientation, expected_type=type_hints["word_orientation"])
                check_type(argname="argument word_padding", value=word_padding, expected_type=type_hints["word_padding"])
                check_type(argname="argument word_scaling", value=word_scaling, expected_type=type_hints["word_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cloud_layout is not None:
                self._values["cloud_layout"] = cloud_layout
            if maximum_string_length is not None:
                self._values["maximum_string_length"] = maximum_string_length
            if word_casing is not None:
                self._values["word_casing"] = word_casing
            if word_orientation is not None:
                self._values["word_orientation"] = word_orientation
            if word_padding is not None:
                self._values["word_padding"] = word_padding
            if word_scaling is not None:
                self._values["word_scaling"] = word_scaling

        @builtins.property
        def cloud_layout(self) -> typing.Optional[builtins.str]:
            '''The cloud layout options (fluid, normal) of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-cloudlayout
            '''
            result = self._values.get("cloud_layout")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def maximum_string_length(self) -> typing.Optional[jsii.Number]:
            '''The length limit of each word from 1-100.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-maximumstringlength
            '''
            result = self._values.get("maximum_string_length")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def word_casing(self) -> typing.Optional[builtins.str]:
            '''The word casing options (lower_case, existing_case) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordcasing
            '''
            result = self._values.get("word_casing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_orientation(self) -> typing.Optional[builtins.str]:
            '''The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordorientation
            '''
            result = self._values.get("word_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_padding(self) -> typing.Optional[builtins.str]:
            '''The word padding options (none, small, medium, large) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordpadding
            '''
            result = self._values.get("word_padding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_scaling(self) -> typing.Optional[builtins.str]:
            '''The word scaling options (emphasize, normal) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordscaling
            '''
            result = self._values.get("word_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WordCloudSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WordCloudSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a word cloud visual.

            :param category_items_limit: The limit on the number of groups that are displayed in a word cloud.
            :param category_sort: The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_sort_configuration_property = quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__91e4a78fa1ff40dae0ff2b7e02cbbbacf78bd14272c794ac6d09b2ba201e180d)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of groups that are displayed in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html#cfn-quicksight-analysis-wordcloudsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html#cfn-quicksight-analysis-wordcloudsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnAnalysis.WordCloudVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WordCloudVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.WordCloudChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_visual_property = quicksight.CfnAnalysis.WordCloudVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                            word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                            category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                            cloud_layout="cloudLayout",
                            maximum_string_length=123,
                            word_casing="wordCasing",
                            word_orientation="wordOrientation",
                            word_padding="wordPadding",
                            word_scaling="wordScaling"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__025853a74c750e49a6341cb6f02d7032d87a5cb6d002288f2d21d2e11e092d31)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WordCloudChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.WordCloudChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnAnalysis.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="@aws-cdk/aws-quicksight.CfnAnalysisProps",
    jsii_struct_bases=[],
    name_mapping={
        "analysis_id": "analysisId",
        "aws_account_id": "awsAccountId",
        "name": "name",
        "definition": "definition",
        "parameters": "parameters",
        "permissions": "permissions",
        "source_entity": "sourceEntity",
        "status": "status",
        "tags": "tags",
        "theme_arn": "themeArn",
    },
)
class CfnAnalysisProps:
    def __init__(
        self,
        *,
        analysis_id: builtins.str,
        aws_account_id: builtins.str,
        name: builtins.str,
        definition: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AnalysisDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]] = None,
        parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        source_entity: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AnalysisSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        status: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
        theme_arn: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnAnalysis``.

        :param analysis_id: The ID for the analysis that you're creating. This ID displays in the URL of the analysis.
        :param aws_account_id: The ID of the AWS account where you are creating an analysis.
        :param name: A descriptive name for the analysis that you're creating. This name displays for the analysis in the Amazon QuickSight console.
        :param definition: ``AWS::QuickSight::Analysis.Definition``.
        :param parameters: The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.
        :param permissions: A structure that describes the principals and the resource-level permissions on an analysis. You can use the ``Permissions`` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN). To specify no permissions, omit ``Permissions`` .
        :param source_entity: A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets. Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.
        :param status: Status associated with the analysis.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
        :param theme_arn: The ARN for the theme to apply to the analysis that you're creating. To see the theme in the Amazon QuickSight console, make sure that you have access to it.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            import aws_cdk.aws_quicksight as quicksight
            
            # data_driven: Any
            
            cfn_analysis_props = quicksight.CfnAnalysisProps(
                analysis_id="analysisId",
                aws_account_id="awsAccountId",
                name="name",
            
                # the properties below are optional
                definition=quicksight.CfnAnalysis.AnalysisDefinitionProperty(
                    data_set_identifier_declarations=[quicksight.CfnAnalysis.DataSetIdentifierDeclarationProperty(
                        data_set_arn="dataSetArn",
                        identifier="identifier"
                    )],
            
                    # the properties below are optional
                    analysis_defaults=quicksight.CfnAnalysis.AnalysisDefaultsProperty(
                        default_new_sheet_configuration=quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty(
                            interactive_layout_configuration=quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                                free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            ),
                            paginated_layout_configuration=quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                                section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    )
                                )
                            ),
                            sheet_content_type="sheetContentType"
                        )
                    ),
                    calculated_fields=[quicksight.CfnAnalysis.CalculatedFieldProperty(
                        data_set_identifier="dataSetIdentifier",
                        expression="expression",
                        name="name"
                    )],
                    column_configurations=[quicksight.CfnAnalysis.ColumnConfigurationProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
            
                        # the properties below are optional
                        colors_configuration=quicksight.CfnAnalysis.ColorsConfigurationProperty(
                            custom_colors=[quicksight.CfnAnalysis.CustomColorProperty(
                                color="color",
            
                                # the properties below are optional
                                field_value="fieldValue",
                                special_value="specialValue"
                            )]
                        ),
                        format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        role="role"
                    )],
                    filter_groups=[quicksight.CfnAnalysis.FilterGroupProperty(
                        cross_dataset="crossDataset",
                        filter_group_id="filterGroupId",
                        filters=[quicksight.CfnAnalysis.FilterProperty(
                            category_filter=quicksight.CfnAnalysis.CategoryFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                                    custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
            
                                        # the properties below are optional
                                        category_value="categoryValue",
                                        parameter_name="parameterName",
                                        select_all_options="selectAllOptions"
                                    ),
                                    custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
            
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    ),
                                    filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                                        match_operator="matchOperator",
            
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    )
                                ),
                                filter_id="filterId"
                            ),
                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                match_operator="matchOperator",
                                null_option="nullOption",
            
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions",
                                value=123
                            ),
                            numeric_range_filter=quicksight.CfnAnalysis.NumericRangeFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
            
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                select_all_options="selectAllOptions"
                            ),
                            relative_dates_filter=quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                                anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                                    anchor_option="anchorOption",
                                    parameter_name="parameterName"
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                                relative_date_type="relativeDateType",
                                time_granularity="timeGranularity",
            
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
            
                                    # the properties below are optional
                                    status="status"
                                ),
                                minimum_granularity="minimumGranularity",
                                parameter_name="parameterName",
                                relative_date_value=123
                            ),
                            time_equality_filter=quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
            
                                # the properties below are optional
                                parameter_name="parameterName",
                                time_granularity="timeGranularity",
                                value="value"
                            ),
                            time_range_filter=quicksight.CfnAnalysis.TimeRangeFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
            
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
            
                                    # the properties below are optional
                                    status="status"
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                        expression="expression",
            
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                        expression="expression",
            
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                time_granularity="timeGranularity"
                            ),
                            top_bottom_filter=quicksight.CfnAnalysis.TopBottomFilterProperty(
                                aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    sort_direction="sortDirection"
                                )],
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
            
                                # the properties below are optional
                                limit=123,
                                parameter_name="parameterName",
                                time_granularity="timeGranularity"
                            )
                        )],
                        scope_configuration=quicksight.CfnAnalysis.FilterScopeConfigurationProperty(
                            selected_sheets=quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                                sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                                    scope="scope",
                                    sheet_id="sheetId",
            
                                    # the properties below are optional
                                    visual_ids=["visualIds"]
                                )]
                            )
                        ),
            
                        # the properties below are optional
                        status="status"
                    )],
                    parameter_declarations=[quicksight.CfnAnalysis.ParameterDeclarationProperty(
                        date_time_parameter_declaration=quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty(
                            name="name",
            
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
            
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            time_granularity="timeGranularity",
                            value_when_unset=quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        decimal_parameter_declaration=quicksight.CfnAnalysis.DecimalParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        integer_parameter_declaration=quicksight.CfnAnalysis.IntegerParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        string_parameter_declaration=quicksight.CfnAnalysis.StringParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.StringDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        )
                    )],
                    sheets=[quicksight.CfnAnalysis.SheetDefinitionProperty(
                        sheet_id="sheetId",
            
                        # the properties below are optional
                        content_type="contentType",
                        description="description",
                        filter_controls=[quicksight.CfnAnalysis.FilterControlProperty(
                            date_time_picker=quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            dropdown=quicksight.CfnAnalysis.FilterDropDownControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnAnalysis.FilterListControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            relative_date_time=quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            slider=quicksight.CfnAnalysis.FilterSliderControlProperty(
                                filter_control_id="filterControlId",
                                maximum_value=123,
                                minimum_value=123,
                                source_filter_id="sourceFilterId",
                                step_size=123,
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            text_area=quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        layouts=[quicksight.CfnAnalysis.LayoutProperty(
                            configuration=quicksight.CfnAnalysis.LayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
            
                                        # the properties below are optional
                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
            
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                                    body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                                        content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                            layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                                free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                        element_id="elementId",
                                                        element_type="elementType",
                                                        height="height",
                                                        width="width",
                                                        x_axis_location="xAxisLocation",
                                                        y_axis_location="yAxisLocation",
            
                                                        # the properties below are optional
                                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                            visibility="visibility"
                                                        ),
                                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                                visibility="visibility"
                                                            ),
                                                            expression="expression"
                                                        )],
                                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        visibility="visibility"
                                                    )]
                                                )
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                            after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                                status="status"
                                            )
                                        ),
                                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    ),
                                    footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
            
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
            
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )]
                                )
                            )
                        )],
                        name="name",
                        parameter_controls=[quicksight.CfnAnalysis.ParameterControlProperty(
                            date_time_picker=quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            dropdown=quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnAnalysis.ParameterListControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            slider=quicksight.CfnAnalysis.ParameterSliderControlProperty(
                                maximum_value=123,
                                minimum_value=123,
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                step_size=123,
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_area=quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        sheet_control_layouts=[quicksight.CfnAnalysis.SheetControlLayoutProperty(
                            configuration=quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                                grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
            
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            )
                        )],
                        text_boxes=[quicksight.CfnAnalysis.SheetTextBoxProperty(
                            sheet_text_box_id="sheetTextBoxId",
            
                            # the properties below are optional
                            content="content"
                        )],
                        title="title",
                        visuals=[quicksight.CfnAnalysis.VisualProperty(
                            bar_chart_visual=quicksight.CfnAnalysis.BarChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.BarChartConfigurationProperty(
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                                        bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    orientation="orientation",
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            box_plot_visual=quicksight.CfnAnalysis.BoxPlotVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                                    box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                                        all_data_points_visibility="allDataPointsVisibility",
                                        outlier_visibility="outlierVisibility",
                                        style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                                            fill_style="fillStyle"
                                        )
                                    ),
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                                        box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        )
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            combo_chart_visual=quicksight.CfnAnalysis.ComboChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                                    bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                                        combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                                            bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            custom_content_visual=quicksight.CfnAnalysis.CustomContentVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                                    content_type="contentType",
                                    content_url="contentUrl",
                                    image_scaling="imageScaling"
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            empty_visual=quicksight.CfnAnalysis.EmptyVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )]
                            ),
                            filled_map_visual=quicksight.CfnAnalysis.FilledMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                                    field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                                        filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                                            geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                                        shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            funnel_chart_visual=quicksight.CfnAnalysis.FunnelChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        label_color="labelColor",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_data_label_style="measureDataLabelStyle",
                                        measure_label_visibility="measureLabelVisibility",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                                        funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            gauge_chart_visual=quicksight.CfnAnalysis.GaugeChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                                        target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                                        arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                                            arc_angle=123,
                                            arc_thickness="arcThickness"
                                        ),
                                        arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                                            range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                                max=123,
                                                min=123
                                            ),
                                            reserve_range=123
                                        ),
                                        comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    ),
                                    tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                conditional_formatting=quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                                        arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
            
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            geospatial_map_visual=quicksight.CfnAnalysis.GeospatialMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                                    field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                                        geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                                        cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                                            cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                                simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                                    color="color"
                                                )
                                            )
                                        ),
                                        selected_point_style="selectedPointStyle"
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            heat_map_visual=quicksight.CfnAnalysis.HeatMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                                    color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
            
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                                        heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                                        heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            histogram_visual=quicksight.CfnAnalysis.HistogramVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.HistogramConfigurationProperty(
                                    bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                                        bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                                            value=123
                                        ),
                                        bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                                            bin_count_limit=123,
                                            value=123
                                        ),
                                        selected_bin_type="selectedBinType",
                                        start_value=123
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                                        histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    )
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            insight_visual=quicksight.CfnAnalysis.InsightVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                insight_configuration=quicksight.CfnAnalysis.InsightConfigurationProperty(
                                    computations=[quicksight.CfnAnalysis.ComputationProperty(
                                        forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            custom_seasonality_value=123,
                                            lower_boundary=123,
                                            name="name",
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality="seasonality",
                                            upper_boundary=123,
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            period_size=123,
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
            
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                                            computation_id="computationId",
                                            from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            period_time_granularity="periodTimeGranularity",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
            
                                            # the properties below are optional
                                            mover_size=123,
                                            name="name",
                                            sort_order="sortOrder",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            type="type",
            
                                            # the properties below are optional
                                            name="name",
                                            result_size=123,
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                                            computation_id="computationId",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
            
                                            # the properties below are optional
                                            name="name"
                                        )
                                    )],
                                    custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                                        narrative="narrative"
                                    )
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            kpi_visual=quicksight.CfnAnalysis.KPIVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.KPIConfigurationProperty(
                                    field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                                        target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                                        comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                                        trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                                        primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
            
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            line_chart_visual=quicksight.CfnAnalysis.LineChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.LineChartConfigurationProperty(
                                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                                        axis_binding="axisBinding",
                                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                                        line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                                        forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                                            lower_boundary=123,
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality=123,
                                            upper_boundary=123
                                        ),
                                        scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                                            what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                                date="date",
                                                value=123
                                            ),
                                            what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                                end_date="endDate",
                                                start_date="startDate",
                                                value=123
                                            )
                                        )
                                    )],
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    series=[quicksight.CfnAnalysis.SeriesItemProperty(
                                        data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            field_value="fieldValue",
                                            settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        ),
                                        field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                                        category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    type="type",
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pie_chart_visual=quicksight.CfnAnalysis.PieChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.PieChartConfigurationProperty(
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                                        arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                                            arc_thickness="arcThickness"
                                        ),
                                        donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                                            label_visibility="labelVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                                        pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pivot_table_visual=quicksight.CfnAnalysis.PivotTableVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                                    field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                                        data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                                            data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )],
            
                                            # the properties below are optional
                                            width="width"
                                        )],
                                        selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            visibility="visibility"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                                        pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                                        field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                                            field_id="fieldId",
                                            sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                                column=quicksight.CfnAnalysis.ColumnSortProperty(
                                                    direction="direction",
                                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    )
                                                ),
                                                data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                                    direction="direction",
                                                    sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                        field_id="fieldId",
                                                        field_value="fieldValue"
                                                    )]
                                                ),
                                                field=quicksight.CfnAnalysis.FieldSortProperty(
                                                    direction="direction",
                                                    field_id="fieldId"
                                                )
                                            )
                                        )]
                                    ),
                                    table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                                        cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_names_visibility="columnNamesVisibility",
                                        metric_placement="metricPlacement",
                                        row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        ),
                                        row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        single_metric_visibility="singleMetricVisibility",
                                        toggle_buttons_visibility="toggleButtonsVisibility"
                                    ),
                                    total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                                        column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    )
                                ),
                                conditional_formatting=quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                                role="role"
                                            ),
                                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
            
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            radar_chart_visual=quicksight.CfnAnalysis.RadarChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                                    alternate_band_even_color="alternateBandEvenColor",
                                    alternate_band_odd_color="alternateBandOddColor",
                                    base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                                        area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                                        radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    shape="shape",
                                    sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    start_angle=123,
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            sankey_diagram_visual=quicksight.CfnAnalysis.SankeyDiagramVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                                        sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                                            destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                                        destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            scatter_plot_visual=quicksight.CfnAnalysis.ScatterPlotVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            table_visual=quicksight.CfnAnalysis.TableVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.TableConfigurationProperty(
                                    field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                                        order=["order"],
                                        selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                                image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                                    sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                    )
                                                ),
                                                link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                                    content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                                        custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                                            icon="icon"
                                                        ),
                                                        custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                                font_color="fontColor",
                                                                font_decoration="fontDecoration",
                                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                                    relative="relative"
                                                                ),
                                                                font_style="fontStyle",
                                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                                    name="name"
                                                                )
                                                            ),
            
                                                            # the properties below are optional
                                                            value="value"
                                                        )
                                                    ),
                                                    target="target"
                                                )
                                            ),
                                            visibility="visibility",
                                            width="width"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                                        table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                                            values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                                    date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                                        pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        ),
                                        row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                                        data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            negative_color="negativeColor",
                                            positive_color="positiveColor"
                                        )
                                    )],
                                    table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                                        cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        orientation="orientation",
                                        row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        )
                                    ),
                                    total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                                        custom_label="customLabel",
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility"
                                    )
                                ),
                                conditional_formatting=quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
            
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        ),
                                        row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            tree_map_visual=quicksight.CfnAnalysis.TreeMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
            
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                                        tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                                        tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            waterfall_visual=quicksight.CfnAnalysis.WaterfallVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                                    category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                                        waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                                            breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                                        breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                                        total_bar_label="totalBarLabel"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            word_cloud_visual=quicksight.CfnAnalysis.WordCloudVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                                        word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                                        cloud_layout="cloudLayout",
                                        maximum_string_length=123,
                                        word_casing="wordCasing",
                                        word_orientation="wordOrientation",
                                        word_padding="wordPadding",
                                        word_scaling="wordScaling"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )]
                    )]
                ),
                parameters=quicksight.CfnAnalysis.ParametersProperty(
                    date_time_parameters=[quicksight.CfnAnalysis.DateTimeParameterProperty(
                        name="name",
                        values=["values"]
                    )],
                    decimal_parameters=[quicksight.CfnAnalysis.DecimalParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    integer_parameters=[quicksight.CfnAnalysis.IntegerParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    string_parameters=[quicksight.CfnAnalysis.StringParameterProperty(
                        name="name",
                        values=["values"]
                    )]
                ),
                permissions=[quicksight.CfnAnalysis.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
            
                    # the properties below are optional
                    resource="resource"
                )],
                source_entity=quicksight.CfnAnalysis.AnalysisSourceEntityProperty(
                    source_template=quicksight.CfnAnalysis.AnalysisSourceTemplateProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnAnalysis.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    )
                ),
                status="status",
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                theme_arn="themeArn"
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d8da32aafcf32570140f4a3398c868f104809ea7a94b36bb2fac9dce178f0208)
            check_type(argname="argument analysis_id", value=analysis_id, expected_type=type_hints["analysis_id"])
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
            check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument source_entity", value=source_entity, expected_type=type_hints["source_entity"])
            check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument theme_arn", value=theme_arn, expected_type=type_hints["theme_arn"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "analysis_id": analysis_id,
            "aws_account_id": aws_account_id,
            "name": name,
        }
        if definition is not None:
            self._values["definition"] = definition
        if parameters is not None:
            self._values["parameters"] = parameters
        if permissions is not None:
            self._values["permissions"] = permissions
        if source_entity is not None:
            self._values["source_entity"] = source_entity
        if status is not None:
            self._values["status"] = status
        if tags is not None:
            self._values["tags"] = tags
        if theme_arn is not None:
            self._values["theme_arn"] = theme_arn

    @builtins.property
    def analysis_id(self) -> builtins.str:
        '''The ID for the analysis that you're creating.

        This ID displays in the URL of the analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-analysisid
        '''
        result = self._values.get("analysis_id")
        assert result is not None, "Required property 'analysis_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you are creating an analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        assert result is not None, "Required property 'aws_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''A descriptive name for the analysis that you're creating.

        This name displays for the analysis in the Amazon QuickSight console.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-name
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def definition(
        self,
    ) -> typing.Optional[typing.Union[CfnAnalysis.AnalysisDefinitionProperty, _aws_cdk_core_f4b25747.IResolvable]]:
        '''``AWS::QuickSight::Analysis.Definition``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-definition
        '''
        result = self._values.get("definition")
        return typing.cast(typing.Optional[typing.Union[CfnAnalysis.AnalysisDefinitionProperty, _aws_cdk_core_f4b25747.IResolvable]], result)

    @builtins.property
    def parameters(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnAnalysis.ParametersProperty]]:
        '''The parameter names and override values that you want to use.

        An analysis can have any parameter type, and some parameters might accept multiple values.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-parameters
        '''
        result = self._values.get("parameters")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnAnalysis.ParametersProperty]], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnAnalysis.ResourcePermissionProperty]]]]:
        '''A structure that describes the principals and the resource-level permissions on an analysis.

        You can use the ``Permissions`` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN).

        To specify no permissions, omit ``Permissions`` .

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnAnalysis.ResourcePermissionProperty]]]], result)

    @builtins.property
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnAnalysis.AnalysisSourceEntityProperty]]:
        '''A source entity to use for the analysis that you're creating.

        This metadata structure contains details that describe a source template and one or more datasets.

        Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-sourceentity
        '''
        result = self._values.get("source_entity")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnAnalysis.AnalysisSourceEntityProperty]], result)

    @builtins.property
    def status(self) -> typing.Optional[builtins.str]:
        '''Status associated with the analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-status
        '''
        result = self._values.get("status")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]], result)

    @builtins.property
    def theme_arn(self) -> typing.Optional[builtins.str]:
        '''The ARN for the theme to apply to the analysis that you're creating.

        To see the theme in the Amazon QuickSight console, make sure that you have access to it.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-themearn
        '''
        result = self._values.get("theme_arn")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnAnalysisProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_aws_cdk_core_f4b25747.IInspectable)
class CfnDashboard(
    _aws_cdk_core_f4b25747.CfnResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@aws-cdk/aws-quicksight.CfnDashboard",
):
    '''A CloudFormation ``AWS::QuickSight::Dashboard``.

    Creates a dashboard from a template. To first create a template, see the ``CreateTemplate`` API operation.

    A dashboard is an entity in Amazon QuickSight that identifies Amazon QuickSight reports, created from analyses. You can share Amazon QuickSight dashboards. With the right permissions, you can create scheduled email reports from them. If you have the correct permissions, you can create a dashboard from a template that exists in a different AWS account .

    :cloudformationResource: AWS::QuickSight::Dashboard
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        import aws_cdk.aws_quicksight as quicksight
        
        # data_driven: Any
        
        cfn_dashboard = quicksight.CfnDashboard(self, "MyCfnDashboard",
            aws_account_id="awsAccountId",
            dashboard_id="dashboardId",
            name="name",
        
            # the properties below are optional
            dashboard_publish_options=quicksight.CfnDashboard.DashboardPublishOptionsProperty(
                ad_hoc_filtering_option=quicksight.CfnDashboard.AdHocFilteringOptionProperty(
                    availability_status="availabilityStatus"
                ),
                data_point_drill_up_down_option=quicksight.CfnDashboard.DataPointDrillUpDownOptionProperty(
                    availability_status="availabilityStatus"
                ),
                data_point_menu_label_option=quicksight.CfnDashboard.DataPointMenuLabelOptionProperty(
                    availability_status="availabilityStatus"
                ),
                data_point_tooltip_option=quicksight.CfnDashboard.DataPointTooltipOptionProperty(
                    availability_status="availabilityStatus"
                ),
                export_to_csv_option=quicksight.CfnDashboard.ExportToCSVOptionProperty(
                    availability_status="availabilityStatus"
                ),
                export_with_hidden_fields_option=quicksight.CfnDashboard.ExportWithHiddenFieldsOptionProperty(
                    availability_status="availabilityStatus"
                ),
                sheet_controls_option=quicksight.CfnDashboard.SheetControlsOptionProperty(
                    visibility_state="visibilityState"
                ),
                sheet_layout_element_maximization_option=quicksight.CfnDashboard.SheetLayoutElementMaximizationOptionProperty(
                    availability_status="availabilityStatus"
                ),
                visual_axis_sort_option=quicksight.CfnDashboard.VisualAxisSortOptionProperty(
                    availability_status="availabilityStatus"
                ),
                visual_menu_option=quicksight.CfnDashboard.VisualMenuOptionProperty(
                    availability_status="availabilityStatus"
                ),
                visual_publish_options=quicksight.CfnDashboard.DashboardVisualPublishOptionsProperty(
                    export_hidden_fields_option=quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty(
                        availability_status="availabilityStatus"
                    )
                )
            ),
            definition=quicksight.CfnDashboard.DashboardVersionDefinitionProperty(
                data_set_identifier_declarations=[quicksight.CfnDashboard.DataSetIdentifierDeclarationProperty(
                    data_set_arn="dataSetArn",
                    identifier="identifier"
                )],
        
                # the properties below are optional
                analysis_defaults=quicksight.CfnDashboard.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                ),
                calculated_fields=[quicksight.CfnDashboard.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )],
                column_configurations=[quicksight.CfnDashboard.ColumnConfigurationProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
        
                    # the properties below are optional
                    colors_configuration=quicksight.CfnDashboard.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnDashboard.CustomColorProperty(
                            color="color",
        
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )],
                filter_groups=[quicksight.CfnDashboard.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnDashboard.FilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
        
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
        
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
        
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
        
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnDashboard.NumericRangeFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
        
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnDashboard.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
        
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
        
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnDashboard.TimeEqualityFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
        
                            # the properties below are optional
                            parameter_name="parameterName",
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
        
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
        
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
        
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
        
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnDashboard.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection"
                            )],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
        
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnDashboard.FilterScopeConfigurationProperty(
                        selected_sheets=quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
        
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
        
                    # the properties below are optional
                    status="status"
                )],
                parameter_declarations=[quicksight.CfnDashboard.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnDashboard.DateTimeParameterDeclarationProperty(
                        name="name",
        
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                expression="expression",
        
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnDashboard.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnDashboard.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnDashboard.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )],
                sheets=[quicksight.CfnDashboard.SheetDefinitionProperty(
                    sheet_id="sheetId",
        
                    # the properties below are optional
                    content_type="contentType",
                    description="description",
                    filter_controls=[quicksight.CfnDashboard.FilterControlProperty(
                        date_time_picker=quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        dropdown=quicksight.CfnDashboard.FilterDropDownControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnDashboard.FilterListControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        relative_date_time=quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        slider=quicksight.CfnDashboard.FilterSliderControlProperty(
                            filter_control_id="filterControlId",
                            maximum_value=123,
                            minimum_value=123,
                            source_filter_id="sourceFilterId",
                            step_size=123,
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        text_area=quicksight.CfnDashboard.FilterTextAreaControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnDashboard.FilterTextFieldControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    layouts=[quicksight.CfnDashboard.LayoutProperty(
                        configuration=quicksight.CfnDashboard.LayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
        
                                    # the properties below are optional
                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
        
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                                body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                                    content=quicksight.CfnDashboard.BodySectionContentProperty(
                                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
        
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                        after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                            status="status"
                                        )
                                    ),
                                    style=quicksight.CfnDashboard.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                ),
                                footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
        
                                                # the properties below are optional
                                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    style=quicksight.CfnDashboard.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
        
                                                # the properties below are optional
                                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    style=quicksight.CfnDashboard.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )]
                            )
                        )
                    )],
                    name="name",
                    parameter_controls=[quicksight.CfnDashboard.ParameterControlProperty(
                        date_time_picker=quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        dropdown=quicksight.CfnDashboard.ParameterDropDownControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnDashboard.ParameterListControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        slider=quicksight.CfnDashboard.ParameterSliderControlProperty(
                            maximum_value=123,
                            minimum_value=123,
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            step_size=123,
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_area=quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    sheet_control_layouts=[quicksight.CfnDashboard.SheetControlLayoutProperty(
                        configuration=quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                            grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
        
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        )
                    )],
                    text_boxes=[quicksight.CfnDashboard.SheetTextBoxProperty(
                        sheet_text_box_id="sheetTextBoxId",
        
                        # the properties below are optional
                        content="content"
                    )],
                    title="title",
                    visuals=[quicksight.CfnDashboard.VisualProperty(
                        bar_chart_visual=quicksight.CfnDashboard.BarChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.BarChartConfigurationProperty(
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                                    bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                orientation="orientation",
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        box_plot_visual=quicksight.CfnDashboard.BoxPlotVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                                box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                                    all_data_points_visibility="allDataPointsVisibility",
                                    outlier_visibility="outlierVisibility",
                                    style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                                        fill_style="fillStyle"
                                    )
                                ),
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                                    box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    )
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        combo_chart_visual=quicksight.CfnDashboard.ComboChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.ComboChartConfigurationProperty(
                                bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                                    combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                                        bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        custom_content_visual=quicksight.CfnDashboard.CustomContentVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.CustomContentConfigurationProperty(
                                content_type="contentType",
                                content_url="contentUrl",
                                image_scaling="imageScaling"
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        empty_visual=quicksight.CfnDashboard.EmptyVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )]
                        ),
                        filled_map_visual=quicksight.CfnDashboard.FilledMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.FilledMapConfigurationProperty(
                                field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                                    filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                                        geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                                    shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        funnel_chart_visual=quicksight.CfnDashboard.FunnelChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    label_color="labelColor",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_data_label_style="measureDataLabelStyle",
                                    measure_label_visibility="measureLabelVisibility",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                                    funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        gauge_chart_visual=quicksight.CfnDashboard.GaugeChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                                    target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                                    arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                                        arc_angle=123,
                                        arc_thickness="arcThickness"
                                    ),
                                    arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                                        range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                            max=123,
                                            min=123
                                        ),
                                        reserve_range=123
                                    ),
                                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                ),
                                tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            conditional_formatting=quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                                    arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
        
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        geospatial_map_visual=quicksight.CfnDashboard.GeospatialMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                                field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                                    geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                                    cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                                        cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                            simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                                color="color"
                                            )
                                        )
                                    ),
                                    selected_point_style="selectedPointStyle"
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        heat_map_visual=quicksight.CfnDashboard.HeatMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.HeatMapConfigurationProperty(
                                color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
        
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                                    heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                                    heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        histogram_visual=quicksight.CfnDashboard.HistogramVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.HistogramConfigurationProperty(
                                bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                                    bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                                        value=123
                                    ),
                                    bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                                        bin_count_limit=123,
                                        value=123
                                    ),
                                    selected_bin_type="selectedBinType",
                                    start_value=123
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                                    histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                )
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        insight_visual=quicksight.CfnDashboard.InsightVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            insight_configuration=quicksight.CfnDashboard.InsightConfigurationProperty(
                                computations=[quicksight.CfnDashboard.ComputationProperty(
                                    forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        custom_seasonality_value=123,
                                        lower_boundary=123,
                                        name="name",
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality="seasonality",
                                        upper_boundary=123,
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        period_size=123,
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
        
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                                        computation_id="computationId",
                                        from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        period_time_granularity="periodTimeGranularity",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
        
                                        # the properties below are optional
                                        mover_size=123,
                                        name="name",
                                        sort_order="sortOrder",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        type="type",
        
                                        # the properties below are optional
                                        name="name",
                                        result_size=123,
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                                        computation_id="computationId",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
        
                                        # the properties below are optional
                                        name="name"
                                    )
                                )],
                                custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                                    narrative="narrative"
                                )
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        kpi_visual=quicksight.CfnDashboard.KPIVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.KPIConfigurationProperty(
                                field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                                    target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                                    trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                                    primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
        
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        line_chart_visual=quicksight.CfnDashboard.LineChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.LineChartConfigurationProperty(
                                contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                                    axis_binding="axisBinding",
                                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                                    line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                                    forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                                        lower_boundary=123,
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality=123,
                                        upper_boundary=123
                                    ),
                                    scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                                        what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                            date="date",
                                            value=123
                                        ),
                                        what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                            end_date="endDate",
                                            start_date="startDate",
                                            value=123
                                        )
                                    )
                                )],
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                series=[quicksight.CfnDashboard.SeriesItemProperty(
                                    data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        field_value="fieldValue",
                                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    ),
                                    field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    )
                                )],
                                small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                                    category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                type="type",
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pie_chart_visual=quicksight.CfnDashboard.PieChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.PieChartConfigurationProperty(
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                                    arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                                        arc_thickness="arcThickness"
                                    ),
                                    donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                                        label_visibility="labelVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                                    pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pivot_table_visual=quicksight.CfnDashboard.PivotTableVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.PivotTableConfigurationProperty(
                                field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                                    data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                                        data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )],
        
                                        # the properties below are optional
                                        width="width"
                                    )],
                                    selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        visibility="visibility"
                                    )]
                                ),
                                field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                                    pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                                    field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                                        field_id="fieldId",
                                        sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                            column=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                                direction="direction",
                                                sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                                    field_id="fieldId",
                                                    field_value="fieldValue"
                                                )]
                                            ),
                                            field=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )
                                    )]
                                ),
                                table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_names_visibility="columnNamesVisibility",
                                    metric_placement="metricPlacement",
                                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    ),
                                    row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    single_metric_visibility="singleMetricVisibility",
                                    toggle_buttons_visibility="toggleButtonsVisibility"
                                ),
                                total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                                    column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                )
                            ),
                            conditional_formatting=quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                            role="role"
                                        ),
                                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
        
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        radar_chart_visual=quicksight.CfnDashboard.RadarChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.RadarChartConfigurationProperty(
                                alternate_band_colors_visibility="alternateBandColorsVisibility",
                                alternate_band_even_color="alternateBandEvenColor",
                                alternate_band_odd_color="alternateBandOddColor",
                                base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                                    area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                                    radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                shape="shape",
                                sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                start_angle=123,
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        sankey_diagram_visual=quicksight.CfnDashboard.SankeyDiagramVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                                    sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                                        destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                                    destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        scatter_plot_visual=quicksight.CfnDashboard.ScatterPlotVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        table_visual=quicksight.CfnDashboard.TableVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.TableConfigurationProperty(
                                field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                                    order=["order"],
                                    selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                            image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                                sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                )
                                            ),
                                            link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                                content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                                    custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                                        icon="icon"
                                                    ),
                                                    custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                            font_color="fontColor",
                                                            font_decoration="fontDecoration",
                                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                                relative="relative"
                                                            ),
                                                            font_style="fontStyle",
                                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                                name="name"
                                                            )
                                                        ),
        
                                                        # the properties below are optional
                                                        value="value"
                                                    )
                                                ),
                                                target="target"
                                            )
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    )]
                                ),
                                field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                                    table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                                        values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                                date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    ),
                                    row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                                    data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        negative_color="negativeColor",
                                        positive_color="positiveColor"
                                    )
                                )],
                                table_options=quicksight.CfnDashboard.TableOptionsProperty(
                                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    orientation="orientation",
                                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    )
                                ),
                                total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                                    custom_label="customLabel",
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility"
                                )
                            ),
                            conditional_formatting=quicksight.CfnDashboard.TableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
        
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    ),
                                    row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        tree_map_visual=quicksight.CfnDashboard.TreeMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.TreeMapConfigurationProperty(
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
        
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                                    tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                                    tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        waterfall_visual=quicksight.CfnDashboard.WaterfallVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                                category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                                    waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                                        breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                                    breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                                    total_bar_label="totalBarLabel"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        word_cloud_visual=quicksight.CfnDashboard.WordCloudVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                                    word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                                    cloud_layout="cloudLayout",
                                    maximum_string_length=123,
                                    word_casing="wordCasing",
                                    word_orientation="wordOrientation",
                                    word_padding="wordPadding",
                                    word_scaling="wordScaling"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        )
                    )]
                )]
            ),
            parameters=quicksight.CfnDashboard.ParametersProperty(
                date_time_parameters=[quicksight.CfnDashboard.DateTimeParameterProperty(
                    name="name",
                    values=["values"]
                )],
                decimal_parameters=[quicksight.CfnDashboard.DecimalParameterProperty(
                    name="name",
                    values=[123]
                )],
                integer_parameters=[quicksight.CfnDashboard.IntegerParameterProperty(
                    name="name",
                    values=[123]
                )],
                string_parameters=[quicksight.CfnDashboard.StringParameterProperty(
                    name="name",
                    values=["values"]
                )]
            ),
            permissions=[quicksight.CfnDashboard.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal",
        
                # the properties below are optional
                resource="resource"
            )],
            source_entity=quicksight.CfnDashboard.DashboardSourceEntityProperty(
                source_template=quicksight.CfnDashboard.DashboardSourceTemplateProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnDashboard.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                )
            ),
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            theme_arn="themeArn",
            version_description="versionDescription"
        )
    '''

    def __init__(
        self,
        scope: _aws_cdk_core_f4b25747.Construct,
        id: builtins.str,
        *,
        aws_account_id: builtins.str,
        dashboard_id: builtins.str,
        name: builtins.str,
        dashboard_publish_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DashboardPublishOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        definition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DashboardVersionDefinitionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        source_entity: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DashboardSourceEntityProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
        theme_arn: typing.Optional[builtins.str] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::Dashboard``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param aws_account_id: The ID of the AWS account where you want to create the dashboard.
        :param dashboard_id: The ID for the dashboard, also added to the IAM policy.
        :param name: The display name of the dashboard.
        :param dashboard_publish_options: Options for publishing the dashboard when you create it:. - ``AvailabilityStatus`` for ``AdHocFilteringOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . When this is set to ``DISABLED`` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is ``ENABLED`` by default. - ``AvailabilityStatus`` for ``ExportToCSVOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . The visual option to export data to .CSV format isn't enabled when this is set to ``DISABLED`` . This option is ``ENABLED`` by default. - ``VisibilityState`` for ``SheetControlsOption`` - This visibility state can be either ``COLLAPSED`` or ``EXPANDED`` . This option is ``COLLAPSED`` by default.
        :param definition: ``AWS::QuickSight::Dashboard.Definition``.
        :param parameters: The parameters for the creation of the dashboard, which you want to use to override the default settings. A dashboard can have any type of parameters, and some parameters might accept multiple values.
        :param permissions: A structure that contains the permissions of the dashboard. You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN. To specify no permissions, omit the permissions list.
        :param source_entity: The entity that you are using as a source when you create the dashboard. In ``SourceEntity`` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a ``SourceTemplate`` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the ``CreateTemplate`` API operation. For ``SourceTemplate`` , specify the Amazon Resource Name (ARN) of the source template. The ``SourceTemplate`` ARN can contain any AWS account; and any QuickSight-supported AWS Region . Use the ``DataSetReferences`` entity within ``SourceTemplate`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.
        :param theme_arn: The Amazon Resource Name (ARN) of the theme that is being used for this dashboard. If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.
        :param version_description: A description for the first version of the dashboard being created.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e48367cd54dd9342e391cb843301b0a936d22766cb638c832b428f342aa489c)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnDashboardProps(
            aws_account_id=aws_account_id,
            dashboard_id=dashboard_id,
            name=name,
            dashboard_publish_options=dashboard_publish_options,
            definition=definition,
            parameters=parameters,
            permissions=permissions,
            source_entity=source_entity,
            tags=tags,
            theme_arn=theme_arn,
            version_description=version_description,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _aws_cdk_core_f4b25747.TreeInspector) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8bad017d19650f323faec0b36b2ab696b4749216593cd1a29d42368e9afe1b69)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__931b87b452937f94bdd3e2f5f24b94a904e2dab888b63f53db6e2f70228b4884)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the dashboard.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time this dashboard version was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastPublishedTime")
    def attr_last_published_time(self) -> builtins.str:
        '''The time that the dashboard was last published.

        :cloudformationAttribute: LastPublishedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastPublishedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time that the dashboard was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionArn")
    def attr_version_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionCreatedTime")
    def attr_version_created_time(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDataSetArns")
    def attr_version_data_set_arns(self) -> typing.List[builtins.str]:
        '''
        :cloudformationAttribute: Version.DataSetArns
        '''
        return typing.cast(typing.List[builtins.str], jsii.get(self, "attrVersionDataSetArns"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDescription")
    def attr_version_description(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Description
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionDescription"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionErrors")
    def attr_version_errors(self) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: Version.Errors
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrVersionErrors"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionSheets")
    def attr_version_sheets(self) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: Version.Sheets
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrVersionSheets"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionSourceEntityArn")
    def attr_version_source_entity_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.SourceEntityArn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionSourceEntityArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionStatus")
    def attr_version_status(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionStatus"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionThemeArn")
    def attr_version_theme_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.ThemeArn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionThemeArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionVersionNumber")
    def attr_version_version_number(self) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: Version.VersionNumber
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrVersionVersionNumber"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _aws_cdk_core_f4b25747.TagManager:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-tags
        '''
        return typing.cast(_aws_cdk_core_f4b25747.TagManager, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you want to create the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-awsaccountid
        '''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b972d8c0c3150e9f5a1bdb792c63f2c279e226dedd4975b4da79e30fb77a918b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="dashboardId")
    def dashboard_id(self) -> builtins.str:
        '''The ID for the dashboard, also added to the IAM policy.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardid
        '''
        return typing.cast(builtins.str, jsii.get(self, "dashboardId"))

    @dashboard_id.setter
    def dashboard_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48e8c8e06e7d4bae8fad721c7d0ae648922375cc8f3b218071c33324d873f611)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dashboardId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        '''The display name of the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-name
        '''
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e9159b4085acfe5d6a2168f6985c6cf8ee2d1211654ce74f200090a28a367a41)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="dashboardPublishOptions")
    def dashboard_publish_options(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardPublishOptionsProperty"]]:
        '''Options for publishing the dashboard when you create it:.

        - ``AvailabilityStatus`` for ``AdHocFilteringOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . When this is set to ``DISABLED`` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is ``ENABLED`` by default.
        - ``AvailabilityStatus`` for ``ExportToCSVOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . The visual option to export data to .CSV format isn't enabled when this is set to ``DISABLED`` . This option is ``ENABLED`` by default.
        - ``VisibilityState`` for ``SheetControlsOption`` - This visibility state can be either ``COLLAPSED`` or ``EXPANDED`` . This option is ``COLLAPSED`` by default.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardpublishoptions
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardPublishOptionsProperty"]], jsii.get(self, "dashboardPublishOptions"))

    @dashboard_publish_options.setter
    def dashboard_publish_options(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardPublishOptionsProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6166a160983f3fe5ecc4dec24ccab014411608bfa6601bfe643aeed996ecf98)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dashboardPublishOptions", value)

    @builtins.property
    @jsii.member(jsii_name="definition")
    def definition(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardVersionDefinitionProperty"]]:
        '''``AWS::QuickSight::Dashboard.Definition``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-definition
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardVersionDefinitionProperty"]], jsii.get(self, "definition"))

    @definition.setter
    def definition(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardVersionDefinitionProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dad7ef1e78398e551e3f72128d73794e4b508c110731d3b32fb78152d5bc63b8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "definition", value)

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParametersProperty"]]:
        '''The parameters for the creation of the dashboard, which you want to use to override the default settings.

        A dashboard can have any type of parameters, and some parameters might accept multiple values.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-parameters
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParametersProperty"]], jsii.get(self, "parameters"))

    @parameters.setter
    def parameters(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParametersProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__62bcb2fd16475e12a58e66fad3f786954abf247b8132b2a3d6bf016b303d87b7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "parameters", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ResourcePermissionProperty"]]]]:
        '''A structure that contains the permissions of the dashboard.

        You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN.

        To specify no permissions, omit the permissions list.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-permissions
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ResourcePermissionProperty"]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ResourcePermissionProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ec6bfab964c113b8287aa298797dc1a7980041501cfad366928b8a78ee8f24f8)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="sourceEntity")
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardSourceEntityProperty"]]:
        '''The entity that you are using as a source when you create the dashboard.

        In ``SourceEntity`` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a ``SourceTemplate`` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the ``CreateTemplate`` API operation. For ``SourceTemplate`` , specify the Amazon Resource Name (ARN) of the source template. The ``SourceTemplate`` ARN can contain any AWS account; and any QuickSight-supported AWS Region .

        Use the ``DataSetReferences`` entity within ``SourceTemplate`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-sourceentity
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardSourceEntityProperty"]], jsii.get(self, "sourceEntity"))

    @source_entity.setter
    def source_entity(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardSourceEntityProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6322cbd31cfb4201b0d40b2f6b3f28979b28f2d4db0f57d89f5661a6452b9acf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sourceEntity", value)

    @builtins.property
    @jsii.member(jsii_name="themeArn")
    def theme_arn(self) -> typing.Optional[builtins.str]:
        '''The Amazon Resource Name (ARN) of the theme that is being used for this dashboard.

        If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-themearn
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "themeArn"))

    @theme_arn.setter
    def theme_arn(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__093d29b03ae1a3d648643f06f55e38223831e4cb654f49158366a3b23ebe4e52)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "themeArn", value)

    @builtins.property
    @jsii.member(jsii_name="versionDescription")
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description for the first version of the dashboard being created.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-versiondescription
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionDescription"))

    @version_description.setter
    def version_description(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__80e94bee2991d499e821ae8089ca34094075772a7a7a36f07d476ab8d3021f1c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "versionDescription", value)

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AdHocFilteringOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class AdHocFilteringOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An ad hoc (one-time) filtering option.

            :param availability_status: Availability status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-adhocfilteringoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                ad_hoc_filtering_option_property = quicksight.CfnDashboard.AdHocFilteringOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b698be7589ff435eeaa53af02cb3ce9630ee1f49c2c7a79513138c50a055a6d)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''Availability status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-adhocfilteringoption.html#cfn-quicksight-dashboard-adhocfilteringoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AdHocFilteringOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_aggregation_function": "categoricalAggregationFunction",
            "date_aggregation_function": "dateAggregationFunction",
            "numerical_aggregation_function": "numericalAggregationFunction",
        },
    )
    class AggregationFunctionProperty:
        def __init__(
            self,
            *,
            categorical_aggregation_function: typing.Optional[builtins.str] = None,
            date_aggregation_function: typing.Optional[builtins.str] = None,
            numerical_aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''An aggregation function aggregates values from a dimension or measure.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param categorical_aggregation_function: Aggregation for categorical values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            :param date_aggregation_function: Aggregation for date values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values. - ``MIN`` : Select the smallest date value. - ``MAX`` : Select the largest date value.
            :param numerical_aggregation_function: Aggregation for numerical values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                aggregation_function_property = quicksight.CfnDashboard.AggregationFunctionProperty(
                    categorical_aggregation_function="categoricalAggregationFunction",
                    date_aggregation_function="dateAggregationFunction",
                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bf49ccb8809892f6cfbac13f76b3481af8c8a83754ae23ff05af63ec62ae59de)
                check_type(argname="argument categorical_aggregation_function", value=categorical_aggregation_function, expected_type=type_hints["categorical_aggregation_function"])
                check_type(argname="argument date_aggregation_function", value=date_aggregation_function, expected_type=type_hints["date_aggregation_function"])
                check_type(argname="argument numerical_aggregation_function", value=numerical_aggregation_function, expected_type=type_hints["numerical_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_aggregation_function is not None:
                self._values["categorical_aggregation_function"] = categorical_aggregation_function
            if date_aggregation_function is not None:
                self._values["date_aggregation_function"] = date_aggregation_function
            if numerical_aggregation_function is not None:
                self._values["numerical_aggregation_function"] = numerical_aggregation_function

        @builtins.property
        def categorical_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for categorical values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-categoricalaggregationfunction
            '''
            result = self._values.get("categorical_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def date_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for date values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            - ``MIN`` : Select the smallest date value.
            - ``MAX`` : Select the largest date value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-dateaggregationfunction
            '''
            result = self._values.get("date_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def numerical_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericalAggregationFunctionProperty"]]:
            '''Aggregation for numerical values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-numericalaggregationfunction
            '''
            result = self._values.get("numerical_aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericalAggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AggregationSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_function": "aggregationFunction",
            "column": "column",
            "sort_direction": "sortDirection",
        },
    )
    class AggregationSortConfigurationProperty:
        def __init__(
            self,
            *,
            aggregation_function: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            sort_direction: builtins.str,
        ) -> None:
            '''The configuration options to sort aggregated values.

            :param aggregation_function: The function that aggregates the values in ``Column`` .
            :param column: The column that determines the sort order of aggregated values.
            :param sort_direction: The sort direction of values. - ``ASC`` : Sort in ascending order. - ``DESC`` : Sort in descending order.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                aggregation_sort_configuration_property = quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    sort_direction="sortDirection"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__16749183c430f5514e9ee9cf94ae9025f9d33ba4a8f53fb01fc6911ba191bf84)
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument sort_direction", value=sort_direction, expected_type=type_hints["sort_direction"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_function": aggregation_function,
                "column": column,
                "sort_direction": sort_direction,
            }

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationFunctionProperty"]:
            '''The function that aggregates the values in ``Column`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            assert result is not None, "Required property 'aggregation_function' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationFunctionProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that determines the sort order of aggregated values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def sort_direction(self) -> builtins.str:
            '''The sort direction of values.

            - ``ASC`` : Sort in ascending order.
            - ``DESC`` : Sort in descending order.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-sortdirection
            '''
            result = self._values.get("sort_direction")
            assert result is not None, "Required property 'sort_direction' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AnalysisDefaultsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_new_sheet_configuration": "defaultNewSheetConfiguration",
        },
    )
    class AnalysisDefaultsProperty:
        def __init__(
            self,
            *,
            default_new_sheet_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DefaultNewSheetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The configuration for default analysis settings.

            :param default_new_sheet_configuration: The configuration for default new sheet settings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-analysisdefaults.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                analysis_defaults_property = quicksight.CfnDashboard.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5075815710d94e2f81de88c7c8a6ae1d1e947322db7fd05b0d15f190af0d764e)
                check_type(argname="argument default_new_sheet_configuration", value=default_new_sheet_configuration, expected_type=type_hints["default_new_sheet_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_new_sheet_configuration": default_new_sheet_configuration,
            }

        @builtins.property
        def default_new_sheet_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DefaultNewSheetConfigurationProperty"]:
            '''The configuration for default new sheet settings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-analysisdefaults.html#cfn-quicksight-dashboard-analysisdefaults-defaultnewsheetconfiguration
            '''
            result = self._values.get("default_new_sheet_configuration")
            assert result is not None, "Required property 'default_new_sheet_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DefaultNewSheetConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisDefaultsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AnchorDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_option": "anchorOption",
            "parameter_name": "parameterName",
        },
    )
    class AnchorDateConfigurationProperty:
        def __init__(
            self,
            *,
            anchor_option: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The date configuration of the filter.

            :param anchor_option: The options for the date configuration. Choose one of the options below:. - ``NOW``
            :param parameter_name: The name of the parameter that is used for the anchor date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                anchor_date_configuration_property = quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                    anchor_option="anchorOption",
                    parameter_name="parameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96edef06a056262fc22dfc9f06599f90901acca9268fc8b97ce27f39bbdbb4dc)
                check_type(argname="argument anchor_option", value=anchor_option, expected_type=type_hints["anchor_option"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if anchor_option is not None:
                self._values["anchor_option"] = anchor_option
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name

        @builtins.property
        def anchor_option(self) -> typing.Optional[builtins.str]:
            '''The options for the date configuration. Choose one of the options below:.

            - ``NOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html#cfn-quicksight-dashboard-anchordateconfiguration-anchoroption
            '''
            result = self._values.get("anchor_option")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The name of the parameter that is used for the anchor date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html#cfn-quicksight-dashboard-anchordateconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnchorDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ArcAxisConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "reserve_range": "reserveRange"},
    )
    class ArcAxisConfigurationProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ArcAxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reserve_range: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :param range: The arc axis range of a ``GaugeChartVisual`` .
            :param reserve_range: The reserved range of the arc axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                arc_axis_configuration_property = quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                    range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                        max=123,
                        min=123
                    ),
                    reserve_range=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9176a3f0dc1a20494ce546d33d6f3fd02cec576840e08224c0264b590a6126d8)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument reserve_range", value=reserve_range, expected_type=type_hints["reserve_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if reserve_range is not None:
                self._values["reserve_range"] = reserve_range

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ArcAxisDisplayRangeProperty"]]:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html#cfn-quicksight-dashboard-arcaxisconfiguration-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ArcAxisDisplayRangeProperty"]], result)

        @builtins.property
        def reserve_range(self) -> typing.Optional[jsii.Number]:
            '''The reserved range of the arc axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html#cfn-quicksight-dashboard-arcaxisconfiguration-reserverange
            '''
            result = self._values.get("reserve_range")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ArcAxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"max": "max", "min": "min"},
    )
    class ArcAxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            max: typing.Optional[jsii.Number] = None,
            min: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :param max: The maximum value of the arc axis range.
            :param min: The minimum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                arc_axis_display_range_property = quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                    max=123,
                    min=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__12a771a16c265538a625aaaa712718421dd8f7fe9d51dcad4c2ef52912fc2974)
                check_type(argname="argument max", value=max, expected_type=type_hints["max"])
                check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max is not None:
                self._values["max"] = max
            if min is not None:
                self._values["min"] = min

        @builtins.property
        def max(self) -> typing.Optional[jsii.Number]:
            '''The maximum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html#cfn-quicksight-dashboard-arcaxisdisplayrange-max
            '''
            result = self._values.get("max")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def min(self) -> typing.Optional[jsii.Number]:
            '''The minimum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html#cfn-quicksight-dashboard-arcaxisdisplayrange-min
            '''
            result = self._values.get("min")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ArcConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_angle": "arcAngle", "arc_thickness": "arcThickness"},
    )
    class ArcConfigurationProperty:
        def __init__(
            self,
            *,
            arc_angle: typing.Optional[jsii.Number] = None,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :param arc_angle: The option that determines the arc angle of a ``GaugeChartVisual`` .
            :param arc_thickness: The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                arc_configuration_property = quicksight.CfnDashboard.ArcConfigurationProperty(
                    arc_angle=123,
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c68645b2d68641a2901b34535a709e7b8ec320836b1ee0c7bdac1423845460d8)
                check_type(argname="argument arc_angle", value=arc_angle, expected_type=type_hints["arc_angle"])
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_angle is not None:
                self._values["arc_angle"] = arc_angle
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_angle(self) -> typing.Optional[jsii.Number]:
            '''The option that determines the arc angle of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html#cfn-quicksight-dashboard-arcconfiguration-arcangle
            '''
            result = self._values.get("arc_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html#cfn-quicksight-dashboard-arcconfiguration-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ArcOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_thickness": "arcThickness"},
    )
    class ArcOptionsProperty:
        def __init__(
            self,
            *,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :param arc_thickness: The arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                arc_options_property = quicksight.CfnDashboard.ArcOptionsProperty(
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fec0672915f93e5a544811f60fad5643e68e2de357546a3ec9f169d43ffbcc9a)
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcoptions.html#cfn-quicksight-dashboard-arcoptions-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AxisDataOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_axis_options": "dateAxisOptions",
            "numeric_axis_options": "numericAxisOptions",
        },
    )
    class AxisDataOptionsProperty:
        def __init__(
            self,
            *,
            date_axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DateAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data options for an axis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_axis_options: The options for an axis with a date field.
            :param numeric_axis_options: The options for an axis with a numeric field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_data_options_property = quicksight.CfnDashboard.AxisDataOptionsProperty(
                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                        missing_date_visibility="missingDateVisibility"
                    ),
                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                            data_driven=data_driven,
                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                maximum=123,
                                minimum=123
                            )
                        ),
                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                step_count=123,
                                step_size=123
                            ),
                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                base=123
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d0b97004ad028b08d2a7a5ab7667b7b8345578ea2c7fc1a86b5b38bfbf32001a)
                check_type(argname="argument date_axis_options", value=date_axis_options, expected_type=type_hints["date_axis_options"])
                check_type(argname="argument numeric_axis_options", value=numeric_axis_options, expected_type=type_hints["numeric_axis_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_axis_options is not None:
                self._values["date_axis_options"] = date_axis_options
            if numeric_axis_options is not None:
                self._values["numeric_axis_options"] = numeric_axis_options

        @builtins.property
        def date_axis_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateAxisOptionsProperty"]]:
            '''The options for an axis with a date field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html#cfn-quicksight-dashboard-axisdataoptions-dateaxisoptions
            '''
            result = self._values.get("date_axis_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateAxisOptionsProperty"]], result)

        @builtins.property
        def numeric_axis_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericAxisOptionsProperty"]]:
            '''The options for an axis with a numeric field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html#cfn-quicksight-dashboard-axisdataoptions-numericaxisoptions
            '''
            result = self._values.get("numeric_axis_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericAxisOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDataOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"maximum": "maximum", "minimum": "minimum"},
    )
    class AxisDisplayMinMaxRangeProperty:
        def __init__(
            self,
            *,
            maximum: typing.Optional[jsii.Number] = None,
            minimum: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The minimum and maximum setup for an axis display range.

            :param maximum: The maximum setup for an axis display range.
            :param minimum: The minimum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_display_min_max_range_property = quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                    maximum=123,
                    minimum=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7683b81cec62e659b564f0bfa294b411bc8caa01a8a1c84da263d0f0397293f9)
                check_type(argname="argument maximum", value=maximum, expected_type=type_hints["maximum"])
                check_type(argname="argument minimum", value=minimum, expected_type=type_hints["minimum"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if maximum is not None:
                self._values["maximum"] = maximum
            if minimum is not None:
                self._values["minimum"] = minimum

        @builtins.property
        def maximum(self) -> typing.Optional[jsii.Number]:
            '''The maximum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html#cfn-quicksight-dashboard-axisdisplayminmaxrange-maximum
            '''
            result = self._values.get("maximum")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def minimum(self) -> typing.Optional[jsii.Number]:
            '''The minimum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html#cfn-quicksight-dashboard-axisdisplayminmaxrange-minimum
            '''
            result = self._values.get("minimum")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayMinMaxRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_line_visibility": "axisLineVisibility",
            "axis_offset": "axisOffset",
            "data_options": "dataOptions",
            "grid_line_visibility": "gridLineVisibility",
            "scrollbar_options": "scrollbarOptions",
            "tick_label_options": "tickLabelOptions",
        },
    )
    class AxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_line_visibility: typing.Optional[builtins.str] = None,
            axis_offset: typing.Optional[builtins.str] = None,
            data_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDataOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid_line_visibility: typing.Optional[builtins.str] = None,
            scrollbar_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ScrollBarOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tick_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisTickLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options for the axis label.

            :param axis_line_visibility: Determines whether or not the axis line is visible.
            :param axis_offset: The offset value that determines the starting placement of the axis within a visual's bounds.
            :param data_options: The data options for an axis.
            :param grid_line_visibility: Determines whether or not the grid line is visible.
            :param scrollbar_options: The scroll bar options for an axis.
            :param tick_label_options: The tick label options of an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_options_property = quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                    axis_line_visibility="axisLineVisibility",
                    axis_offset="axisOffset",
                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                            missing_date_visibility="missingDateVisibility"
                        ),
                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                data_driven=data_driven,
                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                    maximum=123,
                                    minimum=123
                                )
                            ),
                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                    step_count=123,
                                    step_size=123
                                ),
                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                    base=123
                                )
                            )
                        )
                    ),
                    grid_line_visibility="gridLineVisibility",
                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                        visibility="visibility",
                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                from=123,
                                to=123
                            )
                        )
                    ),
                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        rotation_angle=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eadbe89875f8d4cec1b1202ad2d0e0460747e4f231141d7700f28964d9e24e8a)
                check_type(argname="argument axis_line_visibility", value=axis_line_visibility, expected_type=type_hints["axis_line_visibility"])
                check_type(argname="argument axis_offset", value=axis_offset, expected_type=type_hints["axis_offset"])
                check_type(argname="argument data_options", value=data_options, expected_type=type_hints["data_options"])
                check_type(argname="argument grid_line_visibility", value=grid_line_visibility, expected_type=type_hints["grid_line_visibility"])
                check_type(argname="argument scrollbar_options", value=scrollbar_options, expected_type=type_hints["scrollbar_options"])
                check_type(argname="argument tick_label_options", value=tick_label_options, expected_type=type_hints["tick_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_line_visibility is not None:
                self._values["axis_line_visibility"] = axis_line_visibility
            if axis_offset is not None:
                self._values["axis_offset"] = axis_offset
            if data_options is not None:
                self._values["data_options"] = data_options
            if grid_line_visibility is not None:
                self._values["grid_line_visibility"] = grid_line_visibility
            if scrollbar_options is not None:
                self._values["scrollbar_options"] = scrollbar_options
            if tick_label_options is not None:
                self._values["tick_label_options"] = tick_label_options

        @builtins.property
        def axis_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the axis line is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-axislinevisibility
            '''
            result = self._values.get("axis_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def axis_offset(self) -> typing.Optional[builtins.str]:
            '''The offset value that determines the starting placement of the axis within a visual's bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-axisoffset
            '''
            result = self._values.get("axis_offset")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDataOptionsProperty"]]:
            '''The data options for an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-dataoptions
            '''
            result = self._values.get("data_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDataOptionsProperty"]], result)

        @builtins.property
        def grid_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the grid line is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-gridlinevisibility
            '''
            result = self._values.get("grid_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scrollbar_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ScrollBarOptionsProperty"]]:
            '''The scroll bar options for an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-scrollbaroptions
            '''
            result = self._values.get("scrollbar_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ScrollBarOptionsProperty"]], result)

        @builtins.property
        def tick_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisTickLabelOptionsProperty"]]:
            '''The tick label options of an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-ticklabeloptions
            '''
            result = self._values.get("tick_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisTickLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"data_driven": "dataDriven", "min_max": "minMax"},
    )
    class AxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            data_driven: typing.Any = None,
            min_max: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayMinMaxRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The range setup of a numeric axis display range.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_driven: The data-driven setup of an axis display range.
            :param min_max: The minimum and maximum setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_range_property = quicksight.CfnDashboard.AxisDisplayRangeProperty(
                    data_driven=data_driven,
                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                        maximum=123,
                        minimum=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f8a0daab21a55eb94ef9c0c537727c8196c96099007bee2b4676901dc9dac07)
                check_type(argname="argument data_driven", value=data_driven, expected_type=type_hints["data_driven"])
                check_type(argname="argument min_max", value=min_max, expected_type=type_hints["min_max"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_driven is not None:
                self._values["data_driven"] = data_driven
            if min_max is not None:
                self._values["min_max"] = min_max

        @builtins.property
        def data_driven(self) -> typing.Any:
            '''The data-driven setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html#cfn-quicksight-dashboard-axisdisplayrange-datadriven
            '''
            result = self._values.get("data_driven")
            return typing.cast(typing.Any, result)

        @builtins.property
        def min_max(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayMinMaxRangeProperty"]]:
            '''The minimum and maximum setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html#cfn-quicksight-dashboard-axisdisplayrange-minmax
            '''
            result = self._values.get("min_max")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayMinMaxRangeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "apply_to": "applyTo",
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
        },
    )
    class AxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            apply_to: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisLabelReferenceOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The label options for a chart axis.

            You must specify the field that the label is targeted to.

            :param apply_to: The options that indicate which field the label belongs to.
            :param custom_label: The text for the axis label.
            :param font_configuration: The font configuration of the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_label_options_property = quicksight.CfnDashboard.AxisLabelOptionsProperty(
                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId"
                    ),
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9cafd7f59053ba60f0a6fead0d1f83670c21b659df44146d7fb59bd9032b0c62)
                check_type(argname="argument apply_to", value=apply_to, expected_type=type_hints["apply_to"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if apply_to is not None:
                self._values["apply_to"] = apply_to
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration

        @builtins.property
        def apply_to(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisLabelReferenceOptionsProperty"]]:
            '''The options that indicate which field the label belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-applyto
            '''
            result = self._values.get("apply_to")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisLabelReferenceOptionsProperty"]], result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]]:
            '''The font configuration of the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "field_id": "fieldId"},
    )
    class AxisLabelReferenceOptionsProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
        ) -> None:
            '''The reference that specifies where the axis label is applied to.

            :param column: The column that the axis label is targeted to.
            :param field_id: The field that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_label_reference_options_property = quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c183dd904676555d4b4b9b52b9981b3e4a07253c04413d02b89ce484c6c77444)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html#cfn-quicksight-dashboard-axislabelreferenceoptions-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html#cfn-quicksight-dashboard-axislabelreferenceoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelReferenceOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AxisLinearScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"step_count": "stepCount", "step_size": "stepSize"},
    )
    class AxisLinearScaleProperty:
        def __init__(
            self,
            *,
            step_count: typing.Optional[jsii.Number] = None,
            step_size: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The liner axis scale setup.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param step_count: The step count setup of a linear axis.
            :param step_size: The step size setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_linear_scale_property = quicksight.CfnDashboard.AxisLinearScaleProperty(
                    step_count=123,
                    step_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9bb18d42a6720e8a6947d59b34fa91c87d9a42db0bc3daa62fe0776eb454e285)
                check_type(argname="argument step_count", value=step_count, expected_type=type_hints["step_count"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if step_count is not None:
                self._values["step_count"] = step_count
            if step_size is not None:
                self._values["step_size"] = step_size

        @builtins.property
        def step_count(self) -> typing.Optional[jsii.Number]:
            '''The step count setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html#cfn-quicksight-dashboard-axislinearscale-stepcount
            '''
            result = self._values.get("step_count")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def step_size(self) -> typing.Optional[jsii.Number]:
            '''The step size setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html#cfn-quicksight-dashboard-axislinearscale-stepsize
            '''
            result = self._values.get("step_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLinearScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AxisLogarithmicScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"base": "base"},
    )
    class AxisLogarithmicScaleProperty:
        def __init__(self, *, base: typing.Optional[jsii.Number] = None) -> None:
            '''The logarithmic axis scale setup.

            :param base: The base setup of a logarithmic axis scale.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislogarithmicscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_logarithmic_scale_property = quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                    base=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__70c8a36719b88116f32c7087b854b08debb7c1d6c249a59d3f7e88d319c12b99)
                check_type(argname="argument base", value=base, expected_type=type_hints["base"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base is not None:
                self._values["base"] = base

        @builtins.property
        def base(self) -> typing.Optional[jsii.Number]:
            '''The base setup of a logarithmic axis scale.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislogarithmicscale.html#cfn-quicksight-dashboard-axislogarithmicscale-base
            '''
            result = self._values.get("base")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLogarithmicScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AxisScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"linear": "linear", "logarithmic": "logarithmic"},
    )
    class AxisScaleProperty:
        def __init__(
            self,
            *,
            linear: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisLinearScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            logarithmic: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisLogarithmicScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The scale setup options for a numeric axis display.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param linear: The linear axis scale setup.
            :param logarithmic: The logarithmic axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_scale_property = quicksight.CfnDashboard.AxisScaleProperty(
                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                        step_count=123,
                        step_size=123
                    ),
                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                        base=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a541dd13c6e9b660a3afc48d1f0ba9f39e2d3128327965e202b7c6d36971d98)
                check_type(argname="argument linear", value=linear, expected_type=type_hints["linear"])
                check_type(argname="argument logarithmic", value=logarithmic, expected_type=type_hints["logarithmic"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if linear is not None:
                self._values["linear"] = linear
            if logarithmic is not None:
                self._values["logarithmic"] = logarithmic

        @builtins.property
        def linear(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisLinearScaleProperty"]]:
            '''The linear axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html#cfn-quicksight-dashboard-axisscale-linear
            '''
            result = self._values.get("linear")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisLinearScaleProperty"]], result)

        @builtins.property
        def logarithmic(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisLogarithmicScaleProperty"]]:
            '''The logarithmic axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html#cfn-quicksight-dashboard-axisscale-logarithmic
            '''
            result = self._values.get("logarithmic")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisLogarithmicScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.AxisTickLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "label_options": "labelOptions",
            "rotation_angle": "rotationAngle",
        },
    )
    class AxisTickLabelOptionsProperty:
        def __init__(
            self,
            *,
            label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rotation_angle: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The tick label options of an axis.

            :param label_options: Determines whether or not the axis ticks are visible.
            :param rotation_angle: The rotation angle of the axis tick labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_tick_label_options_property = quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    rotation_angle=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b2a6360bb5e2a9e553a9d7d5f0eb0725b62f5e0a6794a38dec7e7255bcb47fef)
                check_type(argname="argument label_options", value=label_options, expected_type=type_hints["label_options"])
                check_type(argname="argument rotation_angle", value=rotation_angle, expected_type=type_hints["rotation_angle"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_options is not None:
                self._values["label_options"] = label_options
            if rotation_angle is not None:
                self._values["rotation_angle"] = rotation_angle

        @builtins.property
        def label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]]:
            '''Determines whether or not the axis ticks are visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html#cfn-quicksight-dashboard-axisticklabeloptions-labeloptions
            '''
            result = self._values.get("label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]], result)

        @builtins.property
        def rotation_angle(self) -> typing.Optional[jsii.Number]:
            '''The rotation angle of the axis tick labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html#cfn-quicksight-dashboard-axisticklabeloptions-rotationangle
            '''
            result = self._values.get("rotation_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisTickLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class BarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a bar chart.

            :param category: The category (y-axis) field well of a bar chart.
            :param colors: The color (group/color) field well of a bar chart.
            :param small_multiples: The small multiples field well of a bar chart.
            :param values: The value field wells of a bar chart. Values are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bar_chart_aggregated_field_wells_property = quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b5f8bd6740c7536cd50ac17cb49112e1a5232d6eca37bb7eb30df00ab36ca544)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The category (y-axis) field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The color (group/color) field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a bar chart.

            Values are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "orientation": "orientation",
            "reference_lines": "referenceLines",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_axis": "valueAxis",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class BarChartConfigurationProperty:
        def __init__(
            self,
            *,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            orientation: typing.Optional[builtins.str] = None,
            reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``BarChartVisual`` .

            :param bars_arrangement: Determines the arrangement of the bars. The orientation and arrangement of bars determine the type of bar that is used in the visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) for bar chart category.
            :param category_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart.
            :param color_label_options: The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param orientation: The orientation of the bars in a bar chart visual. There are two valid values in this structure:. - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts. - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
            :param reference_lines: The reference line setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a ``BarChartVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param value_axis: The label display options (grid line, range, scale, axis step) for a bar chart value.
            :param value_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart value.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                bar_chart_configuration_property = quicksight.CfnDashboard.BarChartConfigurationProperty(
                    bars_arrangement="barsArrangement",
                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                        bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    orientation="orientation",
                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__deb97781027704ed6b8bd2e81c0de81a9e84cdb266a70a4ddb48d7c807e23945)
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_axis", value=value_axis, expected_type=type_hints["value_axis"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if orientation is not None:
                self._values["orientation"] = orientation
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_axis is not None:
                self._values["value_axis"] = value_axis
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the arrangement of the bars.

            The orientation and arrangement of bars determine the type of bar that is used in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) for bar chart category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ContributionAnalysisDefaultProperty"]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BarChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BarChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation of the bars in a bar chart visual. There are two valid values in this structure:.

            - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
            - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineProperty"]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BarChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``BarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BarChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) for a bar chart value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-valueaxis
            '''
            result = self._values.get("value_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_aggregated_field_wells": "barChartAggregatedFieldWells",
        },
    )
    class BarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``BarChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_aggregated_field_wells: The aggregated field wells of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bar_chart_field_wells_property = quicksight.CfnDashboard.BarChartFieldWellsProperty(
                    bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3892b431a3a2eb3420f01a6038e29381e80cf0542e37c63f112d386e61199093)
                check_type(argname="argument bar_chart_aggregated_field_wells", value=bar_chart_aggregated_field_wells, expected_type=type_hints["bar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_aggregated_field_wells is not None:
                self._values["bar_chart_aggregated_field_wells"] = bar_chart_aggregated_field_wells

        @builtins.property
        def bar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BarChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartfieldwells.html#cfn-quicksight-dashboard-barchartfieldwells-barchartaggregatedfieldwells
            '''
            result = self._values.get("bar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BarChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class BarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''sort-configuration-description.

            :param category_items_limit: The limit on the number of categories displayed in a bar chart.
            :param category_sort: The sort configuration of category fields.
            :param color_items_limit: The limit on the number of values displayed in a bar chart.
            :param color_sort: The sort configuration of color fields in a bar chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bar_chart_sort_configuration_property = quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fc5dded84b2e7dc712e22e971b152ba29be73dc90a8d31dc9f472a78f1c77580)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories displayed in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of values displayed in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of color fields in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A bar chart.

            The ``BarChartVisual`` structure describes a visual that is a member of the bar chart family. The following charts can be described using this structure:

            - Horizontal bar chart
            - Vertical bar chart
            - Horizontal stacked bar chart
            - Vertical stacked bar chart
            - Horizontal stacked 100% bar chart
            - Vertical stacked 100% bar chart

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                bar_chart_visual_property = quicksight.CfnDashboard.BarChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.BarChartConfigurationProperty(
                        bars_arrangement="barsArrangement",
                        category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                            bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        orientation="orientation",
                        reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                            data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55183ce3561875d22b98b362c344f7f5a2c65dcfc7f77e8f98c0ec929126843f)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BarChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BarChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BinCountOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class BinCountOptionsProperty:
        def __init__(self, *, value: typing.Optional[jsii.Number] = None) -> None:
            '''The options that determine the bin count of a histogram.

            :param value: The options that determine the bin count value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bincountoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bin_count_options_property = quicksight.CfnDashboard.BinCountOptionsProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__009936f107949a94df6fd6e5b29ade27e95329f0007e24e685ab01d1d21805dd)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bincountoptions.html#cfn-quicksight-dashboard-bincountoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinCountOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BinWidthOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bin_count_limit": "binCountLimit", "value": "value"},
    )
    class BinWidthOptionsProperty:
        def __init__(
            self,
            *,
            bin_count_limit: typing.Optional[jsii.Number] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the bin width of a histogram.

            :param bin_count_limit: The options that determine the bin count limit.
            :param value: The options that determine the bin width value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bin_width_options_property = quicksight.CfnDashboard.BinWidthOptionsProperty(
                    bin_count_limit=123,
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c6f2aebe03941a3002aaa5510ed7717f69ca4cb6acf3a95254807dc8940a3bcd)
                check_type(argname="argument bin_count_limit", value=bin_count_limit, expected_type=type_hints["bin_count_limit"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count_limit is not None:
                self._values["bin_count_limit"] = bin_count_limit
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def bin_count_limit(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count limit.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html#cfn-quicksight-dashboard-binwidthoptions-bincountlimit
            '''
            result = self._values.get("bin_count_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin width value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html#cfn-quicksight-dashboard-binwidthoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinWidthOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BodySectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content": "content",
            "section_id": "sectionId",
            "page_break_configuration": "pageBreakConfiguration",
            "style": "style",
        },
    )
    class BodySectionConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BodySectionContentProperty", typing.Dict[builtins.str, typing.Any]]],
            section_id: builtins.str,
            page_break_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SectionPageBreakConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a body section.

            :param content: The configuration of content in a body section.
            :param section_id: The unique identifier of a body section.
            :param page_break_configuration: The configuration of a page break for a section.
            :param style: The style options of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                body_section_configuration_property = quicksight.CfnDashboard.BodySectionConfigurationProperty(
                    content=quicksight.CfnDashboard.BodySectionContentProperty(
                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                        after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                            status="status"
                        )
                    ),
                    style=quicksight.CfnDashboard.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnDashboard.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6afd1d4accfb726e8d23257d4580346fd5b13ac8b6dd1f4842303d88e31a35ab)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument page_break_configuration", value=page_break_configuration, expected_type=type_hints["page_break_configuration"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "section_id": section_id,
            }
            if page_break_configuration is not None:
                self._values["page_break_configuration"] = page_break_configuration
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def content(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BodySectionContentProperty"]:
            '''The configuration of content in a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BodySectionContentProperty"], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def page_break_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionPageBreakConfigurationProperty"]]:
            '''The configuration of a page break for a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-pagebreakconfiguration
            '''
            result = self._values.get("page_break_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionPageBreakConfigurationProperty"]], result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionStyleProperty"]]:
            '''The style options of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BodySectionContentProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout"},
    )
    class BodySectionContentProperty:
        def __init__(
            self,
            *,
            layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of content in a body section.

            :param layout: The layout configuration of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectioncontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                body_section_content_property = quicksight.CfnDashboard.BodySectionContentProperty(
                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__36b8207b32011a65fd176c373dce22e8104c0d2c11a184352b570918596ae484)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if layout is not None:
                self._values["layout"] = layout

        @builtins.property
        def layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionLayoutConfigurationProperty"]]:
            '''The layout configuration of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectioncontent.html#cfn-quicksight-dashboard-bodysectioncontent-layout
            '''
            result = self._values.get("layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class BoxPlotAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for a box plot.

            :param group_by: The group by field well of a box plot chart. Values are grouped based on group by fields.
            :param values: The value field well of a box plot chart. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_aggregated_field_wells_property = quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c8ec6d64a4adf5ee0eff08f2f82aac5d4e58e363a92fca48bcaa4dcdc1158b08)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The group by field well of a box plot chart.

            Values are grouped based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html#cfn-quicksight-dashboard-boxplotaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field well of a box plot chart.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html#cfn-quicksight-dashboard-boxplotaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BoxPlotChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_options": "boxPlotOptions",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class BoxPlotChartConfigurationProperty:
        def __init__(
            self,
            *,
            box_plot_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BoxPlotOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BoxPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BoxPlotSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``BoxPlotVisual`` .

            :param box_plot_options: The box plot chart options for a box plot visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param category_label_options: The label options (label text, label visibility and sort Icon visibility) of a box plot category.
            :param field_wells: The field wells of the visual.
            :param legend: ``CfnDashboard.BoxPlotChartConfigurationProperty.Legend``.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param primary_y_axis_label_options: The label options (label text, label visibility and sort icon visibility) of a box plot value.
            :param reference_lines: The reference line setup of the visual.
            :param sort_configuration: The sort configuration of a ``BoxPlotVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                box_plot_chart_configuration_property = quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                    box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                        all_data_points_visibility="allDataPointsVisibility",
                        outlier_visibility="outlierVisibility",
                        style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                            fill_style="fillStyle"
                        )
                    ),
                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                        box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                            page_number=123,
                            page_size=123
                        )
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7edf4fbf2bc6783bdd20fc27acf3389eca3a600449b73d15934a83c7eeb5ff44)
                check_type(argname="argument box_plot_options", value=box_plot_options, expected_type=type_hints["box_plot_options"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_options is not None:
                self._values["box_plot_options"] = box_plot_options
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def box_plot_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotOptionsProperty"]]:
            '''The box plot chart options for a box plot visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-boxplotoptions
            '''
            result = self._values.get("box_plot_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotOptionsProperty"]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort Icon visibility) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]]:
            '''``CfnDashboard.BoxPlotChartConfigurationProperty.Legend``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) of a box plot value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineProperty"]]]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotSortConfigurationProperty"]]:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BoxPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_aggregated_field_wells": "boxPlotAggregatedFieldWells",
        },
    )
    class BoxPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            box_plot_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BoxPlotAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``BoxPlotVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param box_plot_aggregated_field_wells: The aggregated field wells of a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_field_wells_property = quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                    box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e37caed209193c1d3e435d4bff8b18bdab1e8e6c75403b7528f575eb186b6efc)
                check_type(argname="argument box_plot_aggregated_field_wells", value=box_plot_aggregated_field_wells, expected_type=type_hints["box_plot_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_aggregated_field_wells is not None:
                self._values["box_plot_aggregated_field_wells"] = box_plot_aggregated_field_wells

        @builtins.property
        def box_plot_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotfieldwells.html#cfn-quicksight-dashboard-boxplotfieldwells-boxplotaggregatedfieldwells
            '''
            result = self._values.get("box_plot_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BoxPlotOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "all_data_points_visibility": "allDataPointsVisibility",
            "outlier_visibility": "outlierVisibility",
            "style_options": "styleOptions",
        },
    )
    class BoxPlotOptionsProperty:
        def __init__(
            self,
            *,
            all_data_points_visibility: typing.Optional[builtins.str] = None,
            outlier_visibility: typing.Optional[builtins.str] = None,
            style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BoxPlotStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options of a box plot visual.

            :param all_data_points_visibility: Determines the visibility of all data points of the box plot.
            :param outlier_visibility: Determines the visibility of the outlier in a box plot.
            :param style_options: The style options of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_options_property = quicksight.CfnDashboard.BoxPlotOptionsProperty(
                    all_data_points_visibility="allDataPointsVisibility",
                    outlier_visibility="outlierVisibility",
                    style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                        fill_style="fillStyle"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cb0333bbaf418cd72dc35b227b6952ca982091e1666e3fc23c6d7838f6b855a7)
                check_type(argname="argument all_data_points_visibility", value=all_data_points_visibility, expected_type=type_hints["all_data_points_visibility"])
                check_type(argname="argument outlier_visibility", value=outlier_visibility, expected_type=type_hints["outlier_visibility"])
                check_type(argname="argument style_options", value=style_options, expected_type=type_hints["style_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if all_data_points_visibility is not None:
                self._values["all_data_points_visibility"] = all_data_points_visibility
            if outlier_visibility is not None:
                self._values["outlier_visibility"] = outlier_visibility
            if style_options is not None:
                self._values["style_options"] = style_options

        @builtins.property
        def all_data_points_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of all data points of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-alldatapointsvisibility
            '''
            result = self._values.get("all_data_points_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def outlier_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the outlier in a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-outliervisibility
            '''
            result = self._values.get("outlier_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotStyleOptionsProperty"]]:
            '''The style options of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-styleoptions
            '''
            result = self._values.get("style_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotStyleOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BoxPlotSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_sort": "categorySort",
            "pagination_configuration": "paginationConfiguration",
        },
    )
    class BoxPlotSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            pagination_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :param category_sort: The sort configuration of a group by fields.
            :param pagination_configuration: The pagination configuration of a table visual or box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_sort_configuration_property = quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__31960feb76515d746b202b901ec437514a07b59746c45a6b59635df52989b415)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of a group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html#cfn-quicksight-dashboard-boxplotsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PaginationConfigurationProperty"]]:
            '''The pagination configuration of a table visual or box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html#cfn-quicksight-dashboard-boxplotsortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PaginationConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BoxPlotStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"fill_style": "fillStyle"},
    )
    class BoxPlotStyleOptionsProperty:
        def __init__(self, *, fill_style: typing.Optional[builtins.str] = None) -> None:
            '''The style options of the box plot.

            :param fill_style: The fill styles (solid, transparent) of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_style_options_property = quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                    fill_style="fillStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e3237fe0e8e28524f2700b41ce7f8fdb33da5683f603d9fc6e0ac3bf8f61631f)
                check_type(argname="argument fill_style", value=fill_style, expected_type=type_hints["fill_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if fill_style is not None:
                self._values["fill_style"] = fill_style

        @builtins.property
        def fill_style(self) -> typing.Optional[builtins.str]:
            '''The fill styles (solid, transparent) of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotstyleoptions.html#cfn-quicksight-dashboard-boxplotstyleoptions-fillstyle
            '''
            result = self._values.get("fill_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.BoxPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BoxPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BoxPlotChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                box_plot_visual_property = quicksight.CfnDashboard.BoxPlotVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                        box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                            all_data_points_visibility="allDataPointsVisibility",
                            outlier_visibility="outlierVisibility",
                            style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                                fill_style="fillStyle"
                            )
                        ),
                        category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                            box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                            data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                page_number=123,
                                page_size=123
                            )
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ea4f97a97a8f3ae36006d62df66b00cbf69200853fd0d5618bdb209c49a24d3)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CalculatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "expression": "expression",
            "name": "name",
        },
    )
    class CalculatedFieldProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            expression: builtins.str,
            name: builtins.str,
        ) -> None:
            '''The calculated field of an analysis.

            :param data_set_identifier: The data set that is used in this calculated field.
            :param expression: The expression of the calculated field.
            :param name: The name of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                calculated_field_property = quicksight.CfnDashboard.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__40979e8c9cdeac16737f8670530c28ca7fcabe1533ada73a6c4b3fb5fb9a8e16)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "expression": expression,
                "name": name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in this calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CalculatedMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "field_id": "fieldId"},
    )
    class CalculatedMeasureFieldProperty:
        def __init__(self, *, expression: builtins.str, field_id: builtins.str) -> None:
            '''The table calculation measure field for pivot tables.

            :param expression: The expression in the table calculation.
            :param field_id: The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                calculated_measure_field_property = quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                    expression="expression",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cc88f8639ceab7dd50c507deb39c7a07aa2682f8d0efa0556d33afd84758b9cd)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "field_id": field_id,
            }

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression in the table calculation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html#cfn-quicksight-dashboard-calculatedmeasurefield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html#cfn-quicksight-dashboard-calculatedmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CascadingControlConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"source_controls": "sourceControls"},
    )
    class CascadingControlConfigurationProperty:
        def __init__(
            self,
            *,
            source_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CascadingControlSourceProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :param source_controls: A list of source controls that determine the values that are used in the current control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                cascading_control_configuration_property = quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        source_sheet_control_id="sourceSheetControlId"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1439ea63ce3691189a4288d7ed64470688c91daafa8a1e847c2926ccca6b5961)
                check_type(argname="argument source_controls", value=source_controls, expected_type=type_hints["source_controls"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_controls is not None:
                self._values["source_controls"] = source_controls

        @builtins.property
        def source_controls(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CascadingControlSourceProperty"]]]]:
            '''A list of source controls that determine the values that are used in the current control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolconfiguration.html#cfn-quicksight-dashboard-cascadingcontrolconfiguration-sourcecontrols
            '''
            result = self._values.get("source_controls")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CascadingControlSourceProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CascadingControlSourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_to_match": "columnToMatch",
            "source_sheet_control_id": "sourceSheetControlId",
        },
    )
    class CascadingControlSourceProperty:
        def __init__(
            self,
            *,
            column_to_match: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_sheet_control_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The source controls that are used in a ``CascadingControlConfiguration`` .

            :param column_to_match: The column identifier that determines which column to look up for the source sheet control.
            :param source_sheet_control_id: The source sheet control ID of a ``CascadingControlSource`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                cascading_control_source_property = quicksight.CfnDashboard.CascadingControlSourceProperty(
                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    source_sheet_control_id="sourceSheetControlId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__66f4b3a56eea4e90ccaab827f528c077cc4b860a21abcb8ec4eeae10c645e8a5)
                check_type(argname="argument column_to_match", value=column_to_match, expected_type=type_hints["column_to_match"])
                check_type(argname="argument source_sheet_control_id", value=source_sheet_control_id, expected_type=type_hints["source_sheet_control_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_to_match is not None:
                self._values["column_to_match"] = column_to_match
            if source_sheet_control_id is not None:
                self._values["source_sheet_control_id"] = source_sheet_control_id

        @builtins.property
        def column_to_match(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]]:
            '''The column identifier that determines which column to look up for the source sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html#cfn-quicksight-dashboard-cascadingcontrolsource-columntomatch
            '''
            result = self._values.get("column_to_match")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]], result)

        @builtins.property
        def source_sheet_control_id(self) -> typing.Optional[builtins.str]:
            '''The source sheet control ID of a ``CascadingControlSource`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html#cfn-quicksight-dashboard-cascadingcontrolsource-sourcesheetcontrolid
            '''
            result = self._values.get("source_sheet_control_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlSourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CategoricalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class CategoricalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with categorical type columns..

            :param column: The column that is used in the ``CategoricalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                categorical_dimension_field_property = quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f5221a7fa4fa42dae1139f03e97e085b67603c445c21d33fcc970a54ccc26ca)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``CategoricalDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CategoricalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class CategoricalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with categorical type columns.

            :param column: The column that is used in the ``CategoricalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                categorical_measure_field_property = quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f17c2e15254a21d2b673ea34b163a218eaae0c54a28013185a7023fbc5a435c8)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``CategoricalMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CategoryDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"category_values": "categoryValues", "column": "column"},
    )
    class CategoryDrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_values: typing.Sequence[builtins.str],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The numeric equality type drill down filter.

            :param category_values: A list of the string inputs that are the values of the category drill down filter.
            :param column: The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                category_drill_down_filter_property = quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                    category_values=["categoryValues"],
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2276e4d4c34144ac6579f9743c1c47706ba807930568f1be786a950764c7e002)
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category_values": category_values,
                "column": column,
            }

        @builtins.property
        def category_values(self) -> typing.List[builtins.str]:
            '''A list of the string inputs that are the values of the category drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html#cfn-quicksight-dashboard-categorydrilldownfilter-categoryvalues
            '''
            result = self._values.get("category_values")
            assert result is not None, "Required property 'category_values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html#cfn-quicksight-dashboard-categorydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CategoryFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_filter_configuration": "customFilterConfiguration",
            "custom_filter_list_configuration": "customFilterListConfiguration",
            "filter_list_configuration": "filterListConfiguration",
        },
    )
    class CategoryFilterConfigurationProperty:
        def __init__(
            self,
            *,
            custom_filter_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CustomFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_filter_list_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CustomFilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filter_list_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``CategoryFilter`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_filter_configuration: A custom filter that filters based on a single value. This filter can be partially matched.
            :param custom_filter_list_configuration: A list of custom filter values. In the Amazon QuickSight console, this filter type is called a custom filter list.
            :param filter_list_configuration: A list of filter configurations. In the Amazon QuickSight console, this filter type is called a filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                category_filter_configuration_property = quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                    custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_value="categoryValue",
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions"
                    ),
                    custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    ),
                    filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                        match_operator="matchOperator",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b7a0a159840618cc8df488aef2f7cfcfe7777161653c7c63d242786ce4251a07)
                check_type(argname="argument custom_filter_configuration", value=custom_filter_configuration, expected_type=type_hints["custom_filter_configuration"])
                check_type(argname="argument custom_filter_list_configuration", value=custom_filter_list_configuration, expected_type=type_hints["custom_filter_list_configuration"])
                check_type(argname="argument filter_list_configuration", value=filter_list_configuration, expected_type=type_hints["filter_list_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_filter_configuration is not None:
                self._values["custom_filter_configuration"] = custom_filter_configuration
            if custom_filter_list_configuration is not None:
                self._values["custom_filter_list_configuration"] = custom_filter_list_configuration
            if filter_list_configuration is not None:
                self._values["filter_list_configuration"] = filter_list_configuration

        @builtins.property
        def custom_filter_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomFilterConfigurationProperty"]]:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-customfilterconfiguration
            '''
            result = self._values.get("custom_filter_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomFilterConfigurationProperty"]], result)

        @builtins.property
        def custom_filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomFilterListConfigurationProperty"]]:
            '''A list of custom filter values.

            In the Amazon QuickSight console, this filter type is called a custom filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-customfilterlistconfiguration
            '''
            result = self._values.get("custom_filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomFilterListConfigurationProperty"]], result)

        @builtins.property
        def filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterListConfigurationProperty"]]:
            '''A list of filter configurations.

            In the Amazon QuickSight console, this filter type is called a filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-filterlistconfiguration
            '''
            result = self._values.get("filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterListConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CategoryFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "configuration": "configuration",
            "filter_id": "filterId",
        },
    )
    class CategoryFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CategoryFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
        ) -> None:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :param column: The column that the filter is applied to.
            :param configuration: The configuration for a ``CategoryFilter`` .
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                category_filter_property = quicksight.CfnDashboard.CategoryFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                        custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_value="categoryValue",
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions"
                        ),
                        custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        ),
                        filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                            match_operator="matchOperator",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        )
                    ),
                    filter_id="filterId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b36b9996c27d036a2e2fa590d1e67d3b6f5cd2d8ae763fd56821ebee7ae5639e)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "configuration": configuration,
                "filter_id": filter_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CategoryFilterConfigurationProperty"]:
            '''The configuration for a ``CategoryFilter`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CategoryFilterConfigurationProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ChartAxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_label_options": "axisLabelOptions",
            "sort_icon_visibility": "sortIconVisibility",
            "visibility": "visibility",
        },
    )
    class ChartAxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sort_icon_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options for an axis on a chart.

            :param axis_label_options: The label options for a chart axis.
            :param sort_icon_visibility: The visibility configuration of the sort icon on a chart's axis label.
            :param visibility: The visibility of an axis label on a chart. Choose one of the following options:. - ``VISIBLE`` : Shows the axis. - ``HIDDEN`` : Hides the axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                chart_axis_label_options_property = quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId"
                        ),
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        )
                    )],
                    sort_icon_visibility="sortIconVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9eed731152875748ace7ed453a4014d7cc2f49964293703c523a63c5166adbb3)
                check_type(argname="argument axis_label_options", value=axis_label_options, expected_type=type_hints["axis_label_options"])
                check_type(argname="argument sort_icon_visibility", value=sort_icon_visibility, expected_type=type_hints["sort_icon_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_label_options is not None:
                self._values["axis_label_options"] = axis_label_options
            if sort_icon_visibility is not None:
                self._values["sort_icon_visibility"] = sort_icon_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisLabelOptionsProperty"]]]]:
            '''The label options for a chart axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-axislabeloptions
            '''
            result = self._values.get("axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisLabelOptionsProperty"]]]], result)

        @builtins.property
        def sort_icon_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the sort icon on a chart's axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-sorticonvisibility
            '''
            result = self._values.get("sort_icon_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an axis label on a chart. Choose one of the following options:.

            - ``VISIBLE`` : Shows the axis.
            - ``HIDDEN`` : Hides the axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ChartAxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ClusterMarkerConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"cluster_marker": "clusterMarker"},
    )
    class ClusterMarkerConfigurationProperty:
        def __init__(
            self,
            *,
            cluster_marker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cluster marker configuration of the geospatial map selected point style.

            :param cluster_marker: The cluster marker that is a part of the cluster marker configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarkerconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                cluster_marker_configuration_property = quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                    cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                        simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e18e75d60cad07a4699d9d9b0dcef4a23b84c9535dc61ee1186d4d40443520e)
                check_type(argname="argument cluster_marker", value=cluster_marker, expected_type=type_hints["cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker is not None:
                self._values["cluster_marker"] = cluster_marker

        @builtins.property
        def cluster_marker(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ClusterMarkerProperty"]]:
            '''The cluster marker that is a part of the cluster marker configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarkerconfiguration.html#cfn-quicksight-dashboard-clustermarkerconfiguration-clustermarker
            '''
            result = self._values.get("cluster_marker")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ClusterMarkerProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"simple_cluster_marker": "simpleClusterMarker"},
    )
    class ClusterMarkerProperty:
        def __init__(
            self,
            *,
            simple_cluster_marker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SimpleClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cluster marker that is a part of the cluster marker configuration.

            :param simple_cluster_marker: The simple cluster marker of the cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                cluster_marker_property = quicksight.CfnDashboard.ClusterMarkerProperty(
                    simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e274be3add0374cff65a72bcc62bb25a2a9c30f337761649644a0d2cead9738e)
                check_type(argname="argument simple_cluster_marker", value=simple_cluster_marker, expected_type=type_hints["simple_cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_cluster_marker is not None:
                self._values["simple_cluster_marker"] = simple_cluster_marker

        @builtins.property
        def simple_cluster_marker(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SimpleClusterMarkerProperty"]]:
            '''The simple cluster marker of the cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarker.html#cfn-quicksight-dashboard-clustermarker-simpleclustermarker
            '''
            result = self._values.get("simple_cluster_marker")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SimpleClusterMarkerProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ColorScaleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_fill_type": "colorFillType",
            "colors": "colors",
            "null_value_color": "nullValueColor",
        },
    )
    class ColorScaleProperty:
        def __init__(
            self,
            *,
            color_fill_type: builtins.str,
            colors: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataColorProperty", typing.Dict[builtins.str, typing.Any]]]]],
            null_value_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the color scale that is applied to the visual.

            :param color_fill_type: Determines the color fill type.
            :param colors: Determines the list of colors that are applied to the visual.
            :param null_value_color: Determines the color that is applied to null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                color_scale_property = quicksight.CfnDashboard.ColorScaleProperty(
                    color_fill_type="colorFillType",
                    colors=[quicksight.CfnDashboard.DataColorProperty(
                        color="color",
                        data_value=123
                    )],
                
                    # the properties below are optional
                    null_value_color=quicksight.CfnDashboard.DataColorProperty(
                        color="color",
                        data_value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__578103127e1c7b8890cc12c174614c6ffac547207d8786af69ec235da644631a)
                check_type(argname="argument color_fill_type", value=color_fill_type, expected_type=type_hints["color_fill_type"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument null_value_color", value=null_value_color, expected_type=type_hints["null_value_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color_fill_type": color_fill_type,
                "colors": colors,
            }
            if null_value_color is not None:
                self._values["null_value_color"] = null_value_color

        @builtins.property
        def color_fill_type(self) -> builtins.str:
            '''Determines the color fill type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-colorfilltype
            '''
            result = self._values.get("color_fill_type")
            assert result is not None, "Required property 'color_fill_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataColorProperty"]]]:
            '''Determines the list of colors that are applied to the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-colors
            '''
            result = self._values.get("colors")
            assert result is not None, "Required property 'colors' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataColorProperty"]]], result)

        @builtins.property
        def null_value_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataColorProperty"]]:
            '''Determines the color that is applied to null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-nullvaluecolor
            '''
            result = self._values.get("null_value_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ColorsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_colors": "customColors"},
    )
    class ColorsConfigurationProperty:
        def __init__(
            self,
            *,
            custom_colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CustomColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''
            :param custom_colors: ``CfnDashboard.ColorsConfigurationProperty.CustomColors``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                colors_configuration_property = quicksight.CfnDashboard.ColorsConfigurationProperty(
                    custom_colors=[quicksight.CfnDashboard.CustomColorProperty(
                        color="color",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        special_value="specialValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc1dfa396a24533c6e375d73df639a9191b10290a39bff6de23ae9fab340f44f)
                check_type(argname="argument custom_colors", value=custom_colors, expected_type=type_hints["custom_colors"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_colors is not None:
                self._values["custom_colors"] = custom_colors

        @builtins.property
        def custom_colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomColorProperty"]]]]:
            '''``CfnDashboard.ColorsConfigurationProperty.CustomColors``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorsconfiguration.html#cfn-quicksight-dashboard-colorsconfiguration-customcolors
            '''
            result = self._values.get("custom_colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ColumnConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "colors_configuration": "colorsConfiguration",
            "format_configuration": "formatConfiguration",
            "role": "role",
        },
    )
    class ColumnConfigurationProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            colors_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColorsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            role: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The general configuration of a column.

            :param column: The column.
            :param colors_configuration: ``CfnDashboard.ColumnConfigurationProperty.ColorsConfiguration``.
            :param format_configuration: The format configuration of a column.
            :param role: The role of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_configuration_property = quicksight.CfnDashboard.ColumnConfigurationProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    colors_configuration=quicksight.CfnDashboard.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnDashboard.CustomColorProperty(
                            color="color",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ca3a7a72254631bb4da834d679c8b33ee3731b0c53f832263db5fca308438df5)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument colors_configuration", value=colors_configuration, expected_type=type_hints["colors_configuration"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if colors_configuration is not None:
                self._values["colors_configuration"] = colors_configuration
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def colors_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColorsConfigurationProperty"]]:
            '''``CfnDashboard.ColumnConfigurationProperty.ColorsConfiguration``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-colorsconfiguration
            '''
            result = self._values.get("colors_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColorsConfigurationProperty"]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FormatConfigurationProperty"]]:
            '''The format configuration of a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FormatConfigurationProperty"]], result)

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ColumnHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_hierarchy": "dateTimeHierarchy",
            "explicit_hierarchy": "explicitHierarchy",
            "predefined_hierarchy": "predefinedHierarchy",
        },
    )
    class ColumnHierarchyProperty:
        def __init__(
            self,
            *,
            date_time_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DateTimeHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            explicit_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ExplicitHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            predefined_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PredefinedHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields for a visual element.

            :param date_time_hierarchy: The option that determines the hierarchy of any ``DateTime`` fields.
            :param explicit_hierarchy: The option that determines the hierarchy of the fields that are built within a visual's field wells. These fields can't be duplicated to other visuals.
            :param predefined_hierarchy: The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_hierarchy_property = quicksight.CfnDashboard.ColumnHierarchyProperty(
                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__496629e1b1f0fdbb3e1be123328776a0f6de6733f0137e37dc963e5d369b4782)
                check_type(argname="argument date_time_hierarchy", value=date_time_hierarchy, expected_type=type_hints["date_time_hierarchy"])
                check_type(argname="argument explicit_hierarchy", value=explicit_hierarchy, expected_type=type_hints["explicit_hierarchy"])
                check_type(argname="argument predefined_hierarchy", value=predefined_hierarchy, expected_type=type_hints["predefined_hierarchy"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_hierarchy is not None:
                self._values["date_time_hierarchy"] = date_time_hierarchy
            if explicit_hierarchy is not None:
                self._values["explicit_hierarchy"] = explicit_hierarchy
            if predefined_hierarchy is not None:
                self._values["predefined_hierarchy"] = predefined_hierarchy

        @builtins.property
        def date_time_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeHierarchyProperty"]]:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-datetimehierarchy
            '''
            result = self._values.get("date_time_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeHierarchyProperty"]], result)

        @builtins.property
        def explicit_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ExplicitHierarchyProperty"]]:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-explicithierarchy
            '''
            result = self._values.get("explicit_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ExplicitHierarchyProperty"]], result)

        @builtins.property
        def predefined_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PredefinedHierarchyProperty"]]:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-predefinedhierarchy
            '''
            result = self._values.get("predefined_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PredefinedHierarchyProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ColumnIdentifierProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class ColumnIdentifierProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            data_set_identifier: builtins.str,
        ) -> None:
            '''A column of a data set.

            :param column_name: The name of the column.
            :param data_set_identifier: The data set that the column belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_identifier_property = quicksight.CfnDashboard.ColumnIdentifierProperty(
                    column_name="columnName",
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0aa9c07b3f5dcb8eeacf6fa5d12dd6b85f9276887b79cb179cf98920b5cae871)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "data_set_identifier": data_set_identifier,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The name of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html#cfn-quicksight-dashboard-columnidentifier-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that the column belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html#cfn-quicksight-dashboard-columnidentifier-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnIdentifierProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ColumnSortProperty",
        jsii_struct_bases=[],
        name_mapping={
            "direction": "direction",
            "sort_by": "sortBy",
            "aggregation_function": "aggregationFunction",
        },
    )
    class ColumnSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_by: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort configuration for a column that is not used in a field well.

            :param direction: The sort direction.
            :param sort_by: ``CfnDashboard.ColumnSortProperty.SortBy``.
            :param aggregation_function: The aggregation function that is defined in the column sort.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_sort_property = quicksight.CfnDashboard.ColumnSortProperty(
                    direction="direction",
                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__80fc478453e48434aedae4865927b3718b81b14697a93359c42ed8241af37efa)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_by": sort_by,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''``CfnDashboard.ColumnSortProperty.SortBy``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationFunctionProperty"]]:
            '''The aggregation function that is defined in the column sort.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ColumnTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "aggregation": "aggregation",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class ColumnTooltipItemProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the columns that are not part of a field well.

            :param column: The target column of the tooltip item.
            :param aggregation: The aggregation function of the column tooltip item.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_tooltip_item_property = quicksight.CfnDashboard.ColumnTooltipItemProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__37918655058dcc7bc7b4e254d2e3cf731b56ba5694484c14bd673cf42f4e5cf2)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The target column of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def aggregation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationFunctionProperty"]]:
            '''The aggregation function of the column tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationFunctionProperty"]], result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_values": "barValues",
            "category": "category",
            "colors": "colors",
            "line_values": "lineValues",
        },
    )
    class ComboChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            line_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a combo chart.

            :param bar_values: The aggregated ``BarValues`` field well of a combo chart.
            :param category: The aggregated category field wells of a combo chart.
            :param colors: The aggregated colors field well of a combo chart.
            :param line_values: The aggregated ``LineValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                combo_chart_aggregated_field_wells_property = quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                    bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9617a32a98e261e8b54e5face66386ac80e746775c9376357efd1a7e6a6f7aa9)
                check_type(argname="argument bar_values", value=bar_values, expected_type=type_hints["bar_values"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument line_values", value=line_values, expected_type=type_hints["line_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_values is not None:
                self._values["bar_values"] = bar_values
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if line_values is not None:
                self._values["line_values"] = line_values

        @builtins.property
        def bar_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The aggregated ``BarValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-barvalues
            '''
            result = self._values.get("bar_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The aggregated category field wells of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The aggregated colors field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def line_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The aggregated ``LineValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-linevalues
            '''
            result = self._values.get("line_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ComboChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_data_labels": "barDataLabels",
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "line_data_labels": "lineDataLabels",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class ComboChartConfigurationProperty:
        def __init__(
            self,
            *,
            bar_data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ComboChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            line_data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ComboChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``ComboChartVisual`` .

            :param bar_data_labels: The options that determine if visual data labels are displayed. The data label options for a bar in a combo chart.
            :param bars_arrangement: Determines the bar arrangement in a combo chart. The following are valid values in this structure:. - ``CLUSTERED`` : For clustered bar combo charts. - ``STACKED`` : For stacked bar combo charts. - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.
            :param category_axis: The category axis of a combo chart.
            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
            :param color_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param line_data_labels: The options that determine if visual data labels are displayed. The data label options for a line in a combo chart.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
            :param primary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
            :param reference_lines: The reference line setup of the visual.
            :param secondary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
            :param secondary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
            :param sort_configuration: The sort configuration of a ``ComboChartVisual`` .
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                combo_chart_configuration_property = quicksight.CfnDashboard.ComboChartConfigurationProperty(
                    bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    bars_arrangement="barsArrangement",
                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                        combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                            bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cc7ce369d810a32b532c61cda467acaa4576193d452b007dcdde2b298696f73c)
                check_type(argname="argument bar_data_labels", value=bar_data_labels, expected_type=type_hints["bar_data_labels"])
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument line_data_labels", value=line_data_labels, expected_type=type_hints["line_data_labels"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_data_labels is not None:
                self._values["bar_data_labels"] = bar_data_labels
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if line_data_labels is not None:
                self._values["line_data_labels"] = line_data_labels
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bar_data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a bar in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-bardatalabels
            '''
            result = self._values.get("bar_data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the bar arrangement in a combo chart. The following are valid values in this structure:.

            - ``CLUSTERED`` : For clustered bar combo charts.
            - ``STACKED`` : For stacked bar combo charts.
            - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The category axis of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComboChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComboChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def line_data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a line in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-linedatalabels
            '''
            result = self._values.get("line_data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineProperty"]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComboChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``ComboChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComboChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ComboChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "combo_chart_aggregated_field_wells": "comboChartAggregatedFieldWells",
        },
    )
    class ComboChartFieldWellsProperty:
        def __init__(
            self,
            *,
            combo_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ComboChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of the visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param combo_chart_aggregated_field_wells: The aggregated field wells of a combo chart. Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                combo_chart_field_wells_property = quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                    combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                        bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1bf693ad40ba36ed350932833aba32367b564d085fe7b09cc4e6cf1c1e20e546)
                check_type(argname="argument combo_chart_aggregated_field_wells", value=combo_chart_aggregated_field_wells, expected_type=type_hints["combo_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if combo_chart_aggregated_field_wells is not None:
                self._values["combo_chart_aggregated_field_wells"] = combo_chart_aggregated_field_wells

        @builtins.property
        def combo_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComboChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a combo chart.

            Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartfieldwells.html#cfn-quicksight-dashboard-combochartfieldwells-combochartaggregatedfieldwells
            '''
            result = self._values.get("combo_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComboChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ComboChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class ComboChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``ComboChartVisual`` .

            :param category_items_limit: The item limit configuration for the category field well of a combo chart.
            :param category_sort: The sort configuration of the category field well in a combo chart.
            :param color_items_limit: The item limit configuration of the color field well in a combo chart.
            :param color_sort: The sort configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                combo_chart_sort_configuration_property = quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6158a9025fa3c388fe8dce90ca10cd5081067b2986f9c803a478135e0f77a54e)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The item limit configuration for the category field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The item limit configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ComboChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ComboChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ComboChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A combo chart.

            The ``ComboChartVisual`` includes stacked bar combo charts and clustered bar combo charts

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                combo_chart_visual_property = quicksight.CfnDashboard.ComboChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.ComboChartConfigurationProperty(
                        bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        bars_arrangement="barsArrangement",
                        category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                            combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                                bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                            data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ba715d9ec79f63de433c29beefe15e0e8df42d7f0138d0c02256460702f9374c)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComboChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComboChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ComparisonConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison_format": "comparisonFormat",
            "comparison_method": "comparisonMethod",
        },
    )
    class ComparisonConfigurationProperty:
        def __init__(
            self,
            *,
            comparison_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ComparisonFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison_method: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The comparison display configuration of a KPI or gauge chart.

            :param comparison_format: The format of the comparison.
            :param comparison_method: The method of the comparison. Choose from the following options:. - ``DIFFERENCE`` - ``PERCENT_DIFFERENCE`` - ``PERCENT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                comparison_configuration_property = quicksight.CfnDashboard.ComparisonConfigurationProperty(
                    comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    comparison_method="comparisonMethod"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c2ba740c3f6d8a30309ecca6ef21fce583dbb520f85fca0c6d2df2bbd05d73dd)
                check_type(argname="argument comparison_format", value=comparison_format, expected_type=type_hints["comparison_format"])
                check_type(argname="argument comparison_method", value=comparison_method, expected_type=type_hints["comparison_method"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison_format is not None:
                self._values["comparison_format"] = comparison_format
            if comparison_method is not None:
                self._values["comparison_method"] = comparison_method

        @builtins.property
        def comparison_format(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComparisonFormatConfigurationProperty"]]:
            '''The format of the comparison.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html#cfn-quicksight-dashboard-comparisonconfiguration-comparisonformat
            '''
            result = self._values.get("comparison_format")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComparisonFormatConfigurationProperty"]], result)

        @builtins.property
        def comparison_method(self) -> typing.Optional[builtins.str]:
            '''The method of the comparison. Choose from the following options:.

            - ``DIFFERENCE``
            - ``PERCENT_DIFFERENCE``
            - ``PERCENT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html#cfn-quicksight-dashboard-comparisonconfiguration-comparisonmethod
            '''
            result = self._values.get("comparison_method")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ComparisonFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class ComparisonFormatConfigurationProperty:
        def __init__(
            self,
            *,
            number_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The format of the comparison.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param number_display_format_configuration: The number display format.
            :param percentage_display_format_configuration: The percentage display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                comparison_format_configuration_property = quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2981421ee9518586342dde9a3fb34a59050f74d484b068ba3abb41b9939146ad)
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumberDisplayFormatConfigurationProperty"]]:
            '''The number display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html#cfn-quicksight-dashboard-comparisonformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumberDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PercentageDisplayFormatConfigurationProperty"]]:
            '''The percentage display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html#cfn-quicksight-dashboard-comparisonformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PercentageDisplayFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast": "forecast",
            "growth_rate": "growthRate",
            "maximum_minimum": "maximumMinimum",
            "metric_comparison": "metricComparison",
            "period_over_period": "periodOverPeriod",
            "period_to_date": "periodToDate",
            "top_bottom_movers": "topBottomMovers",
            "top_bottom_ranked": "topBottomRanked",
            "total_aggregation": "totalAggregation",
            "unique_values": "uniqueValues",
        },
    )
    class ComputationProperty:
        def __init__(
            self,
            *,
            forecast: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ForecastComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            growth_rate: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GrowthRateComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maximum_minimum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MaximumMinimumComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            metric_comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MetricComparisonComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            period_over_period: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PeriodOverPeriodComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            period_to_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PeriodToDateComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_movers: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TopBottomMoversComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_ranked: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TopBottomRankedComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TotalAggregationComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            unique_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.UniqueValuesComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The computation union that is used in an insight visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param forecast: The forecast computation configuration.
            :param growth_rate: The growth rate computation configuration.
            :param maximum_minimum: The maximum and minimum computation configuration.
            :param metric_comparison: The metric comparison computation configuration.
            :param period_over_period: The period over period computation configuration.
            :param period_to_date: The period to ``DataSetIdentifier`` computation configuration.
            :param top_bottom_movers: The top movers and bottom movers computation configuration.
            :param top_bottom_ranked: The top ranked and bottom ranked computation configuration.
            :param total_aggregation: The total aggregation computation configuration.
            :param unique_values: The unique values computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                computation_property = quicksight.CfnDashboard.ComputationProperty(
                    forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        custom_seasonality_value=123,
                        lower_boundary=123,
                        name="name",
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality="seasonality",
                        upper_boundary=123,
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        period_size=123,
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        type="type",
                
                        # the properties below are optional
                        name="name",
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                        computation_id="computationId",
                        from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                        target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name"
                    ),
                    period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        period_time_granularity="periodTimeGranularity",
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        type="type",
                
                        # the properties below are optional
                        mover_size=123,
                        name="name",
                        sort_order="sortOrder",
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                        type="type",
                
                        # the properties below are optional
                        name="name",
                        result_size=123,
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                        computation_id="computationId",
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                
                        # the properties below are optional
                        name="name"
                    ),
                    unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                
                        # the properties below are optional
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__db319162dc46a72097676ed463ee68b1b2d5a29e87e419337b599da7c81e2462)
                check_type(argname="argument forecast", value=forecast, expected_type=type_hints["forecast"])
                check_type(argname="argument growth_rate", value=growth_rate, expected_type=type_hints["growth_rate"])
                check_type(argname="argument maximum_minimum", value=maximum_minimum, expected_type=type_hints["maximum_minimum"])
                check_type(argname="argument metric_comparison", value=metric_comparison, expected_type=type_hints["metric_comparison"])
                check_type(argname="argument period_over_period", value=period_over_period, expected_type=type_hints["period_over_period"])
                check_type(argname="argument period_to_date", value=period_to_date, expected_type=type_hints["period_to_date"])
                check_type(argname="argument top_bottom_movers", value=top_bottom_movers, expected_type=type_hints["top_bottom_movers"])
                check_type(argname="argument top_bottom_ranked", value=top_bottom_ranked, expected_type=type_hints["top_bottom_ranked"])
                check_type(argname="argument total_aggregation", value=total_aggregation, expected_type=type_hints["total_aggregation"])
                check_type(argname="argument unique_values", value=unique_values, expected_type=type_hints["unique_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast is not None:
                self._values["forecast"] = forecast
            if growth_rate is not None:
                self._values["growth_rate"] = growth_rate
            if maximum_minimum is not None:
                self._values["maximum_minimum"] = maximum_minimum
            if metric_comparison is not None:
                self._values["metric_comparison"] = metric_comparison
            if period_over_period is not None:
                self._values["period_over_period"] = period_over_period
            if period_to_date is not None:
                self._values["period_to_date"] = period_to_date
            if top_bottom_movers is not None:
                self._values["top_bottom_movers"] = top_bottom_movers
            if top_bottom_ranked is not None:
                self._values["top_bottom_ranked"] = top_bottom_ranked
            if total_aggregation is not None:
                self._values["total_aggregation"] = total_aggregation
            if unique_values is not None:
                self._values["unique_values"] = unique_values

        @builtins.property
        def forecast(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ForecastComputationProperty"]]:
            '''The forecast computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-forecast
            '''
            result = self._values.get("forecast")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ForecastComputationProperty"]], result)

        @builtins.property
        def growth_rate(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GrowthRateComputationProperty"]]:
            '''The growth rate computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-growthrate
            '''
            result = self._values.get("growth_rate")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GrowthRateComputationProperty"]], result)

        @builtins.property
        def maximum_minimum(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MaximumMinimumComputationProperty"]]:
            '''The maximum and minimum computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-maximumminimum
            '''
            result = self._values.get("maximum_minimum")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MaximumMinimumComputationProperty"]], result)

        @builtins.property
        def metric_comparison(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MetricComparisonComputationProperty"]]:
            '''The metric comparison computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-metriccomparison
            '''
            result = self._values.get("metric_comparison")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MetricComparisonComputationProperty"]], result)

        @builtins.property
        def period_over_period(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PeriodOverPeriodComputationProperty"]]:
            '''The period over period computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-periodoverperiod
            '''
            result = self._values.get("period_over_period")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PeriodOverPeriodComputationProperty"]], result)

        @builtins.property
        def period_to_date(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PeriodToDateComputationProperty"]]:
            '''The period to ``DataSetIdentifier`` computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-periodtodate
            '''
            result = self._values.get("period_to_date")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PeriodToDateComputationProperty"]], result)

        @builtins.property
        def top_bottom_movers(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TopBottomMoversComputationProperty"]]:
            '''The top movers and bottom movers computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-topbottommovers
            '''
            result = self._values.get("top_bottom_movers")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TopBottomMoversComputationProperty"]], result)

        @builtins.property
        def top_bottom_ranked(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TopBottomRankedComputationProperty"]]:
            '''The top ranked and bottom ranked computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-topbottomranked
            '''
            result = self._values.get("top_bottom_ranked")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TopBottomRankedComputationProperty"]], result)

        @builtins.property
        def total_aggregation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TotalAggregationComputationProperty"]]:
            '''The total aggregation computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-totalaggregation
            '''
            result = self._values.get("total_aggregation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TotalAggregationComputationProperty"]], result)

        @builtins.property
        def unique_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.UniqueValuesComputationProperty"]]:
            '''The unique values computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-uniquevalues
            '''
            result = self._values.get("unique_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.UniqueValuesComputationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ConditionalFormattingColorProperty",
        jsii_struct_bases=[],
        name_mapping={"gradient": "gradient", "solid": "solid"},
    )
    class ConditionalFormattingColorProperty:
        def __init__(
            self,
            *,
            gradient: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingGradientColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            solid: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingSolidColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for the color.

            :param gradient: Formatting configuration for gradient color.
            :param solid: Formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_color_property = quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                        color=quicksight.CfnDashboard.GradientColorProperty(
                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                gradient_offset=123,
                
                                # the properties below are optional
                                color="color",
                                data_value=123
                            )]
                        ),
                        expression="expression"
                    ),
                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                        expression="expression",
                
                        # the properties below are optional
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__260ce54f3ce2ce5ea2c21ffe9524641f4850fdc312ee472e47c0922fee55ee98)
                check_type(argname="argument gradient", value=gradient, expected_type=type_hints["gradient"])
                check_type(argname="argument solid", value=solid, expected_type=type_hints["solid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if gradient is not None:
                self._values["gradient"] = gradient
            if solid is not None:
                self._values["solid"] = solid

        @builtins.property
        def gradient(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingGradientColorProperty"]]:
            '''Formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html#cfn-quicksight-dashboard-conditionalformattingcolor-gradient
            '''
            result = self._values.get("gradient")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingGradientColorProperty"]], result)

        @builtins.property
        def solid(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingSolidColorProperty"]]:
            '''Formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html#cfn-quicksight-dashboard-conditionalformattingcolor-solid
            '''
            result = self._values.get("solid")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingSolidColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "icon_options": "iconOptions",
            "color": "color",
            "display_configuration": "displayConfiguration",
        },
    )
    class ConditionalFormattingCustomIconConditionProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingCustomIconOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
            color: typing.Optional[builtins.str] = None,
            display_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the custom condition for an icon set.

            :param expression: The expression that determines the condition of the icon set.
            :param icon_options: Custom icon options for an icon set.
            :param color: Determines the color of the icon.
            :param display_configuration: Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_condition_property = quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                    expression="expression",
                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                        icon="icon",
                        unicode_icon="unicodeIcon"
                    ),
                
                    # the properties below are optional
                    color="color",
                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                        icon_display_option="iconDisplayOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c3cce66ca39c7515c5b3267ac039ed1c29e3d1757d212813d179325cb461f20e)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_options", value=icon_options, expected_type=type_hints["icon_options"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument display_configuration", value=display_configuration, expected_type=type_hints["display_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "icon_options": icon_options,
            }
            if color is not None:
                self._values["color"] = color
            if display_configuration is not None:
                self._values["display_configuration"] = display_configuration

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the condition of the icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingCustomIconOptionsProperty"]:
            '''Custom icon options for an icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-iconoptions
            '''
            result = self._values.get("icon_options")
            assert result is not None, "Required property 'icon_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingCustomIconOptionsProperty"], result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty"]]:
            '''Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-displayconfiguration
            '''
            result = self._values.get("display_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconConditionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "unicode_icon": "unicodeIcon"},
    )
    class ConditionalFormattingCustomIconOptionsProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[builtins.str] = None,
            unicode_icon: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Custom icon options for an icon set.

            :param icon: Determines the type of icon.
            :param unicode_icon: Determines the Unicode icon type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_options_property = quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                    icon="icon",
                    unicode_icon="unicodeIcon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__052a4096d4d0e21c8f57b98fd0d557da04d94faa52c23545d0a2856f7b5a0945)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument unicode_icon", value=unicode_icon, expected_type=type_hints["unicode_icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if unicode_icon is not None:
                self._values["unicode_icon"] = unicode_icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''Determines the type of icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html#cfn-quicksight-dashboard-conditionalformattingcustomiconoptions-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def unicode_icon(self) -> typing.Optional[builtins.str]:
            '''Determines the Unicode icon type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html#cfn-quicksight-dashboard-conditionalformattingcustomiconoptions-unicodeicon
            '''
            result = self._values.get("unicode_icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "expression": "expression"},
    )
    class ConditionalFormattingGradientColorProperty:
        def __init__(
            self,
            *,
            color: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GradientColorProperty", typing.Dict[builtins.str, typing.Any]]],
            expression: builtins.str,
        ) -> None:
            '''Formatting configuration for gradient color.

            :param color: Determines the color.
            :param expression: The expression that determines the formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_gradient_color_property = quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                    color=quicksight.CfnDashboard.GradientColorProperty(
                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                            gradient_offset=123,
                
                            # the properties below are optional
                            color="color",
                            data_value=123
                        )]
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ff6de843724ab94345a0c6400bae50fa4a24d937abc2e295119d900f42ceb50e)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "expression": expression,
            }

        @builtins.property
        def color(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GradientColorProperty"]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html#cfn-quicksight-dashboard-conditionalformattinggradientcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GradientColorProperty"], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html#cfn-quicksight-dashboard-conditionalformattinggradientcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingGradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"icon_display_option": "iconDisplayOption"},
    )
    class ConditionalFormattingIconDisplayConfigurationProperty:
        def __init__(
            self,
            *,
            icon_display_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the icon display configuration.

            :param icon_display_option: Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicondisplayconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_icon_display_configuration_property = quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                    icon_display_option="iconDisplayOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__97d862e4a85c50c1139f3ef1f614e6d75da9152be3b519612c05732ed04ea112)
                check_type(argname="argument icon_display_option", value=icon_display_option, expected_type=type_hints["icon_display_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon_display_option is not None:
                self._values["icon_display_option"] = icon_display_option

        @builtins.property
        def icon_display_option(self) -> typing.Optional[builtins.str]:
            '''Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-dashboard-conditionalformattingicondisplayconfiguration-icondisplayoption
            '''
            result = self._values.get("icon_display_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconDisplayConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ConditionalFormattingIconProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_condition": "customCondition", "icon_set": "iconSet"},
    )
    class ConditionalFormattingIconProperty:
        def __init__(
            self,
            *,
            custom_condition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingCustomIconConditionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            icon_set: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingIconSetProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for the icon.

            :param custom_condition: Determines the custom condition for an icon set.
            :param icon_set: Formatting configuration for icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_icon_property = quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                        expression="expression",
                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                            icon="icon",
                            unicode_icon="unicodeIcon"
                        ),
                
                        # the properties below are optional
                        color="color",
                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                            icon_display_option="iconDisplayOption"
                        )
                    ),
                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                        expression="expression",
                
                        # the properties below are optional
                        icon_set_type="iconSetType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2ea9d0e053d178c5f7ed9d43a0578eb1b68a073cc60e7f345d32aba2819024c4)
                check_type(argname="argument custom_condition", value=custom_condition, expected_type=type_hints["custom_condition"])
                check_type(argname="argument icon_set", value=icon_set, expected_type=type_hints["icon_set"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_condition is not None:
                self._values["custom_condition"] = custom_condition
            if icon_set is not None:
                self._values["icon_set"] = icon_set

        @builtins.property
        def custom_condition(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingCustomIconConditionProperty"]]:
            '''Determines the custom condition for an icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html#cfn-quicksight-dashboard-conditionalformattingicon-customcondition
            '''
            result = self._values.get("custom_condition")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingCustomIconConditionProperty"]], result)

        @builtins.property
        def icon_set(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingIconSetProperty"]]:
            '''Formatting configuration for icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html#cfn-quicksight-dashboard-conditionalformattingicon-iconset
            '''
            result = self._values.get("icon_set")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingIconSetProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ConditionalFormattingIconSetProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "icon_set_type": "iconSetType"},
    )
    class ConditionalFormattingIconSetProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_set_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for icon set.

            :param expression: The expression that determines the formatting configuration for the icon set.
            :param icon_set_type: Determines the icon set type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_icon_set_property = quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                    expression="expression",
                
                    # the properties below are optional
                    icon_set_type="iconSetType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4c7c7f3787fcef7aed83073c60cb037202489be2d4d080fe99bd55ec27eb384b)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_set_type", value=icon_set_type, expected_type=type_hints["icon_set_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if icon_set_type is not None:
                self._values["icon_set_type"] = icon_set_type

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for the icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html#cfn-quicksight-dashboard-conditionalformattingiconset-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_set_type(self) -> typing.Optional[builtins.str]:
            '''Determines the icon set type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html#cfn-quicksight-dashboard-conditionalformattingiconset-iconsettype
            '''
            result = self._values.get("icon_set_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconSetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "color": "color"},
    )
    class ConditionalFormattingSolidColorProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for solid color.

            :param expression: The expression that determines the formatting configuration for solid color.
            :param color: Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_solid_color_property = quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                    expression="expression",
                
                    # the properties below are optional
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1eea2a7bbd91bd56ff24fdaf8181c112f785885778422661e33530294c03f57b)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html#cfn-quicksight-dashboard-conditionalformattingsolidcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html#cfn-quicksight-dashboard-conditionalformattingsolidcolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingSolidColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ContributionAnalysisDefaultProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contributor_dimensions": "contributorDimensions",
            "measure_field_id": "measureFieldId",
        },
    )
    class ContributionAnalysisDefaultProperty:
        def __init__(
            self,
            *,
            contributor_dimensions: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            measure_field_id: builtins.str,
        ) -> None:
            '''The contribution analysis visual display for a line, pie, or bar chart.

            :param contributor_dimensions: The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .
            :param measure_field_id: The measure field that is used in the contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                contribution_analysis_default_property = quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    measure_field_id="measureFieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__14d27c350b096a0267c6183664d0a24cfa1d53153e9d6260a5269392208551d0)
                check_type(argname="argument contributor_dimensions", value=contributor_dimensions, expected_type=type_hints["contributor_dimensions"])
                check_type(argname="argument measure_field_id", value=measure_field_id, expected_type=type_hints["measure_field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "contributor_dimensions": contributor_dimensions,
                "measure_field_id": measure_field_id,
            }

        @builtins.property
        def contributor_dimensions(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]]]:
            '''The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html#cfn-quicksight-dashboard-contributionanalysisdefault-contributordimensions
            '''
            result = self._values.get("contributor_dimensions")
            assert result is not None, "Required property 'contributor_dimensions' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def measure_field_id(self) -> builtins.str:
            '''The measure field that is used in the contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html#cfn-quicksight-dashboard-contributionanalysisdefault-measurefieldid
            '''
            result = self._values.get("measure_field_id")
            assert result is not None, "Required property 'measure_field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ContributionAnalysisDefaultProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
            "symbol": "symbol",
        },
    )
    class CurrencyDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
            symbol: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the currency display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value for the currency format.
            :param prefix: Determines the prefix value of the currency format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the currency format.
            :param symbol: Determines the symbol for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                currency_display_format_configuration_property = quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix",
                    symbol="symbol"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0661a7e804c438adf52e32e8ad396f335caabf21ec4f9b9a9f828b5c4bf9a20c)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix
            if symbol is not None:
                self._values["symbol"] = symbol

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the symbol for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CurrencyDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CustomActionFilterOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_fields_configuration": "selectedFieldsConfiguration",
            "target_visuals_configuration": "targetVisualsConfiguration",
        },
    )
    class CustomActionFilterOperationProperty:
        def __init__(
            self,
            *,
            selected_fields_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            target_visuals_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterOperationTargetVisualsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :param selected_fields_configuration: The configuration that chooses the fields to be filtered.
            :param target_visuals_configuration: The configuration that chooses the target visuals to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_action_filter_operation_property = quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                        selected_field_options="selectedFieldOptions",
                        selected_fields=["selectedFields"]
                    ),
                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                            target_visual_options="targetVisualOptions",
                            target_visuals=["targetVisuals"]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__76376d3ffd52c3b6f5ed567c64212552742f93c87c28e01bca215de00143449a)
                check_type(argname="argument selected_fields_configuration", value=selected_fields_configuration, expected_type=type_hints["selected_fields_configuration"])
                check_type(argname="argument target_visuals_configuration", value=target_visuals_configuration, expected_type=type_hints["target_visuals_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "selected_fields_configuration": selected_fields_configuration,
                "target_visuals_configuration": target_visuals_configuration,
            }

        @builtins.property
        def selected_fields_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty"]:
            '''The configuration that chooses the fields to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html#cfn-quicksight-dashboard-customactionfilteroperation-selectedfieldsconfiguration
            '''
            result = self._values.get("selected_fields_configuration")
            assert result is not None, "Required property 'selected_fields_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty"], result)

        @builtins.property
        def target_visuals_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterOperationTargetVisualsConfigurationProperty"]:
            '''The configuration that chooses the target visuals to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html#cfn-quicksight-dashboard-customactionfilteroperation-targetvisualsconfiguration
            '''
            result = self._values.get("target_visuals_configuration")
            assert result is not None, "Required property 'target_visuals_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterOperationTargetVisualsConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionFilterOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CustomActionNavigationOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "local_navigation_configuration": "localNavigationConfiguration",
        },
    )
    class CustomActionNavigationOperationProperty:
        def __init__(
            self,
            *,
            local_navigation_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LocalNavigationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The navigation operation that navigates between different sheets in the same analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param local_navigation_configuration: The configuration that chooses the navigation target.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionnavigationoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_action_navigation_operation_property = quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                        target_sheet_id="targetSheetId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__29a007631b8b5484f10cf756bec18eaae974fbb36b8829e3a528a5707cb4d028)
                check_type(argname="argument local_navigation_configuration", value=local_navigation_configuration, expected_type=type_hints["local_navigation_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if local_navigation_configuration is not None:
                self._values["local_navigation_configuration"] = local_navigation_configuration

        @builtins.property
        def local_navigation_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LocalNavigationConfigurationProperty"]]:
            '''The configuration that chooses the navigation target.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionnavigationoperation.html#cfn-quicksight-dashboard-customactionnavigationoperation-localnavigationconfiguration
            '''
            result = self._values.get("local_navigation_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LocalNavigationConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionNavigationOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CustomActionSetParametersOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_value_configurations": "parameterValueConfigurations",
        },
    )
    class CustomActionSetParametersOperationProperty:
        def __init__(
            self,
            *,
            parameter_value_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SetParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The set parameter operation that sets parameters in custom action.

            :param parameter_value_configurations: The parameter that determines the value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionsetparametersoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_action_set_parameters_operation_property = quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                        destination_parameter_name="destinationParameterName",
                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                    date_time_values=["dateTimeValues"],
                                    decimal_values=[123],
                                    integer_values=[123],
                                    string_values=["stringValues"]
                                ),
                
                                # the properties below are optional
                                include_null_value=False
                            ),
                            select_all_value_options="selectAllValueOptions",
                            source_field="sourceField",
                            source_parameter_name="sourceParameterName"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4a4a779c5b99cec7ab599ea770a1dfd33efcc602795d46631146a620b8c9674a)
                check_type(argname="argument parameter_value_configurations", value=parameter_value_configurations, expected_type=type_hints["parameter_value_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_value_configurations": parameter_value_configurations,
            }

        @builtins.property
        def parameter_value_configurations(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SetParameterValueConfigurationProperty"]]]:
            '''The parameter that determines the value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionsetparametersoperation.html#cfn-quicksight-dashboard-customactionsetparametersoperation-parametervalueconfigurations
            '''
            result = self._values.get("parameter_value_configurations")
            assert result is not None, "Required property 'parameter_value_configurations' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SetParameterValueConfigurationProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionSetParametersOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CustomActionURLOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"url_target": "urlTarget", "url_template": "urlTemplate"},
    )
    class CustomActionURLOperationProperty:
        def __init__(
            self,
            *,
            url_target: builtins.str,
            url_template: builtins.str,
        ) -> None:
            '''The URL operation that opens a link to another webpage.

            :param url_target: The target of the ``CustomActionURLOperation`` . Valid values are defined as follows: - ``NEW_TAB`` : Opens the target URL in a new browser tab. - ``NEW_WINDOW`` : Opens the target URL in a new browser window. - ``SAME_TAB`` : Opens the target URL in the same browser tab.
            :param url_template: THe URL link of the ``CustomActionURLOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_action_uRLOperation_property = quicksight.CfnDashboard.CustomActionURLOperationProperty(
                    url_target="urlTarget",
                    url_template="urlTemplate"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cc23249d6637e0c6c0d438dab26db6ca1dc77dd7820885b6875a10bd43a99e9e)
                check_type(argname="argument url_target", value=url_target, expected_type=type_hints["url_target"])
                check_type(argname="argument url_template", value=url_template, expected_type=type_hints["url_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "url_target": url_target,
                "url_template": url_template,
            }

        @builtins.property
        def url_target(self) -> builtins.str:
            '''The target of the ``CustomActionURLOperation`` .

            Valid values are defined as follows:

            - ``NEW_TAB`` : Opens the target URL in a new browser tab.
            - ``NEW_WINDOW`` : Opens the target URL in a new browser window.
            - ``SAME_TAB`` : Opens the target URL in the same browser tab.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html#cfn-quicksight-dashboard-customactionurloperation-urltarget
            '''
            result = self._values.get("url_target")
            assert result is not None, "Required property 'url_target' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def url_template(self) -> builtins.str:
            '''THe URL link of the ``CustomActionURLOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html#cfn-quicksight-dashboard-customactionurloperation-urltemplate
            '''
            result = self._values.get("url_template")
            assert result is not None, "Required property 'url_template' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionURLOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CustomColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "field_value": "fieldValue",
            "special_value": "specialValue",
        },
    )
    class CustomColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            special_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''
            :param color: ``CfnDashboard.CustomColorProperty.Color``.
            :param field_value: ``CfnDashboard.CustomColorProperty.FieldValue``.
            :param special_value: ``CfnDashboard.CustomColorProperty.SpecialValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_color_property = quicksight.CfnDashboard.CustomColorProperty(
                    color="color",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    special_value="specialValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__baccb380931844a2c5bb6ce153c972b21ef1544e2bed9b24d5de491075f2683c)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument special_value", value=special_value, expected_type=type_hints["special_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if special_value is not None:
                self._values["special_value"] = special_value

        @builtins.property
        def color(self) -> builtins.str:
            '''``CfnDashboard.CustomColorProperty.Color``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''``CfnDashboard.CustomColorProperty.FieldValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def special_value(self) -> typing.Optional[builtins.str]:
            '''``CfnDashboard.CustomColorProperty.SpecialValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-specialvalue
            '''
            result = self._values.get("special_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CustomContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content_type": "contentType",
            "content_url": "contentUrl",
            "image_scaling": "imageScaling",
        },
    )
    class CustomContentConfigurationProperty:
        def __init__(
            self,
            *,
            content_type: typing.Optional[builtins.str] = None,
            content_url: typing.Optional[builtins.str] = None,
            image_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of a ``CustomContentVisual`` .

            :param content_type: The content type of the custom content visual. You can use this to have the visual render as an image.
            :param content_url: The input URL that links to the custom content that you want in the custom visual.
            :param image_scaling: The sizing options for the size of the custom content visual. This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_content_configuration_property = quicksight.CfnDashboard.CustomContentConfigurationProperty(
                    content_type="contentType",
                    content_url="contentUrl",
                    image_scaling="imageScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0bfdaf5bc05511dbabd06e75741140dfa8ae9cd0b83bb8067deb0e6a0be9d9bf)
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument content_url", value=content_url, expected_type=type_hints["content_url"])
                check_type(argname="argument image_scaling", value=image_scaling, expected_type=type_hints["image_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if content_type is not None:
                self._values["content_type"] = content_type
            if content_url is not None:
                self._values["content_url"] = content_url
            if image_scaling is not None:
                self._values["image_scaling"] = image_scaling

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The content type of the custom content visual.

            You can use this to have the visual render as an image.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def content_url(self) -> typing.Optional[builtins.str]:
            '''The input URL that links to the custom content that you want in the custom visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-contenturl
            '''
            result = self._values.get("content_url")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def image_scaling(self) -> typing.Optional[builtins.str]:
            '''The sizing options for the size of the custom content visual.

            This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-imagescaling
            '''
            result = self._values.get("image_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CustomContentVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class CustomContentVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CustomContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used to create the custom content visual. You can't create a visual without a dataset.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``CustomContentVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_content_visual_property = quicksight.CfnDashboard.CustomContentVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.CustomContentConfigurationProperty(
                        content_type="contentType",
                        content_url="contentUrl",
                        image_scaling="imageScaling"
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ed66f89a240e218e0c8c3ba6c9a7d145cc68080d4b9132c0d1e07f2685e6efa8)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used to create the custom content visual.

            You can't create a visual without a dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomContentConfigurationProperty"]]:
            '''The configuration of a ``CustomContentVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomContentConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CustomFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_value": "categoryValue",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_value: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_value: The category value for the filter. This field is mutually exclusive to ``ParameterName`` .
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``CategoryValue`` .
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_filter_configuration_property = quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_value="categoryValue",
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8a310f47ac79e090af0ed23f47fbf50776a7844e4ea84aaa4e0365831e4a8bcc)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_value", value=category_value, expected_type=type_hints["category_value"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_value is not None:
                self._values["category_value"] = category_value
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_value(self) -> typing.Optional[builtins.str]:
            '''The category value for the filter.

            This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-categoryvalue
            '''
            result = self._values.get("category_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``CategoryValue`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CustomFilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of custom filter values.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_filter_list_configuration_property = quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33254ba3130bc49e5f51efc4cb05d1eed4b22c61ae762c05d2ea8f7143f15e95)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CustomNarrativeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"narrative": "narrative"},
    )
    class CustomNarrativeOptionsProperty:
        def __init__(self, *, narrative: builtins.str) -> None:
            '''The custom narrative options.

            :param narrative: The string input of custom narrative.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customnarrativeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_narrative_options_property = quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                    narrative="narrative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aab7040ac5d1962b3e703310059404d17164df0f6d46b805ed54e49d44cf8ba8)
                check_type(argname="argument narrative", value=narrative, expected_type=type_hints["narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "narrative": narrative,
            }

        @builtins.property
        def narrative(self) -> builtins.str:
            '''The string input of custom narrative.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customnarrativeoptions.html#cfn-quicksight-dashboard-customnarrativeoptions-narrative
            '''
            result = self._values.get("narrative")
            assert result is not None, "Required property 'narrative' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomNarrativeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CustomParameterValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_values": "dateTimeValues",
            "decimal_values": "decimalValues",
            "integer_values": "integerValues",
            "string_values": "stringValues",
        },
    )
    class CustomParameterValuesProperty:
        def __init__(
            self,
            *,
            date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            decimal_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
            integer_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
            string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The customized parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_values: A list of datetime-type parameter values.
            :param decimal_values: A list of decimal-type parameter values.
            :param integer_values: A list of integer-type parameter values.
            :param string_values: A list of string-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_parameter_values_property = quicksight.CfnDashboard.CustomParameterValuesProperty(
                    date_time_values=["dateTimeValues"],
                    decimal_values=[123],
                    integer_values=[123],
                    string_values=["stringValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__17abcb30f8053b14584c3eb72e49bb753cac4e323b218f32ab841702d3d988b6)
                check_type(argname="argument date_time_values", value=date_time_values, expected_type=type_hints["date_time_values"])
                check_type(argname="argument decimal_values", value=decimal_values, expected_type=type_hints["decimal_values"])
                check_type(argname="argument integer_values", value=integer_values, expected_type=type_hints["integer_values"])
                check_type(argname="argument string_values", value=string_values, expected_type=type_hints["string_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_values is not None:
                self._values["date_time_values"] = date_time_values
            if decimal_values is not None:
                self._values["decimal_values"] = decimal_values
            if integer_values is not None:
                self._values["integer_values"] = integer_values
            if string_values is not None:
                self._values["string_values"] = string_values

        @builtins.property
        def date_time_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of datetime-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-datetimevalues
            '''
            result = self._values.get("date_time_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def decimal_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]]:
            '''A list of decimal-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-decimalvalues
            '''
            result = self._values.get("decimal_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]], result)

        @builtins.property
        def integer_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]]:
            '''A list of integer-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-integervalues
            '''
            result = self._values.get("integer_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]], result)

        @builtins.property
        def string_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of string-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-stringvalues
            '''
            result = self._values.get("string_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomParameterValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.CustomValuesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values": "customValues",
            "include_null_value": "includeNullValue",
        },
    )
    class CustomValuesConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CustomParameterValuesProperty", typing.Dict[builtins.str, typing.Any]]],
            include_null_value: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
        ) -> None:
            '''The configuration of custom values for the destination parameter in ``DestinationParameterValueConfiguration`` .

            :param custom_values: ``CfnDashboard.CustomValuesConfigurationProperty.CustomValues``.
            :param include_null_value: Includes the null value in custom action parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_values_configuration_property = quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                        date_time_values=["dateTimeValues"],
                        decimal_values=[123],
                        integer_values=[123],
                        string_values=["stringValues"]
                    ),
                
                    # the properties below are optional
                    include_null_value=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ccfaf1e44209400545f10770b059ed57547cb2f9e5caef923da26ae51989523)
                check_type(argname="argument custom_values", value=custom_values, expected_type=type_hints["custom_values"])
                check_type(argname="argument include_null_value", value=include_null_value, expected_type=type_hints["include_null_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_values": custom_values,
            }
            if include_null_value is not None:
                self._values["include_null_value"] = include_null_value

        @builtins.property
        def custom_values(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomParameterValuesProperty"]:
            '''``CfnDashboard.CustomValuesConfigurationProperty.CustomValues``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html#cfn-quicksight-dashboard-customvaluesconfiguration-customvalues
            '''
            result = self._values.get("custom_values")
            assert result is not None, "Required property 'custom_values' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomParameterValuesProperty"], result)

        @builtins.property
        def include_null_value(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Includes the null value in custom action parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html#cfn-quicksight-dashboard-customvaluesconfiguration-includenullvalue
            '''
            result = self._values.get("include_null_value")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomValuesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DashboardErrorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "message": "message",
            "type": "type",
            "violated_entities": "violatedEntities",
        },
    )
    class DashboardErrorProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
            violated_entities: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.EntityProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Dashboard error.

            :param message: Message.
            :param type: Type.
            :param violated_entities: Lists the violated entities that caused the dashboard error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                dashboard_error_property = quicksight.CfnDashboard.DashboardErrorProperty(
                    message="message",
                    type="type",
                    violated_entities=[quicksight.CfnDashboard.EntityProperty(
                        path="path"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fa288d76cf7caed79a8405021a8eb02cf1b19ea9755d0aa77ff4f8afb914214d)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument violated_entities", value=violated_entities, expected_type=type_hints["violated_entities"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type
            if violated_entities is not None:
                self._values["violated_entities"] = violated_entities

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''Message.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def violated_entities(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.EntityProperty"]]]]:
            '''Lists the violated entities that caused the dashboard error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-violatedentities
            '''
            result = self._values.get("violated_entities")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.EntityProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardErrorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DashboardPublishOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "ad_hoc_filtering_option": "adHocFilteringOption",
            "data_point_drill_up_down_option": "dataPointDrillUpDownOption",
            "data_point_menu_label_option": "dataPointMenuLabelOption",
            "data_point_tooltip_option": "dataPointTooltipOption",
            "export_to_csv_option": "exportToCsvOption",
            "export_with_hidden_fields_option": "exportWithHiddenFieldsOption",
            "sheet_controls_option": "sheetControlsOption",
            "sheet_layout_element_maximization_option": "sheetLayoutElementMaximizationOption",
            "visual_axis_sort_option": "visualAxisSortOption",
            "visual_menu_option": "visualMenuOption",
            "visual_publish_options": "visualPublishOptions",
        },
    )
    class DashboardPublishOptionsProperty:
        def __init__(
            self,
            *,
            ad_hoc_filtering_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AdHocFilteringOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_point_drill_up_down_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataPointDrillUpDownOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_point_menu_label_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataPointMenuLabelOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_point_tooltip_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataPointTooltipOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            export_to_csv_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ExportToCSVOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            export_with_hidden_fields_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ExportWithHiddenFieldsOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sheet_controls_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SheetControlsOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sheet_layout_element_maximization_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SheetLayoutElementMaximizationOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_axis_sort_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualAxisSortOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_menu_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualMenuOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_publish_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DashboardVisualPublishOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Dashboard publish options.

            :param ad_hoc_filtering_option: Ad hoc (one-time) filtering option.
            :param data_point_drill_up_down_option: The drill-down options of data points in a dashboard.
            :param data_point_menu_label_option: The data point menu label options of a dashboard.
            :param data_point_tooltip_option: The data point tool tip options of a dashboard.
            :param export_to_csv_option: Export to .csv option.
            :param export_with_hidden_fields_option: Determines if hidden fields are exported with a dashboard.
            :param sheet_controls_option: Sheet controls option.
            :param sheet_layout_element_maximization_option: The sheet layout maximization options of a dashbaord.
            :param visual_axis_sort_option: The axis sort options of a dashboard.
            :param visual_menu_option: The menu options of a visual in a dashboard.
            :param visual_publish_options: The visual publish options of a visual in a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                dashboard_publish_options_property = quicksight.CfnDashboard.DashboardPublishOptionsProperty(
                    ad_hoc_filtering_option=quicksight.CfnDashboard.AdHocFilteringOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_drill_up_down_option=quicksight.CfnDashboard.DataPointDrillUpDownOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_menu_label_option=quicksight.CfnDashboard.DataPointMenuLabelOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_tooltip_option=quicksight.CfnDashboard.DataPointTooltipOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    export_to_csv_option=quicksight.CfnDashboard.ExportToCSVOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    export_with_hidden_fields_option=quicksight.CfnDashboard.ExportWithHiddenFieldsOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    sheet_controls_option=quicksight.CfnDashboard.SheetControlsOptionProperty(
                        visibility_state="visibilityState"
                    ),
                    sheet_layout_element_maximization_option=quicksight.CfnDashboard.SheetLayoutElementMaximizationOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_axis_sort_option=quicksight.CfnDashboard.VisualAxisSortOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_menu_option=quicksight.CfnDashboard.VisualMenuOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_publish_options=quicksight.CfnDashboard.DashboardVisualPublishOptionsProperty(
                        export_hidden_fields_option=quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty(
                            availability_status="availabilityStatus"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4cfc8872e7946f6ede4fe2a4a911fd8bcc79da312a3feaf9d0e0ab0e2935c33a)
                check_type(argname="argument ad_hoc_filtering_option", value=ad_hoc_filtering_option, expected_type=type_hints["ad_hoc_filtering_option"])
                check_type(argname="argument data_point_drill_up_down_option", value=data_point_drill_up_down_option, expected_type=type_hints["data_point_drill_up_down_option"])
                check_type(argname="argument data_point_menu_label_option", value=data_point_menu_label_option, expected_type=type_hints["data_point_menu_label_option"])
                check_type(argname="argument data_point_tooltip_option", value=data_point_tooltip_option, expected_type=type_hints["data_point_tooltip_option"])
                check_type(argname="argument export_to_csv_option", value=export_to_csv_option, expected_type=type_hints["export_to_csv_option"])
                check_type(argname="argument export_with_hidden_fields_option", value=export_with_hidden_fields_option, expected_type=type_hints["export_with_hidden_fields_option"])
                check_type(argname="argument sheet_controls_option", value=sheet_controls_option, expected_type=type_hints["sheet_controls_option"])
                check_type(argname="argument sheet_layout_element_maximization_option", value=sheet_layout_element_maximization_option, expected_type=type_hints["sheet_layout_element_maximization_option"])
                check_type(argname="argument visual_axis_sort_option", value=visual_axis_sort_option, expected_type=type_hints["visual_axis_sort_option"])
                check_type(argname="argument visual_menu_option", value=visual_menu_option, expected_type=type_hints["visual_menu_option"])
                check_type(argname="argument visual_publish_options", value=visual_publish_options, expected_type=type_hints["visual_publish_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if ad_hoc_filtering_option is not None:
                self._values["ad_hoc_filtering_option"] = ad_hoc_filtering_option
            if data_point_drill_up_down_option is not None:
                self._values["data_point_drill_up_down_option"] = data_point_drill_up_down_option
            if data_point_menu_label_option is not None:
                self._values["data_point_menu_label_option"] = data_point_menu_label_option
            if data_point_tooltip_option is not None:
                self._values["data_point_tooltip_option"] = data_point_tooltip_option
            if export_to_csv_option is not None:
                self._values["export_to_csv_option"] = export_to_csv_option
            if export_with_hidden_fields_option is not None:
                self._values["export_with_hidden_fields_option"] = export_with_hidden_fields_option
            if sheet_controls_option is not None:
                self._values["sheet_controls_option"] = sheet_controls_option
            if sheet_layout_element_maximization_option is not None:
                self._values["sheet_layout_element_maximization_option"] = sheet_layout_element_maximization_option
            if visual_axis_sort_option is not None:
                self._values["visual_axis_sort_option"] = visual_axis_sort_option
            if visual_menu_option is not None:
                self._values["visual_menu_option"] = visual_menu_option
            if visual_publish_options is not None:
                self._values["visual_publish_options"] = visual_publish_options

        @builtins.property
        def ad_hoc_filtering_option(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AdHocFilteringOptionProperty"]]:
            '''Ad hoc (one-time) filtering option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-adhocfilteringoption
            '''
            result = self._values.get("ad_hoc_filtering_option")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AdHocFilteringOptionProperty"]], result)

        @builtins.property
        def data_point_drill_up_down_option(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPointDrillUpDownOptionProperty"]]:
            '''The drill-down options of data points in a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointdrillupdownoption
            '''
            result = self._values.get("data_point_drill_up_down_option")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPointDrillUpDownOptionProperty"]], result)

        @builtins.property
        def data_point_menu_label_option(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPointMenuLabelOptionProperty"]]:
            '''The data point menu label options of a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointmenulabeloption
            '''
            result = self._values.get("data_point_menu_label_option")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPointMenuLabelOptionProperty"]], result)

        @builtins.property
        def data_point_tooltip_option(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPointTooltipOptionProperty"]]:
            '''The data point tool tip options of a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointtooltipoption
            '''
            result = self._values.get("data_point_tooltip_option")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPointTooltipOptionProperty"]], result)

        @builtins.property
        def export_to_csv_option(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ExportToCSVOptionProperty"]]:
            '''Export to .csv option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-exporttocsvoption
            '''
            result = self._values.get("export_to_csv_option")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ExportToCSVOptionProperty"]], result)

        @builtins.property
        def export_with_hidden_fields_option(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ExportWithHiddenFieldsOptionProperty"]]:
            '''Determines if hidden fields are exported with a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-exportwithhiddenfieldsoption
            '''
            result = self._values.get("export_with_hidden_fields_option")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ExportWithHiddenFieldsOptionProperty"]], result)

        @builtins.property
        def sheet_controls_option(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetControlsOptionProperty"]]:
            '''Sheet controls option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-sheetcontrolsoption
            '''
            result = self._values.get("sheet_controls_option")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetControlsOptionProperty"]], result)

        @builtins.property
        def sheet_layout_element_maximization_option(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetLayoutElementMaximizationOptionProperty"]]:
            '''The sheet layout maximization options of a dashbaord.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-sheetlayoutelementmaximizationoption
            '''
            result = self._values.get("sheet_layout_element_maximization_option")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetLayoutElementMaximizationOptionProperty"]], result)

        @builtins.property
        def visual_axis_sort_option(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualAxisSortOptionProperty"]]:
            '''The axis sort options of a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualaxissortoption
            '''
            result = self._values.get("visual_axis_sort_option")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualAxisSortOptionProperty"]], result)

        @builtins.property
        def visual_menu_option(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualMenuOptionProperty"]]:
            '''The menu options of a visual in a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualmenuoption
            '''
            result = self._values.get("visual_menu_option")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualMenuOptionProperty"]], result)

        @builtins.property
        def visual_publish_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardVisualPublishOptionsProperty"]]:
            '''The visual publish options of a visual in a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualpublishoptions
            '''
            result = self._values.get("visual_publish_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardVisualPublishOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardPublishOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DashboardSourceEntityProperty",
        jsii_struct_bases=[],
        name_mapping={"source_template": "sourceTemplate"},
    )
    class DashboardSourceEntityProperty:
        def __init__(
            self,
            *,
            source_template: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DashboardSourceTemplateProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Dashboard source entity.

            :param source_template: Source template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourceentity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                dashboard_source_entity_property = quicksight.CfnDashboard.DashboardSourceEntityProperty(
                    source_template=quicksight.CfnDashboard.DashboardSourceTemplateProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnDashboard.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__95ac0a43c376eeab6e6c9daabc99cad6641a22d70a49ff384d4345905e5e0475)
                check_type(argname="argument source_template", value=source_template, expected_type=type_hints["source_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_template is not None:
                self._values["source_template"] = source_template

        @builtins.property
        def source_template(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardSourceTemplateProperty"]]:
            '''Source template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourceentity.html#cfn-quicksight-dashboard-dashboardsourceentity-sourcetemplate
            '''
            result = self._values.get("source_template")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardSourceTemplateProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardSourceEntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DashboardSourceTemplateProperty",
        jsii_struct_bases=[],
        name_mapping={"arn": "arn", "data_set_references": "dataSetReferences"},
    )
    class DashboardSourceTemplateProperty:
        def __init__(
            self,
            *,
            arn: builtins.str,
            data_set_references: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataSetReferenceProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''Dashboard source template.

            :param arn: The Amazon Resource Name (ARN) of the resource.
            :param data_set_references: Dataset references.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                dashboard_source_template_property = quicksight.CfnDashboard.DashboardSourceTemplateProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnDashboard.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec4b1c8f9abb3a690b756b53fc5f73110c6f67d197acf44415593c23064d92d7)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument data_set_references", value=data_set_references, expected_type=type_hints["data_set_references"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
                "data_set_references": data_set_references,
            }

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the resource.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html#cfn-quicksight-dashboard-dashboardsourcetemplate-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_references(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataSetReferenceProperty"]]]:
            '''Dataset references.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html#cfn-quicksight-dashboard-dashboardsourcetemplate-datasetreferences
            '''
            result = self._values.get("data_set_references")
            assert result is not None, "Required property 'data_set_references' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataSetReferenceProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardSourceTemplateProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DashboardVersionDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier_declarations": "dataSetIdentifierDeclarations",
            "analysis_defaults": "analysisDefaults",
            "calculated_fields": "calculatedFields",
            "column_configurations": "columnConfigurations",
            "filter_groups": "filterGroups",
            "parameter_declarations": "parameterDeclarations",
            "sheets": "sheets",
        },
    )
    class DashboardVersionDefinitionProperty:
        def __init__(
            self,
            *,
            data_set_identifier_declarations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataSetIdentifierDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AnalysisDefaultsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            calculated_fields: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CalculatedFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            column_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            filter_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterGroupProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            parameter_declarations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SheetDefinitionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The contents of a dashboard.

            :param data_set_identifier_declarations: An array of dataset identifier declarations. With this mapping,you can use dataset identifiers instead of dataset Amazon Resource Names (ARNs) throughout the dashboard's sub-structures.
            :param analysis_defaults: ``CfnDashboard.DashboardVersionDefinitionProperty.AnalysisDefaults``.
            :param calculated_fields: An array of calculated field definitions for the dashboard.
            :param column_configurations: An array of dashboard-level column configurations. Column configurations are used to set the default formatting for a column that is used throughout a dashboard.
            :param filter_groups: The filter definitions for a dashboard. For more information, see `Filtering Data in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html>`_ in the *Amazon QuickSight User Guide* .
            :param parameter_declarations: The parameter declarations for a dashboard. Parameters are named variables that can transfer a value for use by an action or an object. For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheets: An array of sheet definitions for a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                dashboard_version_definition_property = quicksight.CfnDashboard.DashboardVersionDefinitionProperty(
                    data_set_identifier_declarations=[quicksight.CfnDashboard.DataSetIdentifierDeclarationProperty(
                        data_set_arn="dataSetArn",
                        identifier="identifier"
                    )],
                
                    # the properties below are optional
                    analysis_defaults=quicksight.CfnDashboard.AnalysisDefaultsProperty(
                        default_new_sheet_configuration=quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty(
                            interactive_layout_configuration=quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                                free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            ),
                            paginated_layout_configuration=quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                                section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    )
                                )
                            ),
                            sheet_content_type="sheetContentType"
                        )
                    ),
                    calculated_fields=[quicksight.CfnDashboard.CalculatedFieldProperty(
                        data_set_identifier="dataSetIdentifier",
                        expression="expression",
                        name="name"
                    )],
                    column_configurations=[quicksight.CfnDashboard.ColumnConfigurationProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        colors_configuration=quicksight.CfnDashboard.ColorsConfigurationProperty(
                            custom_colors=[quicksight.CfnDashboard.CustomColorProperty(
                                color="color",
                
                                # the properties below are optional
                                field_value="fieldValue",
                                special_value="specialValue"
                            )]
                        ),
                        format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        role="role"
                    )],
                    filter_groups=[quicksight.CfnDashboard.FilterGroupProperty(
                        cross_dataset="crossDataset",
                        filter_group_id="filterGroupId",
                        filters=[quicksight.CfnDashboard.FilterProperty(
                            category_filter=quicksight.CfnDashboard.CategoryFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                                    custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
                
                                        # the properties below are optional
                                        category_value="categoryValue",
                                        parameter_name="parameterName",
                                        select_all_options="selectAllOptions"
                                    ),
                                    custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
                
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    ),
                                    filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                                        match_operator="matchOperator",
                
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    )
                                ),
                                filter_id="filterId"
                            ),
                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions",
                                value=123
                            ),
                            numeric_range_filter=quicksight.CfnDashboard.NumericRangeFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                select_all_options="selectAllOptions"
                            ),
                            relative_dates_filter=quicksight.CfnDashboard.RelativeDatesFilterProperty(
                                anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                                    anchor_option="anchorOption",
                                    parameter_name="parameterName"
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                                relative_date_type="relativeDateType",
                                time_granularity="timeGranularity",
                
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
                
                                    # the properties below are optional
                                    status="status"
                                ),
                                minimum_granularity="minimumGranularity",
                                parameter_name="parameterName",
                                relative_date_value=123
                            ),
                            time_equality_filter=quicksight.CfnDashboard.TimeEqualityFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                
                                # the properties below are optional
                                parameter_name="parameterName",
                                time_granularity="timeGranularity",
                                value="value"
                            ),
                            time_range_filter=quicksight.CfnDashboard.TimeRangeFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
                
                                    # the properties below are optional
                                    status="status"
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                time_granularity="timeGranularity"
                            ),
                            top_bottom_filter=quicksight.CfnDashboard.TopBottomFilterProperty(
                                aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    sort_direction="sortDirection"
                                )],
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                
                                # the properties below are optional
                                limit=123,
                                parameter_name="parameterName",
                                time_granularity="timeGranularity"
                            )
                        )],
                        scope_configuration=quicksight.CfnDashboard.FilterScopeConfigurationProperty(
                            selected_sheets=quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                                sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                                    scope="scope",
                                    sheet_id="sheetId",
                
                                    # the properties below are optional
                                    visual_ids=["visualIds"]
                                )]
                            )
                        ),
                
                        # the properties below are optional
                        status="status"
                    )],
                    parameter_declarations=[quicksight.CfnDashboard.ParameterDeclarationProperty(
                        date_time_parameter_declaration=quicksight.CfnDashboard.DateTimeParameterDeclarationProperty(
                            name="name",
                
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            time_granularity="timeGranularity",
                            value_when_unset=quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        decimal_parameter_declaration=quicksight.CfnDashboard.DecimalParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        integer_parameter_declaration=quicksight.CfnDashboard.IntegerParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        string_parameter_declaration=quicksight.CfnDashboard.StringParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.StringDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        )
                    )],
                    sheets=[quicksight.CfnDashboard.SheetDefinitionProperty(
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        content_type="contentType",
                        description="description",
                        filter_controls=[quicksight.CfnDashboard.FilterControlProperty(
                            date_time_picker=quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            dropdown=quicksight.CfnDashboard.FilterDropDownControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnDashboard.FilterListControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            relative_date_time=quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            slider=quicksight.CfnDashboard.FilterSliderControlProperty(
                                filter_control_id="filterControlId",
                                maximum_value=123,
                                minimum_value=123,
                                source_filter_id="sourceFilterId",
                                step_size=123,
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            text_area=quicksight.CfnDashboard.FilterTextAreaControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnDashboard.FilterTextFieldControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        layouts=[quicksight.CfnDashboard.LayoutProperty(
                            configuration=quicksight.CfnDashboard.LayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
                
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                                    body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                                        content=quicksight.CfnDashboard.BodySectionContentProperty(
                                            layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                                free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                        element_id="elementId",
                                                        element_type="elementType",
                                                        height="height",
                                                        width="width",
                                                        x_axis_location="xAxisLocation",
                                                        y_axis_location="yAxisLocation",
                
                                                        # the properties below are optional
                                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                            visibility="visibility"
                                                        ),
                                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                                visibility="visibility"
                                                            ),
                                                            expression="expression"
                                                        )],
                                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        visibility="visibility"
                                                    )]
                                                )
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                            after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                                status="status"
                                            )
                                        ),
                                        style=quicksight.CfnDashboard.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    ),
                                    footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        style=quicksight.CfnDashboard.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        style=quicksight.CfnDashboard.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )]
                                )
                            )
                        )],
                        name="name",
                        parameter_controls=[quicksight.CfnDashboard.ParameterControlProperty(
                            date_time_picker=quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            dropdown=quicksight.CfnDashboard.ParameterDropDownControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnDashboard.ParameterListControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            slider=quicksight.CfnDashboard.ParameterSliderControlProperty(
                                maximum_value=123,
                                minimum_value=123,
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                step_size=123,
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_area=quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        sheet_control_layouts=[quicksight.CfnDashboard.SheetControlLayoutProperty(
                            configuration=quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                                grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
                
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            )
                        )],
                        text_boxes=[quicksight.CfnDashboard.SheetTextBoxProperty(
                            sheet_text_box_id="sheetTextBoxId",
                
                            # the properties below are optional
                            content="content"
                        )],
                        title="title",
                        visuals=[quicksight.CfnDashboard.VisualProperty(
                            bar_chart_visual=quicksight.CfnDashboard.BarChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.BarChartConfigurationProperty(
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                                        bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    orientation="orientation",
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            box_plot_visual=quicksight.CfnDashboard.BoxPlotVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                                    box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                                        all_data_points_visibility="allDataPointsVisibility",
                                        outlier_visibility="outlierVisibility",
                                        style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                                            fill_style="fillStyle"
                                        )
                                    ),
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                                        box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        )
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            combo_chart_visual=quicksight.CfnDashboard.ComboChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.ComboChartConfigurationProperty(
                                    bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                                        combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                                            bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            custom_content_visual=quicksight.CfnDashboard.CustomContentVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.CustomContentConfigurationProperty(
                                    content_type="contentType",
                                    content_url="contentUrl",
                                    image_scaling="imageScaling"
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            empty_visual=quicksight.CfnDashboard.EmptyVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )]
                            ),
                            filled_map_visual=quicksight.CfnDashboard.FilledMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.FilledMapConfigurationProperty(
                                    field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                                        filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                                            geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                                        shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            funnel_chart_visual=quicksight.CfnDashboard.FunnelChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        label_color="labelColor",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_data_label_style="measureDataLabelStyle",
                                        measure_label_visibility="measureLabelVisibility",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                                        funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            gauge_chart_visual=quicksight.CfnDashboard.GaugeChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                                        target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                                        arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                                            arc_angle=123,
                                            arc_thickness="arcThickness"
                                        ),
                                        arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                                            range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                                max=123,
                                                min=123
                                            ),
                                            reserve_range=123
                                        ),
                                        comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    ),
                                    tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                conditional_formatting=quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                                        arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            geospatial_map_visual=quicksight.CfnDashboard.GeospatialMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                                    field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                                        geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                                        cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                                            cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                                simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                                    color="color"
                                                )
                                            )
                                        ),
                                        selected_point_style="selectedPointStyle"
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            heat_map_visual=quicksight.CfnDashboard.HeatMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.HeatMapConfigurationProperty(
                                    color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
                
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                                        heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                                        heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            histogram_visual=quicksight.CfnDashboard.HistogramVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.HistogramConfigurationProperty(
                                    bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                                        bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                                            value=123
                                        ),
                                        bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                                            bin_count_limit=123,
                                            value=123
                                        ),
                                        selected_bin_type="selectedBinType",
                                        start_value=123
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                                        histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    )
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            insight_visual=quicksight.CfnDashboard.InsightVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                insight_configuration=quicksight.CfnDashboard.InsightConfigurationProperty(
                                    computations=[quicksight.CfnDashboard.ComputationProperty(
                                        forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            custom_seasonality_value=123,
                                            lower_boundary=123,
                                            name="name",
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality="seasonality",
                                            upper_boundary=123,
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            period_size=123,
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
                
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                                            computation_id="computationId",
                                            from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            period_time_granularity="periodTimeGranularity",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
                
                                            # the properties below are optional
                                            mover_size=123,
                                            name="name",
                                            sort_order="sortOrder",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            type="type",
                
                                            # the properties below are optional
                                            name="name",
                                            result_size=123,
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                                            computation_id="computationId",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                
                                            # the properties below are optional
                                            name="name"
                                        )
                                    )],
                                    custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                                        narrative="narrative"
                                    )
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            kpi_visual=quicksight.CfnDashboard.KPIVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.KPIConfigurationProperty(
                                    field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                                        target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                                        comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                                        trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                                        primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            line_chart_visual=quicksight.CfnDashboard.LineChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.LineChartConfigurationProperty(
                                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                                        axis_binding="axisBinding",
                                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                                        line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                                        forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                                            lower_boundary=123,
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality=123,
                                            upper_boundary=123
                                        ),
                                        scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                                            what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                                date="date",
                                                value=123
                                            ),
                                            what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                                end_date="endDate",
                                                start_date="startDate",
                                                value=123
                                            )
                                        )
                                    )],
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    series=[quicksight.CfnDashboard.SeriesItemProperty(
                                        data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            field_value="fieldValue",
                                            settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        ),
                                        field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                                        category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    type="type",
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pie_chart_visual=quicksight.CfnDashboard.PieChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.PieChartConfigurationProperty(
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                                        arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                                            arc_thickness="arcThickness"
                                        ),
                                        donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                                            label_visibility="labelVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                                        pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pivot_table_visual=quicksight.CfnDashboard.PivotTableVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.PivotTableConfigurationProperty(
                                    field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                                        data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                                            data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )],
                
                                            # the properties below are optional
                                            width="width"
                                        )],
                                        selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            visibility="visibility"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                                        pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                                        field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                                            field_id="fieldId",
                                            sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                                column=quicksight.CfnDashboard.ColumnSortProperty(
                                                    direction="direction",
                                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    )
                                                ),
                                                data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                                    direction="direction",
                                                    sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                                        field_id="fieldId",
                                                        field_value="fieldValue"
                                                    )]
                                                ),
                                                field=quicksight.CfnDashboard.FieldSortProperty(
                                                    direction="direction",
                                                    field_id="fieldId"
                                                )
                                            )
                                        )]
                                    ),
                                    table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                                        cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_names_visibility="columnNamesVisibility",
                                        metric_placement="metricPlacement",
                                        row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        ),
                                        row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        single_metric_visibility="singleMetricVisibility",
                                        toggle_buttons_visibility="toggleButtonsVisibility"
                                    ),
                                    total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                                        column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    )
                                ),
                                conditional_formatting=quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                                role="role"
                                            ),
                                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
                
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            radar_chart_visual=quicksight.CfnDashboard.RadarChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.RadarChartConfigurationProperty(
                                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                                    alternate_band_even_color="alternateBandEvenColor",
                                    alternate_band_odd_color="alternateBandOddColor",
                                    base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                                        area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                                        radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    shape="shape",
                                    sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    start_angle=123,
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            sankey_diagram_visual=quicksight.CfnDashboard.SankeyDiagramVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                                        sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                                            destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                                        destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            scatter_plot_visual=quicksight.CfnDashboard.ScatterPlotVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            table_visual=quicksight.CfnDashboard.TableVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.TableConfigurationProperty(
                                    field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                                        order=["order"],
                                        selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                                image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                                    sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                    )
                                                ),
                                                link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                                    content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                                        custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                                            icon="icon"
                                                        ),
                                                        custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                                font_color="fontColor",
                                                                font_decoration="fontDecoration",
                                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                                    relative="relative"
                                                                ),
                                                                font_style="fontStyle",
                                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                                    name="name"
                                                                )
                                                            ),
                
                                                            # the properties below are optional
                                                            value="value"
                                                        )
                                                    ),
                                                    target="target"
                                                )
                                            ),
                                            visibility="visibility",
                                            width="width"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                                        table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                                            values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                                    date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                                        pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        ),
                                        row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                                        data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            negative_color="negativeColor",
                                            positive_color="positiveColor"
                                        )
                                    )],
                                    table_options=quicksight.CfnDashboard.TableOptionsProperty(
                                        cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        orientation="orientation",
                                        row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        )
                                    ),
                                    total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                                        custom_label="customLabel",
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility"
                                    )
                                ),
                                conditional_formatting=quicksight.CfnDashboard.TableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
                
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        ),
                                        row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            tree_map_visual=quicksight.CfnDashboard.TreeMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.TreeMapConfigurationProperty(
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
                
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                                        tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                                        tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            waterfall_visual=quicksight.CfnDashboard.WaterfallVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                                    category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                                        waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                                            breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                                        breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                                        total_bar_label="totalBarLabel"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            word_cloud_visual=quicksight.CfnDashboard.WordCloudVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                                        word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                                        cloud_layout="cloudLayout",
                                        maximum_string_length=123,
                                        word_casing="wordCasing",
                                        word_orientation="wordOrientation",
                                        word_padding="wordPadding",
                                        word_scaling="wordScaling"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5bfcab882e1b0a7459c16fa736358b5f7e1649da0e925bd5d7b5660498d64edb)
                check_type(argname="argument data_set_identifier_declarations", value=data_set_identifier_declarations, expected_type=type_hints["data_set_identifier_declarations"])
                check_type(argname="argument analysis_defaults", value=analysis_defaults, expected_type=type_hints["analysis_defaults"])
                check_type(argname="argument calculated_fields", value=calculated_fields, expected_type=type_hints["calculated_fields"])
                check_type(argname="argument column_configurations", value=column_configurations, expected_type=type_hints["column_configurations"])
                check_type(argname="argument filter_groups", value=filter_groups, expected_type=type_hints["filter_groups"])
                check_type(argname="argument parameter_declarations", value=parameter_declarations, expected_type=type_hints["parameter_declarations"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier_declarations": data_set_identifier_declarations,
            }
            if analysis_defaults is not None:
                self._values["analysis_defaults"] = analysis_defaults
            if calculated_fields is not None:
                self._values["calculated_fields"] = calculated_fields
            if column_configurations is not None:
                self._values["column_configurations"] = column_configurations
            if filter_groups is not None:
                self._values["filter_groups"] = filter_groups
            if parameter_declarations is not None:
                self._values["parameter_declarations"] = parameter_declarations
            if sheets is not None:
                self._values["sheets"] = sheets

        @builtins.property
        def data_set_identifier_declarations(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataSetIdentifierDeclarationProperty"]]]:
            '''An array of dataset identifier declarations.

            With this mapping,you can use dataset identifiers instead of dataset Amazon Resource Names (ARNs) throughout the dashboard's sub-structures.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-datasetidentifierdeclarations
            '''
            result = self._values.get("data_set_identifier_declarations")
            assert result is not None, "Required property 'data_set_identifier_declarations' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataSetIdentifierDeclarationProperty"]]], result)

        @builtins.property
        def analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AnalysisDefaultsProperty"]]:
            '''``CfnDashboard.DashboardVersionDefinitionProperty.AnalysisDefaults``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-analysisdefaults
            '''
            result = self._values.get("analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AnalysisDefaultsProperty"]], result)

        @builtins.property
        def calculated_fields(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CalculatedFieldProperty"]]]]:
            '''An array of calculated field definitions for the dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-calculatedfields
            '''
            result = self._values.get("calculated_fields")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CalculatedFieldProperty"]]]], result)

        @builtins.property
        def column_configurations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnConfigurationProperty"]]]]:
            '''An array of dashboard-level column configurations.

            Column configurations are used to set the default formatting for a column that is used throughout a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-columnconfigurations
            '''
            result = self._values.get("column_configurations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnConfigurationProperty"]]]], result)

        @builtins.property
        def filter_groups(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterGroupProperty"]]]]:
            '''The filter definitions for a dashboard.

            For more information, see `Filtering Data in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-filtergroups
            '''
            result = self._values.get("filter_groups")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterGroupProperty"]]]], result)

        @builtins.property
        def parameter_declarations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterDeclarationProperty"]]]]:
            '''The parameter declarations for a dashboard.

            Parameters are named variables that can transfer a value for use by an action or an object.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-parameterdeclarations
            '''
            result = self._values.get("parameter_declarations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterDeclarationProperty"]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetDefinitionProperty"]]]]:
            '''An array of sheet definitions for a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetDefinitionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardVersionDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DashboardVersionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arn": "arn",
            "created_time": "createdTime",
            "data_set_arns": "dataSetArns",
            "description": "description",
            "errors": "errors",
            "sheets": "sheets",
            "source_entity_arn": "sourceEntityArn",
            "status": "status",
            "theme_arn": "themeArn",
            "version_number": "versionNumber",
        },
    )
    class DashboardVersionProperty:
        def __init__(
            self,
            *,
            arn: typing.Optional[builtins.str] = None,
            created_time: typing.Optional[builtins.str] = None,
            data_set_arns: typing.Optional[typing.Sequence[builtins.str]] = None,
            description: typing.Optional[builtins.str] = None,
            errors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DashboardErrorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SheetProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            source_entity_arn: typing.Optional[builtins.str] = None,
            status: typing.Optional[builtins.str] = None,
            theme_arn: typing.Optional[builtins.str] = None,
            version_number: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Dashboard version.

            :param arn: The Amazon Resource Name (ARN) of the resource.
            :param created_time: The time that this dashboard version was created.
            :param data_set_arns: The Amazon Resource Numbers (ARNs) for the datasets that are associated with this version of the dashboard.
            :param description: Description.
            :param errors: Errors associated with this dashboard version.
            :param sheets: A list of the associated sheets with the unique identifier and name of each sheet.
            :param source_entity_arn: Source entity ARN.
            :param status: The HTTP status of the request.
            :param theme_arn: The ARN of the theme associated with a version of the dashboard.
            :param version_number: Version number for this version of the dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                dashboard_version_property = quicksight.CfnDashboard.DashboardVersionProperty(
                    arn="arn",
                    created_time="createdTime",
                    data_set_arns=["dataSetArns"],
                    description="description",
                    errors=[quicksight.CfnDashboard.DashboardErrorProperty(
                        message="message",
                        type="type",
                        violated_entities=[quicksight.CfnDashboard.EntityProperty(
                            path="path"
                        )]
                    )],
                    sheets=[quicksight.CfnDashboard.SheetProperty(
                        name="name",
                        sheet_id="sheetId"
                    )],
                    source_entity_arn="sourceEntityArn",
                    status="status",
                    theme_arn="themeArn",
                    version_number=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d1cd71b2a2397fa023c43748542c1d9990398f4d8b263021516e141f717ee5c3)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument created_time", value=created_time, expected_type=type_hints["created_time"])
                check_type(argname="argument data_set_arns", value=data_set_arns, expected_type=type_hints["data_set_arns"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument errors", value=errors, expected_type=type_hints["errors"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
                check_type(argname="argument source_entity_arn", value=source_entity_arn, expected_type=type_hints["source_entity_arn"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument theme_arn", value=theme_arn, expected_type=type_hints["theme_arn"])
                check_type(argname="argument version_number", value=version_number, expected_type=type_hints["version_number"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arn is not None:
                self._values["arn"] = arn
            if created_time is not None:
                self._values["created_time"] = created_time
            if data_set_arns is not None:
                self._values["data_set_arns"] = data_set_arns
            if description is not None:
                self._values["description"] = description
            if errors is not None:
                self._values["errors"] = errors
            if sheets is not None:
                self._values["sheets"] = sheets
            if source_entity_arn is not None:
                self._values["source_entity_arn"] = source_entity_arn
            if status is not None:
                self._values["status"] = status
            if theme_arn is not None:
                self._values["theme_arn"] = theme_arn
            if version_number is not None:
                self._values["version_number"] = version_number

        @builtins.property
        def arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of the resource.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-arn
            '''
            result = self._values.get("arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def created_time(self) -> typing.Optional[builtins.str]:
            '''The time that this dashboard version was created.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-createdtime
            '''
            result = self._values.get("created_time")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_set_arns(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The Amazon Resource Numbers (ARNs) for the datasets that are associated with this version of the dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-datasetarns
            '''
            result = self._values.get("data_set_arns")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''Description.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def errors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardErrorProperty"]]]]:
            '''Errors associated with this dashboard version.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-errors
            '''
            result = self._values.get("errors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DashboardErrorProperty"]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetProperty"]]]]:
            '''A list of the associated sheets with the unique identifier and name of each sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetProperty"]]]], result)

        @builtins.property
        def source_entity_arn(self) -> typing.Optional[builtins.str]:
            '''Source entity ARN.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-sourceentityarn
            '''
            result = self._values.get("source_entity_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The HTTP status of the request.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def theme_arn(self) -> typing.Optional[builtins.str]:
            '''The ARN of the theme associated with a version of the dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-themearn
            '''
            result = self._values.get("theme_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def version_number(self) -> typing.Optional[jsii.Number]:
            '''Version number for this version of the dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-versionnumber
            '''
            result = self._values.get("version_number")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardVersionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DashboardVisualPublishOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"export_hidden_fields_option": "exportHiddenFieldsOption"},
    )
    class DashboardVisualPublishOptionsProperty:
        def __init__(
            self,
            *,
            export_hidden_fields_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ExportHiddenFieldsOptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The visual publish options of a visual in a dashboard.

            :param export_hidden_fields_option: Determines if hidden fields are included in an exported dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardvisualpublishoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                dashboard_visual_publish_options_property = quicksight.CfnDashboard.DashboardVisualPublishOptionsProperty(
                    export_hidden_fields_option=quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty(
                        availability_status="availabilityStatus"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__087652de777a58e6cc5f05aff691abc5496763429f2b2c21e168b276632deab2)
                check_type(argname="argument export_hidden_fields_option", value=export_hidden_fields_option, expected_type=type_hints["export_hidden_fields_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if export_hidden_fields_option is not None:
                self._values["export_hidden_fields_option"] = export_hidden_fields_option

        @builtins.property
        def export_hidden_fields_option(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ExportHiddenFieldsOptionProperty"]]:
            '''Determines if hidden fields are included in an exported dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardvisualpublishoptions.html#cfn-quicksight-dashboard-dashboardvisualpublishoptions-exporthiddenfieldsoption
            '''
            result = self._values.get("export_hidden_fields_option")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ExportHiddenFieldsOptionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardVisualPublishOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataBarsOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "negative_color": "negativeColor",
            "positive_color": "positiveColor",
        },
    )
    class DataBarsOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            negative_color: typing.Optional[builtins.str] = None,
            positive_color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for data bars.

            :param field_id: The field ID for the data bars options.
            :param negative_color: The color of the negative data bar.
            :param positive_color: The color of the positive data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_bars_options_property = quicksight.CfnDashboard.DataBarsOptionsProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    negative_color="negativeColor",
                    positive_color="positiveColor"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__66a928ed261b7f2a81adddd0df469ba54d9745a362b70a3ecf9ba05933985362)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument negative_color", value=negative_color, expected_type=type_hints["negative_color"])
                check_type(argname="argument positive_color", value=positive_color, expected_type=type_hints["positive_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if negative_color is not None:
                self._values["negative_color"] = negative_color
            if positive_color is not None:
                self._values["positive_color"] = positive_color

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the data bars options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def negative_color(self) -> typing.Optional[builtins.str]:
            '''The color of the negative data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-negativecolor
            '''
            result = self._values.get("negative_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def positive_color(self) -> typing.Optional[builtins.str]:
            '''The color of the positive data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-positivecolor
            '''
            result = self._values.get("positive_color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataBarsOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "data_value": "dataValue"},
    )
    class DataColorProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the color that is applied to a particular data value.

            :param color: The color that is applied to the data value.
            :param data_value: The data value that the color is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_color_property = quicksight.CfnDashboard.DataColorProperty(
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f2990ac04e1845daf895f568fe9de7844c5e8cc45ced311c3a6242363c466264)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color that is applied to the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html#cfn-quicksight-dashboard-datacolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''The data value that the color is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html#cfn-quicksight-dashboard-datacolor-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataFieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "settings": "settings",
        },
    )
    class DataFieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field that you are setting the axis binding to.
            :param field_value: The field value of the field that you are setting the axis binding to.
            :param settings: The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_field_series_item_property = quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6ebf8ceb14ff875af3af6b8643da1722ce9e80bb9b858aef5094e864576c82e6)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that you are setting the axis binding to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The field value of the field that you are setting the axis binding to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartSeriesSettingsProperty"]]:
            '''The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartSeriesSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataFieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "data_label_types": "dataLabelTypes",
            "label_color": "labelColor",
            "label_content": "labelContent",
            "label_font_configuration": "labelFontConfiguration",
            "measure_label_visibility": "measureLabelVisibility",
            "overlap": "overlap",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class DataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            data_label_types: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_content: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            overlap: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: Determines the visibility of the category field labels.
            :param data_label_types: The option that determines the data label type.
            :param label_color: Determines the color of the data labels.
            :param label_content: Determines the content of the data labels.
            :param label_font_configuration: Determines the font configuration of the data labels.
            :param measure_label_visibility: Determines the visibility of the measure field labels.
            :param overlap: Determines whether overlap is enabled or disabled for the data labels.
            :param position: Determines the position of the data labels.
            :param visibility: Determines the visibility of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_label_options_property = quicksight.CfnDashboard.DataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                            field_id="fieldId",
                            field_value="fieldValue",
                            visibility="visibility"
                        ),
                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                            field_id="fieldId",
                            visibility="visibility"
                        ),
                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                            visibility="visibility"
                        )
                    )],
                    label_color="labelColor",
                    label_content="labelContent",
                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_label_visibility="measureLabelVisibility",
                    overlap="overlap",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__88bd694a9b51da9e5068a53df594cc196dcb929bfb4f551e5e2aab00d19d1fb8)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument data_label_types", value=data_label_types, expected_type=type_hints["data_label_types"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_content", value=label_content, expected_type=type_hints["label_content"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument overlap", value=overlap, expected_type=type_hints["overlap"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if data_label_types is not None:
                self._values["data_label_types"] = data_label_types
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_content is not None:
                self._values["label_content"] = label_content
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if overlap is not None:
                self._values["overlap"] = overlap
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the category field labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_label_types(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelTypeProperty"]]]]:
            '''The option that determines the data label type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-datalabeltypes
            '''
            result = self._values.get("data_label_types")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelTypeProperty"]]]], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_content(self) -> typing.Optional[builtins.str]:
            '''Determines the content of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelcontent
            '''
            result = self._values.get("label_content")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]]:
            '''Determines the font configuration of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the measure field labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def overlap(self) -> typing.Optional[builtins.str]:
            '''Determines whether overlap is enabled or disabled for the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-overlap
            '''
            result = self._values.get("overlap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the position of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_label_type": "dataPathLabelType",
            "field_label_type": "fieldLabelType",
            "maximum_label_type": "maximumLabelType",
            "minimum_label_type": "minimumLabelType",
            "range_ends_label_type": "rangeEndsLabelType",
        },
    )
    class DataLabelTypeProperty:
        def __init__(
            self,
            *,
            data_path_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataPathLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maximum_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MaximumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            minimum_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MinimumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_ends_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RangeEndsLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The option that determines the data label type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_path_label_type: The option that specifies individual data values for labels.
            :param field_label_type: Determines the label configuration for the entire field.
            :param maximum_label_type: Determines the label configuration for the maximum value in a visual.
            :param minimum_label_type: Determines the label configuration for the minimum value in a visual.
            :param range_ends_label_type: Determines the label configuration for range end value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_label_type_property = quicksight.CfnDashboard.DataLabelTypeProperty(
                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                        field_id="fieldId",
                        field_value="fieldValue",
                        visibility="visibility"
                    ),
                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                        field_id="fieldId",
                        visibility="visibility"
                    ),
                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c72d17b861907d098e5bda0e212c223319d2b0e32acc9fbe3a819780c7a62c1f)
                check_type(argname="argument data_path_label_type", value=data_path_label_type, expected_type=type_hints["data_path_label_type"])
                check_type(argname="argument field_label_type", value=field_label_type, expected_type=type_hints["field_label_type"])
                check_type(argname="argument maximum_label_type", value=maximum_label_type, expected_type=type_hints["maximum_label_type"])
                check_type(argname="argument minimum_label_type", value=minimum_label_type, expected_type=type_hints["minimum_label_type"])
                check_type(argname="argument range_ends_label_type", value=range_ends_label_type, expected_type=type_hints["range_ends_label_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_label_type is not None:
                self._values["data_path_label_type"] = data_path_label_type
            if field_label_type is not None:
                self._values["field_label_type"] = field_label_type
            if maximum_label_type is not None:
                self._values["maximum_label_type"] = maximum_label_type
            if minimum_label_type is not None:
                self._values["minimum_label_type"] = minimum_label_type
            if range_ends_label_type is not None:
                self._values["range_ends_label_type"] = range_ends_label_type

        @builtins.property
        def data_path_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPathLabelTypeProperty"]]:
            '''The option that specifies individual data values for labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-datapathlabeltype
            '''
            result = self._values.get("data_path_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPathLabelTypeProperty"]], result)

        @builtins.property
        def field_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldLabelTypeProperty"]]:
            '''Determines the label configuration for the entire field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-fieldlabeltype
            '''
            result = self._values.get("field_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldLabelTypeProperty"]], result)

        @builtins.property
        def maximum_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MaximumLabelTypeProperty"]]:
            '''Determines the label configuration for the maximum value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-maximumlabeltype
            '''
            result = self._values.get("maximum_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MaximumLabelTypeProperty"]], result)

        @builtins.property
        def minimum_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MinimumLabelTypeProperty"]]:
            '''Determines the label configuration for the minimum value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-minimumlabeltype
            '''
            result = self._values.get("minimum_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MinimumLabelTypeProperty"]], result)

        @builtins.property
        def range_ends_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RangeEndsLabelTypeProperty"]]:
            '''Determines the label configuration for range end value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-rangeendslabeltype
            '''
            result = self._values.get("range_ends_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RangeEndsLabelTypeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataPathColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "element": "element",
            "time_granularity": "timeGranularity",
        },
    )
    class DataPathColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            element: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]],
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The color map that determines the color options for a particular element.

            :param color: The color that needs to be applied to the element.
            :param element: The element that the color needs to be applied to.
            :param time_granularity: The time granularity of the field that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_path_color_property = quicksight.CfnDashboard.DataPathColorProperty(
                    color="color",
                    element=quicksight.CfnDashboard.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    ),
                
                    # the properties below are optional
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6772eae9cb657f1d72dfa556428e880f7605aa5ff464fd4543e53b57d69f7ee7)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument element", value=element, expected_type=type_hints["element"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "element": element,
            }
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def color(self) -> builtins.str:
            '''The color that needs to be applied to the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPathValueProperty"]:
            '''The element that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-element
            '''
            result = self._values.get("element")
            assert result is not None, "Required property 'element' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPathValueProperty"], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity of the field that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataPathLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "visibility": "visibility",
        },
    )
    class DataPathLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            field_value: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The option that specifies individual data values for labels.

            :param field_id: The field ID of the field that the data label needs to be applied to.
            :param field_value: The actual value of the field that is labeled.
            :param visibility: The visibility of the data label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_path_label_type_property = quicksight.CfnDashboard.DataPathLabelTypeProperty(
                    field_id="fieldId",
                    field_value="fieldValue",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f72ad312a3f6434083b5eb1519fc9a2a3c47ae4d56abb157d1333b738af935e5)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if field_value is not None:
                self._values["field_value"] = field_value
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the field that the data label needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The actual value of the field that is labeled.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataPathSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "sort_paths": "sortPaths"},
    )
    class DataPathSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_paths: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''Allows data paths to be sorted by a specific data value.

            :param direction: Determines the sort direction.
            :param sort_paths: The list of data paths that need to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_path_sort_property = quicksight.CfnDashboard.DataPathSortProperty(
                    direction="direction",
                    sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1b1fd519a1df5d1a3b591a8bb0c8c6703b7cc2f27e7e4bb36b876d7ee4c82f99)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_paths", value=sort_paths, expected_type=type_hints["sort_paths"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_paths": sort_paths,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''Determines the sort direction.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html#cfn-quicksight-dashboard-datapathsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_paths(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPathValueProperty"]]]:
            '''The list of data paths that need to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html#cfn-quicksight-dashboard-datapathsort-sortpaths
            '''
            result = self._values.get("sort_paths")
            assert result is not None, "Required property 'sort_paths' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPathValueProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataPathValueProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "field_value": "fieldValue"},
    )
    class DataPathValueProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            field_value: builtins.str,
        ) -> None:
            '''The data path that needs to be sorted.

            :param field_id: The field ID of the field that needs to be sorted.
            :param field_value: The actual value of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_path_value_property = quicksight.CfnDashboard.DataPathValueProperty(
                    field_id="fieldId",
                    field_value="fieldValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce381cea0f90c39ec0e4af27533dbb0a30a15f375c60f6ec373fce1ea5bd64a5)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "field_value": field_value,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html#cfn-quicksight-dashboard-datapathvalue-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> builtins.str:
            '''The actual value of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html#cfn-quicksight-dashboard-datapathvalue-fieldvalue
            '''
            result = self._values.get("field_value")
            assert result is not None, "Required property 'field_value' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataPointDrillUpDownOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class DataPointDrillUpDownOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The drill down options for data points in a dashbaord.

            :param availability_status: The status of the drill down options of data points.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointdrillupdownoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_point_drill_up_down_option_property = quicksight.CfnDashboard.DataPointDrillUpDownOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6cf1a21c97ee69418e13603daa93cf4ea1805781e3d86533040e2c75a53b7db3)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the drill down options of data points.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointdrillupdownoption.html#cfn-quicksight-dashboard-datapointdrillupdownoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPointDrillUpDownOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataPointMenuLabelOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class DataPointMenuLabelOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data point menu options of a dashboard.

            :param availability_status: The status of the data point menu options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointmenulabeloption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_point_menu_label_option_property = quicksight.CfnDashboard.DataPointMenuLabelOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__794c00e4db08799105f78127f5577f7a44af0a5ceed6b50b8e2ba48e0470a8f3)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the data point menu options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointmenulabeloption.html#cfn-quicksight-dashboard-datapointmenulabeloption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPointMenuLabelOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataPointTooltipOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class DataPointTooltipOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data point tooltip options.

            :param availability_status: The status of the data point tool tip options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointtooltipoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_point_tooltip_option_property = quicksight.CfnDashboard.DataPointTooltipOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bfbdb7a441430ef0002a7319f8ecc3af008db5ee975b2c0003f5c91af43c9b06)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the data point tool tip options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointtooltipoption.html#cfn-quicksight-dashboard-datapointtooltipoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPointTooltipOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataSetIdentifierDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_set_arn": "dataSetArn", "identifier": "identifier"},
    )
    class DataSetIdentifierDeclarationProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            identifier: builtins.str,
        ) -> None:
            '''A data set.

            :param data_set_arn: The Amazon Resource Name (ARN) of the data set.
            :param identifier: The identifier of the data set, typically the data set's name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_set_identifier_declaration_property = quicksight.CfnDashboard.DataSetIdentifierDeclarationProperty(
                    data_set_arn="dataSetArn",
                    identifier="identifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__39d6ce72f4cfae32bbc755072ddd9306d8182f453234b0924c67305013fa24cc)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "identifier": identifier,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the data set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html#cfn-quicksight-dashboard-datasetidentifierdeclaration-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def identifier(self) -> builtins.str:
            '''The identifier of the data set, typically the data set's name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html#cfn-quicksight-dashboard-datasetidentifierdeclaration-identifier
            '''
            result = self._values.get("identifier")
            assert result is not None, "Required property 'identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetIdentifierDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DataSetReferenceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_arn": "dataSetArn",
            "data_set_placeholder": "dataSetPlaceholder",
        },
    )
    class DataSetReferenceProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            data_set_placeholder: builtins.str,
        ) -> None:
            '''Dataset reference.

            :param data_set_arn: Dataset Amazon Resource Name (ARN).
            :param data_set_placeholder: Dataset placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_set_reference_property = quicksight.CfnDashboard.DataSetReferenceProperty(
                    data_set_arn="dataSetArn",
                    data_set_placeholder="dataSetPlaceholder"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ffb1276fd469efa21c07a6e5c83251d4ed2658706bd09094781ee19a260f6a57)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument data_set_placeholder", value=data_set_placeholder, expected_type=type_hints["data_set_placeholder"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "data_set_placeholder": data_set_placeholder,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''Dataset Amazon Resource Name (ARN).

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html#cfn-quicksight-dashboard-datasetreference-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_placeholder(self) -> builtins.str:
            '''Dataset placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html#cfn-quicksight-dashboard-datasetreference-datasetplaceholder
            '''
            result = self._values.get("data_set_placeholder")
            assert result is not None, "Required property 'data_set_placeholder' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetReferenceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DateAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"missing_date_visibility": "missingDateVisibility"},
    )
    class DateAxisOptionsProperty:
        def __init__(
            self,
            *,
            missing_date_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine how a date axis is displayed.

            :param missing_date_visibility: Determines whether or not missing dates are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dateaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_axis_options_property = quicksight.CfnDashboard.DateAxisOptionsProperty(
                    missing_date_visibility="missingDateVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__95b5ad19dfe069f3d64428f38946307be05acb48bede3ddbc5af9f04713df137)
                check_type(argname="argument missing_date_visibility", value=missing_date_visibility, expected_type=type_hints["missing_date_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if missing_date_visibility is not None:
                self._values["missing_date_visibility"] = missing_date_visibility

        @builtins.property
        def missing_date_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not missing dates are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dateaxisoptions.html#cfn-quicksight-dashboard-dateaxisoptions-missingdatevisibility
            '''
            result = self._values.get("missing_date_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DateDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "date_granularity": "dateGranularity",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class DateDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            date_granularity: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with date type columns.

            :param column: The column that is used in the ``DateDimensionField`` .
            :param field_id: The custom field ID.
            :param date_granularity: The date granularity of the ``DateDimensionField`` . Choose one of the following options:. - ``YEAR`` - ``QUARTER`` - ``MONTH`` - ``WEEK`` - ``DAY`` - ``HOUR`` - ``MINUTE`` - ``SECOND`` - ``MILLISECOND``
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_dimension_field_property = quicksight.CfnDashboard.DateDimensionFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    date_granularity="dateGranularity",
                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__439375606295e1de09676955bbc653cd0396926f2ba587fa2c1a9ee88c8b0963)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument date_granularity", value=date_granularity, expected_type=type_hints["date_granularity"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if date_granularity is not None:
                self._values["date_granularity"] = date_granularity
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``DateDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def date_granularity(self) -> typing.Optional[builtins.str]:
            '''The date granularity of the ``DateDimensionField`` . Choose one of the following options:.

            - ``YEAR``
            - ``QUARTER``
            - ``MONTH``
            - ``WEEK``
            - ``DAY``
            - ``HOUR``
            - ``MINUTE``
            - ``SECOND``
            - ``MILLISECOND``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-dategranularity
            '''
            result = self._values.get("date_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DateMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class DateMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with date type columns.

            :param column: The column that is used in the ``DateMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_measure_field_property = quicksight.CfnDashboard.DateMeasureFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5e28262e880ab4a1e2a2a8441403133b582a042964ec45737e5c875d769ba721)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``DateMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DateTimeDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "rolling_date": "rollingDate",
            "static_values": "staticValues",
        },
    )
    class DateTimeDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rolling_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``DateTimeParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DataTimeDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param rolling_date: The rolling date of the ``DataTimeDefaultValues`` . The date is determined from the dataset based on input expression.
            :param static_values: The static values of the ``DataTimeDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_default_values_property = quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                    dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__69605c73216e22958282e5c37a83b2f02591f4dd5aab22418596e3d1b7207b52)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``DataTimeDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RollingDateConfigurationProperty"]]:
            '''The rolling date of the ``DataTimeDefaultValues`` .

            The date is determined from the dataset based on input expression.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DataTimeDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DateTimeFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class DateTimeFormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for ``DateTime`` fields.

            :param date_time_format: Determines the ``DateTime`` format.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_format_configuration_property = quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                    date_time_format="dateTimeFormat",
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cea9df0a1b6abc984c3d6e60dc06d76fb9089b61d0d649a1ceaff2e7fcc65c28)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Determines the ``DateTime`` format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericFormatConfigurationProperty"]]:
            '''The formatting configuration for numeric ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DateTimeHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class DateTimeHierarchyProperty:
        def __init__(
            self,
            *,
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :param hierarchy_id: The hierarchy ID of the ``DateTime`` hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_hierarchy_property = quicksight.CfnDashboard.DateTimeHierarchyProperty(
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2962a7a0c45203491af8f1bd4b7aaa9ebd6ed9db13d1d9d685cef080baadabd8)
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html#cfn-quicksight-dashboard-datetimehierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html#cfn-quicksight-dashboard-datetimehierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DateTimeParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "time_granularity": "timeGranularity",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DateTimeParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DateTimeDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``DateTime`` data type.

            :param name: The name of the parameter that is being declared.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnDashboard.DateTimeParameterDeclarationProperty.MappedDataSetParameters``.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value_when_unset: The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_parameter_declaration_property = quicksight.CfnDashboard.DateTimeParameterDeclarationProperty(
                    name="name",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                        dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    time_granularity="timeGranularity",
                    value_when_unset=quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__70936c6088da7bd0d74d6ccbec4d00deba440742d1961d1ac73f4d15f4d7ee9a)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MappedDataSetParameterProperty"]]]]:
            '''``CfnDashboard.DateTimeParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DateTimeParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class DateTimeParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Sequence[builtins.str],
        ) -> None:
            '''A date-time parameter.

            :param name: A display name for the date-time parameter.
            :param values: The values for the date-time parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_parameter_property = quicksight.CfnDashboard.DateTimeParameterProperty(
                    name="name",
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__824f85950bef2bd116513c64d39bd525d638eeb70cfd976f8959c13ed639dab2)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the date-time parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html#cfn-quicksight-dashboard-datetimeparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(self) -> typing.List[builtins.str]:
            '''The values for the date-time parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html#cfn-quicksight-dashboard-datetimeparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "title_options": "titleOptions",
        },
    )
    class DateTimePickerControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_picker_control_display_options_property = quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0d87a131ac70d9448e4b7dfaf3ffaa0d685d31da4754280a03a21158f0cc1c12)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html#cfn-quicksight-dashboard-datetimepickercontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html#cfn-quicksight-dashboard-datetimepickercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimePickerControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DateTimeValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_value_when_unset_configuration_property = quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__762dd648e8e8915c30be0326b2ce7490e8659c63243baf6a93f30b099400ebef)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-datetimevaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DecimalDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class DecimalDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``DecimalParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DecimalDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_default_values_property = quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                    dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__afdf80a85935c1d10fd8620e405bb680c8653c16ca2138ebad702459a08caa77)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``DecimalDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html#cfn-quicksight-dashboard-decimaldefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html#cfn-quicksight-dashboard-decimaldefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DecimalParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DecimalParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DecimalDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DecimalValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``Decimal`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnDashboard.DecimalParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_parameter_declaration_property = quicksight.CfnDashboard.DecimalParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                        dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__edec106080316f61fb384286e5beda3518ba0387954f6063651da0a25e7ba0ab)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MappedDataSetParameterProperty"]]]]:
            '''``CfnDashboard.DecimalParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DecimalParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class DecimalParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]],
        ) -> None:
            '''A decimal parameter.

            :param name: A display name for the decimal parameter.
            :param values: The values for the decimal parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_parameter_property = quicksight.CfnDashboard.DecimalParameterProperty(
                    name="name",
                    values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__adebed9e07a7e08f1bd1455352bfedcc0507dca5264b0c0de2fdf21d8727e685)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the decimal parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html#cfn-quicksight-dashboard-decimalparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]:
            '''The values for the decimal parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html#cfn-quicksight-dashboard-decimalparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DecimalPlacesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"decimal_places": "decimalPlaces"},
    )
    class DecimalPlacesConfigurationProperty:
        def __init__(self, *, decimal_places: jsii.Number) -> None:
            '''The option that determines the decimal places configuration.

            :param decimal_places: The values of the decimal places.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalplacesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_places_configuration_property = quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                    decimal_places=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2e83454d4338a6109dd29062254bde75464130540090dc35262921011503464f)
                check_type(argname="argument decimal_places", value=decimal_places, expected_type=type_hints["decimal_places"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "decimal_places": decimal_places,
            }

        @builtins.property
        def decimal_places(self) -> jsii.Number:
            '''The values of the decimal places.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalplacesconfiguration.html#cfn-quicksight-dashboard-decimalplacesconfiguration-decimalplaces
            '''
            result = self._values.get("decimal_places")
            assert result is not None, "Required property 'decimal_places' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalPlacesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DecimalValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_value_when_unset_configuration_property = quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9a0bdb1cab464ff8679346a45a7124340fda478d6ad6fafa314d04385818851)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-decimalvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultFreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings of a free-form layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultfreeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_free_form_layout_configuration_property = quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7829bb6196bd92fb1347a7dacc197bfdd3ee38a15531061c1c676e62cd3fbcc5)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultfreeformlayoutconfiguration.html#cfn-quicksight-dashboard-defaultfreeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultFreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultGridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings for a grid layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultgridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_grid_layout_configuration_property = quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1a283fca5f047250b78ee659e7283fa61747b7018d37b0b422c430747d01f913)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GridLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultgridlayoutconfiguration.html#cfn-quicksight-dashboard-defaultgridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GridLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultGridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form": "freeForm", "grid": "grid"},
    )
    class DefaultInteractiveLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DefaultFreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DefaultGridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default settings for interactive layout configuration.

            :param free_form: The options that determine the default settings of a free-form layout configuration.
            :param grid: The options that determine the default settings for a grid layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_interactive_layout_configuration_property = quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                    free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ccd6879029d47ebed2b58c9c228eddbb14659c6361e54cbae121381d7f18599d)
                check_type(argname="argument free_form", value=free_form, expected_type=type_hints["free_form"])
                check_type(argname="argument grid", value=grid, expected_type=type_hints["grid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form is not None:
                self._values["free_form"] = free_form
            if grid is not None:
                self._values["grid"] = grid

        @builtins.property
        def free_form(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DefaultFreeFormLayoutConfigurationProperty"]]:
            '''The options that determine the default settings of a free-form layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html#cfn-quicksight-dashboard-defaultinteractivelayoutconfiguration-freeform
            '''
            result = self._values.get("free_form")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DefaultFreeFormLayoutConfigurationProperty"]], result)

        @builtins.property
        def grid(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DefaultGridLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a grid layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html#cfn-quicksight-dashboard-defaultinteractivelayoutconfiguration-grid
            '''
            result = self._values.get("grid")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DefaultGridLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultInteractiveLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "interactive_layout_configuration": "interactiveLayoutConfiguration",
            "paginated_layout_configuration": "paginatedLayoutConfiguration",
            "sheet_content_type": "sheetContentType",
        },
    )
    class DefaultNewSheetConfigurationProperty:
        def __init__(
            self,
            *,
            interactive_layout_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DefaultInteractiveLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_layout_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DefaultPaginatedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sheet_content_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration for default new sheet settings.

            :param interactive_layout_configuration: The options that determine the default settings for interactive layout configuration.
            :param paginated_layout_configuration: The options that determine the default settings for a paginated layout configuration.
            :param sheet_content_type: The option that determines the sheet content type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_new_sheet_configuration_property = quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty(
                    interactive_layout_configuration=quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                        free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    ),
                    paginated_layout_configuration=quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                        section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            )
                        )
                    ),
                    sheet_content_type="sheetContentType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e403ffb5c19c681c045174a81d25ff01a2874ed06222dd75de5c0c5a8c79bd48)
                check_type(argname="argument interactive_layout_configuration", value=interactive_layout_configuration, expected_type=type_hints["interactive_layout_configuration"])
                check_type(argname="argument paginated_layout_configuration", value=paginated_layout_configuration, expected_type=type_hints["paginated_layout_configuration"])
                check_type(argname="argument sheet_content_type", value=sheet_content_type, expected_type=type_hints["sheet_content_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if interactive_layout_configuration is not None:
                self._values["interactive_layout_configuration"] = interactive_layout_configuration
            if paginated_layout_configuration is not None:
                self._values["paginated_layout_configuration"] = paginated_layout_configuration
            if sheet_content_type is not None:
                self._values["sheet_content_type"] = sheet_content_type

        @builtins.property
        def interactive_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DefaultInteractiveLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for interactive layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-interactivelayoutconfiguration
            '''
            result = self._values.get("interactive_layout_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DefaultInteractiveLayoutConfigurationProperty"]], result)

        @builtins.property
        def paginated_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DefaultPaginatedLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a paginated layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-paginatedlayoutconfiguration
            '''
            result = self._values.get("paginated_layout_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DefaultPaginatedLayoutConfigurationProperty"]], result)

        @builtins.property
        def sheet_content_type(self) -> typing.Optional[builtins.str]:
            '''The option that determines the sheet content type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-sheetcontenttype
            '''
            result = self._values.get("sheet_content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultNewSheetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"section_based": "sectionBased"},
    )
    class DefaultPaginatedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            section_based: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default settings for a paginated layout configuration.

            :param section_based: The options that determine the default settings for a section-based layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultpaginatedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_paginated_layout_configuration_property = quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                    section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac8f28333d56a49b1a7ff80996141774addbe5918efe5beed9dc667c5279c13a)
                check_type(argname="argument section_based", value=section_based, expected_type=type_hints["section_based"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if section_based is not None:
                self._values["section_based"] = section_based

        @builtins.property
        def section_based(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a section-based layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-dashboard-defaultpaginatedlayoutconfiguration-sectionbased
            '''
            result = self._values.get("section_based")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultPaginatedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultSectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings for a section-based layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultsectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_section_based_layout_configuration_property = quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c3dcfee6c8538e7d761c04438cebb74e4e7ed6fcb262a6e618ed281a57c2f19e)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-defaultsectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultSectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values_configuration": "customValuesConfiguration",
            "select_all_value_options": "selectAllValueOptions",
            "source_field": "sourceField",
            "source_parameter_name": "sourceParameterName",
        },
    )
    class DestinationParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CustomValuesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_value_options: typing.Optional[builtins.str] = None,
            source_field: typing.Optional[builtins.str] = None,
            source_parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of destination parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_values_configuration: The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .
            :param select_all_value_options: The configuration that selects all options.
            :param source_field: The source field ID of the destination parameter.
            :param source_parameter_name: The source parameter name of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                destination_parameter_value_configuration_property = quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                            date_time_values=["dateTimeValues"],
                            decimal_values=[123],
                            integer_values=[123],
                            string_values=["stringValues"]
                        ),
                
                        # the properties below are optional
                        include_null_value=False
                    ),
                    select_all_value_options="selectAllValueOptions",
                    source_field="sourceField",
                    source_parameter_name="sourceParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9d374fa1285668b208daffce1752c0a4961f0b534d210ea802c54b5972ecd814)
                check_type(argname="argument custom_values_configuration", value=custom_values_configuration, expected_type=type_hints["custom_values_configuration"])
                check_type(argname="argument select_all_value_options", value=select_all_value_options, expected_type=type_hints["select_all_value_options"])
                check_type(argname="argument source_field", value=source_field, expected_type=type_hints["source_field"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_values_configuration is not None:
                self._values["custom_values_configuration"] = custom_values_configuration
            if select_all_value_options is not None:
                self._values["select_all_value_options"] = select_all_value_options
            if source_field is not None:
                self._values["source_field"] = source_field
            if source_parameter_name is not None:
                self._values["source_parameter_name"] = source_parameter_name

        @builtins.property
        def custom_values_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomValuesConfigurationProperty"]]:
            '''The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-customvaluesconfiguration
            '''
            result = self._values.get("custom_values_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomValuesConfigurationProperty"]], result)

        @builtins.property
        def select_all_value_options(self) -> typing.Optional[builtins.str]:
            '''The configuration that selects all options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-selectallvalueoptions
            '''
            result = self._values.get("select_all_value_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_field(self) -> typing.Optional[builtins.str]:
            '''The source field ID of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-sourcefield
            '''
            result = self._values.get("source_field")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_parameter_name(self) -> typing.Optional[builtins.str]:
            '''The source parameter name of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DestinationParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_dimension_field": "categoricalDimensionField",
            "date_dimension_field": "dateDimensionField",
            "numerical_dimension_field": "numericalDimensionField",
        },
    )
    class DimensionFieldProperty:
        def __init__(
            self,
            *,
            categorical_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CategoricalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            date_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DateDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numerical_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The dimension type field.

            :param categorical_dimension_field: The dimension type field with categorical type columns.
            :param date_dimension_field: The dimension type field with date type columns.
            :param numerical_dimension_field: The dimension type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                dimension_field_property = quicksight.CfnDashboard.DimensionFieldProperty(
                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        date_granularity="dateGranularity",
                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fe4ceafe6990c62b955d1f2778daf12dd56e699b8309df454e800604764c3cae)
                check_type(argname="argument categorical_dimension_field", value=categorical_dimension_field, expected_type=type_hints["categorical_dimension_field"])
                check_type(argname="argument date_dimension_field", value=date_dimension_field, expected_type=type_hints["date_dimension_field"])
                check_type(argname="argument numerical_dimension_field", value=numerical_dimension_field, expected_type=type_hints["numerical_dimension_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_dimension_field is not None:
                self._values["categorical_dimension_field"] = categorical_dimension_field
            if date_dimension_field is not None:
                self._values["date_dimension_field"] = date_dimension_field
            if numerical_dimension_field is not None:
                self._values["numerical_dimension_field"] = numerical_dimension_field

        @builtins.property
        def categorical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CategoricalDimensionFieldProperty"]]:
            '''The dimension type field with categorical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-categoricaldimensionfield
            '''
            result = self._values.get("categorical_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CategoricalDimensionFieldProperty"]], result)

        @builtins.property
        def date_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateDimensionFieldProperty"]]:
            '''The dimension type field with date type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-datedimensionfield
            '''
            result = self._values.get("date_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateDimensionFieldProperty"]], result)

        @builtins.property
        def numerical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericalDimensionFieldProperty"]]:
            '''The dimension type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-numericaldimensionfield
            '''
            result = self._values.get("numerical_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericalDimensionFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DonutCenterOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"label_visibility": "labelVisibility"},
    )
    class DonutCenterOptionsProperty:
        def __init__(
            self,
            *,
            label_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :param label_visibility: Determines the visibility of the label in a donut chart. In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutcenteroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                donut_center_options_property = quicksight.CfnDashboard.DonutCenterOptionsProperty(
                    label_visibility="labelVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4947d789cc9737a6dab74bb656fe63d9f81ceedebcf40ea461bd90d0c5a17cc4)
                check_type(argname="argument label_visibility", value=label_visibility, expected_type=type_hints["label_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_visibility is not None:
                self._values["label_visibility"] = label_visibility

        @builtins.property
        def label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the label in a donut chart.

            In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutcenteroptions.html#cfn-quicksight-dashboard-donutcenteroptions-labelvisibility
            '''
            result = self._values.get("label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutCenterOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DonutOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc_options": "arcOptions",
            "donut_center_options": "donutCenterOptions",
        },
    )
    class DonutOptionsProperty:
        def __init__(
            self,
            *,
            arc_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ArcOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            donut_center_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DonutCenterOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for configuring a donut chart or pie chart.

            :param arc_options: The option for define the arc of the chart shape. Valid values are as follows:. - ``WHOLE`` - A pie chart - ``SMALL`` - A small-sized donut chart - ``MEDIUM`` - A medium-sized donut chart - ``LARGE`` - A large-sized donut chart
            :param donut_center_options: The label options of the label that is displayed in the center of a donut chart. This option isn't available for pie charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                donut_options_property = quicksight.CfnDashboard.DonutOptionsProperty(
                    arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                        arc_thickness="arcThickness"
                    ),
                    donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                        label_visibility="labelVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5913ecbf59f0e780db8762b39235e8ab3be1b522e778ff304bdce05d96ae108b)
                check_type(argname="argument arc_options", value=arc_options, expected_type=type_hints["arc_options"])
                check_type(argname="argument donut_center_options", value=donut_center_options, expected_type=type_hints["donut_center_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_options is not None:
                self._values["arc_options"] = arc_options
            if donut_center_options is not None:
                self._values["donut_center_options"] = donut_center_options

        @builtins.property
        def arc_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ArcOptionsProperty"]]:
            '''The option for define the arc of the chart shape. Valid values are as follows:.

            - ``WHOLE`` - A pie chart
            - ``SMALL`` - A small-sized donut chart
            - ``MEDIUM`` - A medium-sized donut chart
            - ``LARGE`` - A large-sized donut chart

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html#cfn-quicksight-dashboard-donutoptions-arcoptions
            '''
            result = self._values.get("arc_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ArcOptionsProperty"]], result)

        @builtins.property
        def donut_center_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DonutCenterOptionsProperty"]]:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html#cfn-quicksight-dashboard-donutoptions-donutcenteroptions
            '''
            result = self._values.get("donut_center_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DonutCenterOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "time_range_filter": "timeRangeFilter",
        },
    )
    class DrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CategoryDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericEqualityDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TimeRangeDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The drill down filter for the column hierarchies.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: The category type drill down filter. This filter is used for string type columns.
            :param numeric_equality_filter: The numeric equality type drill down filter. This filter is used for number type columns.
            :param time_range_filter: The time range drill down filter. This filter is used for date time columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                drill_down_filter_property = quicksight.CfnDashboard.DrillDownFilterProperty(
                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                        category_values=["categoryValues"],
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        value=123
                    ),
                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        range_maximum="rangeMaximum",
                        range_minimum="rangeMinimum",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__856a3cfa51fdf6fd0a7b8e58653fcde341d0412eb229a1aa07c9fee095dfb8bb)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CategoryDrillDownFilterProperty"]]:
            '''The category type drill down filter.

            This filter is used for string type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CategoryDrillDownFilterProperty"]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericEqualityDrillDownFilterProperty"]]:
            '''The numeric equality type drill down filter.

            This filter is used for number type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericEqualityDrillDownFilterProperty"]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TimeRangeDrillDownFilterProperty"]]:
            '''The time range drill down filter.

            This filter is used for date time columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TimeRangeDrillDownFilterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class DropDownControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            select_all_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param select_all_options: The configuration of the ``Select all`` options in a dropdown control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                drop_down_control_display_options_property = quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6b2f5242b0fad4321f93ecd6642d88e20c5e2f38b7e84dedd5e283ef1d6106fe)
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ListControlSelectAllOptionsProperty"]]:
            '''The configuration of the ``Select all`` options in a dropdown control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html#cfn-quicksight-dashboard-dropdowncontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ListControlSelectAllOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html#cfn-quicksight-dashboard-dropdowncontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DropDownControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.DynamicDefaultValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_value_column": "defaultValueColumn",
            "group_name_column": "groupNameColumn",
            "user_name_column": "userNameColumn",
        },
    )
    class DynamicDefaultValueProperty:
        def __init__(
            self,
            *,
            default_value_column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            group_name_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            user_name_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Defines different defaults to the users or groups based on mapping.

            :param default_value_column: The column that contains the default value of each user or group.
            :param group_name_column: The column that contains the group name.
            :param user_name_column: The column that contains the username.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                dynamic_default_value_property = quicksight.CfnDashboard.DynamicDefaultValueProperty(
                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a76342c977b70befa54135e482bd4ad163e8704a12cde4861b8a96705d34c29c)
                check_type(argname="argument default_value_column", value=default_value_column, expected_type=type_hints["default_value_column"])
                check_type(argname="argument group_name_column", value=group_name_column, expected_type=type_hints["group_name_column"])
                check_type(argname="argument user_name_column", value=user_name_column, expected_type=type_hints["user_name_column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_value_column": default_value_column,
            }
            if group_name_column is not None:
                self._values["group_name_column"] = group_name_column
            if user_name_column is not None:
                self._values["user_name_column"] = user_name_column

        @builtins.property
        def default_value_column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that contains the default value of each user or group.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-defaultvaluecolumn
            '''
            result = self._values.get("default_value_column")
            assert result is not None, "Required property 'default_value_column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def group_name_column(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]]:
            '''The column that contains the group name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-groupnamecolumn
            '''
            result = self._values.get("group_name_column")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]], result)

        @builtins.property
        def user_name_column(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]]:
            '''The column that contains the username.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-usernamecolumn
            '''
            result = self._values.get("user_name_column")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DynamicDefaultValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.EmptyVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
        },
    )
    class EmptyVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''An empty visual.

            Empty visuals are used in layouts but have not been configured to show any data. A new visual created in the Amazon QuickSight console is considered an ``EmptyVisual`` until a visual type is selected.

            :param data_set_identifier: The data set that is used in the empty visual. Every visual requires a dataset to render.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                empty_visual_property = quicksight.CfnDashboard.EmptyVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f01ba9a07d855673258fc9f0387691820e38b72f5d04cdf9e3fb642f1fe4d405)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in the empty visual.

            Every visual requires a dataset to render.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EmptyVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.EntityProperty",
        jsii_struct_bases=[],
        name_mapping={"path": "path"},
    )
    class EntityProperty:
        def __init__(self, *, path: typing.Optional[builtins.str] = None) -> None:
            '''An object, structure, or sub-structure of an analysis, template, or dashboard.

            :param path: The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-entity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                entity_property = quicksight.CfnDashboard.EntityProperty(
                    path="path"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0535b9caa7bc0f5989529241ee57902786b9337c53a6525ce777188e2f1f3140)
                check_type(argname="argument path", value=path, expected_type=type_hints["path"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if path is not None:
                self._values["path"] = path

        @builtins.property
        def path(self) -> typing.Optional[builtins.str]:
            '''The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-entity.html#cfn-quicksight-dashboard-entity-path
            '''
            result = self._values.get("path")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ExcludePeriodConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "amount": "amount",
            "granularity": "granularity",
            "status": "status",
        },
    )
    class ExcludePeriodConfigurationProperty:
        def __init__(
            self,
            *,
            amount: jsii.Number,
            granularity: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The exclude period of ``TimeRangeFilter`` or ``RelativeDatesFilter`` .

            :param amount: The amount or number of the exclude period.
            :param granularity: The granularity or unit (day, month, year) of the exclude period.
            :param status: The status of the exclude period. Choose from the following options:. - ``ENABLED`` - ``DISABLED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                exclude_period_configuration_property = quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                    amount=123,
                    granularity="granularity",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__276f1c6f517b23eee62d19a3ed4cfb00a0225e807e7f66f05bc1be5bc4034fae)
                check_type(argname="argument amount", value=amount, expected_type=type_hints["amount"])
                check_type(argname="argument granularity", value=granularity, expected_type=type_hints["granularity"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "amount": amount,
                "granularity": granularity,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def amount(self) -> jsii.Number:
            '''The amount or number of the exclude period.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-amount
            '''
            result = self._values.get("amount")
            assert result is not None, "Required property 'amount' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def granularity(self) -> builtins.str:
            '''The granularity or unit (day, month, year) of the exclude period.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-granularity
            '''
            result = self._values.get("granularity")
            assert result is not None, "Required property 'granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the exclude period. Choose from the following options:.

            - ``ENABLED``
            - ``DISABLED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExcludePeriodConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ExplicitHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class ExplicitHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :param columns: The list of columns that define the explicit hierarchy.
            :param hierarchy_id: The hierarchy ID of the explicit hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                explicit_hierarchy_property = quicksight.CfnDashboard.ExplicitHierarchyProperty(
                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ed45f7d11a6f3c5ae74c5635e384418ce066e31c93371f318e952446e1f4b496)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]]]:
            '''The list of columns that define the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExplicitHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class ExportHiddenFieldsOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines if hidden fields are included in an exported dashboard.

            :param availability_status: The status of the export hidden fields options of a dashbaord.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporthiddenfieldsoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                export_hidden_fields_option_property = quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__68a0f1c7b932b1e67f02418900d17f9cb2dcc1927dbd48fc4b8442283f17292e)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the export hidden fields options of a dashbaord.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporthiddenfieldsoption.html#cfn-quicksight-dashboard-exporthiddenfieldsoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExportHiddenFieldsOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ExportToCSVOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class ExportToCSVOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Export to .csv option.

            :param availability_status: Availability status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporttocsvoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                export_to_cSVOption_property = quicksight.CfnDashboard.ExportToCSVOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a10f24a03440d898d5e89d497d328b00831653b62a278324ca65ca96ddef52ee)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''Availability status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporttocsvoption.html#cfn-quicksight-dashboard-exporttocsvoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExportToCSVOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ExportWithHiddenFieldsOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class ExportWithHiddenFieldsOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines whether or not hidden fields are visible on exported dashbaords.

            :param availability_status: The status of the export with hidden fields options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exportwithhiddenfieldsoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                export_with_hidden_fields_option_property = quicksight.CfnDashboard.ExportWithHiddenFieldsOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1bffee76d2a25382c4563857c2d117a3e343af4b5170984e70a4029c25ef415b)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the export with hidden fields options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exportwithhiddenfieldsoption.html#cfn-quicksight-dashboard-exportwithhiddenfieldsoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExportWithHiddenFieldsOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FieldBasedTooltipProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_visibility": "aggregationVisibility",
            "tooltip_fields": "tooltipFields",
            "tooltip_title_type": "tooltipTitleType",
        },
    )
    class FieldBasedTooltipProperty:
        def __init__(
            self,
            *,
            aggregation_visibility: typing.Optional[builtins.str] = None,
            tooltip_fields: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            tooltip_title_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The setup for the detailed tooltip.

            :param aggregation_visibility: The visibility of ``Show aggregations`` .
            :param tooltip_fields: The fields configuration in the tooltip.
            :param tooltip_title_type: The type for the >tooltip title. Choose one of the following options:. - ``NONE`` : Doesn't use the primary value as the title. - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_based_tooltip_property = quicksight.CfnDashboard.FieldBasedTooltipProperty(
                    aggregation_visibility="aggregationVisibility",
                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            label="label",
                            visibility="visibility"
                        ),
                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            label="label",
                            visibility="visibility"
                        )
                    )],
                    tooltip_title_type="tooltipTitleType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4566d0f5217b4da258276dd2b03d857cd25b79021ec0c15930330aa95a4d5536)
                check_type(argname="argument aggregation_visibility", value=aggregation_visibility, expected_type=type_hints["aggregation_visibility"])
                check_type(argname="argument tooltip_fields", value=tooltip_fields, expected_type=type_hints["tooltip_fields"])
                check_type(argname="argument tooltip_title_type", value=tooltip_title_type, expected_type=type_hints["tooltip_title_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if aggregation_visibility is not None:
                self._values["aggregation_visibility"] = aggregation_visibility
            if tooltip_fields is not None:
                self._values["tooltip_fields"] = tooltip_fields
            if tooltip_title_type is not None:
                self._values["tooltip_title_type"] = tooltip_title_type

        @builtins.property
        def aggregation_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of ``Show aggregations`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-aggregationvisibility
            '''
            result = self._values.get("aggregation_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_fields(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipItemProperty"]]]]:
            '''The fields configuration in the tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-tooltipfields
            '''
            result = self._values.get("tooltip_fields")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipItemProperty"]]]], result)

        @builtins.property
        def tooltip_title_type(self) -> typing.Optional[builtins.str]:
            '''The type for the >tooltip title. Choose one of the following options:.

            - ``NONE`` : Doesn't use the primary value as the title.
            - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-tooltiptitletype
            '''
            result = self._values.get("tooltip_title_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldBasedTooltipProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FieldLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "visibility": "visibility"},
    )
    class FieldLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The field label type.

            :param field_id: Indicates the field that is targeted by the field label.
            :param visibility: The visibility of the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_label_type_property = quicksight.CfnDashboard.FieldLabelTypeProperty(
                    field_id="fieldId",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__58bb42996227cf98d7d838c3d86d09bd7875d5066358c6de757946154deb0d41)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''Indicates the field that is targeted by the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html#cfn-quicksight-dashboard-fieldlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html#cfn-quicksight-dashboard-fieldlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "settings": "settings",
        },
    )
    class FieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field for which you are setting the axis binding.
            :param settings: The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_series_item_property = quicksight.CfnDashboard.FieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2467034994483dc1260912d3f4e901f62134b0c8503bc62b87ce3f0eec2988b1)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field for which you are setting the axis binding.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartSeriesSettingsProperty"]]:
            '''The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartSeriesSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column_sort": "columnSort", "field_sort": "fieldSort"},
    )
    class FieldSortOptionsProperty:
        def __init__(
            self,
            *,
            column_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field sort options in a chart configuration.

            :param column_sort: The sort configuration for a column that is not used in a field well.
            :param field_sort: The sort configuration for a field in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_sort_options_property = quicksight.CfnDashboard.FieldSortOptionsProperty(
                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ca35aac02d97e7e66cc2ba4caa3b2188f0582b5d9ed67390cb85dcea6d850342)
                check_type(argname="argument column_sort", value=column_sort, expected_type=type_hints["column_sort"])
                check_type(argname="argument field_sort", value=field_sort, expected_type=type_hints["field_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_sort is not None:
                self._values["column_sort"] = column_sort
            if field_sort is not None:
                self._values["field_sort"] = field_sort

        @builtins.property
        def column_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnSortProperty"]]:
            '''The sort configuration for a column that is not used in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html#cfn-quicksight-dashboard-fieldsortoptions-columnsort
            '''
            result = self._values.get("column_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnSortProperty"]], result)

        @builtins.property
        def field_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortProperty"]]:
            '''The sort configuration for a field in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html#cfn-quicksight-dashboard-fieldsortoptions-fieldsort
            '''
            result = self._values.get("field_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FieldSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "field_id": "fieldId"},
    )
    class FieldSortProperty:
        def __init__(self, *, direction: builtins.str, field_id: builtins.str) -> None:
            '''The sort configuration for a field in a field well.

            :param direction: The sort direction. Choose one of the following options:. - ``ASC`` : Ascending - ``DESC`` : Descending
            :param field_id: The sort configuration target field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_sort_property = quicksight.CfnDashboard.FieldSortProperty(
                    direction="direction",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__26672b93e4548bd08910decb70adfecc4e08a7d34bc9af4ea3c7c1620201882d)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "field_id": field_id,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction. Choose one of the following options:.

            - ``ASC`` : Ascending
            - ``DESC`` : Descending

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html#cfn-quicksight-dashboard-fieldsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The sort configuration target field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html#cfn-quicksight-dashboard-fieldsort-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FieldTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class FieldTooltipItemProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the fields.

            :param field_id: The unique ID of the field that is targeted by the tooltip.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_tooltip_item_property = quicksight.CfnDashboard.FieldTooltipItemProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__51dca7939ab3839617c9068d3b2e2772d946aa360f4c94b587eab7e2a155a218)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The unique ID of the field that is targeted by the tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"geospatial": "geospatial", "values": "values"},
    )
    class FilledMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well of the filled map.

            :param geospatial: The aggregated location field well of the filled map. Values are grouped by location fields.
            :param values: The aggregated color field well of a filled map. Values are aggregated based on location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_aggregated_field_wells_property = quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                    geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__124b87657f930b94dd2a4ee74a847b2c3e1868e456c7e472be2f83d17b6eda2d)
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The aggregated location field well of the filled map.

            Values are grouped by location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html#cfn-quicksight-dashboard-filledmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The aggregated color field well of a filled map.

            Values are aggregated based on location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html#cfn-quicksight-dashboard-filledmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"shape": "shape"},
    )
    class FilledMapConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            shape: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilledMapShapeConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :param shape: The conditional formatting that determines the shape of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_conditional_formatting_option_property = quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                    shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6a11bbeb9f1f70cc4b58792bf02d9aeee8b2c614d6aef772c7b8ccdc01acb953)
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "shape": shape,
            }

        @builtins.property
        def shape(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapShapeConditionalFormattingProperty"]:
            '''The conditional formatting that determines the shape of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformattingoption.html#cfn-quicksight-dashboard-filledmapconditionalformattingoption-shape
            '''
            result = self._values.get("shape")
            assert result is not None, "Required property 'shape' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapShapeConditionalFormattingProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilledMapConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class FilledMapConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilledMapConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_conditional_formatting_property = quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                        shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b37b8ad4c92decb9d6abbea55fc2892bfcf59d813167d0a34b52950979738848)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "conditional_formatting_options": conditional_formatting_options,
            }

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapConditionalFormattingOptionProperty"]]]:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformatting.html#cfn-quicksight-dashboard-filledmapconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            assert result is not None, "Required property 'conditional_formatting_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapConditionalFormattingOptionProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilledMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "window_options": "windowOptions",
        },
    )
    class FilledMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilledMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilledMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            window_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``FilledMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the filled map visual.
            :param sort_configuration: The sort configuration of a ``FilledMapVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param window_options: The window options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_configuration_property = quicksight.CfnDashboard.FilledMapConfigurationProperty(
                    field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                        filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                            geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                        base_map_style="baseMapStyle"
                    ),
                    sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                        bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                            east=123,
                            north=123,
                            south=123,
                            west=123
                        ),
                        map_zoom_mode="mapZoomMode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__996c9332d7d22db081ea7ad249fe18d03313b8cd55383d7995c8818b84cd18e7)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialMapStyleOptionsProperty"]]:
            '''The map style options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialMapStyleOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapSortConfigurationProperty"]]:
            '''The sort configuration of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialWindowOptionsProperty"]]:
            '''The window options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialWindowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilledMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filled_map_aggregated_field_wells": "filledMapAggregatedFieldWells",
        },
    )
    class FilledMapFieldWellsProperty:
        def __init__(
            self,
            *,
            filled_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilledMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``FilledMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filled_map_aggregated_field_wells: The aggregated field well of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_field_wells_property = quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                    filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                        geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d2aecc0ee208c4837c9578033fe84882b65e3bb7a222f33665c47e3a27834382)
                check_type(argname="argument filled_map_aggregated_field_wells", value=filled_map_aggregated_field_wells, expected_type=type_hints["filled_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filled_map_aggregated_field_wells is not None:
                self._values["filled_map_aggregated_field_wells"] = filled_map_aggregated_field_wells

        @builtins.property
        def filled_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field well of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapfieldwells.html#cfn-quicksight-dashboard-filledmapfieldwells-filledmapaggregatedfieldwells
            '''
            result = self._values.get("filled_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "format": "format"},
    )
    class FilledMapShapeConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ShapeConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting that determines the shape of the filled map.

            :param field_id: The field ID of the filled map shape.
            :param format: The conditional formatting that determines the background color of a filled map's shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_shape_conditional_formatting_property = quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__64deff2cc8940b5e9c20d128e696aeb0186446210b1b99a76801ca45d0e2a67c)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if format is not None:
                self._values["format"] = format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the filled map shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html#cfn-quicksight-dashboard-filledmapshapeconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ShapeConditionalFormatProperty"]]:
            '''The conditional formatting that determines the background color of a filled map's shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html#cfn-quicksight-dashboard-filledmapshapeconditionalformatting-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ShapeConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapShapeConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilledMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"category_sort": "categorySort"},
    )
    class FilledMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FilledMapVisual`` .

            :param category_sort: The sort configuration of the location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_sort_configuration_property = quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac6bcf88085744d1ecf9b8ad78f5c961fd1bc0f5afd538cbc9828f315405b4db)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapsortconfiguration.html#cfn-quicksight-dashboard-filledmapsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilledMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FilledMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilledMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilledMapConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a ``FilledMapVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_visual_property = quicksight.CfnDashboard.FilledMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.FilledMapConfigurationProperty(
                        field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                            filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                                geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                            base_map_style="baseMapStyle"
                        ),
                        sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                            bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                east=123,
                                north=123,
                                south=123,
                                west=123
                            ),
                            map_zoom_mode="mapZoomMode"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    conditional_formatting=quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                            shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__747c522cff2db38ababdc616ca416c1f0bbaad3e5450ed686d29cdd222a8604d)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapConditionalFormattingProperty"]]:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "relative_date_time": "relativeDateTime",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class FilterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            dropdown: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterListControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_date_time: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterRelativeDateTimeControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            slider: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterSliderControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_area: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The control of a filter that is used to interact with a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date filter that is used to specify date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list of buttons or boxes. This is used to select either a single value or multiple values.
            :param relative_date_time: A control from a date filter that is used to specify the relative date.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_control_property = quicksight.CfnDashboard.FilterControlProperty(
                    date_time_picker=quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    dropdown=quicksight.CfnDashboard.FilterDropDownControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                            select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnDashboard.FilterListControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                            search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    relative_date_time=quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    slider=quicksight.CfnDashboard.FilterSliderControlProperty(
                        filter_control_id="filterControlId",
                        maximum_value=123,
                        minimum_value=123,
                        source_filter_id="sourceFilterId",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    text_area=quicksight.CfnDashboard.FilterTextAreaControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnDashboard.FilterTextFieldControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__638913be2a432dd85cd6afd0eaeacc1be67b527021857ba46e789a7faa792cc5)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument relative_date_time", value=relative_date_time, expected_type=type_hints["relative_date_time"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if relative_date_time is not None:
                self._values["relative_date_time"] = relative_date_time
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterDateTimePickerControlProperty"]]:
            '''A control from a date filter that is used to specify date and time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterDateTimePickerControlProperty"]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterDropDownControlProperty"]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterDropDownControlProperty"]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterListControlProperty"]]:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterListControlProperty"]], result)

        @builtins.property
        def relative_date_time(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterRelativeDateTimeControlProperty"]]:
            '''A control from a date filter that is used to specify the relative date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-relativedatetime
            '''
            result = self._values.get("relative_date_time")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterRelativeDateTimeControlProperty"]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterSliderControlProperty"]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterSliderControlProperty"]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterTextAreaControlProperty"]]:
            '''A control to display a text box that is used to enter multiple entries.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterTextAreaControlProperty"]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterTextFieldControlProperty"]]:
            '''A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterTextFieldControlProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control from a date filter that is used to specify date and time.

            :param filter_control_id: The ID of the ``FilterDateTimePickerControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDateTimePickerControl`` .
            :param title: The title of the ``FilterDateTimePickerControl`` .
            :param display_options: The display options of a control.
            :param type: The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:. - ``SINGLE_VALUED`` : The filter condition is a fixed date. - ``DATE_RANGE`` : The filter condition is a date time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_date_time_picker_control_property = quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c2645a3ecca348bcb6ddd9edaf7dece1a230f6d8ef50e8a54cdfcd48919bae1b)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimePickerControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimePickerControlDisplayOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:.

            - ``SINGLE_VALUED`` : The filter condition is a fixed date.
            - ``DATE_RANGE`` : The filter condition is a date time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterDropDownControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param filter_control_id: The ID of the ``FilterDropDownControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDropDownControl`` .
            :param title: The title of the ``FilterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of the ``FilterDropDownControl`` .
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of the ``FilterDropDownControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu. - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_drop_down_control_property = quicksight.CfnDashboard.FilterDropDownControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                        select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e8125d83669b486dca262ab91b9a18447811457c9a61f158fc966fe7f4f9be58)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DropDownControlDisplayOptionsProperty"]]:
            '''The display options of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DropDownControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of the ``FilterDropDownControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu.
            - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterGroupProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cross_dataset": "crossDataset",
            "filter_group_id": "filterGroupId",
            "filters": "filters",
            "scope_configuration": "scopeConfiguration",
            "status": "status",
        },
    )
    class FilterGroupProperty:
        def __init__(
            self,
            *,
            cross_dataset: builtins.str,
            filter_group_id: builtins.str,
            filters: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterProperty", typing.Dict[builtins.str, typing.Any]]]]],
            scope_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A grouping of individual filters. Filter groups are applied to the same group of visuals.

            For more information, see `Adding filter conditions (group filters) with AND and OR operators <https://docs.aws.amazon.com/quicksight/latest/user/add-a-compound-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :param cross_dataset: The filter new feature which can apply filter group to all data sets. Choose one of the following options:. - ``ALL_DATASETS`` - ``SINGLE_DATASET``
            :param filter_group_id: The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.
            :param filters: The list of filters that are present in a ``FilterGroup`` .
            :param scope_configuration: The configuration that specifies what scope to apply to a ``FilterGroup`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param status: The status of the ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_group_property = quicksight.CfnDashboard.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnDashboard.FilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnDashboard.NumericRangeFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnDashboard.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnDashboard.TimeEqualityFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            parameter_name="parameterName",
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnDashboard.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection"
                            )],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnDashboard.FilterScopeConfigurationProperty(
                        selected_sheets=quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
                
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__85ac1a51359f22ce66c29219edc8464ca7c29007b7250085e5e2b607e5c124ff)
                check_type(argname="argument cross_dataset", value=cross_dataset, expected_type=type_hints["cross_dataset"])
                check_type(argname="argument filter_group_id", value=filter_group_id, expected_type=type_hints["filter_group_id"])
                check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
                check_type(argname="argument scope_configuration", value=scope_configuration, expected_type=type_hints["scope_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "cross_dataset": cross_dataset,
                "filter_group_id": filter_group_id,
                "filters": filters,
                "scope_configuration": scope_configuration,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def cross_dataset(self) -> builtins.str:
            '''The filter new feature which can apply filter group to all data sets. Choose one of the following options:.

            - ``ALL_DATASETS``
            - ``SINGLE_DATASET``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-crossdataset
            '''
            result = self._values.get("cross_dataset")
            assert result is not None, "Required property 'cross_dataset' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filter_group_id(self) -> builtins.str:
            '''The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-filtergroupid
            '''
            result = self._values.get("filter_group_id")
            assert result is not None, "Required property 'filter_group_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filters(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterProperty"]]]:
            '''The list of filters that are present in a ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-filters
            '''
            result = self._values.get("filters")
            assert result is not None, "Required property 'filters' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterProperty"]]], result)

        @builtins.property
        def scope_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterScopeConfigurationProperty"]:
            '''The configuration that specifies what scope to apply to a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-scopeconfiguration
            '''
            result = self._values.get("scope_configuration")
            assert result is not None, "Required property 'scope_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterScopeConfigurationProperty"], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class FilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of filter configurations.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_list_configuration_property = quicksight.CfnDashboard.FilterListConfigurationProperty(
                    match_operator="matchOperator",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__99b532857c54410a622c4589e9ed6acd5be9f710cfad98df0d88123cee396ebf)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterListControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :param filter_control_id: The ID of the ``FilterListControl`` .
            :param source_filter_id: The source filter ID of the ``FilterListControl`` .
            :param title: The title of the ``FilterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``FilterListControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from the list. - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_list_control_property = quicksight.CfnDashboard.FilterListControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                        search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a5ca20cbd17c4af88ec327e1e7f8c9d4aa7b250b3997e4d4a07cd42c97687cd)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ListControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ListControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterListControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from the list.
            - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_field_options": "selectedFieldOptions",
            "selected_fields": "selectedFields",
        },
    )
    class FilterOperationSelectedFieldsConfigurationProperty:
        def __init__(
            self,
            *,
            selected_field_options: typing.Optional[builtins.str] = None,
            selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of selected fields in the ``CustomActionFilterOperation`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_field_options: A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` . Valid values are defined as follows: - ``ALL_FIELDS`` : Applies the filter operation to all fields.
            :param selected_fields: Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_operation_selected_fields_configuration_property = quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                    selected_field_options="selectedFieldOptions",
                    selected_fields=["selectedFields"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a7625ab1e3e46b5936967088962fd07ac0966226e89e6b562009e24983323d0a)
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
                check_type(argname="argument selected_fields", value=selected_fields, expected_type=type_hints["selected_fields"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options
            if selected_fields is not None:
                self._values["selected_fields"] = selected_fields

        @builtins.property
        def selected_field_options(self) -> typing.Optional[builtins.str]:
            '''A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` .

            Valid values are defined as follows:

            - ``ALL_FIELDS`` : Applies the filter operation to all fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-dashboard-filteroperationselectedfieldsconfiguration-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def selected_fields(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-dashboard-filteroperationselectedfieldsconfiguration-selectedfields
            '''
            result = self._values.get("selected_fields")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationSelectedFieldsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "same_sheet_target_visual_configuration": "sameSheetTargetVisualConfiguration",
        },
    )
    class FilterOperationTargetVisualsConfigurationProperty:
        def __init__(
            self,
            *,
            same_sheet_target_visual_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SameSheetTargetVisualConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param same_sheet_target_visual_configuration: The configuration of the same-sheet target visuals that you want to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationtargetvisualsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_operation_target_visuals_configuration_property = quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                        target_visual_options="targetVisualOptions",
                        target_visuals=["targetVisuals"]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__06e18cc8085d97db1fd90a4d3b00dfab05c2b3cb99e4899a96f99e3a6357e89b)
                check_type(argname="argument same_sheet_target_visual_configuration", value=same_sheet_target_visual_configuration, expected_type=type_hints["same_sheet_target_visual_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if same_sheet_target_visual_configuration is not None:
                self._values["same_sheet_target_visual_configuration"] = same_sheet_target_visual_configuration

        @builtins.property
        def same_sheet_target_visual_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SameSheetTargetVisualConfigurationProperty"]]:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-dashboard-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
            '''
            result = self._values.get("same_sheet_target_visual_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SameSheetTargetVisualConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationTargetVisualsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "numeric_range_filter": "numericRangeFilter",
            "relative_dates_filter": "relativeDatesFilter",
            "time_equality_filter": "timeEqualityFilter",
            "time_range_filter": "timeRangeFilter",
            "top_bottom_filter": "topBottomFilter",
        },
    )
    class FilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CategoryFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_dates_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RelativeDatesFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TimeEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TimeRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TopBottomFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''With a ``Filter`` , you can remove portions of data from a particular visual or view.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: A ``CategoryFilter`` filters text values. For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .
            :param numeric_equality_filter: A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.
            :param numeric_range_filter: A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.
            :param relative_dates_filter: A ``RelativeDatesFilter`` filters date values that are relative to a given date.
            :param time_equality_filter: A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.
            :param time_range_filter: A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.
            :param top_bottom_filter: A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_property = quicksight.CfnDashboard.FilterProperty(
                    category_filter=quicksight.CfnDashboard.CategoryFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                            custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_value="categoryValue",
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions"
                            ),
                            custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            ),
                            filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                                match_operator="matchOperator",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            )
                        ),
                        filter_id="filterId"
                    ),
                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions",
                        value=123
                    ),
                    numeric_range_filter=quicksight.CfnDashboard.NumericRangeFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        select_all_options="selectAllOptions"
                    ),
                    relative_dates_filter=quicksight.CfnDashboard.RelativeDatesFilterProperty(
                        anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                            anchor_option="anchorOption",
                            parameter_name="parameterName"
                        ),
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                        relative_date_type="relativeDateType",
                        time_granularity="timeGranularity",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        minimum_granularity="minimumGranularity",
                        parameter_name="parameterName",
                        relative_date_value=123
                    ),
                    time_equality_filter=quicksight.CfnDashboard.TimeEqualityFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        parameter_name="parameterName",
                        time_granularity="timeGranularity",
                        value="value"
                    ),
                    time_range_filter=quicksight.CfnDashboard.TimeRangeFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        time_granularity="timeGranularity"
                    ),
                    top_bottom_filter=quicksight.CfnDashboard.TopBottomFilterProperty(
                        aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            sort_direction="sortDirection"
                        )],
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        limit=123,
                        parameter_name="parameterName",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__89bd72abe7faf3a55676a07daf0572aa02eb6aa4ea3f1d80043e055b7e1521a6)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument numeric_range_filter", value=numeric_range_filter, expected_type=type_hints["numeric_range_filter"])
                check_type(argname="argument relative_dates_filter", value=relative_dates_filter, expected_type=type_hints["relative_dates_filter"])
                check_type(argname="argument time_equality_filter", value=time_equality_filter, expected_type=type_hints["time_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
                check_type(argname="argument top_bottom_filter", value=top_bottom_filter, expected_type=type_hints["top_bottom_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if numeric_range_filter is not None:
                self._values["numeric_range_filter"] = numeric_range_filter
            if relative_dates_filter is not None:
                self._values["relative_dates_filter"] = relative_dates_filter
            if time_equality_filter is not None:
                self._values["time_equality_filter"] = time_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter
            if top_bottom_filter is not None:
                self._values["top_bottom_filter"] = top_bottom_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CategoryFilterProperty"]]:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CategoryFilterProperty"]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericEqualityFilterProperty"]]:
            '''A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericEqualityFilterProperty"]], result)

        @builtins.property
        def numeric_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericRangeFilterProperty"]]:
            '''A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-numericrangefilter
            '''
            result = self._values.get("numeric_range_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericRangeFilterProperty"]], result)

        @builtins.property
        def relative_dates_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RelativeDatesFilterProperty"]]:
            '''A ``RelativeDatesFilter`` filters date values that are relative to a given date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-relativedatesfilter
            '''
            result = self._values.get("relative_dates_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RelativeDatesFilterProperty"]], result)

        @builtins.property
        def time_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TimeEqualityFilterProperty"]]:
            '''A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-timeequalityfilter
            '''
            result = self._values.get("time_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TimeEqualityFilterProperty"]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TimeRangeFilterProperty"]]:
            '''A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TimeRangeFilterProperty"]], result)

        @builtins.property
        def top_bottom_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TopBottomFilterProperty"]]:
            '''A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-topbottomfilter
            '''
            result = self._values.get("top_bottom_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TopBottomFilterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterRelativeDateTimeControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control from a date filter that is used to specify the relative date.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_relative_date_time_control_property = quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dd7bc988e00e114a77db48e3a49a92f914acb22ce6b0f3317c49a738c447e11c)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterRelativeDateTimeControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"selected_sheets": "selectedSheets"},
    )
    class FilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            selected_sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The scope configuration for a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_sheets: The configuration for applying a filter to specific sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_scope_configuration_property = quicksight.CfnDashboard.FilterScopeConfigurationProperty(
                    selected_sheets=quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                        sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                            scope="scope",
                            sheet_id="sheetId",
                
                            # the properties below are optional
                            visual_ids=["visualIds"]
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__acfbc829249d0e2d5db2925ff199f08d175815f54b4cf1b3106b632835eaea83)
                check_type(argname="argument selected_sheets", value=selected_sheets, expected_type=type_hints["selected_sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_sheets is not None:
                self._values["selected_sheets"] = selected_sheets

        @builtins.property
        def selected_sheets(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty"]]:
            '''The configuration for applying a filter to specific sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterscopeconfiguration.html#cfn-quicksight-dashboard-filterscopeconfiguration-selectedsheets
            '''
            result = self._values.get("selected_sheets")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class FilterSelectableValuesProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param values: The values that are used in the ``FilterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_selectable_values_property = quicksight.CfnDashboard.FilterSelectableValuesProperty(
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1370fa00a8135bd20b225e968548b8f64bfbbcded4a9f7099a4a497f24444b6e)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in the ``FilterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterselectablevalues.html#cfn-quicksight-dashboard-filterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "source_filter_id": "sourceFilterId",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterSliderControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            source_filter_id: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param filter_control_id: The ID of the ``FilterSliderControl`` .
            :param maximum_value: The smaller value that is displayed at the left of the slider.
            :param minimum_value: The larger value that is displayed at the right of the slider.
            :param source_filter_id: The source filter ID of the ``FilterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into.
            :param title: The title of the ``FilterSliderControl`` .
            :param display_options: The display options of a control.
            :param type: The type of ``FilterSliderControl`` . Choose one of the following options:. - ``SINGLE_POINT`` : Filter against(equals) a single data point. - ``RANGE`` : Filter data that is in a specified range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_slider_control_property = quicksight.CfnDashboard.FilterSliderControlProperty(
                    filter_control_id="filterControlId",
                    maximum_value=123,
                    minimum_value=123,
                    source_filter_id="sourceFilterId",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dd38e3f62eb6ca1919347327f33cd1f3445dd4a52ffa44382ce68496a8e39bf4)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "source_filter_id": source_filter_id,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SliderControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SliderControlDisplayOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterSliderControl`` . Choose one of the following options:.

            - ``SINGLE_POINT`` : Filter against(equals) a single data point.
            - ``RANGE`` : Filter data that is in a specified range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class FilterTextAreaControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_text_area_control_property = quicksight.CfnDashboard.FilterTextAreaControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd8d6a90a9ca3784ef0eb38d6cb93516cafd14de57b6e60118bd613495a53a96)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextAreaControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextAreaControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FilterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterTextFieldControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param filter_control_id: The ID of the ``FilterTextFieldControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextFieldControl`` .
            :param title: The title of the ``FilterTextFieldControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_text_field_control_property = quicksight.CfnDashboard.FilterTextFieldControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e8fb6ca0c2232cba9adefd93cc8c6a3df28d2e005d6d45c845c3461f48597db9)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextFieldControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextFieldControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FontConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_color": "fontColor",
            "font_decoration": "fontDecoration",
            "font_size": "fontSize",
            "font_style": "fontStyle",
            "font_weight": "fontWeight",
        },
    )
    class FontConfigurationProperty:
        def __init__(
            self,
            *,
            font_color: typing.Optional[builtins.str] = None,
            font_decoration: typing.Optional[builtins.str] = None,
            font_size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FontSizeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_style: typing.Optional[builtins.str] = None,
            font_weight: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FontWeightProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configures the display properties of the given text.

            :param font_color: Determines the color of the text.
            :param font_decoration: Determines the appearance of decorative lines on the text.
            :param font_size: The option that determines the text display size.
            :param font_style: Determines the text display face that is inherited by the given font family.
            :param font_weight: The option that determines the text display weight, or boldness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                font_configuration_property = quicksight.CfnDashboard.FontConfigurationProperty(
                    font_color="fontColor",
                    font_decoration="fontDecoration",
                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                        relative="relative"
                    ),
                    font_style="fontStyle",
                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7f64367ed66330789e99449900860951714a003772dd9941af443a4859df5ef3)
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_decoration", value=font_decoration, expected_type=type_hints["font_decoration"])
                check_type(argname="argument font_size", value=font_size, expected_type=type_hints["font_size"])
                check_type(argname="argument font_style", value=font_style, expected_type=type_hints["font_style"])
                check_type(argname="argument font_weight", value=font_weight, expected_type=type_hints["font_weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_decoration is not None:
                self._values["font_decoration"] = font_decoration
            if font_size is not None:
                self._values["font_size"] = font_size
            if font_style is not None:
                self._values["font_style"] = font_style
            if font_weight is not None:
                self._values["font_weight"] = font_weight

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_decoration(self) -> typing.Optional[builtins.str]:
            '''Determines the appearance of decorative lines on the text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontdecoration
            '''
            result = self._values.get("font_decoration")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_size(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontSizeProperty"]]:
            '''The option that determines the text display size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontsize
            '''
            result = self._values.get("font_size")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontSizeProperty"]], result)

        @builtins.property
        def font_style(self) -> typing.Optional[builtins.str]:
            '''Determines the text display face that is inherited by the given font family.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontstyle
            '''
            result = self._values.get("font_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_weight(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontWeightProperty"]]:
            '''The option that determines the text display weight, or boldness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontweight
            '''
            result = self._values.get("font_weight")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontWeightProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FontSizeProperty",
        jsii_struct_bases=[],
        name_mapping={"relative": "relative"},
    )
    class FontSizeProperty:
        def __init__(self, *, relative: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display size.

            :param relative: The lexical name for the text size, proportional to its surrounding context.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontsize.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                font_size_property = quicksight.CfnDashboard.FontSizeProperty(
                    relative="relative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2eea1ec2fbf52bab3ad89eee77400ba28b6e629c6263b37206191a44ca98d93b)
                check_type(argname="argument relative", value=relative, expected_type=type_hints["relative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if relative is not None:
                self._values["relative"] = relative

        @builtins.property
        def relative(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the text size, proportional to its surrounding context.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontsize.html#cfn-quicksight-dashboard-fontsize-relative
            '''
            result = self._values.get("relative")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontSizeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FontWeightProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name"},
    )
    class FontWeightProperty:
        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display weight, or boldness.

            :param name: The lexical name for the level of boldness of the text display.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontweight.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                font_weight_property = quicksight.CfnDashboard.FontWeightProperty(
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f171ce2bb67b344733a663777f1299d8b94d15b871ed1d128555f582b4470eac)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the level of boldness of the text display.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontweight.html#cfn-quicksight-dashboard-fontweight-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontWeightProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ForecastComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "custom_seasonality_value": "customSeasonalityValue",
            "lower_boundary": "lowerBoundary",
            "name": "name",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
            "value": "value",
        },
    )
    class ForecastComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            custom_seasonality_value: typing.Optional[jsii.Number] = None,
            lower_boundary: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[builtins.str] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param custom_seasonality_value: The custom seasonality value setup of a forecast computation.
            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param name: The name of a computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``AUTOMATIC`` - ``CUSTOM`` : Checks the custom seasonality value.
            :param upper_boundary: The upper boundary setup of a forecast computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                forecast_computation_property = quicksight.CfnDashboard.ForecastComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    custom_seasonality_value=123,
                    lower_boundary=123,
                    name="name",
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality="seasonality",
                    upper_boundary=123,
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5b377e4d88f9d0de22a5997638a597b9ba6d2086e6caf6ab68bf0ac44f82056a)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument custom_seasonality_value", value=custom_seasonality_value, expected_type=type_hints["custom_seasonality_value"])
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if custom_seasonality_value is not None:
                self._values["custom_seasonality_value"] = custom_seasonality_value
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if name is not None:
                self._values["name"] = name
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"], result)

        @builtins.property
        def custom_seasonality_value(self) -> typing.Optional[jsii.Number]:
            '''The custom seasonality value setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-customseasonalityvalue
            '''
            result = self._values.get("custom_seasonality_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[builtins.str]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``AUTOMATIC``
            - ``CUSTOM`` : Checks the custom seasonality value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ForecastConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast_properties": "forecastProperties",
            "scenario": "scenario",
        },
    )
    class ForecastConfigurationProperty:
        def __init__(
            self,
            *,
            forecast_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TimeBasedForecastPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ForecastScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast configuration that is used in a line chart's display properties.

            :param forecast_properties: The forecast properties setup of a forecast in the line chart.
            :param scenario: The forecast scenario of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                forecast_configuration_property = quicksight.CfnDashboard.ForecastConfigurationProperty(
                    forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                        lower_boundary=123,
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality=123,
                        upper_boundary=123
                    ),
                    scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                        what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                            date="date",
                            value=123
                        ),
                        what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                            end_date="endDate",
                            start_date="startDate",
                            value=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__724d72a7b8bc74c6cdf72583a7346ad5a950425215c7dfc02627c737ac60587e)
                check_type(argname="argument forecast_properties", value=forecast_properties, expected_type=type_hints["forecast_properties"])
                check_type(argname="argument scenario", value=scenario, expected_type=type_hints["scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast_properties is not None:
                self._values["forecast_properties"] = forecast_properties
            if scenario is not None:
                self._values["scenario"] = scenario

        @builtins.property
        def forecast_properties(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TimeBasedForecastPropertiesProperty"]]:
            '''The forecast properties setup of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html#cfn-quicksight-dashboard-forecastconfiguration-forecastproperties
            '''
            result = self._values.get("forecast_properties")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TimeBasedForecastPropertiesProperty"]], result)

        @builtins.property
        def scenario(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ForecastScenarioProperty"]]:
            '''The forecast scenario of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html#cfn-quicksight-dashboard-forecastconfiguration-scenario
            '''
            result = self._values.get("scenario")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ForecastScenarioProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ForecastScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "what_if_point_scenario": "whatIfPointScenario",
            "what_if_range_scenario": "whatIfRangeScenario",
        },
    )
    class ForecastScenarioProperty:
        def __init__(
            self,
            *,
            what_if_point_scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WhatIfPointScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            what_if_range_scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WhatIfRangeScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast scenario of a forecast in the line chart.

            :param what_if_point_scenario: The what-if analysis forecast setup with the target date.
            :param what_if_range_scenario: The what-if analysis forecast setup with the date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                forecast_scenario_property = quicksight.CfnDashboard.ForecastScenarioProperty(
                    what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                        date="date",
                        value=123
                    ),
                    what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                        end_date="endDate",
                        start_date="startDate",
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c296ec190aa9cdb0571154df2e357ef8d8a9b2f48b30244eea677fd1f6a928e)
                check_type(argname="argument what_if_point_scenario", value=what_if_point_scenario, expected_type=type_hints["what_if_point_scenario"])
                check_type(argname="argument what_if_range_scenario", value=what_if_range_scenario, expected_type=type_hints["what_if_range_scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if what_if_point_scenario is not None:
                self._values["what_if_point_scenario"] = what_if_point_scenario
            if what_if_range_scenario is not None:
                self._values["what_if_range_scenario"] = what_if_range_scenario

        @builtins.property
        def what_if_point_scenario(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WhatIfPointScenarioProperty"]]:
            '''The what-if analysis forecast setup with the target date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html#cfn-quicksight-dashboard-forecastscenario-whatifpointscenario
            '''
            result = self._values.get("what_if_point_scenario")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WhatIfPointScenarioProperty"]], result)

        @builtins.property
        def what_if_range_scenario(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WhatIfRangeScenarioProperty"]]:
            '''The what-if analysis forecast setup with the date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html#cfn-quicksight-dashboard-forecastscenario-whatifrangescenario
            '''
            result = self._values.get("what_if_range_scenario")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WhatIfRangeScenarioProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format_configuration": "dateTimeFormatConfiguration",
            "number_format_configuration": "numberFormatConfiguration",
            "string_format_configuration": "stringFormatConfiguration",
        },
    )
    class FormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            string_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for all types of field.

            :param date_time_format_configuration: Formatting configuration for ``DateTime`` fields.
            :param number_format_configuration: Formatting configuration for number fields.
            :param string_format_configuration: Formatting configuration for string fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                format_configuration_property = quicksight.CfnDashboard.FormatConfigurationProperty(
                    date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f54ef847cd92ae8b7ac64700c85a30cab90d672ef84f495f1a11c9b2bf7c1c34)
                check_type(argname="argument date_time_format_configuration", value=date_time_format_configuration, expected_type=type_hints["date_time_format_configuration"])
                check_type(argname="argument number_format_configuration", value=number_format_configuration, expected_type=type_hints["number_format_configuration"])
                check_type(argname="argument string_format_configuration", value=string_format_configuration, expected_type=type_hints["string_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format_configuration is not None:
                self._values["date_time_format_configuration"] = date_time_format_configuration
            if number_format_configuration is not None:
                self._values["number_format_configuration"] = number_format_configuration
            if string_format_configuration is not None:
                self._values["string_format_configuration"] = string_format_configuration

        @builtins.property
        def date_time_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeFormatConfigurationProperty"]]:
            '''Formatting configuration for ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-datetimeformatconfiguration
            '''
            result = self._values.get("date_time_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeFormatConfigurationProperty"]], result)

        @builtins.property
        def number_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumberFormatConfigurationProperty"]]:
            '''Formatting configuration for number fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-numberformatconfiguration
            '''
            result = self._values.get("number_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumberFormatConfigurationProperty"]], result)

        @builtins.property
        def string_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringFormatConfigurationProperty"]]:
            '''Formatting configuration for string fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-stringformatconfiguration
            '''
            result = self._values.get("string_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class FreeFormLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configuration options for the canvas of a free-form layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_canvas_size_options_property = quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62cec2b8ebf236742f1b0a291d056576356344fb822aae5b1c372b9d04cc938e)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty"]]:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-freeformlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class FreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a free-form layout.

            :param elements: The elements that are included in a free-form layout.
            :param canvas_size_options: ``CfnDashboard.FreeFormLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_configuration_property = quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3d9ea4a9fec0940ab21cca4f3917394d97661c47fc396bc1e5d698aa0184714d)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutElementProperty"]]]:
            '''The elements that are included in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html#cfn-quicksight-dashboard-freeformlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutElementProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty"]]:
            '''``CfnDashboard.FreeFormLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html#cfn-quicksight-dashboard-freeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBackgroundStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The background color of a free-form layout element.
            :param visibility: The background visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_element_background_style_property = quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c5a2673a45fd2cbd3a3374234e3722b2a63b142f708cfaea0d421f2ebdbc240)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The background color of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-dashboard-freeformlayoutelementbackgroundstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The background visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-dashboard-freeformlayoutelementbackgroundstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBackgroundStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBorderStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The border color of a free-form layout element.
            :param visibility: The border visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_element_border_style_property = quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__595fb28c4e3087a61773e5e72419f87b168dbff612a5317df0d52fb93599bcee)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The border color of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html#cfn-quicksight-dashboard-freeformlayoutelementborderstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The border visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html#cfn-quicksight-dashboard-freeformlayoutelementborderstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBorderStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FreeFormLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "element_id": "elementId",
            "element_type": "elementType",
            "height": "height",
            "width": "width",
            "x_axis_location": "xAxisLocation",
            "y_axis_location": "yAxisLocation",
            "background_style": "backgroundStyle",
            "border_style": "borderStyle",
            "loading_animation": "loadingAnimation",
            "rendering_rules": "renderingRules",
            "selected_border_style": "selectedBorderStyle",
            "visibility": "visibility",
        },
    )
    class FreeFormLayoutElementProperty:
        def __init__(
            self,
            *,
            element_id: builtins.str,
            element_type: builtins.str,
            height: builtins.str,
            width: builtins.str,
            x_axis_location: builtins.str,
            y_axis_location: builtins.str,
            background_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            border_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            loading_animation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LoadingAnimationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rendering_rules: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SheetElementRenderingRuleProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_border_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An element within a free-form layout.

            :param element_id: A unique identifier for an element within a free-form layout.
            :param element_type: The type of element.
            :param height: The height of an element within a free-form layout.
            :param width: The width of an element within a free-form layout.
            :param x_axis_location: The x-axis coordinate of the element.
            :param y_axis_location: The y-axis coordinate of the element.
            :param background_style: The background style configuration of a free-form layout element.
            :param border_style: The border style configuration of a free-form layout element.
            :param loading_animation: The loading animation configuration of a free-form layout element.
            :param rendering_rules: The rendering rules that determine when an element should be displayed within a free-form layout.
            :param selected_border_style: The border style configuration of a free-form layout element. This border style is used when the element is selected.
            :param visibility: The visibility of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_element_property = quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                    element_id="elementId",
                    element_type="elementType",
                    height="height",
                    width="width",
                    x_axis_location="xAxisLocation",
                    y_axis_location="yAxisLocation",
                
                    # the properties below are optional
                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                        visibility="visibility"
                    ),
                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                            visibility="visibility"
                        ),
                        expression="expression"
                    )],
                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c4f8ba3241a3ca34d8cf51c1352ae6e3f51bb0086d05b866e1272e2c1433fbe1)
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
                check_type(argname="argument x_axis_location", value=x_axis_location, expected_type=type_hints["x_axis_location"])
                check_type(argname="argument y_axis_location", value=y_axis_location, expected_type=type_hints["y_axis_location"])
                check_type(argname="argument background_style", value=background_style, expected_type=type_hints["background_style"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument loading_animation", value=loading_animation, expected_type=type_hints["loading_animation"])
                check_type(argname="argument rendering_rules", value=rendering_rules, expected_type=type_hints["rendering_rules"])
                check_type(argname="argument selected_border_style", value=selected_border_style, expected_type=type_hints["selected_border_style"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "element_id": element_id,
                "element_type": element_type,
                "height": height,
                "width": width,
                "x_axis_location": x_axis_location,
                "y_axis_location": y_axis_location,
            }
            if background_style is not None:
                self._values["background_style"] = background_style
            if border_style is not None:
                self._values["border_style"] = border_style
            if loading_animation is not None:
                self._values["loading_animation"] = loading_animation
            if rendering_rules is not None:
                self._values["rendering_rules"] = rendering_rules
            if selected_border_style is not None:
                self._values["selected_border_style"] = selected_border_style
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def height(self) -> builtins.str:
            '''The height of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-height
            '''
            result = self._values.get("height")
            assert result is not None, "Required property 'height' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def width(self) -> builtins.str:
            '''The width of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-width
            '''
            result = self._values.get("width")
            assert result is not None, "Required property 'width' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def x_axis_location(self) -> builtins.str:
            '''The x-axis coordinate of the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-xaxislocation
            '''
            result = self._values.get("x_axis_location")
            assert result is not None, "Required property 'x_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def y_axis_location(self) -> builtins.str:
            '''The y-axis coordinate of the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-yaxislocation
            '''
            result = self._values.get("y_axis_location")
            assert result is not None, "Required property 'y_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def background_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty"]]:
            '''The background style configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-backgroundstyle
            '''
            result = self._values.get("background_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty"]], result)

        @builtins.property
        def border_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutElementBorderStyleProperty"]]:
            '''The border style configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutElementBorderStyleProperty"]], result)

        @builtins.property
        def loading_animation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LoadingAnimationProperty"]]:
            '''The loading animation configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-loadinganimation
            '''
            result = self._values.get("loading_animation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LoadingAnimationProperty"]], result)

        @builtins.property
        def rendering_rules(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetElementRenderingRuleProperty"]]]]:
            '''The rendering rules that determine when an element should be displayed within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-renderingrules
            '''
            result = self._values.get("rendering_rules")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetElementRenderingRuleProperty"]]]], result)

        @builtins.property
        def selected_border_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutElementBorderStyleProperty"]]:
            '''The border style configuration of a free-form layout element.

            This border style is used when the element is selected.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-selectedborderstyle
            '''
            result = self._values.get("selected_border_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutElementBorderStyleProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"optimized_view_port_width": "optimizedViewPortWidth"},
    )
    class FreeFormLayoutScreenCanvasSizeOptionsProperty:
        def __init__(self, *, optimized_view_port_width: builtins.str) -> None:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_screen_canvas_size_options_property = quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cbab328a90a7fb5b0d47cb2374a56f053e12880e40460bef814ebfe31f50e4c3)
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "optimized_view_port_width": optimized_view_port_width,
            }

        @builtins.property
        def optimized_view_port_width(self) -> builtins.str:
            '''The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            assert result is not None, "Required property 'optimized_view_port_width' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"elements": "elements"},
    )
    class FreeFormSectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The free-form layout configuration of a section.

            :param elements: The elements that are included in the free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformsectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_section_layout_configuration_property = quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__21e4e9cdc9e83a7a30a1a852d62a2718fa5000015bf1541d7fc978b0b357f427)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutElementProperty"]]]:
            '''The elements that are included in the free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformsectionlayoutconfiguration.html#cfn-quicksight-dashboard-freeformsectionlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutElementProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormSectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "values": "values"},
    )
    class FunnelChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :param category: The category field wells of a funnel chart. Values are grouped by category fields.
            :param values: The value field wells of a funnel chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_aggregated_field_wells_property = quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8f4d7bfeeef0ba1679d4e04422287c3591dad73890b895061605857d2118435f)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The category field wells of a funnel chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html#cfn-quicksight-dashboard-funnelchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a funnel chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html#cfn-quicksight-dashboard-funnelchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FunnelChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "data_label_options": "dataLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class FunnelChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FunnelChartDataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FunnelChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FunnelChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``FunnelChartVisual`` .

            :param category_label_options: The label options of the categories that are displayed in a ``FunnelChartVisual`` .
            :param data_label_options: The options that determine the presentation of the data labels.
            :param field_wells: The field well configuration of a ``FunnelChartVisual`` .
            :param sort_configuration: The sort configuration of a ``FunnelChartVisual`` .
            :param tooltip: The tooltip configuration of a ``FunnelChartVisual`` .
            :param value_label_options: The label options for the values that are displayed in a ``FunnelChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_configuration_property = quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        label_color="labelColor",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_data_label_style="measureDataLabelStyle",
                        measure_label_visibility="measureLabelVisibility",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                        funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5408b7ad9c45513c79a9c7d27fea9824628e951b373e1b8eb6d785f48225dfdb)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument data_label_options", value=data_label_options, expected_type=type_hints["data_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if data_label_options is not None:
                self._values["data_label_options"] = data_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the categories that are displayed in a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FunnelChartDataLabelOptionsProperty"]]:
            '''The options that determine the presentation of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-datalabeloptions
            '''
            result = self._values.get("data_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FunnelChartDataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FunnelChartFieldWellsProperty"]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FunnelChartFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FunnelChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FunnelChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options for the values that are displayed in a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]]:
            '''The visual palette configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "label_color": "labelColor",
            "label_font_configuration": "labelFontConfiguration",
            "measure_data_label_style": "measureDataLabelStyle",
            "measure_label_visibility": "measureLabelVisibility",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class FunnelChartDataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            measure_data_label_style: typing.Optional[builtins.str] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: The visibility of the category labels within the data labels.
            :param label_color: The color of the data label text.
            :param label_font_configuration: The font configuration for the data labels. Only the ``FontSize`` attribute of the font configuration is used for data labels.
            :param measure_data_label_style: Determines the style of the metric labels.
            :param measure_label_visibility: The visibility of the measure labels within the data labels.
            :param position: Determines the positioning of the data label relative to a section of the funnel.
            :param visibility: The visibility option that determines if data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_data_label_options_property = quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    label_color="labelColor",
                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_data_label_style="measureDataLabelStyle",
                    measure_label_visibility="measureLabelVisibility",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__deec2c3cb1679f33656cc892f4a326aa310e0b557ed24e418324bdf7d74127d1)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_data_label_style", value=measure_data_label_style, expected_type=type_hints["measure_data_label_style"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_data_label_style is not None:
                self._values["measure_data_label_style"] = measure_data_label_style
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the category labels within the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''The color of the data label text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]]:
            '''The font configuration for the data labels.

            Only the ``FontSize`` attribute of the font configuration is used for data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def measure_data_label_style(self) -> typing.Optional[builtins.str]:
            '''Determines the style of the metric labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-measuredatalabelstyle
            '''
            result = self._values.get("measure_data_label_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the measure labels within the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the positioning of the data label relative to a section of the funnel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility option that determines if data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartDataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FunnelChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "funnel_chart_aggregated_field_wells": "funnelChartAggregatedFieldWells",
        },
    )
    class FunnelChartFieldWellsProperty:
        def __init__(
            self,
            *,
            funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FunnelChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param funnel_chart_aggregated_field_wells: The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_field_wells_property = quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                    funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__139945867af8c199f2cd2a07a16e0ebe15aeec4fb5a3481a070a36b77f6fbdc6)
                check_type(argname="argument funnel_chart_aggregated_field_wells", value=funnel_chart_aggregated_field_wells, expected_type=type_hints["funnel_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if funnel_chart_aggregated_field_wells is not None:
                self._values["funnel_chart_aggregated_field_wells"] = funnel_chart_aggregated_field_wells

        @builtins.property
        def funnel_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FunnelChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartfieldwells.html#cfn-quicksight-dashboard-funnelchartfieldwells-funnelchartaggregatedfieldwells
            '''
            result = self._values.get("funnel_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FunnelChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FunnelChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class FunnelChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :param category_items_limit: The limit on the number of categories displayed.
            :param category_sort: The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_sort_configuration_property = quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f44cac5696d984fa70bf7a48b3b626bac9cf4b5825e2ee7be3f97c62378a226)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html#cfn-quicksight-dashboard-funnelchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html#cfn-quicksight-dashboard-funnelchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.FunnelChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FunnelChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FunnelChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``FunnelChartVisual`` .
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_visual_property = quicksight.CfnDashboard.FunnelChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            label_color="labelColor",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_data_label_style="measureDataLabelStyle",
                            measure_label_visibility="measureLabelVisibility",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                            funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__53ba8e52b9ddc401c0d395c8b95aa21641efa1bddf68e8f93b0beae95a4fd62f)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FunnelChartConfigurationProperty"]]:
            '''The configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FunnelChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class GaugeChartArcConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :param foreground_color: The conditional formatting of the arc foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartarcconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_arc_conditional_formatting_property = quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                    foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4241990415d6140f5e5b81a7512dc7b0160a7360ff50b9829ab646c913e14152)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the arc foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartarcconditionalformatting.html#cfn-quicksight-dashboard-gaugechartarcconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartArcConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"arc": "arc", "primary_value": "primaryValue"},
    )
    class GaugeChartConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GaugeChartArcConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :param arc: The options that determine the presentation of the arc of a ``GaugeChartVisual`` .
            :param primary_value: The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_option_property = quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                    arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e44815dd5aab0a29d8a5c53286496eac76c122401332c19f768d70aa3f950daa)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if primary_value is not None:
                self._values["primary_value"] = primary_value

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartArcConditionalFormattingProperty"]]:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html#cfn-quicksight-dashboard-gaugechartconditionalformattingoption-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartArcConditionalFormattingProperty"]], result)

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html#cfn-quicksight-dashboard-gaugechartconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class GaugeChartConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GaugeChartConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_property = quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                        arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a61e2ae32b891e0a58ad40885a0a916f9b545e9ae253aeb96e98001745b4e90e)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformatting.html#cfn-quicksight-dashboard-gaugechartconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GaugeChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "gauge_chart_options": "gaugeChartOptions",
            "tooltip_options": "tooltipOptions",
            "visual_palette": "visualPalette",
        },
    )
    class GaugeChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GaugeChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            gauge_chart_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GaugeChartOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``GaugeChartVisual`` .

            :param data_labels: The data label configuration of a ``GaugeChartVisual`` .
            :param field_wells: The field well configuration of a ``GaugeChartVisual`` .
            :param gauge_chart_options: The options that determine the presentation of the ``GaugeChartVisual`` .
            :param tooltip_options: The tooltip configuration of a ``GaugeChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_configuration_property = quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                        target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                        arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                            arc_angle=123,
                            arc_thickness="arcThickness"
                        ),
                        arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                            range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                max=123,
                                min=123
                            ),
                            reserve_range=123
                        ),
                        comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                            comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            comparison_method="comparisonMethod"
                        ),
                        primary_value_display_type="primaryValueDisplayType",
                        primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        )
                    ),
                    tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__518f0635b23232e7714b54ea6bad80445809895698428139769dac9f1fdf38ff)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument gauge_chart_options", value=gauge_chart_options, expected_type=type_hints["gauge_chart_options"])
                check_type(argname="argument tooltip_options", value=tooltip_options, expected_type=type_hints["tooltip_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if gauge_chart_options is not None:
                self._values["gauge_chart_options"] = gauge_chart_options
            if tooltip_options is not None:
                self._values["tooltip_options"] = tooltip_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The data label configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartFieldWellsProperty"]]:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartFieldWellsProperty"]], result)

        @builtins.property
        def gauge_chart_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartOptionsProperty"]]:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-gaugechartoptions
            '''
            result = self._values.get("gauge_chart_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartOptionsProperty"]], result)

        @builtins.property
        def tooltip_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-tooltipoptions
            '''
            result = self._values.get("tooltip_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]]:
            '''The visual palette configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GaugeChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"target_values": "targetValues", "values": "values"},
    )
    class GaugeChartFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :param target_values: The target value field wells of a ``GaugeChartVisual`` .
            :param values: The value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_field_wells_property = quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                    target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__012cdfa537531c16ce8b36202c1f22b6e72cd76df5e86a0ae86e2d27d7e2106e)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The target value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html#cfn-quicksight-dashboard-gaugechartfieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html#cfn-quicksight-dashboard-gaugechartfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GaugeChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc": "arc",
            "arc_axis": "arcAxis",
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
        },
    )
    class GaugeChartOptionsProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ArcConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            arc_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ArcAxisConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :param arc: The arc configuration of a ``GaugeChartVisual`` .
            :param arc_axis: The arc axis configuration of a ``GaugeChartVisual`` .
            :param comparison: The comparison configuration of a ``GaugeChartVisual`` .
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_options_property = quicksight.CfnDashboard.GaugeChartOptionsProperty(
                    arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                        arc_angle=123,
                        arc_thickness="arcThickness"
                    ),
                    arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                        range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                            max=123,
                            min=123
                        ),
                        reserve_range=123
                    ),
                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__88aa13a7a43657b84ac0b776d9f1af13953d656c06193b62876d790c9227b6af)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument arc_axis", value=arc_axis, expected_type=type_hints["arc_axis"])
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if arc_axis is not None:
                self._values["arc_axis"] = arc_axis
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ArcConfigurationProperty"]]:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ArcConfigurationProperty"]], result)

        @builtins.property
        def arc_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ArcAxisConfigurationProperty"]]:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-arcaxis
            '''
            result = self._values.get("arc_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ArcAxisConfigurationProperty"]], result)

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComparisonConfigurationProperty"]]:
            '''The comparison configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComparisonConfigurationProperty"]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]]:
            '''The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class GaugeChartPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :param icon: The conditional formatting of the primary value icon.
            :param text_color: The conditional formatting of the primary value text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_primary_value_conditional_formatting_property = quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b88947d77af9cf63ba6024b2f31c265f286ad16839391a0b6331462402b0237)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the primary value icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the primary value text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GaugeChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GaugeChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GaugeChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GaugeChartConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``GaugeChartVisual`` .
            :param conditional_formatting: The conditional formatting of a ``GaugeChartVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_visual_property = quicksight.CfnDashboard.GaugeChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                            target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                            arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                                arc_angle=123,
                                arc_thickness="arcThickness"
                            ),
                            arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                                range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                    max=123,
                                    min=123
                                ),
                                reserve_range=123
                            ),
                            comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                comparison_method="comparisonMethod"
                            ),
                            primary_value_display_type="primaryValueDisplayType",
                            primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        ),
                        tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    conditional_formatting=quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                            arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                                foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            ),
                            primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e3411775a2b530ed4e3c05acd4c07b5181957cc7bb4752c78b4a8ac933cccaca)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartConfigurationProperty"]]:
            '''The configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartConditionalFormattingProperty"]]:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "east": "east",
            "north": "north",
            "south": "south",
            "west": "west",
        },
    )
    class GeospatialCoordinateBoundsProperty:
        def __init__(
            self,
            *,
            east: jsii.Number,
            north: jsii.Number,
            south: jsii.Number,
            west: jsii.Number,
        ) -> None:
            '''The bound options (north, south, west, east) of the geospatial window options.

            :param east: The longitude of the east bound of the geospatial coordinate bounds.
            :param north: The latitude of the north bound of the geospatial coordinate bounds.
            :param south: The latitude of the south bound of the geospatial coordinate bounds.
            :param west: The longitude of the west bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_coordinate_bounds_property = quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                    east=123,
                    north=123,
                    south=123,
                    west=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac99491030b0807af0037a5ad5daa0bca2a6cf96a6e379f361d50d640c230573)
                check_type(argname="argument east", value=east, expected_type=type_hints["east"])
                check_type(argname="argument north", value=north, expected_type=type_hints["north"])
                check_type(argname="argument south", value=south, expected_type=type_hints["south"])
                check_type(argname="argument west", value=west, expected_type=type_hints["west"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "east": east,
                "north": north,
                "south": south,
                "west": west,
            }

        @builtins.property
        def east(self) -> jsii.Number:
            '''The longitude of the east bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-east
            '''
            result = self._values.get("east")
            assert result is not None, "Required property 'east' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def north(self) -> jsii.Number:
            '''The latitude of the north bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-north
            '''
            result = self._values.get("north")
            assert result is not None, "Required property 'north' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def south(self) -> jsii.Number:
            '''The latitude of the south bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-south
            '''
            result = self._values.get("south")
            assert result is not None, "Required property 'south' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def west(self) -> jsii.Number:
            '''The longitude of the west bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-west
            '''
            result = self._values.get("west")
            assert result is not None, "Required property 'west' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialCoordinateBoundsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "colors": "colors",
            "geospatial": "geospatial",
            "values": "values",
        },
    )
    class GeospatialMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            geospatial: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells for a geospatial map.

            :param colors: The color field wells of a geospatial map.
            :param geospatial: The geospatial field wells of a geospatial map. Values are grouped by geospatial fields.
            :param values: The size field wells of a geospatial map. Values are aggregated based on geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_aggregated_field_wells_property = quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b7dcb38c8a85191c9d0004754cab5a8735061556fa8d072df0b1f6547f3a191f)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The color field wells of a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The geospatial field wells of a geospatial map.

            Values are grouped by geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The size field wells of a geospatial map.

            Values are aggregated based on geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GeospatialMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "point_style_options": "pointStyleOptions",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "window_options": "windowOptions",
        },
    )
    class GeospatialMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GeospatialMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            point_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GeospatialPointStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            window_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``GeospatialMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the geospatial map.
            :param point_style_options: The point style options of the geospatial map.
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: ``CfnDashboard.GeospatialMapConfigurationProperty.VisualPalette``.
            :param window_options: The window options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_configuration_property = quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                    field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                        geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                        base_map_style="baseMapStyle"
                    ),
                    point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                        cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                            cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                    color="color"
                                )
                            )
                        ),
                        selected_point_style="selectedPointStyle"
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                        bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                            east=123,
                            north=123,
                            south=123,
                            west=123
                        ),
                        map_zoom_mode="mapZoomMode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0c14adcf773cee098865e31a68b60b4f0ecab765bbc7bb64deebb110acf6ae72)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument point_style_options", value=point_style_options, expected_type=type_hints["point_style_options"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if point_style_options is not None:
                self._values["point_style_options"] = point_style_options
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialMapStyleOptionsProperty"]]:
            '''The map style options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialMapStyleOptionsProperty"]], result)

        @builtins.property
        def point_style_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialPointStyleOptionsProperty"]]:
            '''The point style options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-pointstyleoptions
            '''
            result = self._values.get("point_style_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialPointStyleOptionsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]]:
            '''``CfnDashboard.GeospatialMapConfigurationProperty.VisualPalette``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialWindowOptionsProperty"]]:
            '''The window options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialWindowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GeospatialMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "geospatial_map_aggregated_field_wells": "geospatialMapAggregatedFieldWells",
        },
    )
    class GeospatialMapFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GeospatialMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``GeospatialMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param geospatial_map_aggregated_field_wells: The aggregated field well for a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_field_wells_property = quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                    geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__29922be5190581199130c11ae1faf2a5c909b33547f7636faf7676808058dd53)
                check_type(argname="argument geospatial_map_aggregated_field_wells", value=geospatial_map_aggregated_field_wells, expected_type=type_hints["geospatial_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial_map_aggregated_field_wells is not None:
                self._values["geospatial_map_aggregated_field_wells"] = geospatial_map_aggregated_field_wells

        @builtins.property
        def geospatial_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapfieldwells.html#cfn-quicksight-dashboard-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
            '''
            result = self._values.get("geospatial_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"base_map_style": "baseMapStyle"},
    )
    class GeospatialMapStyleOptionsProperty:
        def __init__(
            self,
            *,
            base_map_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The map style options of the geospatial map.

            :param base_map_style: The base map style of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_style_options_property = quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                    base_map_style="baseMapStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c6e345279f7b64bd21f34a33b3fa16704943d7f8f291612a2c7d7cffe530bb7c)
                check_type(argname="argument base_map_style", value=base_map_style, expected_type=type_hints["base_map_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base_map_style is not None:
                self._values["base_map_style"] = base_map_style

        @builtins.property
        def base_map_style(self) -> typing.Optional[builtins.str]:
            '''The base map style of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapstyleoptions.html#cfn-quicksight-dashboard-geospatialmapstyleoptions-basemapstyle
            '''
            result = self._values.get("base_map_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GeospatialMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GeospatialMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GeospatialMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_visual_property = quicksight.CfnDashboard.GeospatialMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                        field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                            geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                                colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                            base_map_style="baseMapStyle"
                        ),
                        point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                            cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                                cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                    simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                        color="color"
                                    )
                                )
                            ),
                            selected_point_style="selectedPointStyle"
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                            bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                east=123,
                                north=123,
                                south=123,
                                west=123
                            ),
                            map_zoom_mode="mapZoomMode"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f5dc93630eabb85f7097df1672b181209066fa6075895cce2c27ccd5995a7c9d)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cluster_marker_configuration": "clusterMarkerConfiguration",
            "selected_point_style": "selectedPointStyle",
        },
    )
    class GeospatialPointStyleOptionsProperty:
        def __init__(
            self,
            *,
            cluster_marker_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ClusterMarkerConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_point_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The point style of the geospatial map.

            :param cluster_marker_configuration: The cluster marker configuration of the geospatial point style.
            :param selected_point_style: The selected point styles (point, cluster) of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_point_style_options_property = quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                    cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                        cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                            simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                color="color"
                            )
                        )
                    ),
                    selected_point_style="selectedPointStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__afb401aaad1f5765ac0725c2bb3b394ed33254e1402c955372a938bd6b6ac71f)
                check_type(argname="argument cluster_marker_configuration", value=cluster_marker_configuration, expected_type=type_hints["cluster_marker_configuration"])
                check_type(argname="argument selected_point_style", value=selected_point_style, expected_type=type_hints["selected_point_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker_configuration is not None:
                self._values["cluster_marker_configuration"] = cluster_marker_configuration
            if selected_point_style is not None:
                self._values["selected_point_style"] = selected_point_style

        @builtins.property
        def cluster_marker_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ClusterMarkerConfigurationProperty"]]:
            '''The cluster marker configuration of the geospatial point style.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html#cfn-quicksight-dashboard-geospatialpointstyleoptions-clustermarkerconfiguration
            '''
            result = self._values.get("cluster_marker_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ClusterMarkerConfigurationProperty"]], result)

        @builtins.property
        def selected_point_style(self) -> typing.Optional[builtins.str]:
            '''The selected point styles (point, cluster) of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html#cfn-quicksight-dashboard-geospatialpointstyleoptions-selectedpointstyle
            '''
            result = self._values.get("selected_point_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialPointStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GeospatialWindowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bounds": "bounds", "map_zoom_mode": "mapZoomMode"},
    )
    class GeospatialWindowOptionsProperty:
        def __init__(
            self,
            *,
            bounds: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GeospatialCoordinateBoundsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_zoom_mode: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The window options of the geospatial map visual.

            :param bounds: The bounds options (north, south, west, east) of the geospatial window options.
            :param map_zoom_mode: The map zoom modes (manual, auto) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_window_options_property = quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                    bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                        east=123,
                        north=123,
                        south=123,
                        west=123
                    ),
                    map_zoom_mode="mapZoomMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d85b0a5e8f407b25d63a044e9f7c56aa0fd6d813f8eacd99b9ccab13b690ec58)
                check_type(argname="argument bounds", value=bounds, expected_type=type_hints["bounds"])
                check_type(argname="argument map_zoom_mode", value=map_zoom_mode, expected_type=type_hints["map_zoom_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bounds is not None:
                self._values["bounds"] = bounds
            if map_zoom_mode is not None:
                self._values["map_zoom_mode"] = map_zoom_mode

        @builtins.property
        def bounds(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialCoordinateBoundsProperty"]]:
            '''The bounds options (north, south, west, east) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html#cfn-quicksight-dashboard-geospatialwindowoptions-bounds
            '''
            result = self._values.get("bounds")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialCoordinateBoundsProperty"]], result)

        @builtins.property
        def map_zoom_mode(self) -> typing.Optional[builtins.str]:
            '''The map zoom modes (manual, auto) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html#cfn-quicksight-dashboard-geospatialwindowoptions-mapzoommode
            '''
            result = self._values.get("map_zoom_mode")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialWindowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GlobalTableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "side_specific_border": "sideSpecificBorder",
            "uniform_border": "uniformBorder",
        },
    )
    class GlobalTableBorderOptionsProperty:
        def __init__(
            self,
            *,
            side_specific_border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableSideBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            uniform_border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the border options for a table visual.

            :param side_specific_border: Determines the options for side specific border.
            :param uniform_border: Determines the options for uniform border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                global_table_border_options_property = quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a111a028e4e373bf6b153cc9e7ddfd0d48748c3c8cb03c58ebdf973d8186672b)
                check_type(argname="argument side_specific_border", value=side_specific_border, expected_type=type_hints["side_specific_border"])
                check_type(argname="argument uniform_border", value=uniform_border, expected_type=type_hints["uniform_border"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if side_specific_border is not None:
                self._values["side_specific_border"] = side_specific_border
            if uniform_border is not None:
                self._values["uniform_border"] = uniform_border

        @builtins.property
        def side_specific_border(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableSideBorderOptionsProperty"]]:
            '''Determines the options for side specific border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html#cfn-quicksight-dashboard-globaltableborderoptions-sidespecificborder
            '''
            result = self._values.get("side_specific_border")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableSideBorderOptionsProperty"]], result)

        @builtins.property
        def uniform_border(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''Determines the options for uniform border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html#cfn-quicksight-dashboard-globaltableborderoptions-uniformborder
            '''
            result = self._values.get("uniform_border")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GlobalTableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"stops": "stops"},
    )
    class GradientColorProperty:
        def __init__(
            self,
            *,
            stops: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GradientStopProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Determines the gradient color settings.

            :param stops: The list of gradient color stops.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gradient_color_property = quicksight.CfnDashboard.GradientColorProperty(
                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                        gradient_offset=123,
                
                        # the properties below are optional
                        color="color",
                        data_value=123
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6569b3e687726ffd2ec44f7cccf9b73a024ee554aefd1c2d61235c0817234ad2)
                check_type(argname="argument stops", value=stops, expected_type=type_hints["stops"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if stops is not None:
                self._values["stops"] = stops

        @builtins.property
        def stops(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GradientStopProperty"]]]]:
            '''The list of gradient color stops.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientcolor.html#cfn-quicksight-dashboard-gradientcolor-stops
            '''
            result = self._values.get("stops")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GradientStopProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GradientStopProperty",
        jsii_struct_bases=[],
        name_mapping={
            "gradient_offset": "gradientOffset",
            "color": "color",
            "data_value": "dataValue",
        },
    )
    class GradientStopProperty:
        def __init__(
            self,
            *,
            gradient_offset: jsii.Number,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the gradient stop configuration.

            :param gradient_offset: Determines gradient offset value.
            :param color: Determines the color.
            :param data_value: Determines the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gradient_stop_property = quicksight.CfnDashboard.GradientStopProperty(
                    gradient_offset=123,
                
                    # the properties below are optional
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__31b8913c1550b3161634d74315447236aa93775569e3ebf10bc20277c7dc8098)
                check_type(argname="argument gradient_offset", value=gradient_offset, expected_type=type_hints["gradient_offset"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "gradient_offset": gradient_offset,
            }
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def gradient_offset(self) -> jsii.Number:
            '''Determines gradient offset value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-gradientoffset
            '''
            result = self._values.get("gradient_offset")
            assert result is not None, "Required property 'gradient_offset' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''Determines the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientStopProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class GridLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configuration options for the canvas of a grid layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                grid_layout_canvas_size_options_property = quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                        resize_option="resizeOption",
                
                        # the properties below are optional
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__59ed64ec30102a49b32ca0de986dc1a255874ba13b16c4128472e5a24201fd94)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty"]]:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class GridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GridLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a grid layout. Also called a tiled layout.

            Visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size.

            :param elements: The elements that are included in a grid layout.
            :param canvas_size_options: ``CfnDashboard.GridLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                grid_layout_configuration_property = quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                    elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                        column_span=123,
                        element_id="elementId",
                        element_type="elementType",
                        row_span=123,
                
                        # the properties below are optional
                        column_index=123,
                        row_index=123
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__25e79f0995231f07cc7604c19ae4b64138d7ab43ae43d1a7426e10ff5cceb34d)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GridLayoutElementProperty"]]]:
            '''The elements that are included in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html#cfn-quicksight-dashboard-gridlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GridLayoutElementProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GridLayoutCanvasSizeOptionsProperty"]]:
            '''``CfnDashboard.GridLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html#cfn-quicksight-dashboard-gridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GridLayoutCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GridLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_span": "columnSpan",
            "element_id": "elementId",
            "element_type": "elementType",
            "row_span": "rowSpan",
            "column_index": "columnIndex",
            "row_index": "rowIndex",
        },
    )
    class GridLayoutElementProperty:
        def __init__(
            self,
            *,
            column_span: jsii.Number,
            element_id: builtins.str,
            element_type: builtins.str,
            row_span: jsii.Number,
            column_index: typing.Optional[jsii.Number] = None,
            row_index: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An element within a grid layout.

            :param column_span: The width of a grid element expressed as a number of grid columns.
            :param element_id: A unique identifier for an element within a grid layout.
            :param element_type: The type of element.
            :param row_span: The height of a grid element expressed as a number of grid rows.
            :param column_index: The column index for the upper left corner of an element.
            :param row_index: The row index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                grid_layout_element_property = quicksight.CfnDashboard.GridLayoutElementProperty(
                    column_span=123,
                    element_id="elementId",
                    element_type="elementType",
                    row_span=123,
                
                    # the properties below are optional
                    column_index=123,
                    row_index=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4656d0cc46048a4966787bd769655891d81a14ca54e0da674f1f1a2a695d04b6)
                check_type(argname="argument column_span", value=column_span, expected_type=type_hints["column_span"])
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument row_span", value=row_span, expected_type=type_hints["row_span"])
                check_type(argname="argument column_index", value=column_index, expected_type=type_hints["column_index"])
                check_type(argname="argument row_index", value=row_index, expected_type=type_hints["row_index"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_span": column_span,
                "element_id": element_id,
                "element_type": element_type,
                "row_span": row_span,
            }
            if column_index is not None:
                self._values["column_index"] = column_index
            if row_index is not None:
                self._values["row_index"] = row_index

        @builtins.property
        def column_span(self) -> jsii.Number:
            '''The width of a grid element expressed as a number of grid columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-columnspan
            '''
            result = self._values.get("column_span")
            assert result is not None, "Required property 'column_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def row_span(self) -> jsii.Number:
            '''The height of a grid element expressed as a number of grid rows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-rowspan
            '''
            result = self._values.get("row_span")
            assert result is not None, "Required property 'row_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def column_index(self) -> typing.Optional[jsii.Number]:
            '''The column index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-columnindex
            '''
            result = self._values.get("column_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def row_index(self) -> typing.Optional[jsii.Number]:
            '''The row index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-rowindex
            '''
            result = self._values.get("row_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "resize_option": "resizeOption",
            "optimized_view_port_width": "optimizedViewPortWidth",
        },
    )
    class GridLayoutScreenCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            resize_option: builtins.str,
            optimized_view_port_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :param resize_option: This value determines the layout behavior when the viewport is resized. - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` . - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .
            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                grid_layout_screen_canvas_size_options_property = quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                    resize_option="resizeOption",
                
                    # the properties below are optional
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f36c3d22c910214e92790af15fdbf3a7521edd7f92d1dc2716a24182a8e2ceb5)
                check_type(argname="argument resize_option", value=resize_option, expected_type=type_hints["resize_option"])
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "resize_option": resize_option,
            }
            if optimized_view_port_width is not None:
                self._values["optimized_view_port_width"] = optimized_view_port_width

        @builtins.property
        def resize_option(self) -> builtins.str:
            '''This value determines the layout behavior when the viewport is resized.

            - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` .
            - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutscreencanvassizeoptions-resizeoption
            '''
            result = self._values.get("resize_option")
            assert result is not None, "Required property 'resize_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def optimized_view_port_width(self) -> typing.Optional[builtins.str]:
            '''The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.GrowthRateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "period_size": "periodSize",
            "value": "value",
        },
    )
    class GrowthRateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
            period_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The growth rate computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param period_size: The period size setup of a growth rate computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                growth_rate_computation_property = quicksight.CfnDashboard.GrowthRateComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    period_size=123,
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__78065b3da7f69fb390247444625913ea4ec553083d9f4e5e49028bb21b0dd795)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_size", value=period_size, expected_type=type_hints["period_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if period_size is not None:
                self._values["period_size"] = period_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_size(self) -> typing.Optional[jsii.Number]:
            '''The period size setup of a growth rate computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-periodsize
            '''
            result = self._values.get("period_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GrowthRateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout", "section_id": "sectionId", "style": "style"},
    )
    class HeaderFooterSectionConfigurationProperty:
        def __init__(
            self,
            *,
            layout: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            section_id: builtins.str,
            style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a header or footer section.

            :param layout: The layout configuration of the header or footer section.
            :param section_id: The unique identifier of the header or footer section.
            :param style: The style options of a header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                header_footer_section_configuration_property = quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    style=quicksight.CfnDashboard.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnDashboard.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__10bf56a99f06c2e750fef7609aa2bfcd4b962017a3b839333d1b823c75cf48f1)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "layout": layout,
                "section_id": section_id,
            }
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def layout(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionLayoutConfigurationProperty"]:
            '''The layout configuration of the header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-layout
            '''
            result = self._values.get("layout")
            assert result is not None, "Required property 'layout' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionLayoutConfigurationProperty"], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of the header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionStyleProperty"]]:
            '''The style options of a header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeaderFooterSectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class HeatMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            rows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a heat map.

            :param columns: The columns field well of a heat map.
            :param rows: The rows field well of a heat map.
            :param values: The values field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_aggregated_field_wells_property = quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                    columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__905e5108acd3f80bcbcade33df12882b36abace985665223c74802e4f4d2f668)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The columns field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The rows field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The values field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.HeatMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_scale": "colorScale",
            "column_label_options": "columnLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "row_label_options": "rowLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class HeatMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.HeatMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.HeatMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a heat map.

            :param color_scale: The color options (gradient color, point of divergence) in a heat map.
            :param column_label_options: The label options of the column that is displayed in a heat map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param row_label_options: The label options of the row that is displayed in a ``heat map`` .
            :param sort_configuration: The sort configuration of a heat map.
            :param tooltip: The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_configuration_property = quicksight.CfnDashboard.HeatMapConfigurationProperty(
                    color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                        color_fill_type="colorFillType",
                        colors=[quicksight.CfnDashboard.DataColorProperty(
                            color="color",
                            data_value=123
                        )],
                
                        # the properties below are optional
                        null_value_color=quicksight.CfnDashboard.DataColorProperty(
                            color="color",
                            data_value=123
                        )
                    ),
                    column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                        heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                            columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                        heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e3e085ccbf88c505d886f8127b672298ff84a37bb2defc186f4d83fa9a5354d2)
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument column_label_options", value=column_label_options, expected_type=type_hints["column_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument row_label_options", value=row_label_options, expected_type=type_hints["row_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if column_label_options is not None:
                self._values["column_label_options"] = column_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if row_label_options is not None:
                self._values["row_label_options"] = row_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColorScaleProperty"]]:
            '''The color options (gradient color, point of divergence) in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColorScaleProperty"]], result)

        @builtins.property
        def column_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the column that is displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-columnlabeloptions
            '''
            result = self._values.get("column_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeatMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeatMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def row_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the row that is displayed in a ``heat map`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-rowlabeloptions
            '''
            result = self._values.get("row_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeatMapSortConfigurationProperty"]]:
            '''The sort configuration of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeatMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.HeatMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_aggregated_field_wells": "heatMapAggregatedFieldWells",
        },
    )
    class HeatMapFieldWellsProperty:
        def __init__(
            self,
            *,
            heat_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.HeatMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a heat map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param heat_map_aggregated_field_wells: The aggregated field wells of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_field_wells_property = quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                    heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                        columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__49db0c7cacf1900534e141af92f8b1ee74ec01c4aa33fca8f3fcac6d5f8460f4)
                check_type(argname="argument heat_map_aggregated_field_wells", value=heat_map_aggregated_field_wells, expected_type=type_hints["heat_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_aggregated_field_wells is not None:
                self._values["heat_map_aggregated_field_wells"] = heat_map_aggregated_field_wells

        @builtins.property
        def heat_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeatMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapfieldwells.html#cfn-quicksight-dashboard-heatmapfieldwells-heatmapaggregatedfieldwells
            '''
            result = self._values.get("heat_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeatMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.HeatMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_column_items_limit_configuration": "heatMapColumnItemsLimitConfiguration",
            "heat_map_column_sort": "heatMapColumnSort",
            "heat_map_row_items_limit_configuration": "heatMapRowItemsLimitConfiguration",
            "heat_map_row_sort": "heatMapRowSort",
        },
    )
    class HeatMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            heat_map_column_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_column_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            heat_map_row_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_row_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a heat map.

            :param heat_map_column_items_limit_configuration: The limit on the number of columns that are displayed in a heat map.
            :param heat_map_column_sort: The column sort configuration for heat map for columns that aren't a part of a field well.
            :param heat_map_row_items_limit_configuration: The limit on the number of rows that are displayed in a heat map.
            :param heat_map_row_sort: The field sort configuration of the rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_sort_configuration_property = quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                    heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5bdb240bed35e11a045da0931685e06eb777e6543403b8b81a52b22f7e93697b)
                check_type(argname="argument heat_map_column_items_limit_configuration", value=heat_map_column_items_limit_configuration, expected_type=type_hints["heat_map_column_items_limit_configuration"])
                check_type(argname="argument heat_map_column_sort", value=heat_map_column_sort, expected_type=type_hints["heat_map_column_sort"])
                check_type(argname="argument heat_map_row_items_limit_configuration", value=heat_map_row_items_limit_configuration, expected_type=type_hints["heat_map_row_items_limit_configuration"])
                check_type(argname="argument heat_map_row_sort", value=heat_map_row_sort, expected_type=type_hints["heat_map_row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_column_items_limit_configuration is not None:
                self._values["heat_map_column_items_limit_configuration"] = heat_map_column_items_limit_configuration
            if heat_map_column_sort is not None:
                self._values["heat_map_column_sort"] = heat_map_column_sort
            if heat_map_row_items_limit_configuration is not None:
                self._values["heat_map_row_items_limit_configuration"] = heat_map_row_items_limit_configuration
            if heat_map_row_sort is not None:
                self._values["heat_map_row_sort"] = heat_map_row_sort

        @builtins.property
        def heat_map_column_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of columns that are displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
            '''
            result = self._values.get("heat_map_column_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def heat_map_column_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The column sort configuration for heat map for columns that aren't a part of a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmapcolumnsort
            '''
            result = self._values.get("heat_map_column_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def heat_map_row_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of rows that are displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
            '''
            result = self._values.get("heat_map_row_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def heat_map_row_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The field sort configuration of the rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmaprowsort
            '''
            result = self._values.get("heat_map_row_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.HeatMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HeatMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.HeatMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a heat map.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_visual_property = quicksight.CfnDashboard.HeatMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.HeatMapConfigurationProperty(
                        color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                            color_fill_type="colorFillType",
                            colors=[quicksight.CfnDashboard.DataColorProperty(
                                color="color",
                                data_value=123
                            )],
                
                            # the properties below are optional
                            null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                color="color",
                                data_value=123
                            )
                        ),
                        column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                            heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                                columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                            heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__91b0c96a8fd040f3d935852ee29ec9388fe499dee89d8698ebda8b8ad2b4e4c5)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeatMapConfigurationProperty"]]:
            '''The configuration of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeatMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class HistogramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param values: The value field wells of a histogram. Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                histogram_aggregated_field_wells_property = quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aa3ec08d0d89c7326d6d34fc2aca2945cd97d2bc2cd1d773eef53a4c6e6d6e50)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a histogram.

            Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramaggregatedfieldwells.html#cfn-quicksight-dashboard-histogramaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.HistogramBinOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_count": "binCount",
            "bin_width": "binWidth",
            "selected_bin_type": "selectedBinType",
            "start_value": "startValue",
        },
    )
    class HistogramBinOptionsProperty:
        def __init__(
            self,
            *,
            bin_count: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BinCountOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            bin_width: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BinWidthOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_bin_type: typing.Optional[builtins.str] = None,
            start_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the presentation of histogram bins.

            :param bin_count: The options that determine the bin count of a histogram.
            :param bin_width: The options that determine the bin width of a histogram.
            :param selected_bin_type: The options that determine the selected bin type.
            :param start_value: The options that determine the bin start value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                histogram_bin_options_property = quicksight.CfnDashboard.HistogramBinOptionsProperty(
                    bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                        value=123
                    ),
                    bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                        bin_count_limit=123,
                        value=123
                    ),
                    selected_bin_type="selectedBinType",
                    start_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4cea12c7bc0d5099097d55ef1d1b393001a79f635ff351b824100e88bfa298be)
                check_type(argname="argument bin_count", value=bin_count, expected_type=type_hints["bin_count"])
                check_type(argname="argument bin_width", value=bin_width, expected_type=type_hints["bin_width"])
                check_type(argname="argument selected_bin_type", value=selected_bin_type, expected_type=type_hints["selected_bin_type"])
                check_type(argname="argument start_value", value=start_value, expected_type=type_hints["start_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count is not None:
                self._values["bin_count"] = bin_count
            if bin_width is not None:
                self._values["bin_width"] = bin_width
            if selected_bin_type is not None:
                self._values["selected_bin_type"] = selected_bin_type
            if start_value is not None:
                self._values["start_value"] = start_value

        @builtins.property
        def bin_count(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BinCountOptionsProperty"]]:
            '''The options that determine the bin count of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-bincount
            '''
            result = self._values.get("bin_count")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BinCountOptionsProperty"]], result)

        @builtins.property
        def bin_width(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BinWidthOptionsProperty"]]:
            '''The options that determine the bin width of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-binwidth
            '''
            result = self._values.get("bin_width")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BinWidthOptionsProperty"]], result)

        @builtins.property
        def selected_bin_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the selected bin type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-selectedbintype
            '''
            result = self._values.get("selected_bin_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin start value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-startvalue
            '''
            result = self._values.get("start_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramBinOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.HistogramConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_options": "binOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
        },
    )
    class HistogramConfigurationProperty:
        def __init__(
            self,
            *,
            bin_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.HistogramBinOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.HistogramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``HistogramVisual`` .

            :param bin_options: The options that determine the presentation of histogram bins.
            :param data_labels: The data label configuration of a histogram.
            :param field_wells: The field well configuration of a histogram.
            :param tooltip: The tooltip configuration of a histogram.
            :param visual_palette: The visual palette configuration of a histogram.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.
            :param y_axis_display_options: The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                histogram_configuration_property = quicksight.CfnDashboard.HistogramConfigurationProperty(
                    bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                        bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                            value=123
                        ),
                        bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                            bin_count_limit=123,
                            value=123
                        ),
                        selected_bin_type="selectedBinType",
                        start_value=123
                    ),
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                        histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5e4bb3c456b4405dd12258013a7caad37961c277da2f6af995b1951408045e74)
                check_type(argname="argument bin_options", value=bin_options, expected_type=type_hints["bin_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_options is not None:
                self._values["bin_options"] = bin_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options

        @builtins.property
        def bin_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HistogramBinOptionsProperty"]]:
            '''The options that determine the presentation of histogram bins.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-binoptions
            '''
            result = self._values.get("bin_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HistogramBinOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The data label configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HistogramFieldWellsProperty"]]:
            '''The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HistogramFieldWellsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]]:
            '''The visual palette configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.HistogramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "histogram_aggregated_field_wells": "histogramAggregatedFieldWells",
        },
    )
    class HistogramFieldWellsProperty:
        def __init__(
            self,
            *,
            histogram_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.HistogramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param histogram_aggregated_field_wells: The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                histogram_field_wells_property = quicksight.CfnDashboard.HistogramFieldWellsProperty(
                    histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2f18ee9f204a5f8ca2cdd03617839e27b1e4498fc2e743ca018bd748bdbd4d8e)
                check_type(argname="argument histogram_aggregated_field_wells", value=histogram_aggregated_field_wells, expected_type=type_hints["histogram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if histogram_aggregated_field_wells is not None:
                self._values["histogram_aggregated_field_wells"] = histogram_aggregated_field_wells

        @builtins.property
        def histogram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HistogramAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramfieldwells.html#cfn-quicksight-dashboard-histogramfieldwells-histogramaggregatedfieldwells
            '''
            result = self._values.get("histogram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HistogramAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.HistogramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HistogramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.HistogramConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a ``HistogramVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                histogram_visual_property = quicksight.CfnDashboard.HistogramVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.HistogramConfigurationProperty(
                        bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                            bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                                value=123
                            ),
                            bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                                bin_count_limit=123,
                                value=123
                            ),
                            selected_bin_type="selectedBinType",
                            start_value=123
                        ),
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                            histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        )
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__173a0e903c915b8af6bef920ca6058732a57faed9507934001233b9350507a4d)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HistogramConfigurationProperty"]]:
            '''The configuration for a ``HistogramVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HistogramConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.InsightConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computations": "computations",
            "custom_narrative": "customNarrative",
        },
    )
    class InsightConfigurationProperty:
        def __init__(
            self,
            *,
            computations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ComputationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            custom_narrative: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CustomNarrativeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of an insight visual.

            :param computations: The computations configurations of the insight visual.
            :param custom_narrative: The custom narrative of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                insight_configuration_property = quicksight.CfnDashboard.InsightConfigurationProperty(
                    computations=[quicksight.CfnDashboard.ComputationProperty(
                        forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            custom_seasonality_value=123,
                            lower_boundary=123,
                            name="name",
                            periods_backward=123,
                            periods_forward=123,
                            prediction_interval=123,
                            seasonality="seasonality",
                            upper_boundary=123,
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            period_size=123,
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            type="type",
                
                            # the properties below are optional
                            name="name",
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                            computation_id="computationId",
                            from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                            target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name"
                        ),
                        period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            period_time_granularity="periodTimeGranularity",
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            type="type",
                
                            # the properties below are optional
                            mover_size=123,
                            name="name",
                            sort_order="sortOrder",
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                            type="type",
                
                            # the properties below are optional
                            name="name",
                            result_size=123,
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                            computation_id="computationId",
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                
                            # the properties below are optional
                            name="name"
                        ),
                        unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                
                            # the properties below are optional
                            name="name"
                        )
                    )],
                    custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                        narrative="narrative"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__affe719870cf0c48710b52c2c6a04f55bfa82f21cc2e4b51b7e27f01aa7770a0)
                check_type(argname="argument computations", value=computations, expected_type=type_hints["computations"])
                check_type(argname="argument custom_narrative", value=custom_narrative, expected_type=type_hints["custom_narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if computations is not None:
                self._values["computations"] = computations
            if custom_narrative is not None:
                self._values["custom_narrative"] = custom_narrative

        @builtins.property
        def computations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComputationProperty"]]]]:
            '''The computations configurations of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html#cfn-quicksight-dashboard-insightconfiguration-computations
            '''
            result = self._values.get("computations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComputationProperty"]]]], result)

        @builtins.property
        def custom_narrative(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomNarrativeOptionsProperty"]]:
            '''The custom narrative of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html#cfn-quicksight-dashboard-insightconfiguration-customnarrative
            '''
            result = self._values.get("custom_narrative")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomNarrativeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.InsightVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "insight_configuration": "insightConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class InsightVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            insight_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.InsightConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used in the insight visual.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param insight_configuration: The configuration of an insight visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                insight_visual_property = quicksight.CfnDashboard.InsightVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    insight_configuration=quicksight.CfnDashboard.InsightConfigurationProperty(
                        computations=[quicksight.CfnDashboard.ComputationProperty(
                            forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                custom_seasonality_value=123,
                                lower_boundary=123,
                                name="name",
                                periods_backward=123,
                                periods_forward=123,
                                prediction_interval=123,
                                seasonality="seasonality",
                                upper_boundary=123,
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                period_size=123,
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                type="type",
                
                                # the properties below are optional
                                name="name",
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                                computation_id="computationId",
                                from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                                target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name"
                            ),
                            period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                period_time_granularity="periodTimeGranularity",
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                                category=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                type="type",
                
                                # the properties below are optional
                                mover_size=123,
                                name="name",
                                sort_order="sortOrder",
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                                category=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                                type="type",
                
                                # the properties below are optional
                                name="name",
                                result_size=123,
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                                computation_id="computationId",
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                
                                # the properties below are optional
                                name="name"
                            ),
                            unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                                category=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                
                                # the properties below are optional
                                name="name"
                            )
                        )],
                        custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                            narrative="narrative"
                        )
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b1dd67632e7bf9691eec7fd109f1d8427f8450fcf3aa62bb3aac701c9ea82322)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument insight_configuration", value=insight_configuration, expected_type=type_hints["insight_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if insight_configuration is not None:
                self._values["insight_configuration"] = insight_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used in the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def insight_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.InsightConfigurationProperty"]]:
            '''The configuration of an insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-insightconfiguration
            '''
            result = self._values.get("insight_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.InsightConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.IntegerDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class IntegerDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``IntegerParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``IntegerDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``IntegerDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                integer_default_values_property = quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                    dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7e860b6787d414805f9b5f613e488cba4714431dcc13327b82a68381e067d90b)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``IntegerDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html#cfn-quicksight-dashboard-integerdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]]:
            '''The static values of the ``IntegerDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html#cfn-quicksight-dashboard-integerdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.IntegerParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class IntegerParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.IntegerDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.IntegerValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnDashboard.IntegerParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                integer_parameter_declaration_property = quicksight.CfnDashboard.IntegerParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                        dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__544fd6b0b310771ff81431324ce78c2d8f6bd09076cfa015768965f7fe75faad)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.IntegerDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.IntegerDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MappedDataSetParameterProperty"]]]]:
            '''``CfnDashboard.IntegerParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.IntegerValueWhenUnsetConfigurationProperty"]]:
            '''A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.IntegerValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.IntegerParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class IntegerParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]],
        ) -> None:
            '''An integer parameter.

            :param name: The name of the integer parameter.
            :param values: The values for the integer parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                integer_parameter_property = quicksight.CfnDashboard.IntegerParameterProperty(
                    name="name",
                    values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e017e02705585f127ebd6a015a673849276d812097d8afa252fe83b8b5b37523)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the integer parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html#cfn-quicksight-dashboard-integerparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]:
            '''The values for the integer parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html#cfn-quicksight-dashboard-integerparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class IntegerValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                integer_value_when_unset_configuration_property = quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4b1732c34725421c2ac841ba89cd8d0c1821902cd50746d9732479a489e6c07d)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-integervaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-integervaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ItemsLimitConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "items_limit": "itemsLimit",
            "other_categories": "otherCategories",
        },
    )
    class ItemsLimitConfigurationProperty:
        def __init__(
            self,
            *,
            items_limit: typing.Optional[jsii.Number] = None,
            other_categories: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The limit configuration of the visual display for an axis.

            :param items_limit: The limit on how many items of a field are showed in the chart. For example, the number of slices that are displayed in a pie chart.
            :param other_categories: The ``Show other`` of an axis in the chart. Choose one of the following options:. - ``INCLUDE`` - ``EXCLUDE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                items_limit_configuration_property = quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                    items_limit=123,
                    other_categories="otherCategories"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__46e9322cde94a687e884360de4a35524408301ffc0786d1c1f03a883f1a172c7)
                check_type(argname="argument items_limit", value=items_limit, expected_type=type_hints["items_limit"])
                check_type(argname="argument other_categories", value=other_categories, expected_type=type_hints["other_categories"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if items_limit is not None:
                self._values["items_limit"] = items_limit
            if other_categories is not None:
                self._values["other_categories"] = other_categories

        @builtins.property
        def items_limit(self) -> typing.Optional[jsii.Number]:
            '''The limit on how many items of a field are showed in the chart.

            For example, the number of slices that are displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html#cfn-quicksight-dashboard-itemslimitconfiguration-itemslimit
            '''
            result = self._values.get("items_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def other_categories(self) -> typing.Optional[builtins.str]:
            '''The ``Show other`` of an axis in the chart. Choose one of the following options:.

            - ``INCLUDE``
            - ``EXCLUDE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html#cfn-quicksight-dashboard-itemslimitconfiguration-othercategories
            '''
            result = self._values.get("other_categories")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ItemsLimitConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"primary_value": "primaryValue", "progress_bar": "progressBar"},
    )
    class KPIConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            primary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.KPIPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            progress_bar: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.KPIProgressBarConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting options of a KPI visual.

            :param primary_value: The conditional formatting for the primary value of a KPI visual.
            :param progress_bar: The conditional formatting for the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIConditional_formatting_option_property = quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                    primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c2cd4f36fa7ec92aab42bc94d1e9fac0efd0bc7761a06ebae83efd1cbf20eef5)
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if primary_value is not None:
                self._values["primary_value"] = primary_value
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIPrimaryValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the primary value of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIPrimaryValueConditionalFormattingProperty"]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIProgressBarConditionalFormattingProperty"]]:
            '''The conditional formatting for the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIProgressBarConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.KPIConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class KPIConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.KPIConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting of a KPI visual.

            :param conditional_formatting_options: The conditional formatting options of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIConditional_formatting_property = quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                        primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bfe176f10420499de6970b5078bae08aeb2c1c708231b6abb04cecca6c3649d4)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIConditionalFormattingOptionProperty"]]]]:
            '''The conditional formatting options of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformatting.html#cfn-quicksight-dashboard-kpiconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.KPIConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "kpi_options": "kpiOptions",
            "sort_configuration": "sortConfiguration",
        },
    )
    class KPIConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.KPIFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            kpi_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.KPIOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.KPISortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a KPI visual.

            :param field_wells: The field well configuration of a KPI visual.
            :param kpi_options: The options that determine the presentation of a KPI visual.
            :param sort_configuration: The sort configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIConfiguration_property = quicksight.CfnDashboard.KPIConfigurationProperty(
                    field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                        target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                        comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                            comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            comparison_method="comparisonMethod"
                        ),
                        primary_value_display_type="primaryValueDisplayType",
                        primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                            visibility="visibility"
                        ),
                        secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                            visibility="visibility"
                        ),
                        secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                            visibility="visibility"
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                        trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c86e64898123333c9d25543485bf0e862ca268b18f58940a86e5a5f16f013349)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument kpi_options", value=kpi_options, expected_type=type_hints["kpi_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if kpi_options is not None:
                self._values["kpi_options"] = kpi_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIFieldWellsProperty"]]:
            '''The field well configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIFieldWellsProperty"]], result)

        @builtins.property
        def kpi_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIOptionsProperty"]]:
            '''The options that determine the presentation of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-kpioptions
            '''
            result = self._values.get("kpi_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPISortConfigurationProperty"]]:
            '''The sort configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPISortConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.KPIFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_values": "targetValues",
            "trend_groups": "trendGroups",
            "values": "values",
        },
    )
    class KPIFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            trend_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a KPI visual.

            :param target_values: The target value field wells of a KPI visual.
            :param trend_groups: The trend group field wells of a KPI visual.
            :param values: The value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIField_wells_property = quicksight.CfnDashboard.KPIFieldWellsProperty(
                    target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2956d0e8ea8f5b11724b98b11d7539a6c2e0740548cf63214600799957cdc7b4)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument trend_groups", value=trend_groups, expected_type=type_hints["trend_groups"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if trend_groups is not None:
                self._values["trend_groups"] = trend_groups
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The target value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def trend_groups(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The trend group field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-trendgroups
            '''
            result = self._values.get("trend_groups")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.KPIOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
            "progress_bar": "progressBar",
            "secondary_value": "secondaryValue",
            "secondary_value_font_configuration": "secondaryValueFontConfiguration",
            "trend_arrows": "trendArrows",
        },
    )
    class KPIOptionsProperty:
        def __init__(
            self,
            *,
            comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            progress_bar: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ProgressBarOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SecondaryValueOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            trend_arrows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TrendArrowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of a KPI visual.

            :param comparison: The comparison configuration of a KPI visual.
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.
            :param progress_bar: The options that determine the presentation of the progress bar of a KPI visual.
            :param secondary_value: The options that determine the presentation of the secondary value of a KPI visual.
            :param secondary_value_font_configuration: The options that determine the secondary value font configuration.
            :param trend_arrows: The options that determine the presentation of trend arrows in a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIOptions_property = quicksight.CfnDashboard.KPIOptionsProperty(
                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__26164f41afbc23d393de4bddae214b784aa4a2be17a32d85af998dee7a4d1a32)
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
                check_type(argname="argument secondary_value", value=secondary_value, expected_type=type_hints["secondary_value"])
                check_type(argname="argument secondary_value_font_configuration", value=secondary_value_font_configuration, expected_type=type_hints["secondary_value_font_configuration"])
                check_type(argname="argument trend_arrows", value=trend_arrows, expected_type=type_hints["trend_arrows"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar
            if secondary_value is not None:
                self._values["secondary_value"] = secondary_value
            if secondary_value_font_configuration is not None:
                self._values["secondary_value_font_configuration"] = secondary_value_font_configuration
            if trend_arrows is not None:
                self._values["trend_arrows"] = trend_arrows

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComparisonConfigurationProperty"]]:
            '''The comparison configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComparisonConfigurationProperty"]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]]:
            '''The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ProgressBarOptionsProperty"]]:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ProgressBarOptionsProperty"]], result)

        @builtins.property
        def secondary_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SecondaryValueOptionsProperty"]]:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-secondaryvalue
            '''
            result = self._values.get("secondary_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SecondaryValueOptionsProperty"]], result)

        @builtins.property
        def secondary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]]:
            '''The options that determine the secondary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-secondaryvaluefontconfiguration
            '''
            result = self._values.get("secondary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def trend_arrows(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TrendArrowOptionsProperty"]]:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-trendarrows
            '''
            result = self._values.get("trend_arrows")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TrendArrowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a KPI visual.

            :param icon: The conditional formatting of the primary value's icon.
            :param text_color: The conditional formatting of the primary value's text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIPrimary_value_conditional_formatting_property = quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d2c56f21f568775e305a40604545dd864e7aed566a67e464a53ad25eb8477f47)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the primary value's icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the primary value's text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class KPIProgressBarConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the progress bar of a KPI visual.

            :param foreground_color: The conditional formatting of the progress bar's foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprogressbarconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIProgress_bar_conditional_formatting_property = quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                    foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9c68cf9b07ca4e0204f629c3dc908629c3c5877cf110accbaeeff9ad90e708e)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the progress bar's foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprogressbarconditionalformatting.html#cfn-quicksight-dashboard-kpiprogressbarconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIProgressBarConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.KPISortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"trend_group_sort": "trendGroupSort"},
    )
    class KPISortConfigurationProperty:
        def __init__(
            self,
            *,
            trend_group_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a KPI visual.

            :param trend_group_sort: The sort configuration of the trend group fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pISort_configuration_property = quicksight.CfnDashboard.KPISortConfigurationProperty(
                    trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cc648f3755fdd0295addc24c77de2d7e787b093333415aafe9d6d26c31326867)
                check_type(argname="argument trend_group_sort", value=trend_group_sort, expected_type=type_hints["trend_group_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if trend_group_sort is not None:
                self._values["trend_group_sort"] = trend_group_sort

        @builtins.property
        def trend_group_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the trend group fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisortconfiguration.html#cfn-quicksight-dashboard-kpisortconfiguration-trendgroupsort
            '''
            result = self._values.get("trend_group_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPISortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.KPIVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class KPIVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.KPIConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.KPIConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a KPI visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a KPI visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIVisual_property = quicksight.CfnDashboard.KPIVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.KPIConfigurationProperty(
                        field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                            target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                            comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                comparison_method="comparisonMethod"
                            ),
                            primary_value_display_type="primaryValueDisplayType",
                            primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                                visibility="visibility"
                            ),
                            secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                                visibility="visibility"
                            ),
                            secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                                visibility="visibility"
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                            trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    conditional_formatting=quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                            primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            ),
                            progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                                foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b7d2cad00eb0b20203ecaac5c537e86b9e33355eaf6eac9b2943240b8e6d59d4)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIConfigurationProperty"]]:
            '''The configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIConditionalFormattingProperty"]]:
            '''The conditional formatting of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
            "visibility": "visibility",
        },
    )
    class LabelOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The share label options for the labels.

            :param custom_label: The text for the label.
            :param font_configuration: The font configuration of the label.
            :param visibility: Determines whether or not the label is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                label_options_property = quicksight.CfnDashboard.LabelOptionsProperty(
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b5a8ae3be2f14e0382c5a15b0bc4bf41d5a57498292b9e6fa3ae28fe6a4e1035)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]]:
            '''The font configuration of the label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the label is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "free_form_layout": "freeFormLayout",
            "grid_layout": "gridLayout",
            "section_based_layout": "sectionBasedLayout",
        },
    )
    class LayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            section_based_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration that determines what the type of layout will be used on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param free_form_layout: A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
            :param grid_layout: A type of layout that can be used on a sheet. In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .
            :param section_based_layout: A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                layout_configuration_property = quicksight.CfnDashboard.LayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                        body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                            content=quicksight.CfnDashboard.BodySectionContentProperty(
                                layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                    status="status"
                                )
                            ),
                            style=quicksight.CfnDashboard.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        ),
                        footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnDashboard.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnDashboard.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4a7e5ef2561a6940f32619f7f9b76babe27b8e5666916e6e9ab7d5fb690bb52c)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
                check_type(argname="argument section_based_layout", value=section_based_layout, expected_type=type_hints["section_based_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form_layout is not None:
                self._values["free_form_layout"] = free_form_layout
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout
            if section_based_layout is not None:
                self._values["section_based_layout"] = section_based_layout

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutConfigurationProperty"]]:
            '''A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormLayoutConfigurationProperty"]], result)

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GridLayoutConfigurationProperty"]]:
            '''A type of layout that can be used on a sheet.

            In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GridLayoutConfigurationProperty"]], result)

        @builtins.property
        def section_based_layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionBasedLayoutConfigurationProperty"]]:
            '''A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-sectionbasedlayout
            '''
            result = self._values.get("section_based_layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionBasedLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class LayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A ``Layout`` defines the placement of elements within a sheet.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param configuration: The configuration that determines what the type of layout for a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                layout_property = quicksight.CfnDashboard.LayoutProperty(
                    configuration=quicksight.CfnDashboard.LayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                            body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                                content=quicksight.CfnDashboard.BodySectionContentProperty(
                                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                    after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                        status="status"
                                    )
                                ),
                                style=quicksight.CfnDashboard.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            ),
                            footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnDashboard.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnDashboard.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b1a52815ff01f8fd11968ba2674197b875a49f86c9002a0e6ffe6523a744088e)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LayoutConfigurationProperty"]:
            '''The configuration that determines what the type of layout for a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layout.html#cfn-quicksight-dashboard-layout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LegendOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "height": "height",
            "position": "position",
            "title": "title",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class LegendOptionsProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for the legend setup of a visual.

            :param height: The height of the legend. If this value is omitted, a default height is used when rendering.
            :param position: The positions for the legend. Choose one of the following options:. - ``AUTO`` - ``RIGHT`` - ``BOTTOM`` - ``LEFT``
            :param title: The custom title for the legend.
            :param visibility: Determines whether or not the legend is visible.
            :param width: The width of the legend. If this value is omitted, a default width is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                legend_options_property = quicksight.CfnDashboard.LegendOptionsProperty(
                    height="height",
                    position="position",
                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__457d195138ef98557536be221172d9143210e816434299b08afd1dc6156dd3eb)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if position is not None:
                self._values["position"] = position
            if title is not None:
                self._values["title"] = title
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of the legend.

            If this value is omitted, a default height is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''The positions for the legend. Choose one of the following options:.

            - ``AUTO``
            - ``RIGHT``
            - ``BOTTOM``
            - ``LEFT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]]:
            '''The custom title for the legend.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the legend is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the legend.

            If this value is omitted, a default width is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LegendOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class LineChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param category: The category field wells of a line chart. Values are grouped by category fields.
            :param colors: The color field wells of a line chart. Values are grouped by category fields.
            :param small_multiples: The small multiples field well of a line chart.
            :param values: The value field wells of a line chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_aggregated_field_wells_property = quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7cef69be20a2746dd8949b5516fe48b2c2725b53f2cac8caefb14114893d85f9)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The category field wells of a line chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The color field wells of a line chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a line chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LineChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "default_series_settings": "defaultSeriesSettings",
            "field_wells": "fieldWells",
            "forecast_configurations": "forecastConfigurations",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "series": "series",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "type": "type",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
        },
    )
    class LineChartConfigurationProperty:
        def __init__(
            self,
            *,
            contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            default_series_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineChartDefaultSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            forecast_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ForecastConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            series: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a line chart.

            :param contribution_analysis_defaults: The default configuration of a line chart's contribution analysis.
            :param data_labels: The data label configuration of a line chart.
            :param default_series_settings: The options that determine the default presentation of all line series in ``LineChartVisual`` .
            :param field_wells: The field well configuration of a line chart.
            :param forecast_configurations: The forecast configuration of a line chart.
            :param legend: The legend configuration of a line chart.
            :param primary_y_axis_display_options: The series axis configuration of a line chart.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param reference_lines: The reference lines configuration of a line chart.
            :param secondary_y_axis_display_options: The series axis configuration of a line chart.
            :param secondary_y_axis_label_options: The options that determine the presentation of the secondary y-axis label.
            :param series: The series item configuration of a line chart.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a line chart.
            :param tooltip: The tooltip configuration of a line chart.
            :param type: Determines the type of the line chart.
            :param visual_palette: The visual palette configuration of a line chart.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_chart_configuration_property = quicksight.CfnDashboard.LineChartConfigurationProperty(
                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                        axis_binding="axisBinding",
                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    ),
                    field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                        line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                        forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                            lower_boundary=123,
                            periods_backward=123,
                            periods_forward=123,
                            prediction_interval=123,
                            seasonality=123,
                            upper_boundary=123
                        ),
                        scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                            what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                date="date",
                                value=123
                            ),
                            what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                end_date="endDate",
                                start_date="startDate",
                                value=123
                            )
                        )
                    )],
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                        axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                            treatment_option="treatmentOption"
                        )]
                    ),
                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                        axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                            treatment_option="treatmentOption"
                        )]
                    ),
                    secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    series=[quicksight.CfnDashboard.SeriesItemProperty(
                        data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                            axis_binding="axisBinding",
                            field_id="fieldId",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            )
                        ),
                        field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                            axis_binding="axisBinding",
                            field_id="fieldId",
                
                            # the properties below are optional
                            settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            )
                        )
                    )],
                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                        category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    type="type",
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9a892952e5d3b964365a23c610d4f553bb574216e1e4421b79e0fff173bba181)
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument default_series_settings", value=default_series_settings, expected_type=type_hints["default_series_settings"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument forecast_configurations", value=forecast_configurations, expected_type=type_hints["forecast_configurations"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument series", value=series, expected_type=type_hints["series"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if default_series_settings is not None:
                self._values["default_series_settings"] = default_series_settings
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if forecast_configurations is not None:
                self._values["forecast_configurations"] = forecast_configurations
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if series is not None:
                self._values["series"] = series
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if type is not None:
                self._values["type"] = type
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ContributionAnalysisDefaultProperty"]]]]:
            '''The default configuration of a line chart's contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The data label configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def default_series_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartDefaultSeriesSettingsProperty"]]:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-defaultseriessettings
            '''
            result = self._values.get("default_series_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartDefaultSeriesSettingsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartFieldWellsProperty"]]:
            '''The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartFieldWellsProperty"]], result)

        @builtins.property
        def forecast_configurations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ForecastConfigurationProperty"]]]]:
            '''The forecast configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-forecastconfigurations
            '''
            result = self._values.get("forecast_configurations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ForecastConfigurationProperty"]]]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineSeriesAxisDisplayOptionsProperty"]]:
            '''The series axis configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineSeriesAxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineProperty"]]]]:
            '''The reference lines configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineProperty"]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineSeriesAxisDisplayOptionsProperty"]]:
            '''The series axis configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineSeriesAxisDisplayOptionsProperty"]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the secondary y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def series(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SeriesItemProperty"]]]]:
            '''The series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-series
            '''
            result = self._values.get("series")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SeriesItemProperty"]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartSortConfigurationProperty"]]:
            '''The sort configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Determines the type of the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]]:
            '''The visual palette configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartDefaultSeriesSettingsProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            line_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            marker_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :param axis_binding: The axis to which you are binding all line series to.
            :param line_style_settings: Line styles options for all line series in the visual.
            :param marker_style_settings: Marker styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_default_series_settings_property = quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                    axis_binding="axisBinding",
                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d1c081928d7b9ea714145550f040f3c877eae6edc4f4f20264a660377a97221f)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis to which you are binding all line series to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartLineStyleSettingsProperty"]]:
            '''Line styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartLineStyleSettingsProperty"]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartMarkerStyleSettingsProperty"]]:
            '''Marker styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartMarkerStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartDefaultSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LineChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_chart_aggregated_field_wells": "lineChartAggregatedFieldWells",
        },
    )
    class LineChartFieldWellsProperty:
        def __init__(
            self,
            *,
            line_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param line_chart_aggregated_field_wells: The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_field_wells_property = quicksight.CfnDashboard.LineChartFieldWellsProperty(
                    line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__172f301c86e1a7c92191e528a6d7d6c9e9671bc7606f66b31354b15725b81cfb)
                check_type(argname="argument line_chart_aggregated_field_wells", value=line_chart_aggregated_field_wells, expected_type=type_hints["line_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_chart_aggregated_field_wells is not None:
                self._values["line_chart_aggregated_field_wells"] = line_chart_aggregated_field_wells

        @builtins.property
        def line_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartfieldwells.html#cfn-quicksight-dashboard-linechartfieldwells-linechartaggregatedfieldwells
            '''
            result = self._values.get("line_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LineChartLineStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_interpolation": "lineInterpolation",
            "line_style": "lineStyle",
            "line_visibility": "lineVisibility",
            "line_width": "lineWidth",
        },
    )
    class LineChartLineStyleSettingsProperty:
        def __init__(
            self,
            *,
            line_interpolation: typing.Optional[builtins.str] = None,
            line_style: typing.Optional[builtins.str] = None,
            line_visibility: typing.Optional[builtins.str] = None,
            line_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :param line_interpolation: Interpolation style for line series. - ``LINEAR`` : Show as default, linear style. - ``SMOOTH`` : Show as a smooth curve. - ``STEPPED`` : Show steps in line.
            :param line_style: Line style for line series. - ``SOLID`` : Show as a solid line. - ``DOTTED`` : Show as a dotted line. - ``DASHED`` : Show as a dashed line.
            :param line_visibility: Configuration option that determines whether to show the line for the series.
            :param line_width: Width that determines the line thickness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_line_style_settings_property = quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                    line_interpolation="lineInterpolation",
                    line_style="lineStyle",
                    line_visibility="lineVisibility",
                    line_width="lineWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b711ffa2915c7a88d8f710a3621cd73d0efb30eed7245d0e2eb84e4e24afb706)
                check_type(argname="argument line_interpolation", value=line_interpolation, expected_type=type_hints["line_interpolation"])
                check_type(argname="argument line_style", value=line_style, expected_type=type_hints["line_style"])
                check_type(argname="argument line_visibility", value=line_visibility, expected_type=type_hints["line_visibility"])
                check_type(argname="argument line_width", value=line_width, expected_type=type_hints["line_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_interpolation is not None:
                self._values["line_interpolation"] = line_interpolation
            if line_style is not None:
                self._values["line_style"] = line_style
            if line_visibility is not None:
                self._values["line_visibility"] = line_visibility
            if line_width is not None:
                self._values["line_width"] = line_width

        @builtins.property
        def line_interpolation(self) -> typing.Optional[builtins.str]:
            '''Interpolation style for line series.

            - ``LINEAR`` : Show as default, linear style.
            - ``SMOOTH`` : Show as a smooth curve.
            - ``STEPPED`` : Show steps in line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-lineinterpolation
            '''
            result = self._values.get("line_interpolation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style(self) -> typing.Optional[builtins.str]:
            '''Line style for line series.

            - ``SOLID`` : Show as a solid line.
            - ``DOTTED`` : Show as a dotted line.
            - ``DASHED`` : Show as a dashed line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linestyle
            '''
            result = self._values.get("line_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the line for the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linevisibility
            '''
            result = self._values.get("line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_width(self) -> typing.Optional[builtins.str]:
            '''Width that determines the line thickness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linewidth
            '''
            result = self._values.get("line_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartLineStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "marker_color": "markerColor",
            "marker_shape": "markerShape",
            "marker_size": "markerSize",
            "marker_visibility": "markerVisibility",
        },
    )
    class LineChartMarkerStyleSettingsProperty:
        def __init__(
            self,
            *,
            marker_color: typing.Optional[builtins.str] = None,
            marker_shape: typing.Optional[builtins.str] = None,
            marker_size: typing.Optional[builtins.str] = None,
            marker_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :param marker_color: Color of marker in the series.
            :param marker_shape: Shape option for markers in the series. - ``CIRCLE`` : Show marker as a circle. - ``TRIANGLE`` : Show marker as a triangle. - ``SQUARE`` : Show marker as a square. - ``DIAMOND`` : Show marker as a diamond. - ``ROUNDED_SQUARE`` : Show marker as a rounded square.
            :param marker_size: Size of marker in the series.
            :param marker_visibility: Configuration option that determines whether to show the markers in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_marker_style_settings_property = quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                    marker_color="markerColor",
                    marker_shape="markerShape",
                    marker_size="markerSize",
                    marker_visibility="markerVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4725126ef49f4c2567215a3e21c4fba843312dcc86398b3fe83b8429d1e8133c)
                check_type(argname="argument marker_color", value=marker_color, expected_type=type_hints["marker_color"])
                check_type(argname="argument marker_shape", value=marker_shape, expected_type=type_hints["marker_shape"])
                check_type(argname="argument marker_size", value=marker_size, expected_type=type_hints["marker_size"])
                check_type(argname="argument marker_visibility", value=marker_visibility, expected_type=type_hints["marker_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if marker_color is not None:
                self._values["marker_color"] = marker_color
            if marker_shape is not None:
                self._values["marker_shape"] = marker_shape
            if marker_size is not None:
                self._values["marker_size"] = marker_size
            if marker_visibility is not None:
                self._values["marker_visibility"] = marker_visibility

        @builtins.property
        def marker_color(self) -> typing.Optional[builtins.str]:
            '''Color of marker in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markercolor
            '''
            result = self._values.get("marker_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_shape(self) -> typing.Optional[builtins.str]:
            '''Shape option for markers in the series.

            - ``CIRCLE`` : Show marker as a circle.
            - ``TRIANGLE`` : Show marker as a triangle.
            - ``SQUARE`` : Show marker as a square.
            - ``DIAMOND`` : Show marker as a diamond.
            - ``ROUNDED_SQUARE`` : Show marker as a rounded square.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markershape
            '''
            result = self._values.get("marker_shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_size(self) -> typing.Optional[builtins.str]:
            '''Size of marker in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markersize
            '''
            result = self._values.get("marker_size")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the markers in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markervisibility
            '''
            result = self._values.get("marker_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartMarkerStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LineChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            line_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            marker_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of a line series in the visual.

            :param line_style_settings: Line styles options for a line series in ``LineChartVisual`` .
            :param marker_style_settings: Marker styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_series_settings_property = quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__66cd13c303f456a7ea2ef4c2b91132e4cf81505ac369eff2b69c9bfd2761ef59)
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartLineStyleSettingsProperty"]]:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html#cfn-quicksight-dashboard-linechartseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartLineStyleSettingsProperty"]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartMarkerStyleSettingsProperty"]]:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html#cfn-quicksight-dashboard-linechartseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartMarkerStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LineChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit_configuration": "categoryItemsLimitConfiguration",
            "category_sort": "categorySort",
            "color_items_limit_configuration": "colorItemsLimitConfiguration",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class LineChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a line chart.

            :param category_items_limit_configuration: The limit on the number of categories that are displayed in a line chart.
            :param category_sort: The sort configuration of the category fields.
            :param color_items_limit_configuration: The limit on the number of lines that are displayed in a line chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_sort_configuration_property = quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                    category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__764e6a41134c95d4ac3b4e56bf2da11057f640be48709dbf62101ffdc389f2b6)
                check_type(argname="argument category_items_limit_configuration", value=category_items_limit_configuration, expected_type=type_hints["category_items_limit_configuration"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit_configuration", value=color_items_limit_configuration, expected_type=type_hints["color_items_limit_configuration"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit_configuration is not None:
                self._values["category_items_limit_configuration"] = category_items_limit_configuration
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit_configuration is not None:
                self._values["color_items_limit_configuration"] = color_items_limit_configuration
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories that are displayed in a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-categoryitemslimitconfiguration
            '''
            result = self._values.get("category_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of lines that are displayed in a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-coloritemslimitconfiguration
            '''
            result = self._values.get("color_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LineChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class LineChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a line chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_chart_visual_property = quicksight.CfnDashboard.LineChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.LineChartConfigurationProperty(
                        contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                            axis_binding="axisBinding",
                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        ),
                        field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                            line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                            forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                                lower_boundary=123,
                                periods_backward=123,
                                periods_forward=123,
                                prediction_interval=123,
                                seasonality=123,
                                upper_boundary=123
                            ),
                            scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                                what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                    date="date",
                                    value=123
                                ),
                                what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                    end_date="endDate",
                                    start_date="startDate",
                                    value=123
                                )
                            )
                        )],
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                            axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                treatment_option="treatmentOption"
                            )]
                        ),
                        primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                            data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                            axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                treatment_option="treatmentOption"
                            )]
                        ),
                        secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        series=[quicksight.CfnDashboard.SeriesItemProperty(
                            data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                                axis_binding="axisBinding",
                                field_id="fieldId",
                
                                # the properties below are optional
                                field_value="fieldValue",
                                settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                )
                            ),
                            field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                                axis_binding="axisBinding",
                                field_id="fieldId",
                
                                # the properties below are optional
                                settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                )
                            )
                        )],
                        small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                            category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        type="type",
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1d0e111b8e1938c8e8ecc91729cfdbaea698e7682cbae7467458b54c6f0cae4f)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartConfigurationProperty"]]:
            '''The configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_options": "axisOptions",
            "missing_data_configurations": "missingDataConfigurations",
        },
    )
    class LineSeriesAxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            missing_data_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MissingDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The series axis configuration of a line chart.

            :param axis_options: The options that determine the presentation of the line series axis.
            :param missing_data_configurations: The configuration options that determine how missing data is treated during the rendering of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_series_axis_display_options_property = quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                    axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                        treatment_option="treatmentOption"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4623b05c5e5c6a51b638262226fe6ae5069cd1693dd9ba599e3811795e7fa386)
                check_type(argname="argument axis_options", value=axis_options, expected_type=type_hints["axis_options"])
                check_type(argname="argument missing_data_configurations", value=missing_data_configurations, expected_type=type_hints["missing_data_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_options is not None:
                self._values["axis_options"] = axis_options
            if missing_data_configurations is not None:
                self._values["missing_data_configurations"] = missing_data_configurations

        @builtins.property
        def axis_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the line series axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html#cfn-quicksight-dashboard-lineseriesaxisdisplayoptions-axisoptions
            '''
            result = self._values.get("axis_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def missing_data_configurations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MissingDataConfigurationProperty"]]]]:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html#cfn-quicksight-dashboard-lineseriesaxisdisplayoptions-missingdataconfigurations
            '''
            result = self._values.get("missing_data_configurations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MissingDataConfigurationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineSeriesAxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ListControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "search_options": "searchOptions",
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class ListControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            search_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ListControlSearchOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param search_options: The configuration of the search options in a list control.
            :param select_all_options: The configuration of the ``Select all`` options in a list control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                list_control_display_options_property = quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                    search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                        visibility="visibility"
                    ),
                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dec4ab4bdb035201666ca03bb1d93ccec4be31ca3638d94656e37a7d6fc67947)
                check_type(argname="argument search_options", value=search_options, expected_type=type_hints["search_options"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if search_options is not None:
                self._values["search_options"] = search_options
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def search_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ListControlSearchOptionsProperty"]]:
            '''The configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-searchoptions
            '''
            result = self._values.get("search_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ListControlSearchOptionsProperty"]], result)

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ListControlSelectAllOptionsProperty"]]:
            '''The configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ListControlSelectAllOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ListControlSearchOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSearchOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the search options in a list control.

            :param visibility: The visibility configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolsearchoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                list_control_search_options_property = quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b6f2755d888fe7114eed3ebd23b1f47ccca7ee4d0af4fe84eead0ac9c4668750)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolsearchoptions.html#cfn-quicksight-dashboard-listcontrolsearchoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSearchOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ListControlSelectAllOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSelectAllOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the ``Select all`` options in a list control.

            :param visibility: The visibility configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolselectalloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                list_control_select_all_options_property = quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__899280bfbc791b382837ead1af8dfef566cb5459acdc5d82ac6ef672cf64c903)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolselectalloptions.html#cfn-quicksight-dashboard-listcontrolselectalloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSelectAllOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LoadingAnimationProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class LoadingAnimationProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of loading animation in free-form layout.

            :param visibility: The visibility configuration of ``LoadingAnimation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-loadinganimation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                loading_animation_property = quicksight.CfnDashboard.LoadingAnimationProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5e28ae8cdac50e883e022fb266b0ec43b35432d5e783e22f9dce7fdb7de78c4f)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of ``LoadingAnimation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-loadinganimation.html#cfn-quicksight-dashboard-loadinganimation-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LoadingAnimationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LocalNavigationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"target_sheet_id": "targetSheetId"},
    )
    class LocalNavigationConfigurationProperty:
        def __init__(self, *, target_sheet_id: builtins.str) -> None:
            '''The navigation configuration for ``CustomActionNavigationOperation`` .

            :param target_sheet_id: The sheet that is targeted for navigation in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-localnavigationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                local_navigation_configuration_property = quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                    target_sheet_id="targetSheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4fbb8ec48d5d32fc163951cf3788735b4e5d2e56e24f95cba0aa95300e7e5ac4)
                check_type(argname="argument target_sheet_id", value=target_sheet_id, expected_type=type_hints["target_sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "target_sheet_id": target_sheet_id,
            }

        @builtins.property
        def target_sheet_id(self) -> builtins.str:
            '''The sheet that is targeted for navigation in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-localnavigationconfiguration.html#cfn-quicksight-dashboard-localnavigationconfiguration-targetsheetid
            '''
            result = self._values.get("target_sheet_id")
            assert result is not None, "Required property 'target_sheet_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LocalNavigationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.LongFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class LongFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for a subtitle.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                long_format_text_property = quicksight.CfnDashboard.LongFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f9ccfefd337bfb15d687773b0f08c28214a39d4273588db52719b29b61a58a2e)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html#cfn-quicksight-dashboard-longformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html#cfn-quicksight-dashboard-longformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LongFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.MappedDataSetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "data_set_parameter_name": "dataSetParameterName",
        },
    )
    class MappedDataSetParameterProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            data_set_parameter_name: builtins.str,
        ) -> None:
            '''
            :param data_set_identifier: ``CfnDashboard.MappedDataSetParameterProperty.DataSetIdentifier``.
            :param data_set_parameter_name: ``CfnDashboard.MappedDataSetParameterProperty.DataSetParameterName``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                mapped_data_set_parameter_property = quicksight.CfnDashboard.MappedDataSetParameterProperty(
                    data_set_identifier="dataSetIdentifier",
                    data_set_parameter_name="dataSetParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__623aa7e3fd86a3f0e6e3433861d275f12d938f74238a42e56fd4c83df43a4eec)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument data_set_parameter_name", value=data_set_parameter_name, expected_type=type_hints["data_set_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "data_set_parameter_name": data_set_parameter_name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''``CfnDashboard.MappedDataSetParameterProperty.DataSetIdentifier``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html#cfn-quicksight-dashboard-mappeddatasetparameter-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_parameter_name(self) -> builtins.str:
            '''``CfnDashboard.MappedDataSetParameterProperty.DataSetParameterName``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html#cfn-quicksight-dashboard-mappeddatasetparameter-datasetparametername
            '''
            result = self._values.get("data_set_parameter_name")
            assert result is not None, "Required property 'data_set_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MappedDataSetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.MaximumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MaximumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The maximum label of a data path label.

            :param visibility: The visibility of the maximum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                maximum_label_type_property = quicksight.CfnDashboard.MaximumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22dabc5578527cc57631a32da1be46743acb90597a1d9ecfa577e20f33a407e6)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the maximum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumlabeltype.html#cfn-quicksight-dashboard-maximumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.MaximumMinimumComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "type": "type",
            "name": "name",
            "value": "value",
        },
    )
    class MaximumMinimumComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The maximum and minimum computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param type: The type of computation. Choose one of the following options:. - MAXIMUM: A maximum computation. - MINIMUM: A minimum computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                maximum_minimum_computation_property = quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__24f5e127ac1b17e5666d3c9ad8db9244d75f2e569e1c1f7ddde7d5f62e108b43)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"], result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of computation. Choose one of the following options:.

            - MAXIMUM: A maximum computation.
            - MINIMUM: A minimum computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumMinimumComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.MeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculated_measure_field": "calculatedMeasureField",
            "categorical_measure_field": "categoricalMeasureField",
            "date_measure_field": "dateMeasureField",
            "numerical_measure_field": "numericalMeasureField",
        },
    )
    class MeasureFieldProperty:
        def __init__(
            self,
            *,
            calculated_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CalculatedMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            categorical_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CategoricalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            date_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DateMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numerical_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure (metric) type field.

            :param calculated_measure_field: The calculated measure field only used in pivot tables.
            :param categorical_measure_field: The measure type field with categorical type columns.
            :param date_measure_field: The measure type field with date type columns.
            :param numerical_measure_field: The measure type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                measure_field_property = quicksight.CfnDashboard.MeasureFieldProperty(
                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                        expression="expression",
                        field_id="fieldId"
                    ),
                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fe21f3c3e64400211fcf6c981975acbbe1ee857fe98569c63ab316fc70c7e5b5)
                check_type(argname="argument calculated_measure_field", value=calculated_measure_field, expected_type=type_hints["calculated_measure_field"])
                check_type(argname="argument categorical_measure_field", value=categorical_measure_field, expected_type=type_hints["categorical_measure_field"])
                check_type(argname="argument date_measure_field", value=date_measure_field, expected_type=type_hints["date_measure_field"])
                check_type(argname="argument numerical_measure_field", value=numerical_measure_field, expected_type=type_hints["numerical_measure_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if calculated_measure_field is not None:
                self._values["calculated_measure_field"] = calculated_measure_field
            if categorical_measure_field is not None:
                self._values["categorical_measure_field"] = categorical_measure_field
            if date_measure_field is not None:
                self._values["date_measure_field"] = date_measure_field
            if numerical_measure_field is not None:
                self._values["numerical_measure_field"] = numerical_measure_field

        @builtins.property
        def calculated_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CalculatedMeasureFieldProperty"]]:
            '''The calculated measure field only used in pivot tables.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-calculatedmeasurefield
            '''
            result = self._values.get("calculated_measure_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CalculatedMeasureFieldProperty"]], result)

        @builtins.property
        def categorical_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CategoricalMeasureFieldProperty"]]:
            '''The measure type field with categorical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-categoricalmeasurefield
            '''
            result = self._values.get("categorical_measure_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CategoricalMeasureFieldProperty"]], result)

        @builtins.property
        def date_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateMeasureFieldProperty"]]:
            '''The measure type field with date type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-datemeasurefield
            '''
            result = self._values.get("date_measure_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateMeasureFieldProperty"]], result)

        @builtins.property
        def numerical_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericalMeasureFieldProperty"]]:
            '''The measure type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-numericalmeasurefield
            '''
            result = self._values.get("numerical_measure_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericalMeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.MetricComparisonComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "from_value": "fromValue",
            "target_value": "targetValue",
            "time": "time",
            "name": "name",
        },
    )
    class MetricComparisonComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            from_value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            target_value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The metric comparison computation configuration.

            :param computation_id: The ID for a computation.
            :param from_value: The field that is used in a metric comparison from value setup.
            :param target_value: The field that is used in a metric comparison to value setup.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                metric_comparison_computation_property = quicksight.CfnDashboard.MetricComparisonComputationProperty(
                    computation_id="computationId",
                    from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                    target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3b6f953b061d6891f09a69182d9880c876e370af3c08793e66bd9b362722515b)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument from_value", value=from_value, expected_type=type_hints["from_value"])
                check_type(argname="argument target_value", value=target_value, expected_type=type_hints["target_value"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "from_value": from_value,
                "target_value": target_value,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def from_value(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]:
            '''The field that is used in a metric comparison from value setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-fromvalue
            '''
            result = self._values.get("from_value")
            assert result is not None, "Required property 'from_value' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"], result)

        @builtins.property
        def target_value(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]:
            '''The field that is used in a metric comparison to value setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-targetvalue
            '''
            result = self._values.get("target_value")
            assert result is not None, "Required property 'target_value' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MetricComparisonComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.MinimumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MinimumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The minimum label of a data path label.

            :param visibility: The visibility of the minimum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-minimumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                minimum_label_type_property = quicksight.CfnDashboard.MinimumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__232a4bc118496c7449cbdfd8d5bfa056794e178620e0f6a1e3ca5037ceb702e6)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the minimum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-minimumlabeltype.html#cfn-quicksight-dashboard-minimumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MinimumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.MissingDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"treatment_option": "treatmentOption"},
    )
    class MissingDataConfigurationProperty:
        def __init__(
            self,
            *,
            treatment_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :param treatment_option: The treatment option that determines how missing data should be rendered. Choose from the following options:. - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value. - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` . - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-missingdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                missing_data_configuration_property = quicksight.CfnDashboard.MissingDataConfigurationProperty(
                    treatment_option="treatmentOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c359da2ed53558c7fb51fcd2d47fb0875148a5de874b02f784a27282ff58456e)
                check_type(argname="argument treatment_option", value=treatment_option, expected_type=type_hints["treatment_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if treatment_option is not None:
                self._values["treatment_option"] = treatment_option

        @builtins.property
        def treatment_option(self) -> typing.Optional[builtins.str]:
            '''The treatment option that determines how missing data should be rendered. Choose from the following options:.

            - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value.
            - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` .
            - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-missingdataconfiguration.html#cfn-quicksight-dashboard-missingdataconfiguration-treatmentoption
            '''
            result = self._values.get("treatment_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MissingDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NegativeValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"display_mode": "displayMode"},
    )
    class NegativeValueConfigurationProperty:
        def __init__(self, *, display_mode: builtins.str) -> None:
            '''The options that determine the negative value configuration.

            :param display_mode: Determines the display mode of the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-negativevalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                negative_value_configuration_property = quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                    display_mode="displayMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0c2e9c144eda5d09644c4292d203063382539ad3f3ba07ed9d2b570e595744a8)
                check_type(argname="argument display_mode", value=display_mode, expected_type=type_hints["display_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "display_mode": display_mode,
            }

        @builtins.property
        def display_mode(self) -> builtins.str:
            '''Determines the display mode of the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-negativevalueconfiguration.html#cfn-quicksight-dashboard-negativevalueconfiguration-displaymode
            '''
            result = self._values.get("display_mode")
            assert result is not None, "Required property 'display_mode' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NegativeValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NullValueFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"null_string": "nullString"},
    )
    class NullValueFormatConfigurationProperty:
        def __init__(self, *, null_string: builtins.str) -> None:
            '''The options that determine the null value format configuration.

            :param null_string: Determines the null string of null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-nullvalueformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                null_value_format_configuration_property = quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                    null_string="nullString"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__709af1be6ed083c0d42c9aac226d217767796d5f56ffda82dd258f78506d1464)
                check_type(argname="argument null_string", value=null_string, expected_type=type_hints["null_string"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "null_string": null_string,
            }

        @builtins.property
        def null_string(self) -> builtins.str:
            '''Determines the null string of null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-nullvalueformatconfiguration.html#cfn-quicksight-dashboard-nullvalueformatconfiguration-nullstring
            '''
            result = self._values.get("null_string")
            assert result is not None, "Required property 'null_string' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NullValueFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class NumberDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the number display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value of the number format.
            :param prefix: Determines the prefix value of the number format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                number_display_format_configuration_property = quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ef9dc00324bdae1096d6bcb32da0ffd48ba9b31b60da5f416445b90b050a1346)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NumberFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"format_configuration": "formatConfiguration"},
    )
    class NumberFormatConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for number fields.

            :param format_configuration: The options that determine the numeric format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                number_format_configuration_property = quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0da159b9af4bfcbf185b9a476447c9397077b644915d1fc486a65d64e79aabe)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericFormatConfigurationProperty"]]:
            '''The options that determine the numeric format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberformatconfiguration.html#cfn-quicksight-dashboard-numberformatconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NumericAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "scale": "scale"},
    )
    class NumericAxisOptionsProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for an axis with a numeric field.

            :param range: The range setup of a numeric axis.
            :param scale: The scale setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                numeric_axis_options_property = quicksight.CfnDashboard.NumericAxisOptionsProperty(
                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                        data_driven=data_driven,
                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                            maximum=123,
                            minimum=123
                        )
                    ),
                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                            step_count=123,
                            step_size=123
                        ),
                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                            base=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93695b688ebd486b486378a566e96f721976cd5a9244e6100dc6d2e5db3ea47c)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if scale is not None:
                self._values["scale"] = scale

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayRangeProperty"]]:
            '''The range setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html#cfn-quicksight-dashboard-numericaxisoptions-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayRangeProperty"]], result)

        @builtins.property
        def scale(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisScaleProperty"]]:
            '''The scale setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html#cfn-quicksight-dashboard-numericaxisoptions-scale
            '''
            result = self._values.get("scale")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "value": "value"},
    )
    class NumericEqualityDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            value: jsii.Number,
        ) -> None:
            '''The category drill down filter.

            :param column: The column that the filter is applied to.
            :param value: The value of the double input numeric drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_equality_drill_down_filter_property = quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9fb28f487b58c66510a4ddcf57462f4ba11db7a6b038ec29f33ec95680a27908)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "value": value,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html#cfn-quicksight-dashboard-numericequalitydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The value of the double input numeric drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html#cfn-quicksight-dashboard-numericequalitydrilldownfilter-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NumericEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
            "value": "value",
        },
    )
    class NumericEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            match_operator: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``NumericEqualityFilter`` filters values that are equal to the specified value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``
            :param value: The input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_equality_filter_property = quicksight.CfnDashboard.NumericEqualityFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__070224fdacee8cb941a68519353b4984445aee007deac4994ae85d1b4337135c)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationFunctionProperty"]]:
            '''The aggregation function of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationFunctionProperty"]], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NumericFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "currency_display_format_configuration": "currencyDisplayFormatConfiguration",
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class NumericFormatConfigurationProperty:
        def __init__(
            self,
            *,
            currency_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CurrencyDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the numeric format configuration.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param currency_display_format_configuration: The options that determine the currency display format configuration.
            :param number_display_format_configuration: The options that determine the number display format configuration.
            :param percentage_display_format_configuration: The options that determine the percentage display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_format_configuration_property = quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix",
                        symbol="symbol"
                    ),
                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7aff34c5ff3a3a3a2e631d57047a938747aab0eaf54834b205c1c427218a5945)
                check_type(argname="argument currency_display_format_configuration", value=currency_display_format_configuration, expected_type=type_hints["currency_display_format_configuration"])
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if currency_display_format_configuration is not None:
                self._values["currency_display_format_configuration"] = currency_display_format_configuration
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def currency_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CurrencyDisplayFormatConfigurationProperty"]]:
            '''The options that determine the currency display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-currencydisplayformatconfiguration
            '''
            result = self._values.get("currency_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CurrencyDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumberDisplayFormatConfigurationProperty"]]:
            '''The options that determine the number display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumberDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PercentageDisplayFormatConfigurationProperty"]]:
            '''The options that determine the percentage display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PercentageDisplayFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NumericRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "select_all_options": "selectAllOptions",
        },
    )
    class NumericRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            range_maximum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_minimum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``NumericRangeFilter`` filters values that are within the value range.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_range_filter_property = quicksight.CfnDashboard.NumericRangeFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__00dc5a36aa55956ac3070093f10452d21427698c007c768af3717d587082d0d2)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum is not None:
                self._values["range_maximum"] = range_maximum
            if range_minimum is not None:
                self._values["range_minimum"] = range_minimum
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationFunctionProperty"]]:
            '''The aggregation function of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationFunctionProperty"]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def range_maximum(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericRangeFilterValueProperty"]]:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericRangeFilterValueProperty"]], result)

        @builtins.property
        def range_minimum(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericRangeFilterValueProperty"]]:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericRangeFilterValueProperty"]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NumericRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={"parameter": "parameter", "static_value": "staticValue"},
    )
    class NumericRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            static_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The value input pf the numeric range filter.

            :param parameter: The parameter that is used in the numeric range.
            :param static_value: The static value of the numeric range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_range_filter_value_property = quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                    parameter="parameter",
                    static_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e9b485a539778ef7858b497857a4341a4941e605cfc2c3c0956fffc06a85ab6b)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter that is used in the numeric range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html#cfn-quicksight-dashboard-numericrangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def static_value(self) -> typing.Optional[jsii.Number]:
            '''The static value of the numeric range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html#cfn-quicksight-dashboard-numericrangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NumericSeparatorConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_separator": "decimalSeparator",
            "thousands_separator": "thousandsSeparator",
        },
    )
    class NumericSeparatorConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_separator: typing.Optional[builtins.str] = None,
            thousands_separator: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ThousandSeparatorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the numeric separator configuration.

            :param decimal_separator: Determines the decimal separator.
            :param thousands_separator: The options that determine the thousands separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_separator_configuration_property = quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                    decimal_separator="decimalSeparator",
                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                        symbol="symbol",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__37e5a6471010547133725092c7de33169afd9289904d97a095a803d4a2c034bd)
                check_type(argname="argument decimal_separator", value=decimal_separator, expected_type=type_hints["decimal_separator"])
                check_type(argname="argument thousands_separator", value=thousands_separator, expected_type=type_hints["thousands_separator"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_separator is not None:
                self._values["decimal_separator"] = decimal_separator
            if thousands_separator is not None:
                self._values["thousands_separator"] = thousands_separator

        @builtins.property
        def decimal_separator(self) -> typing.Optional[builtins.str]:
            '''Determines the decimal separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html#cfn-quicksight-dashboard-numericseparatorconfiguration-decimalseparator
            '''
            result = self._values.get("decimal_separator")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thousands_separator(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ThousandSeparatorOptionsProperty"]]:
            '''The options that determine the thousands separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html#cfn-quicksight-dashboard-numericseparatorconfiguration-thousandsseparator
            '''
            result = self._values.get("thousands_separator")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ThousandSeparatorOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericSeparatorConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NumericalAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "percentile_aggregation": "percentileAggregation",
            "simple_numerical_aggregation": "simpleNumericalAggregation",
        },
    )
    class NumericalAggregationFunctionProperty:
        def __init__(
            self,
            *,
            percentile_aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PercentileAggregationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            simple_numerical_aggregation: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Aggregation for numerical values.

            :param percentile_aggregation: An aggregation based on the percentile of values in a dimension or measure.
            :param simple_numerical_aggregation: Built-in aggregation functions for numerical values. - ``SUM`` : The sum of a dimension or measure. - ``AVERAGE`` : The average of a dimension or measure. - ``MIN`` : The minimum value of a dimension or measure. - ``MAX`` : The maximum value of a dimension or measure. - ``COUNT`` : The count of a dimension or measure. - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure. - ``VAR`` : The variance of a dimension or measure. - ``VARP`` : The partitioned variance of a dimension or measure. - ``STDEV`` : The standard deviation of a dimension or measure. - ``STDEVP`` : The partitioned standard deviation of a dimension or measure. - ``MEDIAN`` : The median value of a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numerical_aggregation_function_property = quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                        percentile_value=123
                    ),
                    simple_numerical_aggregation="simpleNumericalAggregation"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3949f7370aecfe7f50e0927274ec2baaa769d0915cdb7d80c82a513090787803)
                check_type(argname="argument percentile_aggregation", value=percentile_aggregation, expected_type=type_hints["percentile_aggregation"])
                check_type(argname="argument simple_numerical_aggregation", value=simple_numerical_aggregation, expected_type=type_hints["simple_numerical_aggregation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_aggregation is not None:
                self._values["percentile_aggregation"] = percentile_aggregation
            if simple_numerical_aggregation is not None:
                self._values["simple_numerical_aggregation"] = simple_numerical_aggregation

        @builtins.property
        def percentile_aggregation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PercentileAggregationProperty"]]:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html#cfn-quicksight-dashboard-numericalaggregationfunction-percentileaggregation
            '''
            result = self._values.get("percentile_aggregation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PercentileAggregationProperty"]], result)

        @builtins.property
        def simple_numerical_aggregation(self) -> typing.Optional[builtins.str]:
            '''Built-in aggregation functions for numerical values.

            - ``SUM`` : The sum of a dimension or measure.
            - ``AVERAGE`` : The average of a dimension or measure.
            - ``MIN`` : The minimum value of a dimension or measure.
            - ``MAX`` : The maximum value of a dimension or measure.
            - ``COUNT`` : The count of a dimension or measure.
            - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure.
            - ``VAR`` : The variance of a dimension or measure.
            - ``VARP`` : The partitioned variance of a dimension or measure.
            - ``STDEV`` : The standard deviation of a dimension or measure.
            - ``STDEVP`` : The partitioned standard deviation of a dimension or measure.
            - ``MEDIAN`` : The median value of a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html#cfn-quicksight-dashboard-numericalaggregationfunction-simplenumericalaggregation
            '''
            result = self._values.get("simple_numerical_aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NumericalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class NumericalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with numerical type columns.

            :param column: The column that is used in the ``NumericalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numerical_dimension_field_property = quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b90c02598175a5004a822765b4b674395adc4dc416d5c7de3ebef69205112dcb)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``NumericalDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumberFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumberFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.NumericalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class NumericalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with numerical type columns.

            :param column: The column that is used in the ``NumericalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numerical_measure_field_property = quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__112163e48c0afaad6152a756ea8acc6ebbab557db814c6b5b1b67f694eeaea02)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``NumericalMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericalAggregationFunctionProperty"]]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericalAggregationFunctionProperty"]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumberFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumberFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PaginationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"page_number": "pageNumber", "page_size": "pageSize"},
    )
    class PaginationConfigurationProperty:
        def __init__(self, *, page_number: jsii.Number, page_size: jsii.Number) -> None:
            '''The pagination configuration for a table visual or boxplot.

            :param page_number: Indicates the page number.
            :param page_size: Indicates how many items render in one page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pagination_configuration_property = quicksight.CfnDashboard.PaginationConfigurationProperty(
                    page_number=123,
                    page_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d1ad64f06ff3f4b3454be13e3ba249e846ba5cfd204890feb74aa7df2ef9f302)
                check_type(argname="argument page_number", value=page_number, expected_type=type_hints["page_number"])
                check_type(argname="argument page_size", value=page_size, expected_type=type_hints["page_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "page_number": page_number,
                "page_size": page_size,
            }

        @builtins.property
        def page_number(self) -> jsii.Number:
            '''Indicates the page number.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html#cfn-quicksight-dashboard-paginationconfiguration-pagenumber
            '''
            result = self._values.get("page_number")
            assert result is not None, "Required property 'page_number' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def page_size(self) -> jsii.Number:
            '''Indicates how many items render in one page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html#cfn-quicksight-dashboard-paginationconfiguration-pagesize
            '''
            result = self._values.get("page_size")
            assert result is not None, "Required property 'page_size' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PaginationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PanelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "background_visibility": "backgroundVisibility",
            "border_color": "borderColor",
            "border_style": "borderStyle",
            "border_thickness": "borderThickness",
            "border_visibility": "borderVisibility",
            "gutter_spacing": "gutterSpacing",
            "gutter_visibility": "gutterVisibility",
            "title": "title",
        },
    )
    class PanelConfigurationProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            background_visibility: typing.Optional[builtins.str] = None,
            border_color: typing.Optional[builtins.str] = None,
            border_style: typing.Optional[builtins.str] = None,
            border_thickness: typing.Optional[builtins.str] = None,
            border_visibility: typing.Optional[builtins.str] = None,
            gutter_spacing: typing.Optional[builtins.str] = None,
            gutter_visibility: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PanelTitleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A collection of options that configure how each panel displays in a small multiples chart.

            :param background_color: Sets the background color for each panel.
            :param background_visibility: Determines whether or not a background for each small multiples panel is rendered.
            :param border_color: Sets the line color of panel borders.
            :param border_style: Sets the line style of panel borders.
            :param border_thickness: Sets the line thickness of panel borders.
            :param border_visibility: Determines whether or not each panel displays a border.
            :param gutter_spacing: Sets the total amount of negative space to display between sibling panels.
            :param gutter_visibility: Determines whether or not negative space between sibling panels is rendered.
            :param title: Configures the title display within each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                panel_configuration_property = quicksight.CfnDashboard.PanelConfigurationProperty(
                    background_color="backgroundColor",
                    background_visibility="backgroundVisibility",
                    border_color="borderColor",
                    border_style="borderStyle",
                    border_thickness="borderThickness",
                    border_visibility="borderVisibility",
                    gutter_spacing="gutterSpacing",
                    gutter_visibility="gutterVisibility",
                    title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_text_alignment="horizontalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__87b20a3f65053e5a1cd31a84f88c0f865031099d3ccc66697c5510c20e1cfd1b)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument background_visibility", value=background_visibility, expected_type=type_hints["background_visibility"])
                check_type(argname="argument border_color", value=border_color, expected_type=type_hints["border_color"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument border_thickness", value=border_thickness, expected_type=type_hints["border_thickness"])
                check_type(argname="argument border_visibility", value=border_visibility, expected_type=type_hints["border_visibility"])
                check_type(argname="argument gutter_spacing", value=gutter_spacing, expected_type=type_hints["gutter_spacing"])
                check_type(argname="argument gutter_visibility", value=gutter_visibility, expected_type=type_hints["gutter_visibility"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if background_visibility is not None:
                self._values["background_visibility"] = background_visibility
            if border_color is not None:
                self._values["border_color"] = border_color
            if border_style is not None:
                self._values["border_style"] = border_style
            if border_thickness is not None:
                self._values["border_thickness"] = border_thickness
            if border_visibility is not None:
                self._values["border_visibility"] = border_visibility
            if gutter_spacing is not None:
                self._values["gutter_spacing"] = gutter_spacing
            if gutter_visibility is not None:
                self._values["gutter_visibility"] = gutter_visibility
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''Sets the background color for each panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def background_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not a background for each small multiples panel is rendered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-backgroundvisibility
            '''
            result = self._values.get("background_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_color(self) -> typing.Optional[builtins.str]:
            '''Sets the line color of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-bordercolor
            '''
            result = self._values.get("border_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_style(self) -> typing.Optional[builtins.str]:
            '''Sets the line style of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_thickness(self) -> typing.Optional[builtins.str]:
            '''Sets the line thickness of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-borderthickness
            '''
            result = self._values.get("border_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not each panel displays a border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-bordervisibility
            '''
            result = self._values.get("border_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_spacing(self) -> typing.Optional[builtins.str]:
            '''Sets the total amount of negative space to display between sibling panels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-gutterspacing
            '''
            result = self._values.get("gutter_spacing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not negative space between sibling panels is rendered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-guttervisibility
            '''
            result = self._values.get("gutter_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PanelTitleOptionsProperty"]]:
            '''Configures the title display within each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PanelTitleOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PanelTitleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_configuration": "fontConfiguration",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "visibility": "visibility",
        },
    )
    class PanelTitleOptionsProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the title styles for each small multiples panel.

            :param font_configuration: ``CfnDashboard.PanelTitleOptionsProperty.FontConfiguration``.
            :param horizontal_text_alignment: Sets the horizontal text alignment of the title within each panel.
            :param visibility: Determines whether or not panel titles are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                panel_title_options_property = quicksight.CfnDashboard.PanelTitleOptionsProperty(
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_text_alignment="horizontalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9a1e8c8be43617e4e3408c201486654634d4a3bc28b9b30acda399584e7d9dba)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]]:
            '''``CfnDashboard.PanelTitleOptionsProperty.FontConfiguration``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''Sets the horizontal text alignment of the title within each panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not panel titles are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelTitleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ParameterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class ParameterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ParameterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            dropdown: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ParameterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ParameterListControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            slider: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ParameterSliderControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_area: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ParameterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ParameterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The control of a parameter that users can interact with in a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date parameter that specifies date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_control_property = quicksight.CfnDashboard.ParameterControlProperty(
                    date_time_picker=quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    dropdown=quicksight.CfnDashboard.ParameterDropDownControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                            select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnDashboard.ParameterListControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                            search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    slider=quicksight.CfnDashboard.ParameterSliderControlProperty(
                        maximum_value=123,
                        minimum_value=123,
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_area=quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2a8b6c6ebcab4c33e9ed7f1f734fec6d6cc444af360cf064c8a7aa3708fd2743)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterDateTimePickerControlProperty"]]:
            '''A control from a date parameter that specifies date and time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterDateTimePickerControlProperty"]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterDropDownControlProperty"]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterDropDownControlProperty"]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterListControlProperty"]]:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterListControlProperty"]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterSliderControlProperty"]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterSliderControlProperty"]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterTextAreaControlProperty"]]:
            '''A control to display a text box that is used to enter multiple entries.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterTextAreaControlProperty"]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterTextFieldControlProperty"]]:
            '''A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterTextFieldControlProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ParameterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control from a date parameter that specifies date and time.

            :param parameter_control_id: The ID of the ``ParameterDateTimePickerControl`` .
            :param source_parameter_name: The name of the ``ParameterDateTimePickerControl`` .
            :param title: The title of the ``ParameterDateTimePickerControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_date_time_picker_control_property = quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__de54537ba5d311f111ef4e81447a2ef53ec14146e7dc44b6516eeb16cb1660c0)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The name of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimePickerControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimePickerControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameter_declaration": "dateTimeParameterDeclaration",
            "decimal_parameter_declaration": "decimalParameterDeclaration",
            "integer_parameter_declaration": "integerParameterDeclaration",
            "string_parameter_declaration": "stringParameterDeclaration",
        },
    )
    class ParameterDeclarationProperty:
        def __init__(
            self,
            *,
            date_time_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DateTimeParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            decimal_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DecimalParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            integer_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.IntegerParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            string_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.StringParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The declaration definition of a parameter.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_parameter_declaration: A parameter declaration for the ``DateTime`` data type.
            :param decimal_parameter_declaration: A parameter declaration for the ``Decimal`` data type.
            :param integer_parameter_declaration: A parameter declaration for the ``Integer`` data type.
            :param string_parameter_declaration: A parameter declaration for the ``String`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_declaration_property = quicksight.CfnDashboard.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnDashboard.DateTimeParameterDeclarationProperty(
                        name="name",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnDashboard.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnDashboard.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnDashboard.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a083a696c7791ed4ab8ea02b669c15cc31f11683b796b84999688dee3cd1fb39)
                check_type(argname="argument date_time_parameter_declaration", value=date_time_parameter_declaration, expected_type=type_hints["date_time_parameter_declaration"])
                check_type(argname="argument decimal_parameter_declaration", value=decimal_parameter_declaration, expected_type=type_hints["decimal_parameter_declaration"])
                check_type(argname="argument integer_parameter_declaration", value=integer_parameter_declaration, expected_type=type_hints["integer_parameter_declaration"])
                check_type(argname="argument string_parameter_declaration", value=string_parameter_declaration, expected_type=type_hints["string_parameter_declaration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameter_declaration is not None:
                self._values["date_time_parameter_declaration"] = date_time_parameter_declaration
            if decimal_parameter_declaration is not None:
                self._values["decimal_parameter_declaration"] = decimal_parameter_declaration
            if integer_parameter_declaration is not None:
                self._values["integer_parameter_declaration"] = integer_parameter_declaration
            if string_parameter_declaration is not None:
                self._values["string_parameter_declaration"] = string_parameter_declaration

        @builtins.property
        def date_time_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``DateTime`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-datetimeparameterdeclaration
            '''
            result = self._values.get("date_time_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeParameterDeclarationProperty"]], result)

        @builtins.property
        def decimal_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``Decimal`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-decimalparameterdeclaration
            '''
            result = self._values.get("decimal_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalParameterDeclarationProperty"]], result)

        @builtins.property
        def integer_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.IntegerParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-integerparameterdeclaration
            '''
            result = self._values.get("integer_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.IntegerParameterDeclarationProperty"]], result)

        @builtins.property
        def string_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``String`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-stringparameterdeclaration
            '''
            result = self._values.get("string_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringParameterDeclarationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ParameterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterDropDownControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param parameter_control_id: The ID of the ``ParameterDropDownControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterDropDownControl`` .
            :param title: The title of the ``ParameterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_drop_down_control_property = quicksight.CfnDashboard.ParameterDropDownControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                        select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__daccf08b3207be15007e2074e14839097c25b786f0f0a12a2eda07e64c0101c9)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DropDownControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DropDownControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ParameterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterListControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :param parameter_control_id: The ID of the ``ParameterListControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterListControl`` .
            :param title: The title of the ``ParameterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_list_control_property = quicksight.CfnDashboard.ParameterListControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                        search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8f14159a5fef32514b49dafbd4713dc4faf6ec18a11fd4371b02233e6553f1ef)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ListControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ListControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ParameterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "link_to_data_set_column": "linkToDataSetColumn",
            "values": "values",
        },
    )
    class ParameterSelectableValuesProperty:
        def __init__(
            self,
            *,
            link_to_data_set_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param link_to_data_set_column: The column identifier that fetches values from the data set.
            :param values: The values that are used in ``ParameterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_selectable_values_property = quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                    link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb01b988bff788d74e9acce5f7c91cc2670848ec7eb27abd81c926345b73d4df)
                check_type(argname="argument link_to_data_set_column", value=link_to_data_set_column, expected_type=type_hints["link_to_data_set_column"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if link_to_data_set_column is not None:
                self._values["link_to_data_set_column"] = link_to_data_set_column
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def link_to_data_set_column(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]]:
            '''The column identifier that fetches values from the data set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html#cfn-quicksight-dashboard-parameterselectablevalues-linktodatasetcolumn
            '''
            result = self._values.get("link_to_data_set_column")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]], result)

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in ``ParameterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html#cfn-quicksight-dashboard-parameterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ParameterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterSliderControlProperty:
        def __init__(
            self,
            *,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param maximum_value: The smaller value that is displayed at the left of the slider.
            :param minimum_value: The larger value that is displayed at the right of the slider.
            :param parameter_control_id: The ID of the ``ParameterSliderControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into.
            :param title: The title of the ``ParameterSliderControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_slider_control_property = quicksight.CfnDashboard.ParameterSliderControlProperty(
                    maximum_value=123,
                    minimum_value=123,
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3d0f111279ff98cce9f0b571f568610df84051cd90b754d0a4126413eadd375c)
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SliderControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SliderControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ParameterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextAreaControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param parameter_control_id: The ID of the ``ParameterTextAreaControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextAreaControl`` .
            :param title: The title of the ``ParameterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_text_area_control_property = quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aa2d65d57d16808f046f4958c9cf29e827410318e2a15bccfd9f430f441a23c4)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextAreaControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextAreaControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ParameterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextFieldControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param parameter_control_id: The ID of the ``ParameterTextFieldControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextFieldControl`` .
            :param title: The title of the ``ParameterTextFieldControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_text_field_control_property = quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0695b9d702738315e549f7ae7ccb208e53a61a4ff6ba727a0cdefa8784a31e52)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextFieldControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextFieldControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameters": "dateTimeParameters",
            "decimal_parameters": "decimalParameters",
            "integer_parameters": "integerParameters",
            "string_parameters": "stringParameters",
        },
    )
    class ParametersProperty:
        def __init__(
            self,
            *,
            date_time_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DateTimeParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            decimal_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DecimalParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            integer_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.IntegerParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            string_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.StringParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A list of Amazon QuickSight parameters and the list's override values.

            :param date_time_parameters: The parameters that have a data type of date-time.
            :param decimal_parameters: The parameters that have a data type of decimal.
            :param integer_parameters: The parameters that have a data type of integer.
            :param string_parameters: The parameters that have a data type of string.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameters_property = quicksight.CfnDashboard.ParametersProperty(
                    date_time_parameters=[quicksight.CfnDashboard.DateTimeParameterProperty(
                        name="name",
                        values=["values"]
                    )],
                    decimal_parameters=[quicksight.CfnDashboard.DecimalParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    integer_parameters=[quicksight.CfnDashboard.IntegerParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    string_parameters=[quicksight.CfnDashboard.StringParameterProperty(
                        name="name",
                        values=["values"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e801d31157867bb4e87c8b3c5eeb3d91d9ee18ac67d2657fbc8f67d5a8516953)
                check_type(argname="argument date_time_parameters", value=date_time_parameters, expected_type=type_hints["date_time_parameters"])
                check_type(argname="argument decimal_parameters", value=decimal_parameters, expected_type=type_hints["decimal_parameters"])
                check_type(argname="argument integer_parameters", value=integer_parameters, expected_type=type_hints["integer_parameters"])
                check_type(argname="argument string_parameters", value=string_parameters, expected_type=type_hints["string_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameters is not None:
                self._values["date_time_parameters"] = date_time_parameters
            if decimal_parameters is not None:
                self._values["decimal_parameters"] = decimal_parameters
            if integer_parameters is not None:
                self._values["integer_parameters"] = integer_parameters
            if string_parameters is not None:
                self._values["string_parameters"] = string_parameters

        @builtins.property
        def date_time_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeParameterProperty"]]]]:
            '''The parameters that have a data type of date-time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-datetimeparameters
            '''
            result = self._values.get("date_time_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DateTimeParameterProperty"]]]], result)

        @builtins.property
        def decimal_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalParameterProperty"]]]]:
            '''The parameters that have a data type of decimal.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-decimalparameters
            '''
            result = self._values.get("decimal_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalParameterProperty"]]]], result)

        @builtins.property
        def integer_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.IntegerParameterProperty"]]]]:
            '''The parameters that have a data type of integer.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-integerparameters
            '''
            result = self._values.get("integer_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.IntegerParameterProperty"]]]], result)

        @builtins.property
        def string_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringParameterProperty"]]]]:
            '''The parameters that have a data type of string.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-stringparameters
            '''
            result = self._values.get("string_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringParameterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PercentVisibleRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"from_": "from", "to": "to"},
    )
    class PercentVisibleRangeProperty:
        def __init__(
            self,
            *,
            from_: typing.Optional[jsii.Number] = None,
            to: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The percent range in the visible range.

            :param from_: The lower bound of the range.
            :param to: The top bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                percent_visible_range_property = quicksight.CfnDashboard.PercentVisibleRangeProperty(
                    from=123,
                    to=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b1fe12a56c3d69c1a833b48dc6b93155c248e4215a4c2b66ec83b015b31528e5)
                check_type(argname="argument from_", value=from_, expected_type=type_hints["from_"])
                check_type(argname="argument to", value=to, expected_type=type_hints["to"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if from_ is not None:
                self._values["from_"] = from_
            if to is not None:
                self._values["to"] = to

        @builtins.property
        def from_(self) -> typing.Optional[jsii.Number]:
            '''The lower bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html#cfn-quicksight-dashboard-percentvisiblerange-from
            '''
            result = self._values.get("from_")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def to(self) -> typing.Optional[jsii.Number]:
            '''The top bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html#cfn-quicksight-dashboard-percentvisiblerange-to
            '''
            result = self._values.get("to")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentVisibleRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class PercentageDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the percentage display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param prefix: Determines the prefix value of the percentage format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                percentage_display_format_configuration_property = quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    prefix="prefix",
                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c900ba075c6cdb7f7817d74443a701c555d9081605d831bd90935a9142f12830)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentageDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PercentileAggregationProperty",
        jsii_struct_bases=[],
        name_mapping={"percentile_value": "percentileValue"},
    )
    class PercentileAggregationProperty:
        def __init__(
            self,
            *,
            percentile_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :param percentile_value: The percentile value. This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentileaggregation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                percentile_aggregation_property = quicksight.CfnDashboard.PercentileAggregationProperty(
                    percentile_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__17313aacb157c49fd09ba4abd32b5a061bfe636fd5f520e98efa18286998fba3)
                check_type(argname="argument percentile_value", value=percentile_value, expected_type=type_hints["percentile_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_value is not None:
                self._values["percentile_value"] = percentile_value

        @builtins.property
        def percentile_value(self) -> typing.Optional[jsii.Number]:
            '''The percentile value.

            This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentileaggregation.html#cfn-quicksight-dashboard-percentileaggregation-percentilevalue
            '''
            result = self._values.get("percentile_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentileAggregationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PeriodOverPeriodComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "value": "value",
        },
    )
    class PeriodOverPeriodComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The period over period computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                period_over_period_computation_property = quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2b292bef098d2b19225fe970f423987eac05d23493cb7a9ce95da7569eef35e2)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodOverPeriodComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PeriodToDateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "period_time_granularity": "periodTimeGranularity",
            "value": "value",
        },
    )
    class PeriodToDateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
            period_time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The period to date computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param period_time_granularity: The time granularity setup of period to date computation. Choose from the following options:. - YEAR: Year to date. - MONTH: Month to date.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                period_to_date_computation_property = quicksight.CfnDashboard.PeriodToDateComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    period_time_granularity="periodTimeGranularity",
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4172bb670257f633b308cdc57cea26daeffde6ff5f1151ecb135f23d9083181d)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_time_granularity", value=period_time_granularity, expected_type=type_hints["period_time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if period_time_granularity is not None:
                self._values["period_time_granularity"] = period_time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity setup of period to date computation. Choose from the following options:.

            - YEAR: Year to date.
            - MONTH: Month to date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-periodtimegranularity
            '''
            result = self._values.get("period_time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodToDateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class PieChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            :param category: The category (group/color) field wells of a pie chart.
            :param small_multiples: The small multiples field well of a pie chart.
            :param values: The value field wells of a pie chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_aggregated_field_wells_property = quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6cf23556ba715122589b258a1b727e5799b5263237d8d1d9aabae305afdae409)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The category (group/color) field wells of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a pie chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PieChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "donut_options": "donutOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class PieChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            donut_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DonutOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PieChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PieChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a pie chart.

            :param category_label_options: The label options of the group/color that is displayed in a pie chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param donut_options: The options that determine the shape of the chart. This option determines whether the chart is a pie chart or a donut chart.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a pie chart.
            :param tooltip: The tooltip display setup of the visual.
            :param value_label_options: The label options for the value that is displayed in a pie chart.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_configuration_property = quicksight.CfnDashboard.PieChartConfigurationProperty(
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                        arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                            arc_thickness="arcThickness"
                        ),
                        donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                            label_visibility="labelVisibility"
                        )
                    ),
                    field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                        pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__598e9566ca61de8bfb4861e8f49f604f3e551f1d2368ecff06b79f71ce802897)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument donut_options", value=donut_options, expected_type=type_hints["donut_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if donut_options is not None:
                self._values["donut_options"] = donut_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the group/color that is displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ContributionAnalysisDefaultProperty"]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def donut_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DonutOptionsProperty"]]:
            '''The options that determine the shape of the chart.

            This option determines whether the chart is a pie chart or a donut chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-donutoptions
            '''
            result = self._values.get("donut_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DonutOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PieChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PieChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PieChartSortConfigurationProperty"]]:
            '''The sort configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PieChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options for the value that is displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PieChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pie_chart_aggregated_field_wells": "pieChartAggregatedFieldWells",
        },
    )
    class PieChartFieldWellsProperty:
        def __init__(
            self,
            *,
            pie_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PieChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pie_chart_aggregated_field_wells: The field well configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_field_wells_property = quicksight.CfnDashboard.PieChartFieldWellsProperty(
                    pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b4c74c8f35e0c86a08b7d82776579a4fe8b241ef3094734000efdf8d8a794e17)
                check_type(argname="argument pie_chart_aggregated_field_wells", value=pie_chart_aggregated_field_wells, expected_type=type_hints["pie_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pie_chart_aggregated_field_wells is not None:
                self._values["pie_chart_aggregated_field_wells"] = pie_chart_aggregated_field_wells

        @builtins.property
        def pie_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PieChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartfieldwells.html#cfn-quicksight-dashboard-piechartfieldwells-piechartaggregatedfieldwells
            '''
            result = self._values.get("pie_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PieChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PieChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class PieChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a pie chart.

            :param category_items_limit: The limit on the number of categories that are displayed in a pie chart.
            :param category_sort: The sort configuration of the category fields.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_sort_configuration_property = quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__be0f3c5ba8c55f9fa1486ddff4d5c670d46f170a993c7279f79a927dc2afbd0a)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories that are displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PieChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PieChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PieChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A pie or donut chart.

            The ``PieChartVisual`` structure describes a visual that is a member of the pie chart family.

            The following charts can be described by using this structure:

            - Pie charts
            - Donut charts

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            For more information, see `Using donut charts <https://docs.aws.amazon.com/quicksight/latest/user/donut-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a pie chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_visual_property = quicksight.CfnDashboard.PieChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.PieChartConfigurationProperty(
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                            arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                                arc_thickness="arcThickness"
                            ),
                            donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                                label_visibility="labelVisibility"
                            )
                        ),
                        field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                            pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8cc3633e31cc4def7f1bf2cc1efe5ea1ba4d98e6ca38b3a4126adb78de558d73)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PieChartConfigurationProperty"]]:
            '''The configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PieChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotFieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "sort_by": "sortBy"},
    )
    class PivotFieldSortOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            sort_by: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableSortByProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The field sort options for a pivot table sort configuration.

            :param field_id: The field ID for the field sort options.
            :param sort_by: The sort by field for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_field_sort_options_property = quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                    field_id="fieldId",
                    sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                        column=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        data_path=quicksight.CfnDashboard.DataPathSortProperty(
                            direction="direction",
                            sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            )]
                        ),
                        field=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac44ccfb7d82c3943c56a9b0c1ab237c2121845ab81e1899c55f977c2e16988f)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "sort_by": sort_by,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html#cfn-quicksight-dashboard-pivotfieldsortoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableSortByProperty"]:
            '''The sort by field for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html#cfn-quicksight-dashboard-pivotfieldsortoptions-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableSortByProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotFieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class PivotTableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            rows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for the pivot table.

            :param columns: The columns field well for a pivot table. Values are grouped by columns fields.
            :param rows: The rows field well for a pivot table. Values are grouped by rows fields.
            :param values: The values field well for a pivot table. Values are aggregated based on rows and columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_aggregated_field_wells_property = quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                    columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__670516834385831da5995a92430f9a7095f5732df6d3311c9a4e2aa8c8707755)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The columns field well for a pivot table.

            Values are grouped by columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The rows field well for a pivot table.

            Values are grouped by rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on rows and columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "scope": "scope",
            "text_format": "textFormat",
        },
    )
    class PivotTableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            scope: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableConditionalFormattingScopeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cell conditional formatting option for a pivot table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param scope: The scope of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_cell_conditional_formatting_property = quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                        role="role"
                    ),
                    text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__71d76ebcd65857eeffbe9092be812c030914a27e1a2283e6d5b611da3e74f716)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if scope is not None:
                self._values["scope"] = scope
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def scope(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableConditionalFormattingScopeProperty"]]:
            '''The scope of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-scope
            '''
            result = self._values.get("scope")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableConditionalFormattingScopeProperty"]], result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextConditionalFormatProperty"]]:
            '''The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell"},
    )
    class PivotTableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_option_property = quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                            role="role"
                        ),
                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc3d02e6ec41ddb4a4853eb689178263427e67b05f2f6790ccabd2503086303e)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableCellConditionalFormattingProperty"]]:
            '''The cell conditional formatting option for a pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingoption.html#cfn-quicksight-dashboard-pivottableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableCellConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class PivotTableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_property = quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                role="role"
                            ),
                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1263dd696a94a30fb0c672391f6307b1a6929b500aab65430b5d3bc0331a91b6)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformatting.html#cfn-quicksight-dashboard-pivottableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty",
        jsii_struct_bases=[],
        name_mapping={"role": "role"},
    )
    class PivotTableConditionalFormattingScopeProperty:
        def __init__(self, *, role: typing.Optional[builtins.str] = None) -> None:
            '''The scope of the cell for conditional formatting.

            :param role: The role (field, field total, grand total) of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingscope.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_scope_property = quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e0f3cb435b34bb7eb5a69c898f6eaf4590467291668e798aaf9df8eb02f601c7)
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role (field, field total, grand total) of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingscope.html#cfn-quicksight-dashboard-pivottableconditionalformattingscope-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingScopeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class PivotTableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_report_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``PivotTableVisual`` .

            :param field_options: The field options for a pivot table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a pivot table visual.
            :param sort_configuration: The sort configuration for a ``PivotTableVisual`` .
            :param table_options: The table options for a pivot table visual.
            :param total_options: The total options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_configuration_property = quicksight.CfnDashboard.PivotTableConfigurationProperty(
                    field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                        data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                            data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            )],
                
                            # the properties below are optional
                            width="width"
                        )],
                        selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            custom_label="customLabel",
                            visibility="visibility"
                        )]
                    ),
                    field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                        pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                            columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                        vertical_overflow_visibility="verticalOverflowVisibility"
                    ),
                    sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                        field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                            field_id="fieldId",
                            sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                column=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                    direction="direction",
                                    sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    )]
                                ),
                                field=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )
                        )]
                    ),
                    table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                        cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        column_names_visibility="columnNamesVisibility",
                        metric_placement="metricPlacement",
                        row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                            row_alternate_colors=["rowAlternateColors"],
                            status="status"
                        ),
                        row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        single_metric_visibility="singleMetricVisibility",
                        toggle_buttons_visibility="toggleButtonsVisibility"
                    ),
                    total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                        column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                            custom_label="customLabel",
                            field_level="fieldLevel",
                            field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                field_id="fieldId"
                            )],
                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                            custom_label="customLabel",
                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                            custom_label="customLabel",
                            field_level="fieldLevel",
                            field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                field_id="fieldId"
                            )],
                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                            custom_label="customLabel",
                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9475faf3468be8cf868e1682bd98a04641e58326bb87d0ed0d69ed4a6af5dfc)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableFieldOptionsProperty"]]:
            '''The field options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableFieldOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableFieldWellsProperty"]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTablePaginatedReportOptionsProperty"]]:
            '''The paginated report options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTablePaginatedReportOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableSortConfigurationProperty"]]:
            '''The sort configuration for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableSortConfigurationProperty"]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableOptionsProperty"]]:
            '''The table options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableOptionsProperty"]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableTotalOptionsProperty"]]:
            '''The total options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableTotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableDataPathOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"data_path_list": "dataPathList", "width": "width"},
    )
    class PivotTableDataPathOptionProperty:
        def __init__(
            self,
            *,
            data_path_list: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]],
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data path options for the pivot table field options.

            :param data_path_list: The list of data path values for the data path options.
            :param width: The width of the data path option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_data_path_option_property = quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                    data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    )],
                
                    # the properties below are optional
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8fce886a46020121b7b5568e99d9eadb1779bb40f3f323c3c48449883f51a077)
                check_type(argname="argument data_path_list", value=data_path_list, expected_type=type_hints["data_path_list"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_path_list": data_path_list,
            }
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def data_path_list(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPathValueProperty"]]]:
            '''The list of data path values for the data path options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html#cfn-quicksight-dashboard-pivottabledatapathoption-datapathlist
            '''
            result = self._values.get("data_path_list")
            assert result is not None, "Required property 'data_path_list' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPathValueProperty"]]], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the data path option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html#cfn-quicksight-dashboard-pivottabledatapathoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableDataPathOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "visibility": "visibility",
        },
    )
    class PivotTableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The selected field options for the pivot table field options.

            :param field_id: The field ID of the pivot table field.
            :param custom_label: The custom label of the pivot table field.
            :param visibility: The visibility of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_field_option_property = quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8a4a95f2eec36c28f6022e2e12048bc8f4c4e92c4a8b16ac0093d3a23d80aa28)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_options": "dataPathOptions",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class PivotTableFieldOptionsProperty:
        def __init__(
            self,
            *,
            data_path_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableDataPathOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field options for a pivot table visual.

            :param data_path_options: The data path options for the pivot table field options.
            :param selected_field_options: The selected field options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_field_options_property = quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                    data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                        data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        )],
                
                        # the properties below are optional
                        width="width"
                    )],
                    selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__10f5aa2b5aa360e22367dd6e48fabdd8076de1d8cbcc9d415f097dceb1659dbd)
                check_type(argname="argument data_path_options", value=data_path_options, expected_type=type_hints["data_path_options"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_options is not None:
                self._values["data_path_options"] = data_path_options
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def data_path_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableDataPathOptionProperty"]]]]:
            '''The data path options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html#cfn-quicksight-dashboard-pivottablefieldoptions-datapathoptions
            '''
            result = self._values.get("data_path_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableDataPathOptionProperty"]]]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableFieldOptionProperty"]]]]:
            '''The selected field options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html#cfn-quicksight-dashboard-pivottablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableFieldOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId"},
    )
    class PivotTableFieldSubtotalOptionsProperty:
        def __init__(self, *, field_id: typing.Optional[builtins.str] = None) -> None:
            '''The optional configuration of subtotals cells.

            :param field_id: The field ID of the subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldsubtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_field_subtotal_options_property = quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__162cae8bc9ba979d41cf4b5aff6d7b3e86a1efabfaae333ecfc9a6ab87128362)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldsubtotaloptions.html#cfn-quicksight-dashboard-pivottablefieldsubtotaloptions-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldSubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pivot_table_aggregated_field_wells": "pivotTableAggregatedFieldWells",
        },
    )
    class PivotTableFieldWellsProperty:
        def __init__(
            self,
            *,
            pivot_table_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells for a pivot table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pivot_table_aggregated_field_wells: The aggregated field well for the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_field_wells_property = quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                    pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                        columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__51b4f39a41063f41162a82fa1ce82d3a7b1331957efeb9fb38d66781b3323eb1)
                check_type(argname="argument pivot_table_aggregated_field_wells", value=pivot_table_aggregated_field_wells, expected_type=type_hints["pivot_table_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pivot_table_aggregated_field_wells is not None:
                self._values["pivot_table_aggregated_field_wells"] = pivot_table_aggregated_field_wells

        @builtins.property
        def pivot_table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldwells.html#cfn-quicksight-dashboard-pivottablefieldwells-pivottableaggregatedfieldwells
            '''
            result = self._values.get("pivot_table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "column_header_style": "columnHeaderStyle",
            "column_names_visibility": "columnNamesVisibility",
            "metric_placement": "metricPlacement",
            "row_alternate_color_options": "rowAlternateColorOptions",
            "row_field_names_style": "rowFieldNamesStyle",
            "row_header_style": "rowHeaderStyle",
            "single_metric_visibility": "singleMetricVisibility",
            "toggle_buttons_visibility": "toggleButtonsVisibility",
        },
    )
    class PivotTableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_names_visibility: typing.Optional[builtins.str] = None,
            metric_placement: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_field_names_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            single_metric_visibility: typing.Optional[builtins.str] = None,
            toggle_buttons_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table options for a pivot table visual.

            :param cell_style: The table cell style of cells.
            :param column_header_style: The table cell style of the column header.
            :param column_names_visibility: The visibility of the column names.
            :param metric_placement: The metric placement (row, column) options.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors).
            :param row_field_names_style: The table cell style of row field names.
            :param row_header_style: The table cell style of the row headers.
            :param single_metric_visibility: The visibility of the single metric options.
            :param toggle_buttons_visibility: Determines the visibility of the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_options_property = quicksight.CfnDashboard.PivotTableOptionsProperty(
                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_names_visibility="columnNamesVisibility",
                    metric_placement="metricPlacement",
                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status"
                    ),
                    row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    single_metric_visibility="singleMetricVisibility",
                    toggle_buttons_visibility="toggleButtonsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5086005b46a28ecab863f87b69d84c42fbe69b279fae60aa95664e02f9fc3dff)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument column_header_style", value=column_header_style, expected_type=type_hints["column_header_style"])
                check_type(argname="argument column_names_visibility", value=column_names_visibility, expected_type=type_hints["column_names_visibility"])
                check_type(argname="argument metric_placement", value=metric_placement, expected_type=type_hints["metric_placement"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
                check_type(argname="argument row_field_names_style", value=row_field_names_style, expected_type=type_hints["row_field_names_style"])
                check_type(argname="argument row_header_style", value=row_header_style, expected_type=type_hints["row_header_style"])
                check_type(argname="argument single_metric_visibility", value=single_metric_visibility, expected_type=type_hints["single_metric_visibility"])
                check_type(argname="argument toggle_buttons_visibility", value=toggle_buttons_visibility, expected_type=type_hints["toggle_buttons_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if column_header_style is not None:
                self._values["column_header_style"] = column_header_style
            if column_names_visibility is not None:
                self._values["column_names_visibility"] = column_names_visibility
            if metric_placement is not None:
                self._values["metric_placement"] = metric_placement
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options
            if row_field_names_style is not None:
                self._values["row_field_names_style"] = row_field_names_style
            if row_header_style is not None:
                self._values["row_header_style"] = row_header_style
            if single_metric_visibility is not None:
                self._values["single_metric_visibility"] = single_metric_visibility
            if toggle_buttons_visibility is not None:
                self._values["toggle_buttons_visibility"] = toggle_buttons_visibility

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]]:
            '''The table cell style of cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def column_header_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]]:
            '''The table cell style of the column header.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-columnheaderstyle
            '''
            result = self._values.get("column_header_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def column_names_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the column names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-columnnamesvisibility
            '''
            result = self._values.get("column_names_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_placement(self) -> typing.Optional[builtins.str]:
            '''The metric placement (row, column) options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-metricplacement
            '''
            result = self._values.get("metric_placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RowAlternateColorOptionsProperty"]]:
            '''The row alternate color options (widget status, row alternate colors).

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RowAlternateColorOptionsProperty"]], result)

        @builtins.property
        def row_field_names_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]]:
            '''The table cell style of row field names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowfieldnamesstyle
            '''
            result = self._values.get("row_field_names_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def row_header_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]]:
            '''The table cell style of the row headers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowheaderstyle
            '''
            result = self._values.get("row_header_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def single_metric_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the single metric options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-singlemetricvisibility
            '''
            result = self._values.get("single_metric_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def toggle_buttons_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-togglebuttonsvisibility
            '''
            result = self._values.get("toggle_buttons_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class PivotTablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a pivot table visual.

            :param overflow_column_header_visibility: The visibility of the repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of the printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_paginated_report_options_property = quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__be9123e222eb2e603b1e13a4adbd3b18cd1bc4458e5cfd878e441abc68173a13)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the repeating header rows on each page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html#cfn-quicksight-dashboard-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html#cfn-quicksight-dashboard-pivottablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableSortByProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "data_path": "dataPath", "field": "field"},
    )
    class PivotTableSortByProperty:
        def __init__(
            self,
            *,
            column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_path: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataPathSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort by field for the field sort options.

            :param column: The column sort (field id, direction) for the pivot table sort by options.
            :param data_path: The data path sort (data path value, direction) for the pivot table sort by options.
            :param field: The field sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_sort_by_property = quicksight.CfnDashboard.PivotTableSortByProperty(
                    column=quicksight.CfnDashboard.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    data_path=quicksight.CfnDashboard.DataPathSortProperty(
                        direction="direction",
                        sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        )]
                    ),
                    field=quicksight.CfnDashboard.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ba052f8170574466e89792216e47787b147edabb6353a5e26cd79d4084dc99c5)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument data_path", value=data_path, expected_type=type_hints["data_path"])
                check_type(argname="argument field", value=field, expected_type=type_hints["field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column is not None:
                self._values["column"] = column
            if data_path is not None:
                self._values["data_path"] = data_path
            if field is not None:
                self._values["field"] = field

        @builtins.property
        def column(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnSortProperty"]]:
            '''The column sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-column
            '''
            result = self._values.get("column")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnSortProperty"]], result)

        @builtins.property
        def data_path(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPathSortProperty"]]:
            '''The data path sort (data path value, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-datapath
            '''
            result = self._values.get("data_path")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPathSortProperty"]], result)

        @builtins.property
        def field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortProperty"]]:
            '''The field sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-field
            '''
            result = self._values.get("field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortByProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"field_sort_options": "fieldSortOptions"},
    )
    class PivotTableSortConfigurationProperty:
        def __init__(
            self,
            *,
            field_sort_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotFieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration for a ``PivotTableVisual`` .

            :param field_sort_options: The field sort options for a pivot table sort configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_sort_configuration_property = quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                    field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                        field_id="fieldId",
                        sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                            column=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                direction="direction",
                                sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )]
                            ),
                            field=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__29e65dca3cb34f20fac9019fd52bce4f032c0d38831b1982395993ac2f2c8579)
                check_type(argname="argument field_sort_options", value=field_sort_options, expected_type=type_hints["field_sort_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_sort_options is not None:
                self._values["field_sort_options"] = field_sort_options

        @builtins.property
        def field_sort_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotFieldSortOptionsProperty"]]]]:
            '''The field sort options for a pivot table sort configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortconfiguration.html#cfn-quicksight-dashboard-pivottablesortconfiguration-fieldsortoptions
            '''
            result = self._values.get("field_sort_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotFieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_subtotal_options": "columnSubtotalOptions",
            "column_total_options": "columnTotalOptions",
            "row_subtotal_options": "rowSubtotalOptions",
            "row_total_options": "rowTotalOptions",
        },
    )
    class PivotTableTotalOptionsProperty:
        def __init__(
            self,
            *,
            column_subtotal_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_subtotal_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The total options for a pivot table visual.

            :param column_subtotal_options: The column subtotal options.
            :param column_total_options: The column total options.
            :param row_subtotal_options: The row subtotal options.
            :param row_total_options: The row total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_total_options_property = quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                    column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                        custom_label="customLabel",
                        field_level="fieldLevel",
                        field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                            field_id="fieldId"
                        )],
                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                        custom_label="customLabel",
                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                        custom_label="customLabel",
                        field_level="fieldLevel",
                        field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                            field_id="fieldId"
                        )],
                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                        custom_label="customLabel",
                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b5edd8435efcacbe02377d5357408a0ef6a130e3a370795fade30047bbb259a)
                check_type(argname="argument column_subtotal_options", value=column_subtotal_options, expected_type=type_hints["column_subtotal_options"])
                check_type(argname="argument column_total_options", value=column_total_options, expected_type=type_hints["column_total_options"])
                check_type(argname="argument row_subtotal_options", value=row_subtotal_options, expected_type=type_hints["row_subtotal_options"])
                check_type(argname="argument row_total_options", value=row_total_options, expected_type=type_hints["row_total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_subtotal_options is not None:
                self._values["column_subtotal_options"] = column_subtotal_options
            if column_total_options is not None:
                self._values["column_total_options"] = column_total_options
            if row_subtotal_options is not None:
                self._values["row_subtotal_options"] = row_subtotal_options
            if row_total_options is not None:
                self._values["row_total_options"] = row_total_options

        @builtins.property
        def column_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SubtotalOptionsProperty"]]:
            '''The column subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-columnsubtotaloptions
            '''
            result = self._values.get("column_subtotal_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SubtotalOptionsProperty"]], result)

        @builtins.property
        def column_total_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTotalOptionsProperty"]]:
            '''The column total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-columntotaloptions
            '''
            result = self._values.get("column_total_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTotalOptionsProperty"]], result)

        @builtins.property
        def row_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SubtotalOptionsProperty"]]:
            '''The row subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-rowsubtotaloptions
            '''
            result = self._values.get("row_subtotal_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SubtotalOptionsProperty"]], result)

        @builtins.property
        def row_total_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTotalOptionsProperty"]]:
            '''The row total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-rowtotaloptions
            '''
            result = self._values.get("row_total_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PivotTableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_visual_property = quicksight.CfnDashboard.PivotTableVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.PivotTableConfigurationProperty(
                        field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                            data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                                data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )],
                
                                # the properties below are optional
                                width="width"
                            )],
                            selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                custom_label="customLabel",
                                visibility="visibility"
                            )]
                        ),
                        field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                            pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                                columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                            overflow_column_header_visibility="overflowColumnHeaderVisibility",
                            vertical_overflow_visibility="verticalOverflowVisibility"
                        ),
                        sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                            field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                                field_id="fieldId",
                                sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                    column=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                        direction="direction",
                                        sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )]
                                    ),
                                    field=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )
                            )]
                        ),
                        table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                            cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            column_names_visibility="columnNamesVisibility",
                            metric_placement="metricPlacement",
                            row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                row_alternate_colors=["rowAlternateColors"],
                                status="status"
                            ),
                            row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            single_metric_visibility="singleMetricVisibility",
                            toggle_buttons_visibility="toggleButtonsVisibility"
                        ),
                        total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                            column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                custom_label="customLabel",
                                field_level="fieldLevel",
                                field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                    field_id="fieldId"
                                )],
                                metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                custom_label="customLabel",
                                metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                custom_label="customLabel",
                                field_level="fieldLevel",
                                field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                    field_id="fieldId"
                                )],
                                metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                custom_label="customLabel",
                                metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        )
                    ),
                    conditional_formatting=quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                            cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                    role="role"
                                ),
                                text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c09498405ea1b89865d374e29aba009f92cffaca5ba8d633c2b37dd49305e3f7)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableConditionalFormattingProperty"]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PivotTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class PivotTotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            metric_header_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The optional configuration of totals cells in a ``PivotTableVisual`` .

            :param custom_label: The custom label string for the total cells.
            :param metric_header_cell_style: The cell styling options for the total of header cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_cell_style: The cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.
            :param value_cell_style: The cell styling options for the totals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_total_options_property = quicksight.CfnDashboard.PivotTotalOptionsProperty(
                    custom_label="customLabel",
                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62de868ec473c5969a1307b612416b2e06147143001a7aa732b02ee24b684481)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]]:
            '''The cell styling options for the total of header cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]]:
            '''The cell styling options for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]]:
            '''The cell styling options for the totals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.PredefinedHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class PredefinedHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :param columns: The list of columns that define the predefined hierarchy.
            :param hierarchy_id: The hierarchy ID of the predefined hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                predefined_hierarchy_property = quicksight.CfnDashboard.PredefinedHierarchyProperty(
                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__53411431a7530b33c110a0ec28c99f4a4d39badb1bc98e24f83f4504f3ed9585)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]]]:
            '''The list of columns that define the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PredefinedHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ProgressBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ProgressBarOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :param visibility: The visibility of the progress bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-progressbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                progress_bar_options_property = quicksight.CfnDashboard.ProgressBarOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f014657199a848b835662e56e412b8219ec579e77011d666f52146418ef73641)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the progress bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-progressbaroptions.html#cfn-quicksight-dashboard-progressbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ProgressBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "color": "color", "values": "values"},
    )
    class RadarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well configuration of a ``RadarChartVisual`` .

            :param category: The aggregated field well categories of a radar chart.
            :param color: The color that are assigned to the aggregated field wells of a radar chart.
            :param values: The values that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_aggregated_field_wells_property = quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    color=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4ddb3b4569b6e0c0788645e4d6b0b350ba60ec4de7b73c0ad111d916f3b488dc)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if color is not None:
                self._values["color"] = color
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The aggregated field well categories of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The color that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The values that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RadarChartAreaStyleSettingsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configured style settings of a radar chart.

            :param visibility: The visibility settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartareastylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_area_style_settings_property = quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__50ebc1832171cf6c141996712539bdc171409f707552ecba2487b68286025ff5)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartareastylesettings.html#cfn-quicksight-dashboard-radarchartareastylesettings-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAreaStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.RadarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "alternate_band_colors_visibility": "alternateBandColorsVisibility",
            "alternate_band_even_color": "alternateBandEvenColor",
            "alternate_band_odd_color": "alternateBandOddColor",
            "base_series_settings": "baseSeriesSettings",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_axis": "colorAxis",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "shape": "shape",
            "sort_configuration": "sortConfiguration",
            "start_angle": "startAngle",
            "visual_palette": "visualPalette",
        },
    )
    class RadarChartConfigurationProperty:
        def __init__(
            self,
            *,
            alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
            alternate_band_even_color: typing.Optional[builtins.str] = None,
            alternate_band_odd_color: typing.Optional[builtins.str] = None,
            base_series_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RadarChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RadarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            shape: typing.Optional[builtins.str] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RadarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            start_angle: typing.Optional[jsii.Number] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``RadarChartVisual`` .

            :param alternate_band_colors_visibility: Determines the visibility of the colors of alternatign bands in a radar chart.
            :param alternate_band_even_color: The color of the even-numbered alternate bands of a radar chart.
            :param alternate_band_odd_color: The color of the odd-numbered alternate bands of a radar chart.
            :param base_series_settings: The base sreies settings of a radar chart.
            :param category_axis: The category axis of a radar chart.
            :param category_label_options: The category label options of a radar chart.
            :param color_axis: The color axis of a radar chart.
            :param color_label_options: The color label options of a radar chart.
            :param field_wells: The field well configuration of a ``RadarChartVisual`` .
            :param legend: The legend display setup of the visual.
            :param shape: The shape of the radar chart.
            :param sort_configuration: The sort configuration of a ``RadarChartVisual`` .
            :param start_angle: The start angle of a radar chart's axis.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                radar_chart_configuration_property = quicksight.CfnDashboard.RadarChartConfigurationProperty(
                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                    alternate_band_even_color="alternateBandEvenColor",
                    alternate_band_odd_color="alternateBandOddColor",
                    base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                        area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                            visibility="visibility"
                        )
                    ),
                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                        radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    shape="shape",
                    sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    start_angle=123,
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57421022aed140f345d8fbe862d77db1662af50b2d9bf8e17d71f9f8ff30f26f)
                check_type(argname="argument alternate_band_colors_visibility", value=alternate_band_colors_visibility, expected_type=type_hints["alternate_band_colors_visibility"])
                check_type(argname="argument alternate_band_even_color", value=alternate_band_even_color, expected_type=type_hints["alternate_band_even_color"])
                check_type(argname="argument alternate_band_odd_color", value=alternate_band_odd_color, expected_type=type_hints["alternate_band_odd_color"])
                check_type(argname="argument base_series_settings", value=base_series_settings, expected_type=type_hints["base_series_settings"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_axis", value=color_axis, expected_type=type_hints["color_axis"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument start_angle", value=start_angle, expected_type=type_hints["start_angle"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if alternate_band_colors_visibility is not None:
                self._values["alternate_band_colors_visibility"] = alternate_band_colors_visibility
            if alternate_band_even_color is not None:
                self._values["alternate_band_even_color"] = alternate_band_even_color
            if alternate_band_odd_color is not None:
                self._values["alternate_band_odd_color"] = alternate_band_odd_color
            if base_series_settings is not None:
                self._values["base_series_settings"] = base_series_settings
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_axis is not None:
                self._values["color_axis"] = color_axis
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if shape is not None:
                self._values["shape"] = shape
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if start_angle is not None:
                self._values["start_angle"] = start_angle
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def alternate_band_colors_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the colors of alternatign bands in a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandcolorsvisibility
            '''
            result = self._values.get("alternate_band_colors_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_even_color(self) -> typing.Optional[builtins.str]:
            '''The color of the even-numbered alternate bands of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandevencolor
            '''
            result = self._values.get("alternate_band_even_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_odd_color(self) -> typing.Optional[builtins.str]:
            '''The color of the odd-numbered alternate bands of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandoddcolor
            '''
            result = self._values.get("alternate_band_odd_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def base_series_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartSeriesSettingsProperty"]]:
            '''The base sreies settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-baseseriessettings
            '''
            result = self._values.get("base_series_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartSeriesSettingsProperty"]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The category axis of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The category label options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The color axis of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-coloraxis
            '''
            result = self._values.get("color_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The color label options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartFieldWellsProperty"]]:
            '''The field well configuration of a ``RadarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def shape(self) -> typing.Optional[builtins.str]:
            '''The shape of the radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-shape
            '''
            result = self._values.get("shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``RadarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartSortConfigurationProperty"]], result)

        @builtins.property
        def start_angle(self) -> typing.Optional[jsii.Number]:
            '''The start angle of a radar chart's axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-startangle
            '''
            result = self._values.get("start_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.RadarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "radar_chart_aggregated_field_wells": "radarChartAggregatedFieldWells",
        },
    )
    class RadarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            radar_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RadarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a radar chart visual.

            :param radar_chart_aggregated_field_wells: The aggregated field wells of a radar chart visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_field_wells_property = quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                    radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        color=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c7b517550201684c2f7bb281cd2efc6c818188c1cb060fe9ae0752c5d21fc2f2)
                check_type(argname="argument radar_chart_aggregated_field_wells", value=radar_chart_aggregated_field_wells, expected_type=type_hints["radar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if radar_chart_aggregated_field_wells is not None:
                self._values["radar_chart_aggregated_field_wells"] = radar_chart_aggregated_field_wells

        @builtins.property
        def radar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a radar chart visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartfieldwells.html#cfn-quicksight-dashboard-radarchartfieldwells-radarchartaggregatedfieldwells
            '''
            result = self._values.get("radar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.RadarChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"area_style_settings": "areaStyleSettings"},
    )
    class RadarChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            area_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RadarChartAreaStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The series settings of a radar chart.

            :param area_style_settings: The area style settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_series_settings_property = quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                    area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e1c9c358d317fc830ff5bc41f3330afca57117ffedca2ea6707b3c2139b9e174)
                check_type(argname="argument area_style_settings", value=area_style_settings, expected_type=type_hints["area_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if area_style_settings is not None:
                self._values["area_style_settings"] = area_style_settings

        @builtins.property
        def area_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartAreaStyleSettingsProperty"]]:
            '''The area style settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartseriessettings.html#cfn-quicksight-dashboard-radarchartseriessettings-areastylesettings
            '''
            result = self._values.get("area_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartAreaStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.RadarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class RadarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``RadarChartVisual`` .

            :param category_items_limit: The category items limit for a radar chart.
            :param category_sort: The category sort options of a radar chart.
            :param color_items_limit: The color items limit of a radar chart.
            :param color_sort: The color sort configuration of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_sort_configuration_property = quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33a1d6c821d1ad2098556388c548cc2fa196b6a47e23ec2de073532b4d99b67e)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The category items limit for a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The category sort options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The color items limit of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The color sort configuration of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.RadarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class RadarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RadarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A radar chart visual.

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                radar_chart_visual_property = quicksight.CfnDashboard.RadarChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.RadarChartConfigurationProperty(
                        alternate_band_colors_visibility="alternateBandColorsVisibility",
                        alternate_band_even_color="alternateBandEvenColor",
                        alternate_band_odd_color="alternateBandOddColor",
                        base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                            area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                                visibility="visibility"
                            )
                        ),
                        category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                            radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        shape="shape",
                        sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        start_angle=123,
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__800f0c0a2bb1b43b6f8925c808e413ae0341f5bb828469887dcbcba9c266cc13)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.RangeEndsLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RangeEndsLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The range ends label type of a data path label.

            :param visibility: The visibility of the range ends label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rangeendslabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                range_ends_label_type_property = quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__49b5320add42accd7f4b16211a28380fa778db728e2f64019ea38b6997765a8b)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the range ends label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rangeendslabeltype.html#cfn-quicksight-dashboard-rangeendslabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RangeEndsLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_label": "customLabel"},
    )
    class ReferenceLineCustomLabelConfigurationProperty:
        def __init__(self, *, custom_label: builtins.str) -> None:
            '''The configuration for a custom label on a ``ReferenceLine`` .

            :param custom_label: The string text of the custom label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinecustomlabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_custom_label_configuration_property = quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                    custom_label="customLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__db0148d083b5cfd73390e4a1b6162718c9ec089d0f0f61186eec69ee1316e966)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_label": custom_label,
            }

        @builtins.property
        def custom_label(self) -> builtins.str:
            '''The string text of the custom label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinecustomlabelconfiguration.html#cfn-quicksight-dashboard-referencelinecustomlabelconfiguration-customlabel
            '''
            result = self._values.get("custom_label")
            assert result is not None, "Required property 'custom_label' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineCustomLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "dynamic_configuration": "dynamicConfiguration",
            "static_configuration": "staticConfiguration",
        },
    )
    class ReferenceLineDataConfigurationProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            dynamic_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ReferenceLineDynamicDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ReferenceLineStaticDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data configuration of the reference line.

            :param axis_binding: The axis binding type of the reference line. Choose one of the following options:. - PrimaryY - SecondaryY
            :param dynamic_configuration: The dynamic configuration of the reference line data configuration.
            :param static_configuration: The static data configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_data_configuration_property = quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                    axis_binding="axisBinding",
                    dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                        calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a900895fb28c03478ed18adc5778239cc168ff94454a45e9bf89480e34a9bb68)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument dynamic_configuration", value=dynamic_configuration, expected_type=type_hints["dynamic_configuration"])
                check_type(argname="argument static_configuration", value=static_configuration, expected_type=type_hints["static_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if dynamic_configuration is not None:
                self._values["dynamic_configuration"] = dynamic_configuration
            if static_configuration is not None:
                self._values["static_configuration"] = static_configuration

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis binding type of the reference line. Choose one of the following options:.

            - PrimaryY
            - SecondaryY

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dynamic_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineDynamicDataConfigurationProperty"]]:
            '''The dynamic configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-dynamicconfiguration
            '''
            result = self._values.get("dynamic_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineDynamicDataConfigurationProperty"]], result)

        @builtins.property
        def static_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineStaticDataConfigurationProperty"]]:
            '''The static data configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-staticconfiguration
            '''
            result = self._values.get("static_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineStaticDataConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculation": "calculation",
            "column": "column",
            "measure_aggregation_function": "measureAggregationFunction",
        },
    )
    class ReferenceLineDynamicDataConfigurationProperty:
        def __init__(
            self,
            *,
            calculation: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            measure_aggregation_function: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The dynamic configuration of the reference line data configuration.

            :param calculation: The calculation that is used in the dynamic data.
            :param column: The column that the dynamic data targets.
            :param measure_aggregation_function: The aggregation function that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_dynamic_data_configuration_property = quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                    calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f972163ab4e6da0e0156540c2726a32d33cc763969a456a99681aa001834c000)
                check_type(argname="argument calculation", value=calculation, expected_type=type_hints["calculation"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument measure_aggregation_function", value=measure_aggregation_function, expected_type=type_hints["measure_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "calculation": calculation,
                "column": column,
                "measure_aggregation_function": measure_aggregation_function,
            }

        @builtins.property
        def calculation(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericalAggregationFunctionProperty"]:
            '''The calculation that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-calculation
            '''
            result = self._values.get("calculation")
            assert result is not None, "Required property 'calculation' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericalAggregationFunctionProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the dynamic data targets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def measure_aggregation_function(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationFunctionProperty"]:
            '''The aggregation function that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-measureaggregationfunction
            '''
            result = self._values.get("measure_aggregation_function")
            assert result is not None, "Required property 'measure_aggregation_function' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationFunctionProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDynamicDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label_configuration": "customLabelConfiguration",
            "font_color": "fontColor",
            "font_configuration": "fontConfiguration",
            "horizontal_position": "horizontalPosition",
            "value_label_configuration": "valueLabelConfiguration",
            "vertical_position": "verticalPosition",
        },
    )
    class ReferenceLineLabelConfigurationProperty:
        def __init__(
            self,
            *,
            custom_label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ReferenceLineCustomLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_color: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            horizontal_position: typing.Optional[builtins.str] = None,
            value_label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ReferenceLineValueLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            vertical_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label configuration of a reference line.

            :param custom_label_configuration: The custom label configuration of the label in a reference line.
            :param font_color: The font color configuration of the label in a reference line.
            :param font_configuration: The font configuration of the label in a reference line.
            :param horizontal_position: The horizontal position configuration of the label in a reference line. Choose one of the following options:. - ``LEFT`` - ``CENTER`` - ``RIGHT``
            :param value_label_configuration: The value label configuration of the label in a reference line.
            :param vertical_position: The vertical position configuration of the label in a reference line. Choose one of the following options:. - ``ABOVE`` - ``BELOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_label_configuration_property = quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                    custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                        custom_label="customLabel"
                    ),
                    font_color="fontColor",
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_position="horizontalPosition",
                    value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        relative_position="relativePosition"
                    ),
                    vertical_position="verticalPosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f4c6a5c24c35813040d50db47b5ed37d6fe62801bdc54a0cdbdfd23ed613c66d)
                check_type(argname="argument custom_label_configuration", value=custom_label_configuration, expected_type=type_hints["custom_label_configuration"])
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_position", value=horizontal_position, expected_type=type_hints["horizontal_position"])
                check_type(argname="argument value_label_configuration", value=value_label_configuration, expected_type=type_hints["value_label_configuration"])
                check_type(argname="argument vertical_position", value=vertical_position, expected_type=type_hints["vertical_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label_configuration is not None:
                self._values["custom_label_configuration"] = custom_label_configuration
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_position is not None:
                self._values["horizontal_position"] = horizontal_position
            if value_label_configuration is not None:
                self._values["value_label_configuration"] = value_label_configuration
            if vertical_position is not None:
                self._values["vertical_position"] = vertical_position

        @builtins.property
        def custom_label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineCustomLabelConfigurationProperty"]]:
            '''The custom label configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-customlabelconfiguration
            '''
            result = self._values.get("custom_label_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineCustomLabelConfigurationProperty"]], result)

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''The font color configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]]:
            '''The font configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def horizontal_position(self) -> typing.Optional[builtins.str]:
            '''The horizontal position configuration of the label in a reference line. Choose one of the following options:.

            - ``LEFT``
            - ``CENTER``
            - ``RIGHT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-horizontalposition
            '''
            result = self._values.get("horizontal_position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineValueLabelConfigurationProperty"]]:
            '''The value label configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-valuelabelconfiguration
            '''
            result = self._values.get("value_label_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineValueLabelConfigurationProperty"]], result)

        @builtins.property
        def vertical_position(self) -> typing.Optional[builtins.str]:
            '''The vertical position configuration of the label in a reference line. Choose one of the following options:.

            - ``ABOVE``
            - ``BELOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-verticalposition
            '''
            result = self._values.get("vertical_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ReferenceLineProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_configuration": "dataConfiguration",
            "label_configuration": "labelConfiguration",
            "status": "status",
            "style_configuration": "styleConfiguration",
        },
    )
    class ReferenceLineProperty:
        def __init__(
            self,
            *,
            data_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ReferenceLineDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ReferenceLineLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            status: typing.Optional[builtins.str] = None,
            style_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ReferenceLineStyleConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The reference line visual display options.

            :param data_configuration: The data configuration of the reference line.
            :param label_configuration: The label configuration of the reference line.
            :param status: The status of the reference line. Choose one of the following options:. - ``ENABLE`` - ``DISABLE``
            :param style_configuration: The style configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_property = quicksight.CfnDashboard.ReferenceLineProperty(
                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                        axis_binding="axisBinding",
                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                            value=123
                        )
                    ),
                
                    # the properties below are optional
                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                            custom_label="customLabel"
                        ),
                        font_color="fontColor",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_position="horizontalPosition",
                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            relative_position="relativePosition"
                        ),
                        vertical_position="verticalPosition"
                    ),
                    status="status",
                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                        color="color",
                        pattern="pattern"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dc532f5c60946873a990efcca7975ccbac9af85568478f4e0e93d1a82169acac)
                check_type(argname="argument data_configuration", value=data_configuration, expected_type=type_hints["data_configuration"])
                check_type(argname="argument label_configuration", value=label_configuration, expected_type=type_hints["label_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument style_configuration", value=style_configuration, expected_type=type_hints["style_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_configuration": data_configuration,
            }
            if label_configuration is not None:
                self._values["label_configuration"] = label_configuration
            if status is not None:
                self._values["status"] = status
            if style_configuration is not None:
                self._values["style_configuration"] = style_configuration

        @builtins.property
        def data_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineDataConfigurationProperty"]:
            '''The data configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-dataconfiguration
            '''
            result = self._values.get("data_configuration")
            assert result is not None, "Required property 'data_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineDataConfigurationProperty"], result)

        @builtins.property
        def label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineLabelConfigurationProperty"]]:
            '''The label configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-labelconfiguration
            '''
            result = self._values.get("label_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineLabelConfigurationProperty"]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the reference line. Choose one of the following options:.

            - ``ENABLE``
            - ``DISABLE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineStyleConfigurationProperty"]]:
            '''The style configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-styleconfiguration
            '''
            result = self._values.get("style_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ReferenceLineStyleConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class ReferenceLineStaticDataConfigurationProperty:
        def __init__(self, *, value: jsii.Number) -> None:
            '''The static data configuration of the reference line data configuration.

            :param value: The double input of the static data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestaticdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_static_data_configuration_property = quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__41f77029834ba03165613ef83e6babf8a4aa9a1846b9d9b4ae81645b0bc8b74f)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "value": value,
            }

        @builtins.property
        def value(self) -> jsii.Number:
            '''The double input of the static data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestaticdataconfiguration.html#cfn-quicksight-dashboard-referencelinestaticdataconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStaticDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "pattern": "pattern"},
    )
    class ReferenceLineStyleConfigurationProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            pattern: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The style configuration of the reference line.

            :param color: The hex color of the reference line.
            :param pattern: The pattern type of the line style. Choose one of the following options:. - ``SOLID`` - ``DASHED`` - ``DOTTED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_style_configuration_property = quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                    color="color",
                    pattern="pattern"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__11b23d9b31e4b32eb5341c645768a73111a971d437fe706d617a993e70e9bb59)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if pattern is not None:
                self._values["pattern"] = pattern

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The hex color of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html#cfn-quicksight-dashboard-referencelinestyleconfiguration-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def pattern(self) -> typing.Optional[builtins.str]:
            '''The pattern type of the line style. Choose one of the following options:.

            - ``SOLID``
            - ``DASHED``
            - ``DOTTED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html#cfn-quicksight-dashboard-referencelinestyleconfiguration-pattern
            '''
            result = self._values.get("pattern")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStyleConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "format_configuration": "formatConfiguration",
            "relative_position": "relativePosition",
        },
    )
    class ReferenceLineValueLabelConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value label configuration of the label in a reference line.

            :param format_configuration: The format configuration of the value label.
            :param relative_position: The relative position of the value label. Choose one of the following options:. - ``BEFORE_CUSTOM_LABEL`` - ``AFTER_CUSTOM_LABEL``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_value_label_configuration_property = quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    relative_position="relativePosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__61f15c1801bf997d8255231baadefa64b0db477d03917635a86d71748b92012f)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument relative_position", value=relative_position, expected_type=type_hints["relative_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if relative_position is not None:
                self._values["relative_position"] = relative_position

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericFormatConfigurationProperty"]]:
            '''The format configuration of the value label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html#cfn-quicksight-dashboard-referencelinevaluelabelconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericFormatConfigurationProperty"]], result)

        @builtins.property
        def relative_position(self) -> typing.Optional[builtins.str]:
            '''The relative position of the value label. Choose one of the following options:.

            - ``BEFORE_CUSTOM_LABEL``
            - ``AFTER_CUSTOM_LABEL``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html#cfn-quicksight-dashboard-referencelinevaluelabelconfiguration-relativeposition
            '''
            result = self._values.get("relative_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineValueLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "title_options": "titleOptions",
        },
    )
    class RelativeDateTimeControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                relative_date_time_control_display_options_property = quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ed5115ecbb711a040d26610e998222ada8d5d5efb6b2bc8f781499edd9f942ba)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html#cfn-quicksight-dashboard-relativedatetimecontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html#cfn-quicksight-dashboard-relativedatetimecontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDateTimeControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.RelativeDatesFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_date_configuration": "anchorDateConfiguration",
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "relative_date_type": "relativeDateType",
            "time_granularity": "timeGranularity",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "minimum_granularity": "minimumGranularity",
            "parameter_name": "parameterName",
            "relative_date_value": "relativeDateValue",
        },
    )
    class RelativeDatesFilterProperty:
        def __init__(
            self,
            *,
            anchor_date_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AnchorDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            relative_date_type: builtins.str,
            time_granularity: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            minimum_granularity: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            relative_date_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``RelativeDatesFilter`` filters relative dates values.

            :param anchor_date_configuration: The date configuration of the filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param relative_date_type: The range date type of the filter. Choose one of the options below:. - ``PREVIOUS`` - ``THIS`` - ``LAST`` - ``NOW`` - ``NEXT``
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param exclude_period_configuration: The configuration for the exclude period of the filter.
            :param minimum_granularity: The minimum granularity (period granularity) of the relative dates filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param relative_date_value: The date value of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                relative_dates_filter_property = quicksight.CfnDashboard.RelativeDatesFilterProperty(
                    anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                        anchor_option="anchorOption",
                        parameter_name="parameterName"
                    ),
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                    relative_date_type="relativeDateType",
                    time_granularity="timeGranularity",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    minimum_granularity="minimumGranularity",
                    parameter_name="parameterName",
                    relative_date_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0d77437279d4aca9f7446b375bbdf5e7248d78d1b935ed06f5facd24d4d99be2)
                check_type(argname="argument anchor_date_configuration", value=anchor_date_configuration, expected_type=type_hints["anchor_date_configuration"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument relative_date_type", value=relative_date_type, expected_type=type_hints["relative_date_type"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument minimum_granularity", value=minimum_granularity, expected_type=type_hints["minimum_granularity"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument relative_date_value", value=relative_date_value, expected_type=type_hints["relative_date_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "anchor_date_configuration": anchor_date_configuration,
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
                "relative_date_type": relative_date_type,
                "time_granularity": time_granularity,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if minimum_granularity is not None:
                self._values["minimum_granularity"] = minimum_granularity
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if relative_date_value is not None:
                self._values["relative_date_value"] = relative_date_value

        @builtins.property
        def anchor_date_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AnchorDateConfigurationProperty"]:
            '''The date configuration of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-anchordateconfiguration
            '''
            result = self._values.get("anchor_date_configuration")
            assert result is not None, "Required property 'anchor_date_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AnchorDateConfigurationProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def relative_date_type(self) -> builtins.str:
            '''The range date type of the filter. Choose one of the options below:.

            - ``PREVIOUS``
            - ``THIS``
            - ``LAST``
            - ``NOW``
            - ``NEXT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-relativedatetype
            '''
            result = self._values.get("relative_date_type")
            assert result is not None, "Required property 'relative_date_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ExcludePeriodConfigurationProperty"]]:
            '''The configuration for the exclude period of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ExcludePeriodConfigurationProperty"]], result)

        @builtins.property
        def minimum_granularity(self) -> typing.Optional[builtins.str]:
            '''The minimum granularity (period granularity) of the relative dates filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-minimumgranularity
            '''
            result = self._values.get("minimum_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def relative_date_value(self) -> typing.Optional[jsii.Number]:
            '''The date value of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-relativedatevalue
            '''
            result = self._values.get("relative_date_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDatesFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "actions": "actions",
            "principal": "principal",
            "resource": "resource",
        },
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
            resource: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
            :param resource: ``CfnDashboard.ResourcePermissionProperty.Resource``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnDashboard.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
                
                    # the properties below are optional
                    resource="resource"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__711590988b63a980fbfcb7b39f0426b1112d69f6dcf65a7331deab71fd531967)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
                check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }
            if resource is not None:
                self._values["resource"] = resource

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def resource(self) -> typing.Optional[builtins.str]:
            '''``CfnDashboard.ResourcePermissionProperty.Resource``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-resource
            '''
            result = self._values.get("resource")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.RollingDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class RollingDateConfigurationProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            data_set_identifier: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The rolling date configuration of a date time filter.

            :param expression: The expression of the rolling date configuration.
            :param data_set_identifier: The data set that is used in the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                rolling_date_configuration_property = quicksight.CfnDashboard.RollingDateConfigurationProperty(
                    expression="expression",
                
                    # the properties below are optional
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b57fd8837c0f25075c2c2108f044d8b01e8beefc21eefc6e270bb9cdd9b5f5a4)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if data_set_identifier is not None:
                self._values["data_set_identifier"] = data_set_identifier

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html#cfn-quicksight-dashboard-rollingdateconfiguration-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> typing.Optional[builtins.str]:
            '''The data set that is used in the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html#cfn-quicksight-dashboard-rollingdateconfiguration-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RollingDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.RowAlternateColorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "row_alternate_colors": "rowAlternateColors",
            "status": "status",
        },
    )
    class RowAlternateColorOptionsProperty:
        def __init__(
            self,
            *,
            row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the row alternate color options.

            :param row_alternate_colors: Determines the list of row alternate colors.
            :param status: Determines the widget status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                row_alternate_color_options_property = quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                    row_alternate_colors=["rowAlternateColors"],
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1c1945067e48d0aef31beafac083801acf9e668d5d271ed969e058cf99aace27)
                check_type(argname="argument row_alternate_colors", value=row_alternate_colors, expected_type=type_hints["row_alternate_colors"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if row_alternate_colors is not None:
                self._values["row_alternate_colors"] = row_alternate_colors
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def row_alternate_colors(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Determines the list of row alternate colors.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html#cfn-quicksight-dashboard-rowalternatecoloroptions-rowalternatecolors
            '''
            result = self._values.get("row_alternate_colors")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''Determines the widget status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html#cfn-quicksight-dashboard-rowalternatecoloroptions-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowAlternateColorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_visual_options": "targetVisualOptions",
            "target_visuals": "targetVisuals",
        },
    )
    class SameSheetTargetVisualConfigurationProperty:
        def __init__(
            self,
            *,
            target_visual_options: typing.Optional[builtins.str] = None,
            target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param target_visual_options: The options that choose the target visual in the same sheet. Valid values are defined as follows: - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.
            :param target_visuals: A list of the target visual IDs that are located in the same sheet of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                same_sheet_target_visual_configuration_property = quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                    target_visual_options="targetVisualOptions",
                    target_visuals=["targetVisuals"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a054d913d5883b9e5036c1d1ffe1025585547308643ebcc9cedbfcefa28873da)
                check_type(argname="argument target_visual_options", value=target_visual_options, expected_type=type_hints["target_visual_options"])
                check_type(argname="argument target_visuals", value=target_visuals, expected_type=type_hints["target_visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_visual_options is not None:
                self._values["target_visual_options"] = target_visual_options
            if target_visuals is not None:
                self._values["target_visuals"] = target_visuals

        @builtins.property
        def target_visual_options(self) -> typing.Optional[builtins.str]:
            '''The options that choose the target visual in the same sheet.

            Valid values are defined as follows:

            - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html#cfn-quicksight-dashboard-samesheettargetvisualconfiguration-targetvisualoptions
            '''
            result = self._values.get("target_visual_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def target_visuals(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of the target visual IDs that are located in the same sheet of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html#cfn-quicksight-dashboard-samesheettargetvisualconfiguration-targetvisuals
            '''
            result = self._values.get("target_visuals")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SameSheetTargetVisualConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination": "destination",
            "source": "source",
            "weight": "weight",
        },
    )
    class SankeyDiagramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            destination: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            source: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            weight: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param destination: The destination field wells of a sankey diagram.
            :param source: The source field wells of a sankey diagram.
            :param weight: The weight field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_aggregated_field_wells_property = quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                    destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    source=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ffa5b76350a19df844df5c1bccf4c2f17684785cf4f02032f28af790a8277241)
                check_type(argname="argument destination", value=destination, expected_type=type_hints["destination"])
                check_type(argname="argument source", value=source, expected_type=type_hints["source"])
                check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination is not None:
                self._values["destination"] = destination
            if source is not None:
                self._values["source"] = source
            if weight is not None:
                self._values["weight"] = weight

        @builtins.property
        def destination(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The destination field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-destination
            '''
            result = self._values.get("destination")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def source(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The source field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-source
            '''
            result = self._values.get("source")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def weight(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The weight field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-weight
            '''
            result = self._values.get("weight")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
        },
    )
    class SankeyDiagramChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SankeyDiagramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SankeyDiagramSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a sankey diagram.

            :param data_labels: The data label configuration of a sankey diagram.
            :param field_wells: The field well configuration of a sankey diagram.
            :param sort_configuration: The sort configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_chart_configuration_property = quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                        sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                            destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                        destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4f99955d76470f4ba9e98ec70bbaa94637bc914c5f0125aa26215785f2a65917)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The data label configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SankeyDiagramFieldWellsProperty"]]:
            '''The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SankeyDiagramFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SankeyDiagramSortConfigurationProperty"]]:
            '''The sort configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SankeyDiagramSortConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sankey_diagram_aggregated_field_wells": "sankeyDiagramAggregatedFieldWells",
        },
    )
    class SankeyDiagramFieldWellsProperty:
        def __init__(
            self,
            *,
            sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param sankey_diagram_aggregated_field_wells: The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_field_wells_property = quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                    sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                        destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        source=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57c98cfba033cc5d94a17b04f6c0a15beeb496fdd250b78862ccb328deb8fc28)
                check_type(argname="argument sankey_diagram_aggregated_field_wells", value=sankey_diagram_aggregated_field_wells, expected_type=type_hints["sankey_diagram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sankey_diagram_aggregated_field_wells is not None:
                self._values["sankey_diagram_aggregated_field_wells"] = sankey_diagram_aggregated_field_wells

        @builtins.property
        def sankey_diagram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramfieldwells.html#cfn-quicksight-dashboard-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
            '''
            result = self._values.get("sankey_diagram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_items_limit": "destinationItemsLimit",
            "source_items_limit": "sourceItemsLimit",
            "weight_sort": "weightSort",
        },
    )
    class SankeyDiagramSortConfigurationProperty:
        def __init__(
            self,
            *,
            destination_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            weight_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a sankey diagram.

            :param destination_items_limit: The limit on the number of destination nodes that are displayed in a sankey diagram.
            :param source_items_limit: The limit on the number of source nodes that are displayed in a sankey diagram.
            :param weight_sort: The sort configuration of the weight fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_sort_configuration_property = quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                    destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__10ac1d8f38799d1bc851711038bfbfce586b4ee8858e57b10ef8a3bc32f7a783)
                check_type(argname="argument destination_items_limit", value=destination_items_limit, expected_type=type_hints["destination_items_limit"])
                check_type(argname="argument source_items_limit", value=source_items_limit, expected_type=type_hints["source_items_limit"])
                check_type(argname="argument weight_sort", value=weight_sort, expected_type=type_hints["weight_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination_items_limit is not None:
                self._values["destination_items_limit"] = destination_items_limit
            if source_items_limit is not None:
                self._values["source_items_limit"] = source_items_limit
            if weight_sort is not None:
                self._values["weight_sort"] = weight_sort

        @builtins.property
        def destination_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of destination nodes that are displayed in a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-destinationitemslimit
            '''
            result = self._values.get("destination_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def source_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of source nodes that are displayed in a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-sourceitemslimit
            '''
            result = self._values.get("source_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def weight_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the weight fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-weightsort
            '''
            result = self._values.get("weight_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SankeyDiagramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class SankeyDiagramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SankeyDiagramChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a sankey diagram.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_visual_property = quicksight.CfnDashboard.SankeyDiagramVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                            sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                                destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                            destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        )
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5238fca670d5ba3d1c572508fadf88f3f727a4097c764da5c690a04650dcfc3d)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SankeyDiagramChartConfigurationProperty"]]:
            '''The configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SankeyDiagramChartConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "size": "size",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class ScatterPlotCategoricallyAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            x_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            y_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well of a scatter plot.

            :param category: The category field well of a scatter plot.
            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is aggregated by category.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                scatter_plot_categorically_aggregated_field_wells_property = quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d5036b84d4f522624e8ed4d6bb544ba8e23ae2ea7aaefaf89e1a5b0dd88a7662)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The category field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The size field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotCategoricallyAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ScatterPlotConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
            "y_axis_label_options": "yAxisLabelOptions",
        },
    )
    class ScatterPlotConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ScatterPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a scatter plot.

            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.
            :param x_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
            :param x_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
            :param y_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
            :param y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                scatter_plot_configuration_property = quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__65b98ca505ff882507fb3f8caf099818de6839f036e6255c550dc48367ce7c4d)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
                check_type(argname="argument y_axis_label_options", value=y_axis_label_options, expected_type=type_hints["y_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options
            if y_axis_label_options is not None:
                self._values["y_axis_label_options"] = y_axis_label_options

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ScatterPlotFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ScatterPlotFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-yaxislabeloptions
            '''
            result = self._values.get("y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ScatterPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scatter_plot_categorically_aggregated_field_wells": "scatterPlotCategoricallyAggregatedFieldWells",
            "scatter_plot_unaggregated_field_wells": "scatterPlotUnaggregatedFieldWells",
        },
    )
    class ScatterPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a scatter plot.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param scatter_plot_categorically_aggregated_field_wells: The aggregated field wells of a scatter plot. Scatter plots that have a field in the category (group/color) field will have aggregated field wells. The x and y-axes of these scatter plots are aggregated by category.
            :param scatter_plot_unaggregated_field_wells: The unaggregated field wells of a scatter plot. Scatter plots without a category field well have unaggregated field wells. The x and y-axes of these scatter plots are unaggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                scatter_plot_field_wells_property = quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__38a6722b8b62e4f094eb4d22225ed5e4f4c24fdc541524e48bd05fcd83a36a5c)
                check_type(argname="argument scatter_plot_categorically_aggregated_field_wells", value=scatter_plot_categorically_aggregated_field_wells, expected_type=type_hints["scatter_plot_categorically_aggregated_field_wells"])
                check_type(argname="argument scatter_plot_unaggregated_field_wells", value=scatter_plot_unaggregated_field_wells, expected_type=type_hints["scatter_plot_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if scatter_plot_categorically_aggregated_field_wells is not None:
                self._values["scatter_plot_categorically_aggregated_field_wells"] = scatter_plot_categorically_aggregated_field_wells
            if scatter_plot_unaggregated_field_wells is not None:
                self._values["scatter_plot_unaggregated_field_wells"] = scatter_plot_unaggregated_field_wells

        @builtins.property
        def scatter_plot_categorically_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a scatter plot.

            Scatter plots that have a field in the category (group/color) field will have aggregated field wells. The x and y-axes of these scatter plots are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html#cfn-quicksight-dashboard-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_categorically_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty"]], result)

        @builtins.property
        def scatter_plot_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty"]]:
            '''The unaggregated field wells of a scatter plot.

            Scatter plots without a category field well have unaggregated field wells. The x and y-axes of these scatter plots are unaggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html#cfn-quicksight-dashboard-scatterplotfieldwells-scatterplotunaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"size": "size", "x_axis": "xAxis", "y_axis": "yAxis"},
    )
    class ScatterPlotUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            x_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            y_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The unaggregated field wells of a scatter plot.

            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is a dimension field and cannot be aggregated.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                scatter_plot_unaggregated_field_wells_property = quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                    size=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c2fb16b58554bc6aa41cf17168f436f8e10229ca44126a2fb9f0ae18523210b2)
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The size field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ScatterPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ScatterPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ScatterPlotConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                scatter_plot_visual_property = quicksight.CfnDashboard.ScatterPlotVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                            scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                                size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5aab80f6abe3c6cc7fcff1a4dc3e3ff7109e3433af28f239219ec7a4e98eb803)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ScatterPlotConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ScatterPlotConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ScrollBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility", "visible_range": "visibleRange"},
    )
    class ScrollBarOptionsProperty:
        def __init__(
            self,
            *,
            visibility: typing.Optional[builtins.str] = None,
            visible_range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisibleRangeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The visual display options for a data zoom scroll bar.

            :param visibility: The visibility of the data zoom scroll bar.
            :param visible_range: The visibility range for the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                scroll_bar_options_property = quicksight.CfnDashboard.ScrollBarOptionsProperty(
                    visibility="visibility",
                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                            from=123,
                            to=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__44dc6bc2fc3a6d533b939c06f8b36967a5c65cb0f488c2d8fc7c32356cf11b25)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument visible_range", value=visible_range, expected_type=type_hints["visible_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility
            if visible_range is not None:
                self._values["visible_range"] = visible_range

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html#cfn-quicksight-dashboard-scrollbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visible_range(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisibleRangeOptionsProperty"]]:
            '''The visibility range for the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html#cfn-quicksight-dashboard-scrollbaroptions-visiblerange
            '''
            result = self._values.get("visible_range")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisibleRangeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScrollBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SecondaryValueOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SecondaryValueOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :param visibility: Determines the visibility of the secondary value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-secondaryvalueoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                secondary_value_options_property = quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__71663d3a4864e54e14cfe36def14006ca66d24b4b7260bef947090e1d8901675)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the secondary value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-secondaryvalueoptions.html#cfn-quicksight-dashboard-secondaryvalueoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SecondaryValueOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SectionAfterPageBreakProperty",
        jsii_struct_bases=[],
        name_mapping={"status": "status"},
    )
    class SectionAfterPageBreakProperty:
        def __init__(self, *, status: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of a page break after a section.

            :param status: The option that enables or disables a page break at the end of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionafterpagebreak.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_after_page_break_property = quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a400bbe8e0ac07338086374a2a35b92e2d7a825c289a334f56d7a4e237b2d0cb)
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The option that enables or disables a page break at the end of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionafterpagebreak.html#cfn-quicksight-dashboard-sectionafterpagebreak-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionAfterPageBreakProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"paper_canvas_size_options": "paperCanvasSizeOptions"},
    )
    class SectionBasedLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for the canvas of a section-based layout.

            :param paper_canvas_size_options: The options for a paper canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_based_layout_canvas_size_options_property = quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                    paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                        paper_margin=quicksight.CfnDashboard.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        ),
                        paper_orientation="paperOrientation",
                        paper_size="paperSize"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c347b8d2a56f5b34d16da46056b0696fc7a9b246ad51ea7b0bf684a8e32b2789)
                check_type(argname="argument paper_canvas_size_options", value=paper_canvas_size_options, expected_type=type_hints["paper_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_canvas_size_options is not None:
                self._values["paper_canvas_size_options"] = paper_canvas_size_options

        @builtins.property
        def paper_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty"]]:
            '''The options for a paper canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
            '''
            result = self._values.get("paper_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "body_sections": "bodySections",
            "canvas_size_options": "canvasSizeOptions",
            "footer_sections": "footerSections",
            "header_sections": "headerSections",
        },
    )
    class SectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            body_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BodySectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
            footer_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            header_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The configuration for a section-based layout.

            :param body_sections: A list of body section configurations.
            :param canvas_size_options: The options for the canvas of a section-based layout.
            :param footer_sections: A list of footer section configurations.
            :param header_sections: A list of header section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_based_layout_configuration_property = quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                    body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                        content=quicksight.CfnDashboard.BodySectionContentProperty(
                            layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                            after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                status="status"
                            )
                        ),
                        style=quicksight.CfnDashboard.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    ),
                    footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnDashboard.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnDashboard.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__560f6d75aea951cd9bae33bc6685236fbc64e8eda896b0f7dbef14d911e4f8d3)
                check_type(argname="argument body_sections", value=body_sections, expected_type=type_hints["body_sections"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
                check_type(argname="argument footer_sections", value=footer_sections, expected_type=type_hints["footer_sections"])
                check_type(argname="argument header_sections", value=header_sections, expected_type=type_hints["header_sections"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "body_sections": body_sections,
                "canvas_size_options": canvas_size_options,
                "footer_sections": footer_sections,
                "header_sections": header_sections,
            }

        @builtins.property
        def body_sections(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BodySectionConfigurationProperty"]]]:
            '''A list of body section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-bodysections
            '''
            result = self._values.get("body_sections")
            assert result is not None, "Required property 'body_sections' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BodySectionConfigurationProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty"]:
            '''The options for the canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty"], result)

        @builtins.property
        def footer_sections(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeaderFooterSectionConfigurationProperty"]]]:
            '''A list of footer section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-footersections
            '''
            result = self._values.get("footer_sections")
            assert result is not None, "Required property 'footer_sections' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeaderFooterSectionConfigurationProperty"]]], result)

        @builtins.property
        def header_sections(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeaderFooterSectionConfigurationProperty"]]]:
            '''A list of header section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-headersections
            '''
            result = self._values.get("header_sections")
            assert result is not None, "Required property 'header_sections' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeaderFooterSectionConfigurationProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "paper_margin": "paperMargin",
            "paper_orientation": "paperOrientation",
            "paper_size": "paperSize",
        },
    )
    class SectionBasedLayoutPaperCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_margin: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SpacingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paper_orientation: typing.Optional[builtins.str] = None,
            paper_size: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a paper canvas of a section-based layout.

            :param paper_margin: Defines the spacing between the canvas content and the top, bottom, left, and right edges.
            :param paper_orientation: The paper orientation that is used to define canvas dimensions. Choose one of the following options:. - PORTRAIT - LANDSCAPE
            :param paper_size: The paper size that is used to define canvas dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_based_layout_paper_canvas_size_options_property = quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                    paper_margin=quicksight.CfnDashboard.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    ),
                    paper_orientation="paperOrientation",
                    paper_size="paperSize"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5795cbccd070ce84493464a52c0e5a6e23c2dca1182a37c291478b977a69c698)
                check_type(argname="argument paper_margin", value=paper_margin, expected_type=type_hints["paper_margin"])
                check_type(argname="argument paper_orientation", value=paper_orientation, expected_type=type_hints["paper_orientation"])
                check_type(argname="argument paper_size", value=paper_size, expected_type=type_hints["paper_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_margin is not None:
                self._values["paper_margin"] = paper_margin
            if paper_orientation is not None:
                self._values["paper_orientation"] = paper_orientation
            if paper_size is not None:
                self._values["paper_size"] = paper_size

        @builtins.property
        def paper_margin(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SpacingProperty"]]:
            '''Defines the spacing between the canvas content and the top, bottom, left, and right edges.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-papermargin
            '''
            result = self._values.get("paper_margin")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SpacingProperty"]], result)

        @builtins.property
        def paper_orientation(self) -> typing.Optional[builtins.str]:
            '''The paper orientation that is used to define canvas dimensions. Choose one of the following options:.

            - PORTRAIT
            - LANDSCAPE

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-paperorientation
            '''
            result = self._values.get("paper_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def paper_size(self) -> typing.Optional[builtins.str]:
            '''The paper size that is used to define canvas dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-papersize
            '''
            result = self._values.get("paper_size")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutPaperCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form_layout": "freeFormLayout"},
    )
    class SectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FreeFormSectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The layout configuration of a section.

            :param free_form_layout: The free-form layout configuration of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_layout_configuration_property = quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2417d83a3f63a33577839f9e99c11da8d926f314d2e2da30fb46456fe626caa5)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "free_form_layout": free_form_layout,
            }

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormSectionLayoutConfigurationProperty"]:
            '''The free-form layout configuration of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionlayoutconfiguration.html#cfn-quicksight-dashboard-sectionlayoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            assert result is not None, "Required property 'free_form_layout' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FreeFormSectionLayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SectionPageBreakConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"after": "after"},
    )
    class SectionPageBreakConfigurationProperty:
        def __init__(
            self,
            *,
            after: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SectionAfterPageBreakProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a page break for a section.

            :param after: The configuration of a page break after a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionpagebreakconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_page_break_configuration_property = quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                    after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__885b2a451cdb41dbc2e52bbf3ccdff3faa033f24c503405d5b86a025c536541a)
                check_type(argname="argument after", value=after, expected_type=type_hints["after"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if after is not None:
                self._values["after"] = after

        @builtins.property
        def after(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionAfterPageBreakProperty"]]:
            '''The configuration of a page break after a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionpagebreakconfiguration.html#cfn-quicksight-dashboard-sectionpagebreakconfiguration-after
            '''
            result = self._values.get("after")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SectionAfterPageBreakProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionPageBreakConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SectionStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"height": "height", "padding": "padding"},
    )
    class SectionStyleProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            padding: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SpacingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that style a section.

            :param height: The height of a section. Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.
            :param padding: The spacing between section content and its top, bottom, left, and right edges. There is no padding by default.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_style_property = quicksight.CfnDashboard.SectionStyleProperty(
                    height="height",
                    padding=quicksight.CfnDashboard.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1aec607eec2e37f7bcb04fe04edf55b4603f62a87bedd980047b3b5a4d8ccac1)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument padding", value=padding, expected_type=type_hints["padding"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if padding is not None:
                self._values["padding"] = padding

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of a section.

            Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html#cfn-quicksight-dashboard-sectionstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def padding(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SpacingProperty"]]:
            '''The spacing between section content and its top, bottom, left, and right edges.

            There is no padding by default.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html#cfn-quicksight-dashboard-sectionstyle-padding
            '''
            result = self._values.get("padding")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SpacingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_visual_scoping_configurations": "sheetVisualScopingConfigurations",
        },
    )
    class SelectedSheetsFilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            sheet_visual_scoping_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SheetVisualScopingConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The configuration for applying a filter to specific sheets or visuals.

            You can apply this filter to multiple visuals that are on one sheet or to all visuals on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param sheet_visual_scoping_configurations: The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-selectedsheetsfilterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                selected_sheets_filter_scope_configuration_property = quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                    sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                        scope="scope",
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        visual_ids=["visualIds"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93ba53f3b384bad98bc74a54934dffbbd702826949d9e0de289001e42430b7d9)
                check_type(argname="argument sheet_visual_scoping_configurations", value=sheet_visual_scoping_configurations, expected_type=type_hints["sheet_visual_scoping_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sheet_visual_scoping_configurations is not None:
                self._values["sheet_visual_scoping_configurations"] = sheet_visual_scoping_configurations

        @builtins.property
        def sheet_visual_scoping_configurations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetVisualScopingConfigurationProperty"]]]]:
            '''The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-dashboard-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
            '''
            result = self._values.get("sheet_visual_scoping_configurations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetVisualScopingConfigurationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SelectedSheetsFilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_field_series_item": "dataFieldSeriesItem",
            "field_series_item": "fieldSeriesItem",
        },
    )
    class SeriesItemProperty:
        def __init__(
            self,
            *,
            data_field_series_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataFieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_series_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The series item configuration of a line chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_field_series_item: The data field series item configuration of a line chart.
            :param field_series_item: The field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                series_item_property = quicksight.CfnDashboard.SeriesItemProperty(
                    data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    ),
                    field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__81fb7077ac4bf734aabc0b73ae42244d481f843268367e3d705fa476eb6d98de)
                check_type(argname="argument data_field_series_item", value=data_field_series_item, expected_type=type_hints["data_field_series_item"])
                check_type(argname="argument field_series_item", value=field_series_item, expected_type=type_hints["field_series_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_field_series_item is not None:
                self._values["data_field_series_item"] = data_field_series_item
            if field_series_item is not None:
                self._values["field_series_item"] = field_series_item

        @builtins.property
        def data_field_series_item(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataFieldSeriesItemProperty"]]:
            '''The data field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html#cfn-quicksight-dashboard-seriesitem-datafieldseriesitem
            '''
            result = self._values.get("data_field_series_item")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataFieldSeriesItemProperty"]], result)

        @builtins.property
        def field_series_item(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSeriesItemProperty"]]:
            '''The field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html#cfn-quicksight-dashboard-seriesitem-fieldseriesitem
            '''
            result = self._values.get("field_series_item")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSeriesItemProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SetParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_parameter_name": "destinationParameterName",
            "value": "value",
        },
    )
    class SetParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            destination_parameter_name: builtins.str,
            value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DestinationParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The configuration of adding parameters in action.

            :param destination_parameter_name: The destination parameter name of the ``SetParameterValueConfiguration`` .
            :param value: ``CfnDashboard.SetParameterValueConfigurationProperty.Value``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                set_parameter_value_configuration_property = quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                    destination_parameter_name="destinationParameterName",
                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                date_time_values=["dateTimeValues"],
                                decimal_values=[123],
                                integer_values=[123],
                                string_values=["stringValues"]
                            ),
                
                            # the properties below are optional
                            include_null_value=False
                        ),
                        select_all_value_options="selectAllValueOptions",
                        source_field="sourceField",
                        source_parameter_name="sourceParameterName"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a060ee5a2f3b98f16708be310ce8d517e3bcd8c3e17ed5d0c9c02bbfbcb22151)
                check_type(argname="argument destination_parameter_name", value=destination_parameter_name, expected_type=type_hints["destination_parameter_name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "destination_parameter_name": destination_parameter_name,
                "value": value,
            }

        @builtins.property
        def destination_parameter_name(self) -> builtins.str:
            '''The destination parameter name of the ``SetParameterValueConfiguration`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html#cfn-quicksight-dashboard-setparametervalueconfiguration-destinationparametername
            '''
            result = self._values.get("destination_parameter_name")
            assert result is not None, "Required property 'destination_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DestinationParameterValueConfigurationProperty"]:
            '''``CfnDashboard.SetParameterValueConfigurationProperty.Value``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html#cfn-quicksight-dashboard-setparametervalueconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DestinationParameterValueConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SetParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ShapeConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={"background_color": "backgroundColor"},
    )
    class ShapeConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The shape conditional formatting of a filled map visual.

            :param background_color: The conditional formatting for the shape background color of a filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shapeconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                shape_conditional_format_property = quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e1073a839c0eaf1b2810fb1fe6c32507b1c0bb93f0dd32c8d5bdf25cecfdf8aa)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "background_color": background_color,
            }

        @builtins.property
        def background_color(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]:
            '''The conditional formatting for the shape background color of a filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shapeconditionalformat.html#cfn-quicksight-dashboard-shapeconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            assert result is not None, "Required property 'background_color' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShapeConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"grid_layout": "gridLayout"},
    )
    class SheetControlLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            grid_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :param grid_layout: The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_control_layout_configuration_property = quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                    grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3cf52fe310a0d3e22adca96e74fd0a111b08e88da9ba1ae9834142e1a1e90944)
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GridLayoutConfigurationProperty"]]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayoutconfiguration.html#cfn-quicksight-dashboard-sheetcontrollayoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GridLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SheetControlLayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class SheetControlLayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SheetControlLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A grid layout to define the placement of sheet control.

            :param configuration: The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_control_layout_property = quicksight.CfnDashboard.SheetControlLayoutProperty(
                    configuration=quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                        grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c94bf2565325e683667b1bdd41f77a1e72194a3171ddff982e0d0e2370bddb33)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetControlLayoutConfigurationProperty"]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayout.html#cfn-quicksight-dashboard-sheetcontrollayout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetControlLayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SheetControlsOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility_state": "visibilityState"},
    )
    class SheetControlsOptionProperty:
        def __init__(
            self,
            *,
            visibility_state: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Sheet controls option.

            :param visibility_state: Visibility state.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolsoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_controls_option_property = quicksight.CfnDashboard.SheetControlsOptionProperty(
                    visibility_state="visibilityState"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d6fff40196a8bdcd9e7c39c95596d68a8e619159c1cc287194e73ddb1e89b70)
                check_type(argname="argument visibility_state", value=visibility_state, expected_type=type_hints["visibility_state"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility_state is not None:
                self._values["visibility_state"] = visibility_state

        @builtins.property
        def visibility_state(self) -> typing.Optional[builtins.str]:
            '''Visibility state.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolsoption.html#cfn-quicksight-dashboard-sheetcontrolsoption-visibilitystate
            '''
            result = self._values.get("visibility_state")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlsOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SheetDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_id": "sheetId",
            "content_type": "contentType",
            "description": "description",
            "filter_controls": "filterControls",
            "layouts": "layouts",
            "name": "name",
            "parameter_controls": "parameterControls",
            "sheet_control_layouts": "sheetControlLayouts",
            "text_boxes": "textBoxes",
            "title": "title",
            "visuals": "visuals",
        },
    )
    class SheetDefinitionProperty:
        def __init__(
            self,
            *,
            sheet_id: builtins.str,
            content_type: typing.Optional[builtins.str] = None,
            description: typing.Optional[builtins.str] = None,
            filter_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilterControlProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            layouts: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LayoutProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            name: typing.Optional[builtins.str] = None,
            parameter_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ParameterControlProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheet_control_layouts: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SheetControlLayoutProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            text_boxes: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SheetTextBoxProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            title: typing.Optional[builtins.str] = None,
            visuals: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A sheet is an object that contains a set of visuals that are viewed together on one page in a paginated report.

            Every analysis and dashboard must contain at least one sheet.

            :param sheet_id: The unique identifier of a sheet.
            :param content_type: The layout content type of the sheet. Choose one of the following options:. - ``PAGINATED`` : Creates a sheet for a paginated report. - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.
            :param description: A description of the sheet.
            :param filter_controls: The list of filter controls that are on a sheet. For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param layouts: Layouts define how the components of a sheet are arranged. For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .
            :param name: The name of the sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param parameter_controls: The list of parameter controls that are on a sheet. For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheet_control_layouts: The control layouts of the sheet.
            :param text_boxes: The text boxes that are on a sheet.
            :param title: The title of the sheet.
            :param visuals: A list of the visuals that are on a sheet. Visual placement is determined by the layout of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                sheet_definition_property = quicksight.CfnDashboard.SheetDefinitionProperty(
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    content_type="contentType",
                    description="description",
                    filter_controls=[quicksight.CfnDashboard.FilterControlProperty(
                        date_time_picker=quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        dropdown=quicksight.CfnDashboard.FilterDropDownControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnDashboard.FilterListControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        relative_date_time=quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        slider=quicksight.CfnDashboard.FilterSliderControlProperty(
                            filter_control_id="filterControlId",
                            maximum_value=123,
                            minimum_value=123,
                            source_filter_id="sourceFilterId",
                            step_size=123,
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        text_area=quicksight.CfnDashboard.FilterTextAreaControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnDashboard.FilterTextFieldControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    layouts=[quicksight.CfnDashboard.LayoutProperty(
                        configuration=quicksight.CfnDashboard.LayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
                
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                                body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                                    content=quicksight.CfnDashboard.BodySectionContentProperty(
                                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                        after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                            status="status"
                                        )
                                    ),
                                    style=quicksight.CfnDashboard.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                ),
                                footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    style=quicksight.CfnDashboard.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    style=quicksight.CfnDashboard.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )]
                            )
                        )
                    )],
                    name="name",
                    parameter_controls=[quicksight.CfnDashboard.ParameterControlProperty(
                        date_time_picker=quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        dropdown=quicksight.CfnDashboard.ParameterDropDownControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnDashboard.ParameterListControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        slider=quicksight.CfnDashboard.ParameterSliderControlProperty(
                            maximum_value=123,
                            minimum_value=123,
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            step_size=123,
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_area=quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    sheet_control_layouts=[quicksight.CfnDashboard.SheetControlLayoutProperty(
                        configuration=quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                            grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
                
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        )
                    )],
                    text_boxes=[quicksight.CfnDashboard.SheetTextBoxProperty(
                        sheet_text_box_id="sheetTextBoxId",
                
                        # the properties below are optional
                        content="content"
                    )],
                    title="title",
                    visuals=[quicksight.CfnDashboard.VisualProperty(
                        bar_chart_visual=quicksight.CfnDashboard.BarChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.BarChartConfigurationProperty(
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                                    bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                orientation="orientation",
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        box_plot_visual=quicksight.CfnDashboard.BoxPlotVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                                box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                                    all_data_points_visibility="allDataPointsVisibility",
                                    outlier_visibility="outlierVisibility",
                                    style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                                        fill_style="fillStyle"
                                    )
                                ),
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                                    box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    )
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        combo_chart_visual=quicksight.CfnDashboard.ComboChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.ComboChartConfigurationProperty(
                                bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                                    combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                                        bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        custom_content_visual=quicksight.CfnDashboard.CustomContentVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.CustomContentConfigurationProperty(
                                content_type="contentType",
                                content_url="contentUrl",
                                image_scaling="imageScaling"
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        empty_visual=quicksight.CfnDashboard.EmptyVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )]
                        ),
                        filled_map_visual=quicksight.CfnDashboard.FilledMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.FilledMapConfigurationProperty(
                                field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                                    filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                                        geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                                    shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        funnel_chart_visual=quicksight.CfnDashboard.FunnelChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    label_color="labelColor",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_data_label_style="measureDataLabelStyle",
                                    measure_label_visibility="measureLabelVisibility",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                                    funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        gauge_chart_visual=quicksight.CfnDashboard.GaugeChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                                    target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                                    arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                                        arc_angle=123,
                                        arc_thickness="arcThickness"
                                    ),
                                    arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                                        range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                            max=123,
                                            min=123
                                        ),
                                        reserve_range=123
                                    ),
                                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                ),
                                tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            conditional_formatting=quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                                    arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        geospatial_map_visual=quicksight.CfnDashboard.GeospatialMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                                field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                                    geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                                    cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                                        cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                            simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                                color="color"
                                            )
                                        )
                                    ),
                                    selected_point_style="selectedPointStyle"
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        heat_map_visual=quicksight.CfnDashboard.HeatMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.HeatMapConfigurationProperty(
                                color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
                
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                                    heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                                    heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        histogram_visual=quicksight.CfnDashboard.HistogramVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.HistogramConfigurationProperty(
                                bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                                    bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                                        value=123
                                    ),
                                    bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                                        bin_count_limit=123,
                                        value=123
                                    ),
                                    selected_bin_type="selectedBinType",
                                    start_value=123
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                                    histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                )
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        insight_visual=quicksight.CfnDashboard.InsightVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            insight_configuration=quicksight.CfnDashboard.InsightConfigurationProperty(
                                computations=[quicksight.CfnDashboard.ComputationProperty(
                                    forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        custom_seasonality_value=123,
                                        lower_boundary=123,
                                        name="name",
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality="seasonality",
                                        upper_boundary=123,
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        period_size=123,
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
                
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                                        computation_id="computationId",
                                        from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        period_time_granularity="periodTimeGranularity",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
                
                                        # the properties below are optional
                                        mover_size=123,
                                        name="name",
                                        sort_order="sortOrder",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        type="type",
                
                                        # the properties below are optional
                                        name="name",
                                        result_size=123,
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                                        computation_id="computationId",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                
                                        # the properties below are optional
                                        name="name"
                                    )
                                )],
                                custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                                    narrative="narrative"
                                )
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        kpi_visual=quicksight.CfnDashboard.KPIVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.KPIConfigurationProperty(
                                field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                                    target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                                    trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                                    primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        line_chart_visual=quicksight.CfnDashboard.LineChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.LineChartConfigurationProperty(
                                contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                                    axis_binding="axisBinding",
                                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                                    line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                                    forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                                        lower_boundary=123,
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality=123,
                                        upper_boundary=123
                                    ),
                                    scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                                        what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                            date="date",
                                            value=123
                                        ),
                                        what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                            end_date="endDate",
                                            start_date="startDate",
                                            value=123
                                        )
                                    )
                                )],
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                series=[quicksight.CfnDashboard.SeriesItemProperty(
                                    data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        field_value="fieldValue",
                                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    ),
                                    field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    )
                                )],
                                small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                                    category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                type="type",
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pie_chart_visual=quicksight.CfnDashboard.PieChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.PieChartConfigurationProperty(
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                                    arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                                        arc_thickness="arcThickness"
                                    ),
                                    donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                                        label_visibility="labelVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                                    pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pivot_table_visual=quicksight.CfnDashboard.PivotTableVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.PivotTableConfigurationProperty(
                                field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                                    data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                                        data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )],
                
                                        # the properties below are optional
                                        width="width"
                                    )],
                                    selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        visibility="visibility"
                                    )]
                                ),
                                field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                                    pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                                    field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                                        field_id="fieldId",
                                        sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                            column=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                                direction="direction",
                                                sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                                    field_id="fieldId",
                                                    field_value="fieldValue"
                                                )]
                                            ),
                                            field=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )
                                    )]
                                ),
                                table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_names_visibility="columnNamesVisibility",
                                    metric_placement="metricPlacement",
                                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    ),
                                    row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    single_metric_visibility="singleMetricVisibility",
                                    toggle_buttons_visibility="toggleButtonsVisibility"
                                ),
                                total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                                    column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                )
                            ),
                            conditional_formatting=quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                            role="role"
                                        ),
                                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        radar_chart_visual=quicksight.CfnDashboard.RadarChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.RadarChartConfigurationProperty(
                                alternate_band_colors_visibility="alternateBandColorsVisibility",
                                alternate_band_even_color="alternateBandEvenColor",
                                alternate_band_odd_color="alternateBandOddColor",
                                base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                                    area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                                    radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                shape="shape",
                                sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                start_angle=123,
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        sankey_diagram_visual=quicksight.CfnDashboard.SankeyDiagramVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                                    sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                                        destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                                    destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        scatter_plot_visual=quicksight.CfnDashboard.ScatterPlotVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        table_visual=quicksight.CfnDashboard.TableVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.TableConfigurationProperty(
                                field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                                    order=["order"],
                                    selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                            image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                                sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                )
                                            ),
                                            link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                                content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                                    custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                                        icon="icon"
                                                    ),
                                                    custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                            font_color="fontColor",
                                                            font_decoration="fontDecoration",
                                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                                relative="relative"
                                                            ),
                                                            font_style="fontStyle",
                                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                                name="name"
                                                            )
                                                        ),
                
                                                        # the properties below are optional
                                                        value="value"
                                                    )
                                                ),
                                                target="target"
                                            )
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    )]
                                ),
                                field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                                    table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                                        values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                                date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    ),
                                    row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                                    data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        negative_color="negativeColor",
                                        positive_color="positiveColor"
                                    )
                                )],
                                table_options=quicksight.CfnDashboard.TableOptionsProperty(
                                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    orientation="orientation",
                                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    )
                                ),
                                total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                                    custom_label="customLabel",
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility"
                                )
                            ),
                            conditional_formatting=quicksight.CfnDashboard.TableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    ),
                                    row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        tree_map_visual=quicksight.CfnDashboard.TreeMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.TreeMapConfigurationProperty(
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
                
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                                    tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                                    tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        waterfall_visual=quicksight.CfnDashboard.WaterfallVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                                category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                                    waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                                        breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                                    breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                                    total_bar_label="totalBarLabel"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        word_cloud_visual=quicksight.CfnDashboard.WordCloudVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                                    word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                                    cloud_layout="cloudLayout",
                                    maximum_string_length=123,
                                    word_casing="wordCasing",
                                    word_orientation="wordOrientation",
                                    word_padding="wordPadding",
                                    word_scaling="wordScaling"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__782ddc0bc21b686a40084341de2b13e7acacecebee2f7a56d0e1cbab9609b664)
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument filter_controls", value=filter_controls, expected_type=type_hints["filter_controls"])
                check_type(argname="argument layouts", value=layouts, expected_type=type_hints["layouts"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_controls", value=parameter_controls, expected_type=type_hints["parameter_controls"])
                check_type(argname="argument sheet_control_layouts", value=sheet_control_layouts, expected_type=type_hints["sheet_control_layouts"])
                check_type(argname="argument text_boxes", value=text_boxes, expected_type=type_hints["text_boxes"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visuals", value=visuals, expected_type=type_hints["visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_id": sheet_id,
            }
            if content_type is not None:
                self._values["content_type"] = content_type
            if description is not None:
                self._values["description"] = description
            if filter_controls is not None:
                self._values["filter_controls"] = filter_controls
            if layouts is not None:
                self._values["layouts"] = layouts
            if name is not None:
                self._values["name"] = name
            if parameter_controls is not None:
                self._values["parameter_controls"] = parameter_controls
            if sheet_control_layouts is not None:
                self._values["sheet_control_layouts"] = sheet_control_layouts
            if text_boxes is not None:
                self._values["text_boxes"] = text_boxes
            if title is not None:
                self._values["title"] = title
            if visuals is not None:
                self._values["visuals"] = visuals

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The unique identifier of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The layout content type of the sheet. Choose one of the following options:.

            - ``PAGINATED`` : Creates a sheet for a paginated report.
            - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''A description of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def filter_controls(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterControlProperty"]]]]:
            '''The list of filter controls that are on a sheet.

            For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-filtercontrols
            '''
            result = self._values.get("filter_controls")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilterControlProperty"]]]], result)

        @builtins.property
        def layouts(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LayoutProperty"]]]]:
            '''Layouts define how the components of a sheet are arranged.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-layouts
            '''
            result = self._values.get("layouts")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LayoutProperty"]]]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_controls(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterControlProperty"]]]]:
            '''The list of parameter controls that are on a sheet.

            For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-parametercontrols
            '''
            result = self._values.get("parameter_controls")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ParameterControlProperty"]]]], result)

        @builtins.property
        def sheet_control_layouts(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetControlLayoutProperty"]]]]:
            '''The control layouts of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-sheetcontrollayouts
            '''
            result = self._values.get("sheet_control_layouts")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetControlLayoutProperty"]]]], result)

        @builtins.property
        def text_boxes(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetTextBoxProperty"]]]]:
            '''The text boxes that are on a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-textboxes
            '''
            result = self._values.get("text_boxes")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetTextBoxProperty"]]]], result)

        @builtins.property
        def title(self) -> typing.Optional[builtins.str]:
            '''The title of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visuals(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualProperty"]]]]:
            '''A list of the visuals that are on a sheet.

            Visual placement is determined by the layout of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-visuals
            '''
            result = self._values.get("visuals")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SheetElementConfigurationOverridesProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The override configuration of the rendering rules of a sheet.

            :param visibility: Determines whether or not the overrides are visible. Choose one of the following options:. - ``VISIBLE`` - ``HIDDEN``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementconfigurationoverrides.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_element_configuration_overrides_property = quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__12d604fb856810e239394e339e821cb79cc65ec8812d495834674fb63d78839d)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the overrides are visible. Choose one of the following options:.

            - ``VISIBLE``
            - ``HIDDEN``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementconfigurationoverrides.html#cfn-quicksight-dashboard-sheetelementconfigurationoverrides-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementConfigurationOverridesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SheetElementRenderingRuleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "configuration_overrides": "configurationOverrides",
            "expression": "expression",
        },
    )
    class SheetElementRenderingRuleProperty:
        def __init__(
            self,
            *,
            configuration_overrides: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SheetElementConfigurationOverridesProperty", typing.Dict[builtins.str, typing.Any]]],
            expression: builtins.str,
        ) -> None:
            '''The rendering rules of a sheet that uses a free-form layout.

            :param configuration_overrides: The override configuration of the rendering rules of a sheet.
            :param expression: The expression of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_element_rendering_rule_property = quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                        visibility="visibility"
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__38a4710870e427213183005a7f1c1e59d0a9187b3b04a0a0fd98b3f522fe183e)
                check_type(argname="argument configuration_overrides", value=configuration_overrides, expected_type=type_hints["configuration_overrides"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration_overrides": configuration_overrides,
                "expression": expression,
            }

        @builtins.property
        def configuration_overrides(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetElementConfigurationOverridesProperty"]:
            '''The override configuration of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html#cfn-quicksight-dashboard-sheetelementrenderingrule-configurationoverrides
            '''
            result = self._values.get("configuration_overrides")
            assert result is not None, "Required property 'configuration_overrides' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SheetElementConfigurationOverridesProperty"], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html#cfn-quicksight-dashboard-sheetelementrenderingrule-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementRenderingRuleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SheetLayoutElementMaximizationOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class SheetLayoutElementMaximizationOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The sheet layout maximization options of a dashbaord.

            :param availability_status: The status of the sheet layout maximization options of a dashbaord.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetlayoutelementmaximizationoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_layout_element_maximization_option_property = quicksight.CfnDashboard.SheetLayoutElementMaximizationOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dc5036518819074a06d7a3151ff1e712efe539c2953e683ed3619b3ad079a6ca)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the sheet layout maximization options of a dashbaord.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetlayoutelementmaximizationoption.html#cfn-quicksight-dashboard-sheetlayoutelementmaximizationoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetLayoutElementMaximizationOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SheetProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "sheet_id": "sheetId"},
    )
    class SheetProperty:
        def __init__(
            self,
            *,
            name: typing.Optional[builtins.str] = None,
            sheet_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight.

            Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.

            :param name: The name of a sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param sheet_id: The unique identifier associated with a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_property = quicksight.CfnDashboard.SheetProperty(
                    name="name",
                    sheet_id="sheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__333486f3a30de91e0c5d7e6b054ab9b4ae92b3f2cf382eb8492c37cbcc3bcd5b)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name
            if sheet_id is not None:
                self._values["sheet_id"] = sheet_id

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html#cfn-quicksight-dashboard-sheet-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sheet_id(self) -> typing.Optional[builtins.str]:
            '''The unique identifier associated with a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html#cfn-quicksight-dashboard-sheet-sheetid
            '''
            result = self._values.get("sheet_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SheetTextBoxProperty",
        jsii_struct_bases=[],
        name_mapping={"sheet_text_box_id": "sheetTextBoxId", "content": "content"},
    )
    class SheetTextBoxProperty:
        def __init__(
            self,
            *,
            sheet_text_box_id: builtins.str,
            content: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A text box.

            :param sheet_text_box_id: The unique identifier for a text box. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
            :param content: The content that is displayed in the text box.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_text_box_property = quicksight.CfnDashboard.SheetTextBoxProperty(
                    sheet_text_box_id="sheetTextBoxId",
                
                    # the properties below are optional
                    content="content"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__83e625be22f11ff01c308938d355a75fb15011afd168c6c505f19161c7571c49)
                check_type(argname="argument sheet_text_box_id", value=sheet_text_box_id, expected_type=type_hints["sheet_text_box_id"])
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_text_box_id": sheet_text_box_id,
            }
            if content is not None:
                self._values["content"] = content

        @builtins.property
        def sheet_text_box_id(self) -> builtins.str:
            '''The unique identifier for a text box.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html#cfn-quicksight-dashboard-sheettextbox-sheettextboxid
            '''
            result = self._values.get("sheet_text_box_id")
            assert result is not None, "Required property 'sheet_text_box_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content(self) -> typing.Optional[builtins.str]:
            '''The content that is displayed in the text box.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html#cfn-quicksight-dashboard-sheettextbox-content
            '''
            result = self._values.get("content")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetTextBoxProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scope": "scope",
            "sheet_id": "sheetId",
            "visual_ids": "visualIds",
        },
    )
    class SheetVisualScopingConfigurationProperty:
        def __init__(
            self,
            *,
            scope: builtins.str,
            sheet_id: builtins.str,
            visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The filter that is applied to the options.

            :param scope: The scope of the applied entities. Choose one of the following options:. - ``ALL_VISUALS`` - ``SELECTED_VISUALS``
            :param sheet_id: The selected sheet that the filter is applied to.
            :param visual_ids: The selected visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_visual_scoping_configuration_property = quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                    scope="scope",
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    visual_ids=["visualIds"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__28652a27a17131721fdc8f0f29bf1c37916eb4a7b301c11ffc1af5998fe853d7)
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument visual_ids", value=visual_ids, expected_type=type_hints["visual_ids"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "scope": scope,
                "sheet_id": sheet_id,
            }
            if visual_ids is not None:
                self._values["visual_ids"] = visual_ids

        @builtins.property
        def scope(self) -> builtins.str:
            '''The scope of the applied entities. Choose one of the following options:.

            - ``ALL_VISUALS``
            - ``SELECTED_VISUALS``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-scope
            '''
            result = self._values.get("scope")
            assert result is not None, "Required property 'scope' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The selected sheet that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_ids(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The selected visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-visualids
            '''
            result = self._values.get("visual_ids")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetVisualScopingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ShortFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class ShortFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for the title.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                short_format_text_property = quicksight.CfnDashboard.ShortFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__baff6969f15680f9d784fc68e878bfeaa3a137c826de70edde66c3512ea04b4c)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html#cfn-quicksight-dashboard-shortformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html#cfn-quicksight-dashboard-shortformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShortFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SimpleClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color"},
    )
    class SimpleClusterMarkerProperty:
        def __init__(self, *, color: typing.Optional[builtins.str] = None) -> None:
            '''The simple cluster marker of the cluster marker.

            :param color: The color of the simple cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-simpleclustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                simple_cluster_marker_property = quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__69f0f89310e81b15a85d59f2164b6fac594deddfa9eea7c4bf4f0dbbbc9dd0e2)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of the simple cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-simpleclustermarker.html#cfn-quicksight-dashboard-simpleclustermarker-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SimpleClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SliderControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"title_options": "titleOptions"},
    )
    class SliderControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-slidercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                slider_control_display_options_property = quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e6b8cf2a55f0f2b0350f5d3b3dd813441c8a4c962e64ab3b4c98465273993a49)
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-slidercontroldisplayoptions.html#cfn-quicksight-dashboard-slidercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SliderControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SmallMultiplesOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "max_visible_columns": "maxVisibleColumns",
            "max_visible_rows": "maxVisibleRows",
            "panel_configuration": "panelConfiguration",
        },
    )
    class SmallMultiplesOptionsProperty:
        def __init__(
            self,
            *,
            max_visible_columns: typing.Optional[jsii.Number] = None,
            max_visible_rows: typing.Optional[jsii.Number] = None,
            panel_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PanelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Options that determine the layout and display options of a chart's small multiples.

            :param max_visible_columns: Sets the maximum number of visible columns to display in the grid of small multiples panels. The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
            :param max_visible_rows: Sets the maximum number of visible rows to display in the grid of small multiples panels. The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
            :param panel_configuration: Configures the display options for each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                small_multiples_options_property = quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                    max_visible_columns=123,
                    max_visible_rows=123,
                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                        background_color="backgroundColor",
                        background_visibility="backgroundVisibility",
                        border_color="borderColor",
                        border_style="borderStyle",
                        border_thickness="borderThickness",
                        border_visibility="borderVisibility",
                        gutter_spacing="gutterSpacing",
                        gutter_visibility="gutterVisibility",
                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_text_alignment="horizontalTextAlignment",
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee822ddbed5663c047f90bceb2d1170c6b77a63bcfb32b2d330f8863b2fc151a)
                check_type(argname="argument max_visible_columns", value=max_visible_columns, expected_type=type_hints["max_visible_columns"])
                check_type(argname="argument max_visible_rows", value=max_visible_rows, expected_type=type_hints["max_visible_rows"])
                check_type(argname="argument panel_configuration", value=panel_configuration, expected_type=type_hints["panel_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max_visible_columns is not None:
                self._values["max_visible_columns"] = max_visible_columns
            if max_visible_rows is not None:
                self._values["max_visible_rows"] = max_visible_rows
            if panel_configuration is not None:
                self._values["panel_configuration"] = panel_configuration

        @builtins.property
        def max_visible_columns(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible columns to display in the grid of small multiples panels.

            The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-maxvisiblecolumns
            '''
            result = self._values.get("max_visible_columns")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def max_visible_rows(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible rows to display in the grid of small multiples panels.

            The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-maxvisiblerows
            '''
            result = self._values.get("max_visible_rows")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def panel_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PanelConfigurationProperty"]]:
            '''Configures the display options for each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-panelconfiguration
            '''
            result = self._values.get("panel_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PanelConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SmallMultiplesOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SpacingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class SpacingProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[builtins.str] = None,
            left: typing.Optional[builtins.str] = None,
            right: typing.Optional[builtins.str] = None,
            top: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of spacing (often a margin or padding).

            :param bottom: Define the bottom spacing.
            :param left: Define the left spacing.
            :param right: Define the right spacing.
            :param top: Define the top spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                spacing_property = quicksight.CfnDashboard.SpacingProperty(
                    bottom="bottom",
                    left="left",
                    right="right",
                    top="top"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__28c5f744484b45bef3b37db26fbc8965378a61ac42eca5ebae2515c4fa99ed4b)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(self) -> typing.Optional[builtins.str]:
            '''Define the bottom spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def left(self) -> typing.Optional[builtins.str]:
            '''Define the left spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def right(self) -> typing.Optional[builtins.str]:
            '''Define the right spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def top(self) -> typing.Optional[builtins.str]:
            '''Define the top spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SpacingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.StringDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class StringDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``StringParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``StringDefaultValues`` . Different defaults displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_default_values_property = quicksight.CfnDashboard.StringDefaultValuesProperty(
                    dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a29da4eb4e79489a7bdc9c0487c0c66c7b95a41ba63269698b2faf8681512942)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``StringDefaultValues`` .

            Different defaults displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html#cfn-quicksight-dashboard-stringdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html#cfn-quicksight-dashboard-stringdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.StringFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class StringFormatConfigurationProperty:
        def __init__(
            self,
            *,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for string fields.

            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric strings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_format_configuration_property = quicksight.CfnDashboard.StringFormatConfigurationProperty(
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__336890f8beb864ee1828625e53126682ed1c452dc203d9dc8c8a73118408dc33)
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html#cfn-quicksight-dashboard-stringformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericFormatConfigurationProperty"]]:
            '''The formatting configuration for numeric strings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html#cfn-quicksight-dashboard-stringformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.StringParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class StringParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.StringDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.StringValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``String`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnDashboard.StringParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_parameter_declaration_property = quicksight.CfnDashboard.StringParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDashboard.StringDefaultValuesProperty(
                        dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__73e1bebdac2fcac54ecdf8016957ccdb36a76fb284d61326c36f50733765b6e1)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MappedDataSetParameterProperty"]]]]:
            '''``CfnDashboard.StringParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.StringValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.StringParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class StringParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Sequence[builtins.str],
        ) -> None:
            '''A string parameter.

            :param name: A display name for a string parameter.
            :param values: The values of a string parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_parameter_property = quicksight.CfnDashboard.StringParameterProperty(
                    name="name",
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7b7899f4ea2e3384f878eb280858dcdad4fb98f2640dcbefe93dc1fb38a415ca)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for a string parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html#cfn-quicksight-dashboard-stringparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(self) -> typing.List[builtins.str]:
            '''The values of a string parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html#cfn-quicksight-dashboard-stringparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class StringValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_value_when_unset_configuration_property = quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a4bf27e670c8ab8cd9f5635000c051662867f0ef04756fe04852fbd7e2c83aa6)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-stringvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-stringvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.SubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "field_level": "fieldLevel",
            "field_level_options": "fieldLevelOptions",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class SubtotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            field_level: typing.Optional[builtins.str] = None,
            field_level_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableFieldSubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            metric_header_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The subtotal options.

            :param custom_label: The custom label string for the subtotal cells.
            :param field_level: The field level (all, custom, last) for the subtotal cells.
            :param field_level_options: The optional configuration of subtotal cells.
            :param metric_header_cell_style: The cell styling options for the subtotals of header cells.
            :param total_cell_style: The cell styling options for the subtotal cells.
            :param totals_visibility: The visibility configuration for the subtotal cells.
            :param value_cell_style: The cell styling options for the subtotals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                subtotal_options_property = quicksight.CfnDashboard.SubtotalOptionsProperty(
                    custom_label="customLabel",
                    field_level="fieldLevel",
                    field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                        field_id="fieldId"
                    )],
                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__32460144ac18c67b2500cc2cd71e36cc2a3562251c9206c47ee5af61d427bf23)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument field_level", value=field_level, expected_type=type_hints["field_level"])
                check_type(argname="argument field_level_options", value=field_level_options, expected_type=type_hints["field_level_options"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if field_level is not None:
                self._values["field_level"] = field_level
            if field_level_options is not None:
                self._values["field_level_options"] = field_level_options
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level(self) -> typing.Optional[builtins.str]:
            '''The field level (all, custom, last) for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-fieldlevel
            '''
            result = self._values.get("field_level")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableFieldSubtotalOptionsProperty"]]]]:
            '''The optional configuration of subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-fieldleveloptions
            '''
            result = self._values.get("field_level_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableFieldSubtotalOptionsProperty"]]]], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotals of header cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class TableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for the table.

            :param group_by: The group by field well for a pivot table. Values are grouped by group by fields.
            :param values: The values field well for a pivot table. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_aggregated_field_wells_property = quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4232af7bb85dfc7817677942d160a70d0992f7d41cbee4741d609846c5dca23b)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The group by field well for a pivot table.

            Values are grouped by group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html#cfn-quicksight-dashboard-tableaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html#cfn-quicksight-dashboard-tableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "style": "style", "thickness": "thickness"},
    )
    class TableBorderOptionsProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            style: typing.Optional[builtins.str] = None,
            thickness: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The border options for a table border.

            :param color: The color of a table border.
            :param style: The style (none, solid) of a table border.
            :param thickness: The thickness of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_border_options_property = quicksight.CfnDashboard.TableBorderOptionsProperty(
                    color="color",
                    style="style",
                    thickness=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__09230d2948bab176f44a736bdcf6e0f7d47521f8bb5a3685193c15b5b2cec1c2)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
                check_type(argname="argument thickness", value=thickness, expected_type=type_hints["thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if style is not None:
                self._values["style"] = style
            if thickness is not None:
                self._values["thickness"] = thickness

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style(self) -> typing.Optional[builtins.str]:
            '''The style (none, solid) of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thickness(self) -> typing.Optional[jsii.Number]:
            '''The thickness of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-thickness
            '''
            result = self._values.get("thickness")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "text_format": "textFormat"},
    )
    class TableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            text_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cell conditional formatting option for a table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_cell_conditional_formatting_property = quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e53c8a6faa417e001ef3a25750e4153c3596d230ce9baff48f52c24d053c58d)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html#cfn-quicksight-dashboard-tablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextConditionalFormatProperty"]]:
            '''The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html#cfn-quicksight-dashboard-tablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_cell_image_scaling_configuration": "tableCellImageScalingConfiguration",
        },
    )
    class TableCellImageSizingConfigurationProperty:
        def __init__(
            self,
            *,
            table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The sizing options for the table image configuration.

            :param table_cell_image_scaling_configuration: The cell scaling configuration of the sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellimagesizingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_cell_image_sizing_configuration_property = quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a538b287e3253f9343cc93d027c152ce6ccd42012aeb09ba4debb048c5db8d68)
                check_type(argname="argument table_cell_image_scaling_configuration", value=table_cell_image_scaling_configuration, expected_type=type_hints["table_cell_image_scaling_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_cell_image_scaling_configuration is not None:
                self._values["table_cell_image_scaling_configuration"] = table_cell_image_scaling_configuration

        @builtins.property
        def table_cell_image_scaling_configuration(
            self,
        ) -> typing.Optional[builtins.str]:
            '''The cell scaling configuration of the sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellimagesizingconfiguration.html#cfn-quicksight-dashboard-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
            '''
            result = self._values.get("table_cell_image_scaling_configuration")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellImageSizingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableCellStyleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "border": "border",
            "font_configuration": "fontConfiguration",
            "height": "height",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "text_wrap": "textWrap",
            "vertical_text_alignment": "verticalTextAlignment",
            "visibility": "visibility",
        },
    )
    class TableCellStyleProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GlobalTableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            height: typing.Optional[jsii.Number] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            text_wrap: typing.Optional[builtins.str] = None,
            vertical_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table cell style for a cell in pivot table or table visual.

            :param background_color: The background color for the table cells.
            :param border: The borders for the table cells.
            :param font_configuration: The font configuration of the table cells.
            :param height: The height color for the table cells.
            :param horizontal_text_alignment: The horizontal text alignment (left, center, right, auto) for the table cells.
            :param text_wrap: The text wrap (none, wrap) for the table cells.
            :param vertical_text_alignment: The vertical text alignment (top, middle, bottom) for the table cells.
            :param visibility: The visibility of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_cell_style_property = quicksight.CfnDashboard.TableCellStyleProperty(
                    background_color="backgroundColor",
                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    height=123,
                    horizontal_text_alignment="horizontalTextAlignment",
                    text_wrap="textWrap",
                    vertical_text_alignment="verticalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0387cbf1eeb05dd9e5eafd513d421a9a4037e9c827ed855a3a1e758d1ea11042)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument border", value=border, expected_type=type_hints["border"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument text_wrap", value=text_wrap, expected_type=type_hints["text_wrap"])
                check_type(argname="argument vertical_text_alignment", value=vertical_text_alignment, expected_type=type_hints["vertical_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if border is not None:
                self._values["border"] = border
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if height is not None:
                self._values["height"] = height
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if text_wrap is not None:
                self._values["text_wrap"] = text_wrap
            if vertical_text_alignment is not None:
                self._values["vertical_text_alignment"] = vertical_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''The background color for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GlobalTableBorderOptionsProperty"]]:
            '''The borders for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-border
            '''
            result = self._values.get("border")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GlobalTableBorderOptionsProperty"]], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]]:
            '''The font configuration of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]], result)

        @builtins.property
        def height(self) -> typing.Optional[jsii.Number]:
            '''The height color for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The horizontal text alignment (left, center, right, auto) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def text_wrap(self) -> typing.Optional[builtins.str]:
            '''The text wrap (none, wrap) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-textwrap
            '''
            result = self._values.get("text_wrap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The vertical text alignment (top, middle, bottom) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-verticaltextalignment
            '''
            result = self._values.get("vertical_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell", "row": "row"},
    )
    class TableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableRowConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a table.
            :param row: The row conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_conditional_formatting_option_property = quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    ),
                    row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c89c50a0239a5b86d4ae4d4ff3279d3daa673d5b3383db932c6aded416e5c1f4)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
                check_type(argname="argument row", value=row, expected_type=type_hints["row"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell
            if row is not None:
                self._values["row"] = row

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellConditionalFormattingProperty"]]:
            '''The cell conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html#cfn-quicksight-dashboard-tableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellConditionalFormattingProperty"]], result)

        @builtins.property
        def row(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableRowConditionalFormattingProperty"]]:
            '''The row conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html#cfn-quicksight-dashboard-tableconditionalformattingoption-row
            '''
            result = self._values.get("row")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableRowConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class TableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_conditional_formatting_property = quicksight.CfnDashboard.TableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        ),
                        row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f628cc2e0ef6dec361c6c34fe8b316d80322af1f12cf1c4b62dd56f5e752bc45)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformatting.html#cfn-quicksight-dashboard-tableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_inline_visualizations": "tableInlineVisualizations",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class TableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_report_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_inline_visualizations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableInlineVisualizationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            table_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``TableVisual`` .

            :param field_options: The field options for a table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a table visual.
            :param sort_configuration: The sort configuration for a ``TableVisual`` .
            :param table_inline_visualizations: A collection of inline visualizations to display within a chart.
            :param table_options: The table options for a table visual.
            :param total_options: The total options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_configuration_property = quicksight.CfnDashboard.TableConfigurationProperty(
                    field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                        order=["order"],
                        selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            custom_label="customLabel",
                            url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                    sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                    )
                                ),
                                link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                    content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                        custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                            icon="icon"
                                        ),
                                        custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            value="value"
                                        )
                                    ),
                                    target="target"
                                )
                            ),
                            visibility="visibility",
                            width="width"
                        )]
                    ),
                    field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                        table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                            values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                    date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                        vertical_overflow_visibility="verticalOverflowVisibility"
                    ),
                    sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                        pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                            page_number=123,
                            page_size=123
                        ),
                        row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                        data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            negative_color="negativeColor",
                            positive_color="positiveColor"
                        )
                    )],
                    table_options=quicksight.CfnDashboard.TableOptionsProperty(
                        cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        orientation="orientation",
                        row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                            row_alternate_colors=["rowAlternateColors"],
                            status="status"
                        )
                    ),
                    total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                        custom_label="customLabel",
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fa9f87c6d2b7059cc06f6b091f65851e6c96754cdceaaf0cd67277025424cf90)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_inline_visualizations", value=table_inline_visualizations, expected_type=type_hints["table_inline_visualizations"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_inline_visualizations is not None:
                self._values["table_inline_visualizations"] = table_inline_visualizations
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldOptionsProperty"]]:
            '''The field options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldWellsProperty"]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TablePaginatedReportOptionsProperty"]]:
            '''The paginated report options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TablePaginatedReportOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableSortConfigurationProperty"]]:
            '''The sort configuration for a ``TableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableSortConfigurationProperty"]], result)

        @builtins.property
        def table_inline_visualizations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableInlineVisualizationProperty"]]]]:
            '''A collection of inline visualizations to display within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-tableinlinevisualizations
            '''
            result = self._values.get("table_inline_visualizations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableInlineVisualizationProperty"]]]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableOptionsProperty"]]:
            '''The table options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableOptionsProperty"]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TotalOptionsProperty"]]:
            '''The total options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableFieldCustomIconContentProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon"},
    )
    class TableFieldCustomIconContentProperty:
        def __init__(self, *, icon: typing.Optional[builtins.str] = None) -> None:
            '''The custom icon content for the table link content configuration.

            :param icon: The icon set type (link) of the custom icon content for table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomiconcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_custom_icon_content_property = quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                    icon="icon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__41b359193fa1a0f0bee27cc10b6a79dbd80e4d1c07702e55cf8b6d50cbc1ff0f)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''The icon set type (link) of the custom icon content for table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomiconcontent.html#cfn-quicksight-dashboard-tablefieldcustomiconcontent-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomIconContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableFieldCustomTextContentProperty",
        jsii_struct_bases=[],
        name_mapping={"font_configuration": "fontConfiguration", "value": "value"},
    )
    class TableFieldCustomTextContentProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :param font_configuration: The font configuration of the custom text content for the table URL link content.
            :param value: The string value of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_custom_text_content_property = quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                
                    # the properties below are optional
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c8834fcbc2072daab606312687e5c87c6e9921b1bec4b767917bd93dc411b4d3)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "font_configuration": font_configuration,
            }
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"]:
            '''The font configuration of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html#cfn-quicksight-dashboard-tablefieldcustomtextcontent-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            assert result is not None, "Required property 'font_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FontConfigurationProperty"], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The string value of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html#cfn-quicksight-dashboard-tablefieldcustomtextcontent-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomTextContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableFieldImageConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"sizing_options": "sizingOptions"},
    )
    class TableFieldImageConfigurationProperty:
        def __init__(
            self,
            *,
            sizing_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellImageSizingConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The image configuration of a table field URL.

            :param sizing_options: The sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldimageconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_image_configuration_property = quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                    sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9138732cd6647b0d882b40c89d654f1b358cad8a04d430a99b5f830a2d629c40)
                check_type(argname="argument sizing_options", value=sizing_options, expected_type=type_hints["sizing_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sizing_options is not None:
                self._values["sizing_options"] = sizing_options

        @builtins.property
        def sizing_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellImageSizingConfigurationProperty"]]:
            '''The sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldimageconfiguration.html#cfn-quicksight-dashboard-tablefieldimageconfiguration-sizingoptions
            '''
            result = self._values.get("sizing_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellImageSizingConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldImageConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableFieldLinkConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"content": "content", "target": "target"},
    )
    class TableFieldLinkConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableFieldLinkContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            target: builtins.str,
        ) -> None:
            '''The link configuration of a table field URL.

            :param content: The URL content (text, icon) for the table link configuration.
            :param target: The URL target (new tab, new window, same tab) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_link_configuration_property = quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                    content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                        custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                            icon="icon"
                        ),
                        custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                
                            # the properties below are optional
                            value="value"
                        )
                    ),
                    target="target"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a71711eb13fd06de404b7c01ff20feea218d568093b09b13b6dfd14eb75c496c)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument target", value=target, expected_type=type_hints["target"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "target": target,
            }

        @builtins.property
        def content(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldLinkContentConfigurationProperty"]:
            '''The URL content (text, icon) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldLinkContentConfigurationProperty"], result)

        @builtins.property
        def target(self) -> builtins.str:
            '''The URL target (new tab, new window, same tab) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkconfiguration-target
            '''
            result = self._values.get("target")
            assert result is not None, "Required property 'target' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_icon_content": "customIconContent",
            "custom_text_content": "customTextContent",
        },
    )
    class TableFieldLinkContentConfigurationProperty:
        def __init__(
            self,
            *,
            custom_icon_content: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableFieldCustomIconContentProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_text_content: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableFieldCustomTextContentProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The URL content (text, icon) for the table link configuration.

            :param custom_icon_content: The custom icon content for the table link content configuration.
            :param custom_text_content: The custom text content (value, font configuration) for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_link_content_configuration_property = quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                    custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                        icon="icon"
                    ),
                    custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                
                        # the properties below are optional
                        value="value"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__324efe0b31d54ab9ee6fe3ea97269ee0734e2e3aa49b4219fec40eea53f6c619)
                check_type(argname="argument custom_icon_content", value=custom_icon_content, expected_type=type_hints["custom_icon_content"])
                check_type(argname="argument custom_text_content", value=custom_text_content, expected_type=type_hints["custom_text_content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_icon_content is not None:
                self._values["custom_icon_content"] = custom_icon_content
            if custom_text_content is not None:
                self._values["custom_text_content"] = custom_text_content

        @builtins.property
        def custom_icon_content(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldCustomIconContentProperty"]]:
            '''The custom icon content for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkcontentconfiguration-customiconcontent
            '''
            result = self._values.get("custom_icon_content")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldCustomIconContentProperty"]], result)

        @builtins.property
        def custom_text_content(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldCustomTextContentProperty"]]:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkcontentconfiguration-customtextcontent
            '''
            result = self._values.get("custom_text_content")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldCustomTextContentProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "url_styling": "urlStyling",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class TableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            url_styling: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableFieldURLConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a table field.

            :param field_id: The field ID for a table field.
            :param custom_label: The custom label for a table field.
            :param url_styling: The URL configuration for a table field.
            :param visibility: The visibility of a table field.
            :param width: The width for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_option_property = quicksight.CfnDashboard.TableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                        image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                            sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                            )
                        ),
                        link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                            content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                    icon="icon"
                                ),
                                custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    value="value"
                                )
                            ),
                            target="target"
                        )
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__97f349278b968dcd4327442e47afea23385a67b232a8a5d26b83ef802da296ae)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument url_styling", value=url_styling, expected_type=type_hints["url_styling"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if url_styling is not None:
                self._values["url_styling"] = url_styling
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def url_styling(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldURLConfigurationProperty"]]:
            '''The URL configuration for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-urlstyling
            '''
            result = self._values.get("url_styling")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldURLConfigurationProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "order": "order",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class TableFieldOptionsProperty:
        def __init__(
            self,
            *,
            order: typing.Optional[typing.Sequence[builtins.str]] = None,
            selected_field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field options for a table visual.

            :param order: The order of field IDs of the field options for a table visual.
            :param selected_field_options: The selected field options for the table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_options_property = quicksight.CfnDashboard.TableFieldOptionsProperty(
                    order=["order"],
                    selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                            image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                )
                            ),
                            link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                    custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                        icon="icon"
                                    ),
                                    custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        value="value"
                                    )
                                ),
                                target="target"
                            )
                        ),
                        visibility="visibility",
                        width="width"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__30c88b6b75a2cd95c5b4d04d305aaf5577ba01dd8108758443c69f8fac5e4a03)
                check_type(argname="argument order", value=order, expected_type=type_hints["order"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if order is not None:
                self._values["order"] = order
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def order(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The order of field IDs of the field options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html#cfn-quicksight-dashboard-tablefieldoptions-order
            '''
            result = self._values.get("order")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldOptionProperty"]]]]:
            '''The selected field options for the table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html#cfn-quicksight-dashboard-tablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableFieldURLConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "image_configuration": "imageConfiguration",
            "link_configuration": "linkConfiguration",
        },
    )
    class TableFieldURLConfigurationProperty:
        def __init__(
            self,
            *,
            image_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableFieldImageConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            link_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableFieldLinkConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The URL configuration for a table field.

            :param image_configuration: The image configuration of a table field URL.
            :param link_configuration: The link configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_uRLConfiguration_property = quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                    image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                        sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                        )
                    ),
                    link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                        content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                            custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                icon="icon"
                            ),
                            custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                
                                # the properties below are optional
                                value="value"
                            )
                        ),
                        target="target"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bbf7d8befe790448f950764aaed95eaf071bc724ab0c7988b33b63d01b8e69c8)
                check_type(argname="argument image_configuration", value=image_configuration, expected_type=type_hints["image_configuration"])
                check_type(argname="argument link_configuration", value=link_configuration, expected_type=type_hints["link_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if image_configuration is not None:
                self._values["image_configuration"] = image_configuration
            if link_configuration is not None:
                self._values["link_configuration"] = link_configuration

        @builtins.property
        def image_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldImageConfigurationProperty"]]:
            '''The image configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html#cfn-quicksight-dashboard-tablefieldurlconfiguration-imageconfiguration
            '''
            result = self._values.get("image_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldImageConfigurationProperty"]], result)

        @builtins.property
        def link_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldLinkConfigurationProperty"]]:
            '''The link configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html#cfn-quicksight-dashboard-tablefieldurlconfiguration-linkconfiguration
            '''
            result = self._values.get("link_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableFieldLinkConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldURLConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_aggregated_field_wells": "tableAggregatedFieldWells",
            "table_unaggregated_field_wells": "tableUnaggregatedFieldWells",
        },
    )
    class TableFieldWellsProperty:
        def __init__(
            self,
            *,
            table_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_unaggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells for a table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param table_aggregated_field_wells: The aggregated field well for the table.
            :param table_unaggregated_field_wells: The unaggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_wells_property = quicksight.CfnDashboard.TableFieldWellsProperty(
                    table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                        values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f7c677c4b8ab3f53457b2e128fa27878ba3a7fed7cabe54994fe9021c25b42a6)
                check_type(argname="argument table_aggregated_field_wells", value=table_aggregated_field_wells, expected_type=type_hints["table_aggregated_field_wells"])
                check_type(argname="argument table_unaggregated_field_wells", value=table_unaggregated_field_wells, expected_type=type_hints["table_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_aggregated_field_wells is not None:
                self._values["table_aggregated_field_wells"] = table_aggregated_field_wells
            if table_unaggregated_field_wells is not None:
                self._values["table_unaggregated_field_wells"] = table_unaggregated_field_wells

        @builtins.property
        def table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html#cfn-quicksight-dashboard-tablefieldwells-tableaggregatedfieldwells
            '''
            result = self._values.get("table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableAggregatedFieldWellsProperty"]], result)

        @builtins.property
        def table_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableUnaggregatedFieldWellsProperty"]]:
            '''The unaggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html#cfn-quicksight-dashboard-tablefieldwells-tableunaggregatedfieldwells
            '''
            result = self._values.get("table_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableUnaggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableInlineVisualizationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_bars": "dataBars"},
    )
    class TableInlineVisualizationProperty:
        def __init__(
            self,
            *,
            data_bars: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataBarsOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The inline visualization of a specific type to display within a chart.

            :param data_bars: The configuration of the inline visualization of the data bars within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableinlinevisualization.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_inline_visualization_property = quicksight.CfnDashboard.TableInlineVisualizationProperty(
                    data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        negative_color="negativeColor",
                        positive_color="positiveColor"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__35faea7aa261d9e615c7576966277505f175bf43227655da5281b9b8fdde3ab9)
                check_type(argname="argument data_bars", value=data_bars, expected_type=type_hints["data_bars"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_bars is not None:
                self._values["data_bars"] = data_bars

        @builtins.property
        def data_bars(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataBarsOptionsProperty"]]:
            '''The configuration of the inline visualization of the data bars within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableinlinevisualization.html#cfn-quicksight-dashboard-tableinlinevisualization-databars
            '''
            result = self._values.get("data_bars")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataBarsOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableInlineVisualizationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "header_style": "headerStyle",
            "orientation": "orientation",
            "row_alternate_color_options": "rowAlternateColorOptions",
        },
    )
    class TableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            orientation: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The table options for a table visual.

            :param cell_style: The table cell style of table cells.
            :param header_style: The table cell style of a table header.
            :param orientation: The orientation (vertical, horizontal) for a table.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_options_property = quicksight.CfnDashboard.TableOptionsProperty(
                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    orientation="orientation",
                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f651a59d41595350fc39b334832442cd43bd78c088f65b26187c4af284892127)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument header_style", value=header_style, expected_type=type_hints["header_style"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if header_style is not None:
                self._values["header_style"] = header_style
            if orientation is not None:
                self._values["orientation"] = orientation
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]]:
            '''The table cell style of table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def header_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]]:
            '''The table cell style of a table header.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-headerstyle
            '''
            result = self._values.get("header_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation (vertical, horizontal) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RowAlternateColorOptionsProperty"]]:
            '''The row alternate color options (widget status, row alternate colors) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RowAlternateColorOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class TablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a table visual.

            :param overflow_column_header_visibility: The visibility of repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_paginated_report_options_property = quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__db0d119747653f2e41071e4f92dbf07d09aad84793dd9fe74436ead6c4f447ec)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of repeating header rows on each page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html#cfn-quicksight-dashboard-tablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html#cfn-quicksight-dashboard-tablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableRowConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "text_color": "textColor",
        },
    )
    class TableRowConditionalFormattingProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting of a table row.

            :param background_color: The conditional formatting color (solid, gradient) of the background for a table row.
            :param text_color: The conditional formatting color (solid, gradient) of the text for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_row_conditional_formatting_property = quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac63757b4d1b1acfefeffe8e2aea68c11f3fff50de6102079b05995d37bc1588)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting color (solid, gradient) of the background for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html#cfn-quicksight-dashboard-tablerowconditionalformatting-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting color (solid, gradient) of the text for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html#cfn-quicksight-dashboard-tablerowconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableRowConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableSideBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "inner_horizontal": "innerHorizontal",
            "inner_vertical": "innerVertical",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class TableSideBorderOptionsProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inner_horizontal: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inner_vertical: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            left: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            right: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The side border options for a table.

            :param bottom: The table border options of the bottom border.
            :param inner_horizontal: The table border options of the inner horizontal border.
            :param inner_vertical: The table border options of the inner vertical border.
            :param left: The table border options of the left border.
            :param right: The table border options of the right border.
            :param top: The table border options of the top border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_side_border_options_property = quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f077d91fcee57a49418e37c68e20e72616b32ac692fe583593d5745b12c8ad7)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument inner_horizontal", value=inner_horizontal, expected_type=type_hints["inner_horizontal"])
                check_type(argname="argument inner_vertical", value=inner_vertical, expected_type=type_hints["inner_vertical"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if inner_horizontal is not None:
                self._values["inner_horizontal"] = inner_horizontal
            if inner_vertical is not None:
                self._values["inner_vertical"] = inner_vertical
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''The table border options of the bottom border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]], result)

        @builtins.property
        def inner_horizontal(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''The table border options of the inner horizontal border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-innerhorizontal
            '''
            result = self._values.get("inner_horizontal")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]], result)

        @builtins.property
        def inner_vertical(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''The table border options of the inner vertical border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-innervertical
            '''
            result = self._values.get("inner_vertical")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]], result)

        @builtins.property
        def left(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''The table border options of the left border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]], result)

        @builtins.property
        def right(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''The table border options of the right border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]], result)

        @builtins.property
        def top(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]]:
            '''The table border options of the top border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableBorderOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSideBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pagination_configuration": "paginationConfiguration",
            "row_sort": "rowSort",
        },
    )
    class TableSortConfigurationProperty:
        def __init__(
            self,
            *,
            pagination_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration for a ``TableVisual`` .

            :param pagination_configuration: The pagination configuration (page size, page number) for the table.
            :param row_sort: The field sort options for rows in the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_sort_configuration_property = quicksight.CfnDashboard.TableSortConfigurationProperty(
                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    ),
                    row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fac5ea5f39bfce15b2fd6480b14f210301b5272b83f0d66cc8146001f5dce6ff)
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
                check_type(argname="argument row_sort", value=row_sort, expected_type=type_hints["row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration
            if row_sort is not None:
                self._values["row_sort"] = row_sort

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PaginationConfigurationProperty"]]:
            '''The pagination configuration (page size, page number) for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html#cfn-quicksight-dashboard-tablesortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PaginationConfigurationProperty"]], result)

        @builtins.property
        def row_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The field sort options for rows in the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html#cfn-quicksight-dashboard-tablesortconfiguration-rowsort
            '''
            result = self._values.get("row_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class TableUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.UnaggregatedFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The unaggregated field well for the table.

            :param values: The values field well for a pivot table. Values are unaggregated for an unaggregated table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_unaggregated_field_wells_property = quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                    values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a6872f396e242381ae70e064097d6fd47efc7251aca186d3418424e63aa02661)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.UnaggregatedFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are unaggregated for an unaggregated table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableunaggregatedfieldwells.html#cfn-quicksight-dashboard-tableunaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.UnaggregatedFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_visual_property = quicksight.CfnDashboard.TableVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.TableConfigurationProperty(
                        field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                            order=["order"],
                            selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                custom_label="customLabel",
                                url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                    image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                        sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                        )
                                    ),
                                    link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                        content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                            custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                                icon="icon"
                                            ),
                                            custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                
                                                # the properties below are optional
                                                value="value"
                                            )
                                        ),
                                        target="target"
                                    )
                                ),
                                visibility="visibility",
                                width="width"
                            )]
                        ),
                        field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                            table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                                values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                        date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                            overflow_column_header_visibility="overflowColumnHeaderVisibility",
                            vertical_overflow_visibility="verticalOverflowVisibility"
                        ),
                        sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                            pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                page_number=123,
                                page_size=123
                            ),
                            row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                            data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                negative_color="negativeColor",
                                positive_color="positiveColor"
                            )
                        )],
                        table_options=quicksight.CfnDashboard.TableOptionsProperty(
                            cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            orientation="orientation",
                            row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                row_alternate_colors=["rowAlternateColors"],
                                status="status"
                            )
                        ),
                        total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                            custom_label="customLabel",
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility"
                        )
                    ),
                    conditional_formatting=quicksight.CfnDashboard.TableConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                            cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            ),
                            row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6ecd55a34fd01903a1b570f2c5c196e794a7f6cc2449b03759f2eddbd9abe92e)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableConditionalFormattingProperty"]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextAreaControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            placeholder_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param placeholder_options: The configuration of the placeholder options in a text area control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                text_area_control_display_options_property = quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b5fb5b4c2130308950137f6933afe605d257be2047c5215f3eb419b12e2ca9b2)
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextControlPlaceholderOptionsProperty"]]:
            '''The configuration of the placeholder options in a text area control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html#cfn-quicksight-dashboard-textareacontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextControlPlaceholderOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html#cfn-quicksight-dashboard-textareacontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextAreaControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TextConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "icon": "icon",
            "text_color": "textColor",
        },
    )
    class TextConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the text.

            :param background_color: The conditional formatting for the text background color.
            :param icon: The conditional formatting for the icon.
            :param text_color: The conditional formatting for the text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                text_conditional_format_property = quicksight.CfnDashboard.TextConditionalFormatProperty(
                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__86655a9bb96d9d00709c755824fe5e791cbbde111387c852d0eb54253ce08a5a)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting for the text background color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting for the icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting for the text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TextControlPlaceholderOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the placeholder options in a text control.

            :param visibility: The visibility configuration of the placeholder options in a text control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textcontrolplaceholderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                text_control_placeholder_options_property = quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d817a588d164b6a2ac690348b9a8f8ff3c9311334134cf30f159d636ac1d85bc)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the placeholder options in a text control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textcontrolplaceholderoptions.html#cfn-quicksight-dashboard-textcontrolplaceholderoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextControlPlaceholderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextFieldControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            placeholder_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param placeholder_options: The configuration of the placeholder options in a text field control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                text_field_control_display_options_property = quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7b0f2129e735e51df165e7d8ce03f8ed605871f06717e94142f33c64e05484c5)
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextControlPlaceholderOptionsProperty"]]:
            '''The configuration of the placeholder options in a text field control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html#cfn-quicksight-dashboard-textfieldcontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TextControlPlaceholderOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html#cfn-quicksight-dashboard-textfieldcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextFieldControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.ThousandSeparatorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"symbol": "symbol", "visibility": "visibility"},
    )
    class ThousandSeparatorOptionsProperty:
        def __init__(
            self,
            *,
            symbol: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the thousands separator configuration.

            :param symbol: Determines the thousands separator symbol.
            :param visibility: Determines the visibility of the thousands separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                thousand_separator_options_property = quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                    symbol="symbol",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4389251b914d88133c816e4c4e8462fe6c018b6f0256bfbfc1831751da8982ef)
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if symbol is not None:
                self._values["symbol"] = symbol
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the thousands separator symbol.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html#cfn-quicksight-dashboard-thousandseparatoroptions-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the thousands separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html#cfn-quicksight-dashboard-thousandseparatoroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThousandSeparatorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "lower_boundary": "lowerBoundary",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
        },
    )
    class TimeBasedForecastPropertiesProperty:
        def __init__(
            self,
            *,
            lower_boundary: typing.Optional[jsii.Number] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[jsii.Number] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The forecast properties setup of a forecast in the line chart.

            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``NULL`` : The input is set to ``NULL`` . - ``NON_NULL`` : The input is set to a custom value.
            :param upper_boundary: The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_based_forecast_properties_property = quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                    lower_boundary=123,
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality=123,
                    upper_boundary=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b3d7fbdaef66ca353a467880c67f9eb05ed6f58b4a86a41c49bfa6514004f7ac)
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[jsii.Number]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``NULL`` : The input is set to ``NULL`` .
            - ``NON_NULL`` : The input is set to a custom value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeBasedForecastPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TimeEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
            "value": "value",
        },
    )
    class TimeEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeEqualityFilter`` filters values that are equal to a given value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``Value`` .
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value: The value of a ``TimeEquality`` filter. This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_equality_filter_property = quicksight.CfnDashboard.TimeEqualityFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    parameter_name="parameterName",
                    time_granularity="timeGranularity",
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a4797787fde8335c1b83cfd4ea833196e319a04d7ce5c32a02784abb1be474c)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
            }
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``Value`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The value of a ``TimeEquality`` filter.

            This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            range_maximum: builtins.str,
            range_minimum: builtins.str,
            time_granularity: builtins.str,
        ) -> None:
            '''The time range drill down filter.

            :param column: The column that the filter is applied to.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_range_drill_down_filter_property = quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    range_maximum="rangeMaximum",
                    range_minimum="rangeMinimum",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d734946be06edbc08cf9adb841371548ec9016b664f125ffc777775f6da28d38)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "range_maximum": range_maximum,
                "range_minimum": range_minimum,
                "time_granularity": time_granularity,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def range_maximum(self) -> builtins.str:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            assert result is not None, "Required property 'range_maximum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def range_minimum(self) -> builtins.str:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            assert result is not None, "Required property 'range_minimum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TimeRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum_value": "rangeMaximumValue",
            "range_minimum_value": "rangeMinimumValue",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            range_maximum_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_minimum_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeRangeFilter`` filters values that are between two specified values.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param exclude_period_configuration: The exclude period of the time range filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum_value: The maximum value for the filter value range.
            :param range_minimum_value: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_range_filter_property = quicksight.CfnDashboard.TimeRangeFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__38fefdcb0920652715bc4930da59005958690a04253fed9997d72f8261d453be)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum_value", value=range_maximum_value, expected_type=type_hints["range_maximum_value"])
                check_type(argname="argument range_minimum_value", value=range_minimum_value, expected_type=type_hints["range_minimum_value"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum_value is not None:
                self._values["range_maximum_value"] = range_maximum_value
            if range_minimum_value is not None:
                self._values["range_minimum_value"] = range_minimum_value
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ExcludePeriodConfigurationProperty"]]:
            '''The exclude period of the time range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ExcludePeriodConfigurationProperty"]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def range_maximum_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TimeRangeFilterValueProperty"]]:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-rangemaximumvalue
            '''
            result = self._values.get("range_maximum_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TimeRangeFilterValueProperty"]], result)

        @builtins.property
        def range_minimum_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TimeRangeFilterValueProperty"]]:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-rangeminimumvalue
            '''
            result = self._values.get("range_minimum_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TimeRangeFilterValueProperty"]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TimeRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter": "parameter",
            "rolling_date": "rollingDate",
            "static_value": "staticValue",
        },
    )
    class TimeRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            rolling_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value of a time range filter.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param parameter: The parameter type input value.
            :param rolling_date: The rolling date input value.
            :param static_value: The static input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_range_filter_value_property = quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                    parameter="parameter",
                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_value="staticValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__76fa1292bb6963cb633bb10bdd7494f82119e7fd7ea99c30992078a79a4b00ec)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter type input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RollingDateConfigurationProperty"]]:
            '''The rolling date input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def static_value(self) -> typing.Optional[builtins.str]:
            '''The static input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_tooltip_item": "columnTooltipItem",
            "field_tooltip_item": "fieldTooltipItem",
        },
    )
    class TooltipItemProperty:
        def __init__(
            self,
            *,
            column_tooltip_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnTooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_tooltip_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldTooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The tooltip.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param column_tooltip_item: The tooltip item for the columns that are not part of a field well.
            :param field_tooltip_item: The tooltip item for the fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tooltip_item_property = quicksight.CfnDashboard.TooltipItemProperty(
                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        label="label",
                        visibility="visibility"
                    ),
                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        label="label",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__741b197cc761f1a08cd066715d7e5eef2bf1831fa75d4a1af705d8aef3f426b1)
                check_type(argname="argument column_tooltip_item", value=column_tooltip_item, expected_type=type_hints["column_tooltip_item"])
                check_type(argname="argument field_tooltip_item", value=field_tooltip_item, expected_type=type_hints["field_tooltip_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_tooltip_item is not None:
                self._values["column_tooltip_item"] = column_tooltip_item
            if field_tooltip_item is not None:
                self._values["field_tooltip_item"] = field_tooltip_item

        @builtins.property
        def column_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnTooltipItemProperty"]]:
            '''The tooltip item for the columns that are not part of a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html#cfn-quicksight-dashboard-tooltipitem-columntooltipitem
            '''
            result = self._values.get("column_tooltip_item")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnTooltipItemProperty"]], result)

        @builtins.property
        def field_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldTooltipItemProperty"]]:
            '''The tooltip item for the fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html#cfn-quicksight-dashboard-tooltipitem-fieldtooltipitem
            '''
            result = self._values.get("field_tooltip_item")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldTooltipItemProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TooltipOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_based_tooltip": "fieldBasedTooltip",
            "selected_tooltip_type": "selectedTooltipType",
            "tooltip_visibility": "tooltipVisibility",
        },
    )
    class TooltipOptionsProperty:
        def __init__(
            self,
            *,
            field_based_tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldBasedTooltipProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_tooltip_type: typing.Optional[builtins.str] = None,
            tooltip_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The display options for the visual tooltip.

            :param field_based_tooltip: The setup for the detailed tooltip. The tooltip setup is always saved. The display type is decided based on the tooltip type.
            :param selected_tooltip_type: The selected type for the tooltip. Choose one of the following options:. - ``BASIC`` : A basic tooltip. - ``DETAILED`` : A detailed tooltip.
            :param tooltip_visibility: Determines whether or not the tooltip is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tooltip_options_property = quicksight.CfnDashboard.TooltipOptionsProperty(
                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                        aggregation_visibility="aggregationVisibility",
                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                label="label",
                                visibility="visibility"
                            ),
                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                label="label",
                                visibility="visibility"
                            )
                        )],
                        tooltip_title_type="tooltipTitleType"
                    ),
                    selected_tooltip_type="selectedTooltipType",
                    tooltip_visibility="tooltipVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__50a4936666b6d09eedf7e061446f16ae7aea979459277e79b13c2de4f033ffaa)
                check_type(argname="argument field_based_tooltip", value=field_based_tooltip, expected_type=type_hints["field_based_tooltip"])
                check_type(argname="argument selected_tooltip_type", value=selected_tooltip_type, expected_type=type_hints["selected_tooltip_type"])
                check_type(argname="argument tooltip_visibility", value=tooltip_visibility, expected_type=type_hints["tooltip_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_based_tooltip is not None:
                self._values["field_based_tooltip"] = field_based_tooltip
            if selected_tooltip_type is not None:
                self._values["selected_tooltip_type"] = selected_tooltip_type
            if tooltip_visibility is not None:
                self._values["tooltip_visibility"] = tooltip_visibility

        @builtins.property
        def field_based_tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldBasedTooltipProperty"]]:
            '''The setup for the detailed tooltip.

            The tooltip setup is always saved. The display type is decided based on the tooltip type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-fieldbasedtooltip
            '''
            result = self._values.get("field_based_tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldBasedTooltipProperty"]], result)

        @builtins.property
        def selected_tooltip_type(self) -> typing.Optional[builtins.str]:
            '''The selected type for the tooltip. Choose one of the following options:.

            - ``BASIC`` : A basic tooltip.
            - ``DETAILED`` : A detailed tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-selectedtooltiptype
            '''
            result = self._values.get("selected_tooltip_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the tooltip is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-tooltipvisibility
            '''
            result = self._values.get("tooltip_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TopBottomFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_sort_configurations": "aggregationSortConfigurations",
            "column": "column",
            "filter_id": "filterId",
            "limit": "limit",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
        },
    )
    class TopBottomFilterProperty:
        def __init__(
            self,
            *,
            aggregation_sort_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AggregationSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            limit: typing.Optional[jsii.Number] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TopBottomFilter`` filters values that are at the top or the bottom.

            :param aggregation_sort_configurations: The aggregation and sort configuration of the top bottom filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param limit: The number of items to include in the top bottom filter results.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                top_bottom_filter_property = quicksight.CfnDashboard.TopBottomFilterProperty(
                    aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        sort_direction="sortDirection"
                    )],
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    limit=123,
                    parameter_name="parameterName",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d218be80d4f2886d7a7bde137e82babe3442434021260e45fab03000e6f433a8)
                check_type(argname="argument aggregation_sort_configurations", value=aggregation_sort_configurations, expected_type=type_hints["aggregation_sort_configurations"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_sort_configurations": aggregation_sort_configurations,
                "column": column,
                "filter_id": filter_id,
            }
            if limit is not None:
                self._values["limit"] = limit
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def aggregation_sort_configurations(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationSortConfigurationProperty"]]]:
            '''The aggregation and sort configuration of the top bottom filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-aggregationsortconfigurations
            '''
            result = self._values.get("aggregation_sort_configurations")
            assert result is not None, "Required property 'aggregation_sort_configurations' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AggregationSortConfigurationProperty"]]], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def limit(self) -> typing.Optional[jsii.Number]:
            '''The number of items to include in the top bottom filter results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-limit
            '''
            result = self._values.get("limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TopBottomMoversComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "time": "time",
            "type": "type",
            "mover_size": "moverSize",
            "name": "name",
            "sort_order": "sortOrder",
            "value": "value",
        },
    )
    class TopBottomMoversComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            type: builtins.str,
            mover_size: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            sort_order: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The top movers and bottom movers computation setup.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param type: The computation type. Choose from the following options:. - TOP: Top movers computation. - BOTTOM: Bottom movers computation.
            :param mover_size: The mover size setup of the top and bottom movers computation.
            :param name: The name of a computation.
            :param sort_order: The sort order setup of the top and bottom movers computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                top_bottom_movers_computation_property = quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                    category=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    type="type",
                
                    # the properties below are optional
                    mover_size=123,
                    name="name",
                    sort_order="sortOrder",
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f3f3e929c7e32cad867295b62641c8fadc6dfb5223a53fdd0b439f867763455)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument mover_size", value=mover_size, expected_type=type_hints["mover_size"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sort_order", value=sort_order, expected_type=type_hints["sort_order"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
                "time": time,
                "type": type,
            }
            if mover_size is not None:
                self._values["mover_size"] = mover_size
            if name is not None:
                self._values["name"] = name
            if sort_order is not None:
                self._values["sort_order"] = sort_order
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def category(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"], result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose from the following options:.

            - TOP: Top movers computation.
            - BOTTOM: Bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def mover_size(self) -> typing.Optional[jsii.Number]:
            '''The mover size setup of the top and bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-moversize
            '''
            result = self._values.get("mover_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_order(self) -> typing.Optional[builtins.str]:
            '''The sort order setup of the top and bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-sortorder
            '''
            result = self._values.get("sort_order")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomMoversComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TopBottomRankedComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "type": "type",
            "name": "name",
            "result_size": "resultSize",
            "value": "value",
        },
    )
    class TopBottomRankedComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            computation_id: builtins.str,
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            result_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The top ranked and bottom ranked computation configuration.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param type: The computation type. Choose one of the following options:. - TOP: A top ranked computation. - BOTTOM: A bottom ranked computation.
            :param name: The name of a computation.
            :param result_size: The result size of a top and bottom ranked computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                top_bottom_ranked_computation_property = quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                    category=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    result_size=123,
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3de31453d017b2641633ebd1e786e3ede9cb59e06ca82fc1bfceaebe586d45d7)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument result_size", value=result_size, expected_type=type_hints["result_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if result_size is not None:
                self._values["result_size"] = result_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def category(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose one of the following options:.

            - TOP: A top ranked computation.
            - BOTTOM: A bottom ranked computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def result_size(self) -> typing.Optional[jsii.Number]:
            '''The result size of a top and bottom ranked computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-resultsize
            '''
            result = self._values.get("result_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomRankedComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TotalAggregationComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "value": "value",
            "name": "name",
        },
    )
    class TotalAggregationComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total aggregation computation configuration.

            :param computation_id: The ID for a computation.
            :param value: The value field that is used in a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                total_aggregation_computation_property = quicksight.CfnDashboard.TotalAggregationComputationProperty(
                    computation_id="computationId",
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c0982dcf272f86829964a54f1f6033a586fb10f1f224629311404be2381ed3f2)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "value": value,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
        },
    )
    class TotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total options for a table visual.

            :param custom_label: The custom label string for the total cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_cell_style: Cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                total_options_property = quicksight.CfnDashboard.TotalOptionsProperty(
                    custom_label="customLabel",
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d4c99c30f8bc65960c70ff51133f0894e6f8c9fa5987f872477ae889db76fde)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]]:
            '''Cell styling options for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"colors": "colors", "groups": "groups", "sizes": "sizes"},
    )
    class TreeMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sizes: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Aggregated field wells of a tree map.

            :param colors: The color field well of a tree map. Values are grouped by aggregations based on group by fields.
            :param groups: The group by field well of a tree map. Values are grouped based on group by fields.
            :param sizes: The size field well of a tree map. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_aggregated_field_wells_property = quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                    colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fb28a429f0b96f25dc530ce96a592cd6fc4ffd1075674cd3db2b49fd8fffe5c5)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument groups", value=groups, expected_type=type_hints["groups"])
                check_type(argname="argument sizes", value=sizes, expected_type=type_hints["sizes"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if groups is not None:
                self._values["groups"] = groups
            if sizes is not None:
                self._values["sizes"] = sizes

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The color field well of a tree map.

            Values are grouped by aggregations based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        @builtins.property
        def groups(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The group by field well of a tree map.

            Values are grouped based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-groups
            '''
            result = self._values.get("groups")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def sizes(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The size field well of a tree map.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-sizes
            '''
            result = self._values.get("sizes")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TreeMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_label_options": "colorLabelOptions",
            "color_scale": "colorScale",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "group_label_options": "groupLabelOptions",
            "legend": "legend",
            "size_label_options": "sizeLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class TreeMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TreeMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            group_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            size_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TreeMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a tree map.

            :param color_label_options: The label options (label text, label visibility) for the colors displayed in a tree map.
            :param color_scale: The color options (gradient color, point of divergence) of a tree map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param group_label_options: The label options (label text, label visibility) of the groups that are displayed in a tree map.
            :param legend: The legend display setup of the visual.
            :param size_label_options: The label options (label text, label visibility) of the sizes that are displayed in a tree map.
            :param sort_configuration: The sort configuration of a tree map.
            :param tooltip: The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_configuration_property = quicksight.CfnDashboard.TreeMapConfigurationProperty(
                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                        color_fill_type="colorFillType",
                        colors=[quicksight.CfnDashboard.DataColorProperty(
                            color="color",
                            data_value=123
                        )],
                
                        # the properties below are optional
                        null_value_color=quicksight.CfnDashboard.DataColorProperty(
                            color="color",
                            data_value=123
                        )
                    ),
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                        tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                            colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                        tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5539543240d8d04372eb0f7d1cc77e5ae44ef66561a2b1c438f096e067df8ece)
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument group_label_options", value=group_label_options, expected_type=type_hints["group_label_options"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument size_label_options", value=size_label_options, expected_type=type_hints["size_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if group_label_options is not None:
                self._values["group_label_options"] = group_label_options
            if legend is not None:
                self._values["legend"] = legend
            if size_label_options is not None:
                self._values["size_label_options"] = size_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) for the colors displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColorScaleProperty"]]:
            '''The color options (gradient color, point of divergence) of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColorScaleProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TreeMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TreeMapFieldWellsProperty"]], result)

        @builtins.property
        def group_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) of the groups that are displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-grouplabeloptions
            '''
            result = self._values.get("group_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def size_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) of the sizes that are displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-sizelabeloptions
            '''
            result = self._values.get("size_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TreeMapSortConfigurationProperty"]]:
            '''The sort configuration of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TreeMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TooltipOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TreeMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_aggregated_field_wells": "treeMapAggregatedFieldWells",
        },
    )
    class TreeMapFieldWellsProperty:
        def __init__(
            self,
            *,
            tree_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TreeMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a tree map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param tree_map_aggregated_field_wells: The aggregated field wells of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_field_wells_property = quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                    tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                        colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f764447de40e70d37c628f758a7dc071eb3c650acda17c217ed8fd8d60e0c67c)
                check_type(argname="argument tree_map_aggregated_field_wells", value=tree_map_aggregated_field_wells, expected_type=type_hints["tree_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_aggregated_field_wells is not None:
                self._values["tree_map_aggregated_field_wells"] = tree_map_aggregated_field_wells

        @builtins.property
        def tree_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TreeMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapfieldwells.html#cfn-quicksight-dashboard-treemapfieldwells-treemapaggregatedfieldwells
            '''
            result = self._values.get("tree_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TreeMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TreeMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_group_items_limit_configuration": "treeMapGroupItemsLimitConfiguration",
            "tree_map_sort": "treeMapSort",
        },
    )
    class TreeMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            tree_map_group_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tree_map_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a tree map.

            :param tree_map_group_items_limit_configuration: The limit on the number of groups that are displayed.
            :param tree_map_sort: The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_sort_configuration_property = quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                    tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5acc257bf941d7b412243b3d8ea35034943d00f7c17c94d9fcc84604c58ee04)
                check_type(argname="argument tree_map_group_items_limit_configuration", value=tree_map_group_items_limit_configuration, expected_type=type_hints["tree_map_group_items_limit_configuration"])
                check_type(argname="argument tree_map_sort", value=tree_map_sort, expected_type=type_hints["tree_map_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_group_items_limit_configuration is not None:
                self._values["tree_map_group_items_limit_configuration"] = tree_map_group_items_limit_configuration
            if tree_map_sort is not None:
                self._values["tree_map_sort"] = tree_map_sort

        @builtins.property
        def tree_map_group_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of groups that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html#cfn-quicksight-dashboard-treemapsortconfiguration-treemapgroupitemslimitconfiguration
            '''
            result = self._values.get("tree_map_group_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def tree_map_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html#cfn-quicksight-dashboard-treemapsortconfiguration-treemapsort
            '''
            result = self._values.get("tree_map_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TreeMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TreeMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TreeMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_visual_property = quicksight.CfnDashboard.TreeMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.TreeMapConfigurationProperty(
                        color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                            color_fill_type="colorFillType",
                            colors=[quicksight.CfnDashboard.DataColorProperty(
                                color="color",
                                data_value=123
                            )],
                
                            # the properties below are optional
                            null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                color="color",
                                data_value=123
                            )
                        ),
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                            tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                                colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                            tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c56525612f55c1f0c8c4edecc14a1687c54d28388ae1030e28e805e9a1702c74)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TreeMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TreeMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.TrendArrowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TrendArrowOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :param visibility: The visibility of the trend arrows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-trendarrowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                trend_arrow_options_property = quicksight.CfnDashboard.TrendArrowOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fdc21175c8c06eaa877b5f6ca2506c1618914003cc27d406312a3dee9cbb97da)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the trend arrows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-trendarrowoptions.html#cfn-quicksight-dashboard-trendarrowoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TrendArrowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.UnaggregatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
        },
    )
    class UnaggregatedFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The unaggregated field for a table.

            :param column: The column that is used in the ``UnaggregatedField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                unaggregated_field_property = quicksight.CfnDashboard.UnaggregatedFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8390674c47fca9d1737968aa136c63a31ecf4b8b40aceb8f187ccc6f5f219bc5)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"]:
            '''The column that is used in the ``UnaggregatedField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UnaggregatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.UniqueValuesComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "name": "name",
        },
    )
    class UniqueValuesComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The unique values computation configuration.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                unique_values_computation_property = quicksight.CfnDashboard.UniqueValuesComputationProperty(
                    category=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d7f9b20a38922afdd0b6946675c62f0a6bf8dddee811cca96798237cb6237cb9)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def category(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UniqueValuesComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.VisibleRangeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"percent_range": "percentRange"},
    )
    class VisibleRangeOptionsProperty:
        def __init__(
            self,
            *,
            percent_range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PercentVisibleRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The range options for the data zoom scroll bar.

            :param percent_range: The percent range in the visible range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visiblerangeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visible_range_options_property = quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                        from=123,
                        to=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__38e0a2ad5674e67bef9cbaf25875f9297a9ccf6b13974f9b3ea58bb976abe490)
                check_type(argname="argument percent_range", value=percent_range, expected_type=type_hints["percent_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percent_range is not None:
                self._values["percent_range"] = percent_range

        @builtins.property
        def percent_range(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PercentVisibleRangeProperty"]]:
            '''The percent range in the visible range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visiblerangeoptions.html#cfn-quicksight-dashboard-visiblerangeoptions-percentrange
            '''
            result = self._values.get("percent_range")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PercentVisibleRangeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisibleRangeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.VisualAxisSortOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class VisualAxisSortOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The axis sort options for a visual.

            :param availability_status: The availaiblity status of a visual's axis sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualaxissortoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_axis_sort_option_property = quicksight.CfnDashboard.VisualAxisSortOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__63f17db86a1778adb93937b159dbb1a06769ea47f41181dff93db4370cf671aa)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The availaiblity status of a visual's axis sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualaxissortoption.html#cfn-quicksight-dashboard-visualaxissortoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualAxisSortOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.VisualCustomActionOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_operation": "filterOperation",
            "navigation_operation": "navigationOperation",
            "set_parameters_operation": "setParametersOperation",
            "url_operation": "urlOperation",
        },
    )
    class VisualCustomActionOperationProperty:
        def __init__(
            self,
            *,
            filter_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CustomActionFilterOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            navigation_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CustomActionNavigationOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            set_parameters_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CustomActionSetParametersOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            url_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CustomActionURLOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The operation that is defined by the custom action.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filter_operation: The filter operation that filters data included in a visual or in an entire sheet.
            :param navigation_operation: The navigation operation that navigates between different sheets in the same analysis.
            :param set_parameters_operation: The set parameter operation that sets parameters in custom action.
            :param url_operation: The URL operation that opens a link to another webpage.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_custom_action_operation_property = quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                            selected_field_options="selectedFieldOptions",
                            selected_fields=["selectedFields"]
                        ),
                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                target_visual_options="targetVisualOptions",
                                target_visuals=["targetVisuals"]
                            )
                        )
                    ),
                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                            target_sheet_id="targetSheetId"
                        )
                    ),
                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                            destination_parameter_name="destinationParameterName",
                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                        date_time_values=["dateTimeValues"],
                                        decimal_values=[123],
                                        integer_values=[123],
                                        string_values=["stringValues"]
                                    ),
                
                                    # the properties below are optional
                                    include_null_value=False
                                ),
                                select_all_value_options="selectAllValueOptions",
                                source_field="sourceField",
                                source_parameter_name="sourceParameterName"
                            )
                        )]
                    ),
                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                        url_target="urlTarget",
                        url_template="urlTemplate"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6ee4b1b2a27cd7697dc276310fb9b2456719939802409181fd5b23ecf6629b85)
                check_type(argname="argument filter_operation", value=filter_operation, expected_type=type_hints["filter_operation"])
                check_type(argname="argument navigation_operation", value=navigation_operation, expected_type=type_hints["navigation_operation"])
                check_type(argname="argument set_parameters_operation", value=set_parameters_operation, expected_type=type_hints["set_parameters_operation"])
                check_type(argname="argument url_operation", value=url_operation, expected_type=type_hints["url_operation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filter_operation is not None:
                self._values["filter_operation"] = filter_operation
            if navigation_operation is not None:
                self._values["navigation_operation"] = navigation_operation
            if set_parameters_operation is not None:
                self._values["set_parameters_operation"] = set_parameters_operation
            if url_operation is not None:
                self._values["url_operation"] = url_operation

        @builtins.property
        def filter_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomActionFilterOperationProperty"]]:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-filteroperation
            '''
            result = self._values.get("filter_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomActionFilterOperationProperty"]], result)

        @builtins.property
        def navigation_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomActionNavigationOperationProperty"]]:
            '''The navigation operation that navigates between different sheets in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-navigationoperation
            '''
            result = self._values.get("navigation_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomActionNavigationOperationProperty"]], result)

        @builtins.property
        def set_parameters_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomActionSetParametersOperationProperty"]]:
            '''The set parameter operation that sets parameters in custom action.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-setparametersoperation
            '''
            result = self._values.get("set_parameters_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomActionSetParametersOperationProperty"]], result)

        @builtins.property
        def url_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomActionURLOperationProperty"]]:
            '''The URL operation that opens a link to another webpage.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-urloperation
            '''
            result = self._values.get("url_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomActionURLOperationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.VisualCustomActionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "action_operations": "actionOperations",
            "custom_action_id": "customActionId",
            "name": "name",
            "trigger": "trigger",
            "status": "status",
        },
    )
    class VisualCustomActionProperty:
        def __init__(
            self,
            *,
            action_operations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionOperationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            custom_action_id: builtins.str,
            name: builtins.str,
            trigger: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom action defined on a visual.

            :param action_operations: A list of ``VisualCustomActionOperations`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param custom_action_id: The ID of the ``VisualCustomAction`` .
            :param name: The name of the ``VisualCustomAction`` .
            :param trigger: The trigger of the ``VisualCustomAction`` . Valid values are defined as follows: - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point. - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.
            :param status: The status of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_custom_action_property = quicksight.CfnDashboard.VisualCustomActionProperty(
                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                selected_field_options="selectedFieldOptions",
                                selected_fields=["selectedFields"]
                            ),
                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                    target_visual_options="targetVisualOptions",
                                    target_visuals=["targetVisuals"]
                                )
                            )
                        ),
                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                target_sheet_id="targetSheetId"
                            )
                        ),
                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                destination_parameter_name="destinationParameterName",
                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                            date_time_values=["dateTimeValues"],
                                            decimal_values=[123],
                                            integer_values=[123],
                                            string_values=["stringValues"]
                                        ),
                
                                        # the properties below are optional
                                        include_null_value=False
                                    ),
                                    select_all_value_options="selectAllValueOptions",
                                    source_field="sourceField",
                                    source_parameter_name="sourceParameterName"
                                )
                            )]
                        ),
                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                            url_target="urlTarget",
                            url_template="urlTemplate"
                        )
                    )],
                    custom_action_id="customActionId",
                    name="name",
                    trigger="trigger",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb332f9a7ee79547c83dd4fa32eecedbc6dcfa7a682219e523df9e376dc91154)
                check_type(argname="argument action_operations", value=action_operations, expected_type=type_hints["action_operations"])
                check_type(argname="argument custom_action_id", value=custom_action_id, expected_type=type_hints["custom_action_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument trigger", value=trigger, expected_type=type_hints["trigger"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "action_operations": action_operations,
                "custom_action_id": custom_action_id,
                "name": name,
                "trigger": trigger,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def action_operations(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionOperationProperty"]]]:
            '''A list of ``VisualCustomActionOperations`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-actionoperations
            '''
            result = self._values.get("action_operations")
            assert result is not None, "Required property 'action_operations' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionOperationProperty"]]], result)

        @builtins.property
        def custom_action_id(self) -> builtins.str:
            '''The ID of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-customactionid
            '''
            result = self._values.get("custom_action_id")
            assert result is not None, "Required property 'custom_action_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def trigger(self) -> builtins.str:
            '''The trigger of the ``VisualCustomAction`` .

            Valid values are defined as follows:

            - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point.
            - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-trigger
            '''
            result = self._values.get("trigger")
            assert result is not None, "Required property 'trigger' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.VisualMenuOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class VisualMenuOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The menu options for a visual.

            :param availability_status: The availaiblity status of a visual's menu options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualmenuoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_menu_option_property = quicksight.CfnDashboard.VisualMenuOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__411879c5b4d62177901c623481811e12aeaa8b413c4463916432a0c33bd90344)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The availaiblity status of a visual's menu options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualmenuoption.html#cfn-quicksight-dashboard-visualmenuoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualMenuOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.VisualPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={"chart_color": "chartColor", "color_map": "colorMap"},
    )
    class VisualPaletteProperty:
        def __init__(
            self,
            *,
            chart_color: typing.Optional[builtins.str] = None,
            color_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataPathColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The visual display options for the visual palette.

            :param chart_color: The chart color options for the visual palette.
            :param color_map: The color map options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_palette_property = quicksight.CfnDashboard.VisualPaletteProperty(
                    chart_color="chartColor",
                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                        color="color",
                        element=quicksight.CfnDashboard.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        ),
                
                        # the properties below are optional
                        time_granularity="timeGranularity"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__453175ab972bb53876c5bbc8904e1e20556de33d2a61844606f24e988dc3fb0c)
                check_type(argname="argument chart_color", value=chart_color, expected_type=type_hints["chart_color"])
                check_type(argname="argument color_map", value=color_map, expected_type=type_hints["color_map"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if chart_color is not None:
                self._values["chart_color"] = chart_color
            if color_map is not None:
                self._values["color_map"] = color_map

        @builtins.property
        def chart_color(self) -> typing.Optional[builtins.str]:
            '''The chart color options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html#cfn-quicksight-dashboard-visualpalette-chartcolor
            '''
            result = self._values.get("chart_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def color_map(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPathColorProperty"]]]]:
            '''The color map options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html#cfn-quicksight-dashboard-visualpalette-colormap
            '''
            result = self._values.get("color_map")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataPathColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.VisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_visual": "barChartVisual",
            "box_plot_visual": "boxPlotVisual",
            "combo_chart_visual": "comboChartVisual",
            "custom_content_visual": "customContentVisual",
            "empty_visual": "emptyVisual",
            "filled_map_visual": "filledMapVisual",
            "funnel_chart_visual": "funnelChartVisual",
            "gauge_chart_visual": "gaugeChartVisual",
            "geospatial_map_visual": "geospatialMapVisual",
            "heat_map_visual": "heatMapVisual",
            "histogram_visual": "histogramVisual",
            "insight_visual": "insightVisual",
            "kpi_visual": "kpiVisual",
            "line_chart_visual": "lineChartVisual",
            "pie_chart_visual": "pieChartVisual",
            "pivot_table_visual": "pivotTableVisual",
            "radar_chart_visual": "radarChartVisual",
            "sankey_diagram_visual": "sankeyDiagramVisual",
            "scatter_plot_visual": "scatterPlotVisual",
            "table_visual": "tableVisual",
            "tree_map_visual": "treeMapVisual",
            "waterfall_visual": "waterfallVisual",
            "word_cloud_visual": "wordCloudVisual",
        },
    )
    class VisualProperty:
        def __init__(
            self,
            *,
            bar_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BarChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            box_plot_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.BoxPlotVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            combo_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ComboChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_content_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.CustomContentVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            empty_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.EmptyVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filled_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FilledMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            funnel_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FunnelChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            gauge_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GaugeChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            geospatial_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.GeospatialMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.HeatMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            histogram_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.HistogramVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            insight_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.InsightVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            kpi_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.KPIVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            line_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LineChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            pie_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PieChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            pivot_table_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.PivotTableVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            radar_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.RadarChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sankey_diagram_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.SankeyDiagramVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scatter_plot_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ScatterPlotVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TableVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tree_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.TreeMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            waterfall_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WaterfallVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            word_cloud_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WordCloudVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A visual displayed on a sheet in an analysis, dashboard, or template.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_visual: A bar chart. For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param box_plot_visual: A box plot. For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .
            :param combo_chart_visual: A combo chart. For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param custom_content_visual: A visual that contains custom content. For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param empty_visual: An empty visual.
            :param filled_map_visual: A filled map. For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param funnel_chart_visual: A funnel chart. For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param gauge_chart_visual: A gauge chart. For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param geospatial_map_visual: A geospatial map or a points on map visual. For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param heat_map_visual: A heat map. For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param histogram_visual: A histogram. For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param insight_visual: An insight visual. For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .
            :param kpi_visual: A key performance indicator (KPI). For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .
            :param line_chart_visual: A line chart. For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param pie_chart_visual: A pie or donut chart. For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param pivot_table_visual: A pivot table. For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .
            :param radar_chart_visual: A radar chart visual. For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param sankey_diagram_visual: A sankey diagram. For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .
            :param scatter_plot_visual: A scatter plot. For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .
            :param table_visual: A table visual. For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .
            :param tree_map_visual: A tree map. For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param waterfall_visual: A waterfall chart. For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param word_cloud_visual: A word cloud. For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                visual_property = quicksight.CfnDashboard.VisualProperty(
                    bar_chart_visual=quicksight.CfnDashboard.BarChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.BarChartConfigurationProperty(
                            bars_arrangement="barsArrangement",
                            category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                                bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            orientation="orientation",
                            reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    box_plot_visual=quicksight.CfnDashboard.BoxPlotVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                            box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                                all_data_points_visibility="allDataPointsVisibility",
                                outlier_visibility="outlierVisibility",
                                style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                                    fill_style="fillStyle"
                                )
                            ),
                            category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                                box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                    page_number=123,
                                    page_size=123
                                )
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    combo_chart_visual=quicksight.CfnDashboard.ComboChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.ComboChartConfigurationProperty(
                            bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            bars_arrangement="barsArrangement",
                            category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                                combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                                    bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    custom_content_visual=quicksight.CfnDashboard.CustomContentVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.CustomContentConfigurationProperty(
                            content_type="contentType",
                            content_url="contentUrl",
                            image_scaling="imageScaling"
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    empty_visual=quicksight.CfnDashboard.EmptyVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )]
                    ),
                    filled_map_visual=quicksight.CfnDashboard.FilledMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.FilledMapConfigurationProperty(
                            field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                                filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                                    geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                base_map_style="baseMapStyle"
                            ),
                            sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                    east=123,
                                    north=123,
                                    south=123,
                                    west=123
                                ),
                                map_zoom_mode="mapZoomMode"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        conditional_formatting=quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                                shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    funnel_chart_visual=quicksight.CfnDashboard.FunnelChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                label_color="labelColor",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_data_label_style="measureDataLabelStyle",
                                measure_label_visibility="measureLabelVisibility",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                                funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    gauge_chart_visual=quicksight.CfnDashboard.GaugeChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                                target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                                arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                                    arc_angle=123,
                                    arc_thickness="arcThickness"
                                ),
                                arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                                    range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                        max=123,
                                        min=123
                                    ),
                                    reserve_range=123
                                ),
                                comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                    comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    comparison_method="comparisonMethod"
                                ),
                                primary_value_display_type="primaryValueDisplayType",
                                primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            ),
                            tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        conditional_formatting=quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                                arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                                    foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                ),
                                primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    geospatial_map_visual=quicksight.CfnDashboard.GeospatialMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                            field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                                geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                base_map_style="baseMapStyle"
                            ),
                            point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                                cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                                    cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                        simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                            color="color"
                                        )
                                    )
                                ),
                                selected_point_style="selectedPointStyle"
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                    east=123,
                                    north=123,
                                    south=123,
                                    west=123
                                ),
                                map_zoom_mode="mapZoomMode"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    heat_map_visual=quicksight.CfnDashboard.HeatMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.HeatMapConfigurationProperty(
                            color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                color_fill_type="colorFillType",
                                colors=[quicksight.CfnDashboard.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )],
                
                                # the properties below are optional
                                null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )
                            ),
                            column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                                heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                                    columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                                heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    histogram_visual=quicksight.CfnDashboard.HistogramVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.HistogramConfigurationProperty(
                            bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                                bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                                    value=123
                                ),
                                bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                                    bin_count_limit=123,
                                    value=123
                                ),
                                selected_bin_type="selectedBinType",
                                start_value=123
                            ),
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                                histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            )
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    insight_visual=quicksight.CfnDashboard.InsightVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        insight_configuration=quicksight.CfnDashboard.InsightConfigurationProperty(
                            computations=[quicksight.CfnDashboard.ComputationProperty(
                                forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    custom_seasonality_value=123,
                                    lower_boundary=123,
                                    name="name",
                                    periods_backward=123,
                                    periods_forward=123,
                                    prediction_interval=123,
                                    seasonality="seasonality",
                                    upper_boundary=123,
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    period_size=123,
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    type="type",
                
                                    # the properties below are optional
                                    name="name",
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                                    computation_id="computationId",
                                    from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name"
                                ),
                                period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    period_time_granularity="periodTimeGranularity",
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                                    category=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    type="type",
                
                                    # the properties below are optional
                                    mover_size=123,
                                    name="name",
                                    sort_order="sortOrder",
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                                    category=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                                    type="type",
                
                                    # the properties below are optional
                                    name="name",
                                    result_size=123,
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                                    computation_id="computationId",
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name"
                                ),
                                unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                                    category=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                
                                    # the properties below are optional
                                    name="name"
                                )
                            )],
                            custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                                narrative="narrative"
                            )
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    kpi_visual=quicksight.CfnDashboard.KPIVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.KPIConfigurationProperty(
                            field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                                target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                                comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                    comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    comparison_method="comparisonMethod"
                                ),
                                primary_value_display_type="primaryValueDisplayType",
                                primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                                    visibility="visibility"
                                ),
                                secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                                    visibility="visibility"
                                ),
                                secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                                    visibility="visibility"
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                                trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        conditional_formatting=quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                                primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                ),
                                progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                                    foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    line_chart_visual=quicksight.CfnDashboard.LineChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.LineChartConfigurationProperty(
                            contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                                axis_binding="axisBinding",
                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            ),
                            field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                                line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                                forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                                    lower_boundary=123,
                                    periods_backward=123,
                                    periods_forward=123,
                                    prediction_interval=123,
                                    seasonality=123,
                                    upper_boundary=123
                                ),
                                scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                                    what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                        date="date",
                                        value=123
                                    ),
                                    what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                        end_date="endDate",
                                        start_date="startDate",
                                        value=123
                                    )
                                )
                            )],
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                    treatment_option="treatmentOption"
                                )]
                            ),
                            primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                    treatment_option="treatmentOption"
                                )]
                            ),
                            secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            series=[quicksight.CfnDashboard.SeriesItemProperty(
                                data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                                    axis_binding="axisBinding",
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    field_value="fieldValue",
                                    settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    )
                                ),
                                field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                                    axis_binding="axisBinding",
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    )
                                )
                            )],
                            small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                                category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            type="type",
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    pie_chart_visual=quicksight.CfnDashboard.PieChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.PieChartConfigurationProperty(
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                                arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                                    arc_thickness="arcThickness"
                                ),
                                donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                                    label_visibility="labelVisibility"
                                )
                            ),
                            field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                                pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    pivot_table_visual=quicksight.CfnDashboard.PivotTableVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.PivotTableConfigurationProperty(
                            field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                                data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                                    data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    )],
                
                                    # the properties below are optional
                                    width="width"
                                )],
                                selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    custom_label="customLabel",
                                    visibility="visibility"
                                )]
                            ),
                            field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                                pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                                    columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                                overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                vertical_overflow_visibility="verticalOverflowVisibility"
                            ),
                            sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                                field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                                    field_id="fieldId",
                                    sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                        column=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                            direction="direction",
                                            sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )]
                                        ),
                                        field=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )
                                )]
                            ),
                            table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                                cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                column_names_visibility="columnNamesVisibility",
                                metric_placement="metricPlacement",
                                row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                    row_alternate_colors=["rowAlternateColors"],
                                    status="status"
                                ),
                                row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                single_metric_visibility="singleMetricVisibility",
                                toggle_buttons_visibility="toggleButtonsVisibility"
                            ),
                            total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                                column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                    custom_label="customLabel",
                                    field_level="fieldLevel",
                                    field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                        field_id="fieldId"
                                    )],
                                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                    custom_label="customLabel",
                                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                    custom_label="customLabel",
                                    field_level="fieldLevel",
                                    field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                        field_id="fieldId"
                                    )],
                                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                    custom_label="customLabel",
                                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            )
                        ),
                        conditional_formatting=quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                                cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                        role="role"
                                    ),
                                    text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    radar_chart_visual=quicksight.CfnDashboard.RadarChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.RadarChartConfigurationProperty(
                            alternate_band_colors_visibility="alternateBandColorsVisibility",
                            alternate_band_even_color="alternateBandEvenColor",
                            alternate_band_odd_color="alternateBandOddColor",
                            base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                                area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                                    visibility="visibility"
                                )
                            ),
                            category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                                radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            shape="shape",
                            sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            start_angle=123,
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    sankey_diagram_visual=quicksight.CfnDashboard.SankeyDiagramVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                                sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                                    destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                                destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            )
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    scatter_plot_visual=quicksight.CfnDashboard.ScatterPlotVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                                scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                                    size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    table_visual=quicksight.CfnDashboard.TableVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.TableConfigurationProperty(
                            field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                                order=["order"],
                                selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    custom_label="customLabel",
                                    url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                        image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                            sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                            )
                                        ),
                                        link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                            content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                                custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                                    icon="icon"
                                                ),
                                                custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                
                                                    # the properties below are optional
                                                    value="value"
                                                )
                                            ),
                                            target="target"
                                        )
                                    ),
                                    visibility="visibility",
                                    width="width"
                                )]
                            ),
                            field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                                table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                                    values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                            date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                                overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                vertical_overflow_visibility="verticalOverflowVisibility"
                            ),
                            sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                                pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                    page_number=123,
                                    page_size=123
                                ),
                                row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                                data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    negative_color="negativeColor",
                                    positive_color="positiveColor"
                                )
                            )],
                            table_options=quicksight.CfnDashboard.TableOptionsProperty(
                                cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                orientation="orientation",
                                row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                    row_alternate_colors=["rowAlternateColors"],
                                    status="status"
                                )
                            ),
                            total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                                custom_label="customLabel",
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility"
                            )
                        ),
                        conditional_formatting=quicksight.CfnDashboard.TableConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                                cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                ),
                                row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    tree_map_visual=quicksight.CfnDashboard.TreeMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.TreeMapConfigurationProperty(
                            color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                color_fill_type="colorFillType",
                                colors=[quicksight.CfnDashboard.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )],
                
                                # the properties below are optional
                                null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )
                            ),
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                                tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                                    colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                                tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    waterfall_visual=quicksight.CfnDashboard.WaterfallVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                            category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                                waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                                    breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                                breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                                total_bar_label="totalBarLabel"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    word_cloud_visual=quicksight.CfnDashboard.WordCloudVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                                word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                                category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                                cloud_layout="cloudLayout",
                                maximum_string_length=123,
                                word_casing="wordCasing",
                                word_orientation="wordOrientation",
                                word_padding="wordPadding",
                                word_scaling="wordScaling"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ca6ee65e1fbae9a2dbe9305f3576cad15a9eb14418abefc50c443a1a695d8dab)
                check_type(argname="argument bar_chart_visual", value=bar_chart_visual, expected_type=type_hints["bar_chart_visual"])
                check_type(argname="argument box_plot_visual", value=box_plot_visual, expected_type=type_hints["box_plot_visual"])
                check_type(argname="argument combo_chart_visual", value=combo_chart_visual, expected_type=type_hints["combo_chart_visual"])
                check_type(argname="argument custom_content_visual", value=custom_content_visual, expected_type=type_hints["custom_content_visual"])
                check_type(argname="argument empty_visual", value=empty_visual, expected_type=type_hints["empty_visual"])
                check_type(argname="argument filled_map_visual", value=filled_map_visual, expected_type=type_hints["filled_map_visual"])
                check_type(argname="argument funnel_chart_visual", value=funnel_chart_visual, expected_type=type_hints["funnel_chart_visual"])
                check_type(argname="argument gauge_chart_visual", value=gauge_chart_visual, expected_type=type_hints["gauge_chart_visual"])
                check_type(argname="argument geospatial_map_visual", value=geospatial_map_visual, expected_type=type_hints["geospatial_map_visual"])
                check_type(argname="argument heat_map_visual", value=heat_map_visual, expected_type=type_hints["heat_map_visual"])
                check_type(argname="argument histogram_visual", value=histogram_visual, expected_type=type_hints["histogram_visual"])
                check_type(argname="argument insight_visual", value=insight_visual, expected_type=type_hints["insight_visual"])
                check_type(argname="argument kpi_visual", value=kpi_visual, expected_type=type_hints["kpi_visual"])
                check_type(argname="argument line_chart_visual", value=line_chart_visual, expected_type=type_hints["line_chart_visual"])
                check_type(argname="argument pie_chart_visual", value=pie_chart_visual, expected_type=type_hints["pie_chart_visual"])
                check_type(argname="argument pivot_table_visual", value=pivot_table_visual, expected_type=type_hints["pivot_table_visual"])
                check_type(argname="argument radar_chart_visual", value=radar_chart_visual, expected_type=type_hints["radar_chart_visual"])
                check_type(argname="argument sankey_diagram_visual", value=sankey_diagram_visual, expected_type=type_hints["sankey_diagram_visual"])
                check_type(argname="argument scatter_plot_visual", value=scatter_plot_visual, expected_type=type_hints["scatter_plot_visual"])
                check_type(argname="argument table_visual", value=table_visual, expected_type=type_hints["table_visual"])
                check_type(argname="argument tree_map_visual", value=tree_map_visual, expected_type=type_hints["tree_map_visual"])
                check_type(argname="argument waterfall_visual", value=waterfall_visual, expected_type=type_hints["waterfall_visual"])
                check_type(argname="argument word_cloud_visual", value=word_cloud_visual, expected_type=type_hints["word_cloud_visual"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_visual is not None:
                self._values["bar_chart_visual"] = bar_chart_visual
            if box_plot_visual is not None:
                self._values["box_plot_visual"] = box_plot_visual
            if combo_chart_visual is not None:
                self._values["combo_chart_visual"] = combo_chart_visual
            if custom_content_visual is not None:
                self._values["custom_content_visual"] = custom_content_visual
            if empty_visual is not None:
                self._values["empty_visual"] = empty_visual
            if filled_map_visual is not None:
                self._values["filled_map_visual"] = filled_map_visual
            if funnel_chart_visual is not None:
                self._values["funnel_chart_visual"] = funnel_chart_visual
            if gauge_chart_visual is not None:
                self._values["gauge_chart_visual"] = gauge_chart_visual
            if geospatial_map_visual is not None:
                self._values["geospatial_map_visual"] = geospatial_map_visual
            if heat_map_visual is not None:
                self._values["heat_map_visual"] = heat_map_visual
            if histogram_visual is not None:
                self._values["histogram_visual"] = histogram_visual
            if insight_visual is not None:
                self._values["insight_visual"] = insight_visual
            if kpi_visual is not None:
                self._values["kpi_visual"] = kpi_visual
            if line_chart_visual is not None:
                self._values["line_chart_visual"] = line_chart_visual
            if pie_chart_visual is not None:
                self._values["pie_chart_visual"] = pie_chart_visual
            if pivot_table_visual is not None:
                self._values["pivot_table_visual"] = pivot_table_visual
            if radar_chart_visual is not None:
                self._values["radar_chart_visual"] = radar_chart_visual
            if sankey_diagram_visual is not None:
                self._values["sankey_diagram_visual"] = sankey_diagram_visual
            if scatter_plot_visual is not None:
                self._values["scatter_plot_visual"] = scatter_plot_visual
            if table_visual is not None:
                self._values["table_visual"] = table_visual
            if tree_map_visual is not None:
                self._values["tree_map_visual"] = tree_map_visual
            if waterfall_visual is not None:
                self._values["waterfall_visual"] = waterfall_visual
            if word_cloud_visual is not None:
                self._values["word_cloud_visual"] = word_cloud_visual

        @builtins.property
        def bar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BarChartVisualProperty"]]:
            '''A bar chart.

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-barchartvisual
            '''
            result = self._values.get("bar_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BarChartVisualProperty"]], result)

        @builtins.property
        def box_plot_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotVisualProperty"]]:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-boxplotvisual
            '''
            result = self._values.get("box_plot_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.BoxPlotVisualProperty"]], result)

        @builtins.property
        def combo_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComboChartVisualProperty"]]:
            '''A combo chart.

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-combochartvisual
            '''
            result = self._values.get("combo_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ComboChartVisualProperty"]], result)

        @builtins.property
        def custom_content_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomContentVisualProperty"]]:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-customcontentvisual
            '''
            result = self._values.get("custom_content_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.CustomContentVisualProperty"]], result)

        @builtins.property
        def empty_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.EmptyVisualProperty"]]:
            '''An empty visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-emptyvisual
            '''
            result = self._values.get("empty_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.EmptyVisualProperty"]], result)

        @builtins.property
        def filled_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapVisualProperty"]]:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-filledmapvisual
            '''
            result = self._values.get("filled_map_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FilledMapVisualProperty"]], result)

        @builtins.property
        def funnel_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FunnelChartVisualProperty"]]:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-funnelchartvisual
            '''
            result = self._values.get("funnel_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FunnelChartVisualProperty"]], result)

        @builtins.property
        def gauge_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartVisualProperty"]]:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-gaugechartvisual
            '''
            result = self._values.get("gauge_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GaugeChartVisualProperty"]], result)

        @builtins.property
        def geospatial_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialMapVisualProperty"]]:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-geospatialmapvisual
            '''
            result = self._values.get("geospatial_map_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.GeospatialMapVisualProperty"]], result)

        @builtins.property
        def heat_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeatMapVisualProperty"]]:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-heatmapvisual
            '''
            result = self._values.get("heat_map_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HeatMapVisualProperty"]], result)

        @builtins.property
        def histogram_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HistogramVisualProperty"]]:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-histogramvisual
            '''
            result = self._values.get("histogram_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.HistogramVisualProperty"]], result)

        @builtins.property
        def insight_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.InsightVisualProperty"]]:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-insightvisual
            '''
            result = self._values.get("insight_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.InsightVisualProperty"]], result)

        @builtins.property
        def kpi_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIVisualProperty"]]:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-kpivisual
            '''
            result = self._values.get("kpi_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.KPIVisualProperty"]], result)

        @builtins.property
        def line_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartVisualProperty"]]:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-linechartvisual
            '''
            result = self._values.get("line_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LineChartVisualProperty"]], result)

        @builtins.property
        def pie_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PieChartVisualProperty"]]:
            '''A pie or donut chart.

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-piechartvisual
            '''
            result = self._values.get("pie_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PieChartVisualProperty"]], result)

        @builtins.property
        def pivot_table_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableVisualProperty"]]:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-pivottablevisual
            '''
            result = self._values.get("pivot_table_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.PivotTableVisualProperty"]], result)

        @builtins.property
        def radar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartVisualProperty"]]:
            '''A radar chart visual.

            For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-radarchartvisual
            '''
            result = self._values.get("radar_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.RadarChartVisualProperty"]], result)

        @builtins.property
        def sankey_diagram_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SankeyDiagramVisualProperty"]]:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-sankeydiagramvisual
            '''
            result = self._values.get("sankey_diagram_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.SankeyDiagramVisualProperty"]], result)

        @builtins.property
        def scatter_plot_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ScatterPlotVisualProperty"]]:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-scatterplotvisual
            '''
            result = self._values.get("scatter_plot_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ScatterPlotVisualProperty"]], result)

        @builtins.property
        def table_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableVisualProperty"]]:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-tablevisual
            '''
            result = self._values.get("table_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TableVisualProperty"]], result)

        @builtins.property
        def tree_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TreeMapVisualProperty"]]:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-treemapvisual
            '''
            result = self._values.get("tree_map_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.TreeMapVisualProperty"]], result)

        @builtins.property
        def waterfall_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WaterfallVisualProperty"]]:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-waterfallvisual
            '''
            result = self._values.get("waterfall_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WaterfallVisualProperty"]], result)

        @builtins.property
        def word_cloud_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WordCloudVisualProperty"]]:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-wordcloudvisual
            '''
            result = self._values.get("word_cloud_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WordCloudVisualProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualSubtitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LongFormatTextProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The subtitle label options for a visual.

            :param format_text: The long text format of the subtitle label, such as plain text or rich text.
            :param visibility: The visibility of the subtitle label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_subtitle_label_options_property = quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__71307cc2eb08b52fcaef79cd23ccf8a829c8e2f4d4f476e324c76d122ec0363a)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LongFormatTextProperty"]]:
            '''The long text format of the subtitle label, such as plain text or rich text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html#cfn-quicksight-dashboard-visualsubtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LongFormatTextProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the subtitle label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html#cfn-quicksight-dashboard-visualsubtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualSubtitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.VisualTitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualTitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ShortFormatTextProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The title label options for a visual.

            :param format_text: The short text format of the title label, such as plain text or rich text.
            :param visibility: The visibility of the title label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_title_label_options_property = quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cc5a4d621878252f0c90ceb29c65eedbecbad9e82d198fa0c46824d00f6673f7)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ShortFormatTextProperty"]]:
            '''The short text format of the title label, such as plain text or rich text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html#cfn-quicksight-dashboard-visualtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ShortFormatTextProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the title label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html#cfn-quicksight-dashboard-visualtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualTitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdowns": "breakdowns",
            "categories": "categories",
            "values": "values",
        },
    )
    class WaterfallChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            breakdowns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            categories: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param breakdowns: The breakdown field wells of a waterfall visual.
            :param categories: The category field wells of a waterfall visual.
            :param values: The value field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                waterfall_chart_aggregated_field_wells_property = quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                    breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__94b23983a945e5c5460da93385c080a39b3f5cc6b0bcd6aab582782968779cab)
                check_type(argname="argument breakdowns", value=breakdowns, expected_type=type_hints["breakdowns"])
                check_type(argname="argument categories", value=categories, expected_type=type_hints["categories"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdowns is not None:
                self._values["breakdowns"] = breakdowns
            if categories is not None:
                self._values["categories"] = categories
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def breakdowns(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The breakdown field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-breakdowns
            '''
            result = self._values.get("breakdowns")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def categories(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The category field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-categories
            '''
            result = self._values.get("categories")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The value field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WaterfallChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_axis_display_options": "categoryAxisDisplayOptions",
            "category_axis_label_options": "categoryAxisLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "visual_palette": "visualPalette",
            "waterfall_chart_options": "waterfallChartOptions",
        },
    )
    class WaterfallChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WaterfallChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WaterfallChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            waterfall_chart_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WaterfallChartOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a waterfall visual.

            :param category_axis_display_options: The options that determine the presentation of the category axis.
            :param category_axis_label_options: The options that determine the presentation of the category axis label.
            :param data_labels: The data label configuration of a waterfall visual.
            :param field_wells: The field well configuration of a waterfall visual.
            :param legend: The legend configuration of a waterfall visual.
            :param primary_y_axis_display_options: The options that determine the presentation of the y-axis.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param sort_configuration: The sort configuration of a waterfall visual.
            :param visual_palette: The visual palette configuration of a waterfall visual.
            :param waterfall_chart_options: The options that determine the presentation of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                waterfall_chart_configuration_property = quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                    category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                        waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                            breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                        breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                        total_bar_label="totalBarLabel"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f2e39f796b4d5efe0cf85ccded85d3787ff12ad4422a20ddf7fdafda5aa3c1c7)
                check_type(argname="argument category_axis_display_options", value=category_axis_display_options, expected_type=type_hints["category_axis_display_options"])
                check_type(argname="argument category_axis_label_options", value=category_axis_label_options, expected_type=type_hints["category_axis_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument waterfall_chart_options", value=waterfall_chart_options, expected_type=type_hints["waterfall_chart_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_axis_display_options is not None:
                self._values["category_axis_display_options"] = category_axis_display_options
            if category_axis_label_options is not None:
                self._values["category_axis_label_options"] = category_axis_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if waterfall_chart_options is not None:
                self._values["waterfall_chart_options"] = waterfall_chart_options

        @builtins.property
        def category_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the category axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-categoryaxisdisplayoptions
            '''
            result = self._values.get("category_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the category axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-categoryaxislabeloptions
            '''
            result = self._values.get("category_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]]:
            '''The data label configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WaterfallChartFieldWellsProperty"]]:
            '''The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WaterfallChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]]:
            '''The legend configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WaterfallChartSortConfigurationProperty"]]:
            '''The sort configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WaterfallChartSortConfigurationProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]]:
            '''The visual palette configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualPaletteProperty"]], result)

        @builtins.property
        def waterfall_chart_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WaterfallChartOptionsProperty"]]:
            '''The options that determine the presentation of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-waterfallchartoptions
            '''
            result = self._values.get("waterfall_chart_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WaterfallChartOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WaterfallChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "waterfall_chart_aggregated_field_wells": "waterfallChartAggregatedFieldWells",
        },
    )
    class WaterfallChartFieldWellsProperty:
        def __init__(
            self,
            *,
            waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WaterfallChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param waterfall_chart_aggregated_field_wells: The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                waterfall_chart_field_wells_property = quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                    waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                        breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3e1e1536e0502044923a7bb00d2207b092155324914a13d283b4af95c547c6e1)
                check_type(argname="argument waterfall_chart_aggregated_field_wells", value=waterfall_chart_aggregated_field_wells, expected_type=type_hints["waterfall_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if waterfall_chart_aggregated_field_wells is not None:
                self._values["waterfall_chart_aggregated_field_wells"] = waterfall_chart_aggregated_field_wells

        @builtins.property
        def waterfall_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WaterfallChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartfieldwells.html#cfn-quicksight-dashboard-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
            '''
            result = self._values.get("waterfall_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WaterfallChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WaterfallChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"total_bar_label": "totalBarLabel"},
    )
    class WaterfallChartOptionsProperty:
        def __init__(
            self,
            *,
            total_bar_label: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of a waterfall visual.

            :param total_bar_label: This option determines the total bar label of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                waterfall_chart_options_property = quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                    total_bar_label="totalBarLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__68f0e6f3b930c2e4dc9f161ef957a4557be781c457a5d2592b529acd754872e7)
                check_type(argname="argument total_bar_label", value=total_bar_label, expected_type=type_hints["total_bar_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if total_bar_label is not None:
                self._values["total_bar_label"] = total_bar_label

        @builtins.property
        def total_bar_label(self) -> typing.Optional[builtins.str]:
            '''This option determines the total bar label of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartoptions.html#cfn-quicksight-dashboard-waterfallchartoptions-totalbarlabel
            '''
            result = self._values.get("total_bar_label")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdown_items_limit": "breakdownItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WaterfallChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            breakdown_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a waterfall visual.

            :param breakdown_items_limit: The limit on the number of bar groups that are displayed.
            :param category_sort: The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                waterfall_chart_sort_configuration_property = quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                    breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1032239ee2123c174cf348f5651e9c82780602915c2681ba5c51008755141a45)
                check_type(argname="argument breakdown_items_limit", value=breakdown_items_limit, expected_type=type_hints["breakdown_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdown_items_limit is not None:
                self._values["breakdown_items_limit"] = breakdown_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def breakdown_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of bar groups that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html#cfn-quicksight-dashboard-waterfallchartsortconfiguration-breakdownitemslimit
            '''
            result = self._values.get("breakdown_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html#cfn-quicksight-dashboard-waterfallchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WaterfallVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WaterfallVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WaterfallChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a waterfall visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                waterfall_visual_property = quicksight.CfnDashboard.WaterfallVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                        category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                            waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                                breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                            breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                            total_bar_label="totalBarLabel"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5bf99ef8eb221a762bc001504748b5b5b1b1de8c4a78124fda5d3d4e8e04623c)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WaterfallChartConfigurationProperty"]]:
            '''The configuration for a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WaterfallChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WhatIfPointScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={"date": "date", "value": "value"},
    )
    class WhatIfPointScenarioProperty:
        def __init__(self, *, date: builtins.str, value: jsii.Number) -> None:
            '''Provides the forecast to meet the target for a particular date.

            :param date: The date that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                what_if_point_scenario_property = quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                    date="date",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__35306bbac6a3cc00fac0833c48aa7384fff9d17882a2cb4b0d6100bdd088bf6b)
                check_type(argname="argument date", value=date, expected_type=type_hints["date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "date": date,
                "value": value,
            }

        @builtins.property
        def date(self) -> builtins.str:
            '''The date that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html#cfn-quicksight-dashboard-whatifpointscenario-date
            '''
            result = self._values.get("date")
            assert result is not None, "Required property 'date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html#cfn-quicksight-dashboard-whatifpointscenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfPointScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WhatIfRangeScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "end_date": "endDate",
            "start_date": "startDate",
            "value": "value",
        },
    )
    class WhatIfRangeScenarioProperty:
        def __init__(
            self,
            *,
            end_date: builtins.str,
            start_date: builtins.str,
            value: jsii.Number,
        ) -> None:
            '''Provides the forecast to meet the target for a particular date range.

            :param end_date: The end date in the date range that you need the forecast results for.
            :param start_date: The start date in the date range that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                what_if_range_scenario_property = quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                    end_date="endDate",
                    start_date="startDate",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fb70978253d83e33fe234addb4f9be6221ef7ba5eff60ed7d0c7c57f401ec04b)
                check_type(argname="argument end_date", value=end_date, expected_type=type_hints["end_date"])
                check_type(argname="argument start_date", value=start_date, expected_type=type_hints["start_date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "end_date": end_date,
                "start_date": start_date,
                "value": value,
            }

        @builtins.property
        def end_date(self) -> builtins.str:
            '''The end date in the date range that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-enddate
            '''
            result = self._values.get("end_date")
            assert result is not None, "Required property 'end_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def start_date(self) -> builtins.str:
            '''The start date in the date range that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-startdate
            '''
            result = self._values.get("start_date")
            assert result is not None, "Required property 'start_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfRangeScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "size": "size"},
    )
    class WordCloudAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a word cloud.

            :param group_by: The group by field well of a word cloud. Values are grouped by group by fields.
            :param size: The size field well of a word cloud. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_aggregated_field_wells_property = quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f4f623199b3edb88b5a6da0281fdc764308963fdaf708e32c7920f1c76828e9e)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if size is not None:
                self._values["size"] = size

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]]:
            '''The group by field well of a word cloud.

            Values are grouped by group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html#cfn-quicksight-dashboard-wordcloudaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]]:
            '''The size field well of a word cloud.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html#cfn-quicksight-dashboard-wordcloudaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WordCloudChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "word_cloud_options": "wordCloudOptions",
        },
    )
    class WordCloudChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WordCloudFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WordCloudSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            word_cloud_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WordCloudOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a word cloud visual.

            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
            :param field_wells: The field wells of the visual.
            :param sort_configuration: The sort configuration of a word cloud visual.
            :param word_cloud_options: The options for a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_chart_configuration_property = quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                        word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                        cloud_layout="cloudLayout",
                        maximum_string_length=123,
                        word_casing="wordCasing",
                        word_orientation="wordOrientation",
                        word_padding="wordPadding",
                        word_scaling="wordScaling"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b4423f22ef8760ab432b08954070795b27f8653a8e44f9ef24cd1b288a3c77a2)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument word_cloud_options", value=word_cloud_options, expected_type=type_hints["word_cloud_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if word_cloud_options is not None:
                self._values["word_cloud_options"] = word_cloud_options

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) for the word cloud category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WordCloudFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WordCloudFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WordCloudSortConfigurationProperty"]]:
            '''The sort configuration of a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WordCloudSortConfigurationProperty"]], result)

        @builtins.property
        def word_cloud_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WordCloudOptionsProperty"]]:
            '''The options for a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-wordcloudoptions
            '''
            result = self._values.get("word_cloud_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WordCloudOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WordCloudFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "word_cloud_aggregated_field_wells": "wordCloudAggregatedFieldWells",
        },
    )
    class WordCloudFieldWellsProperty:
        def __init__(
            self,
            *,
            word_cloud_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WordCloudAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a word cloud visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param word_cloud_aggregated_field_wells: The aggregated field wells of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_field_wells_property = quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                    word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1e917bb6e0c79d74deb00b9f2f4195f36e8d2d27f4ab63de2ba1c90926cf60f7)
                check_type(argname="argument word_cloud_aggregated_field_wells", value=word_cloud_aggregated_field_wells, expected_type=type_hints["word_cloud_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if word_cloud_aggregated_field_wells is not None:
                self._values["word_cloud_aggregated_field_wells"] = word_cloud_aggregated_field_wells

        @builtins.property
        def word_cloud_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WordCloudAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudfieldwells.html#cfn-quicksight-dashboard-wordcloudfieldwells-wordcloudaggregatedfieldwells
            '''
            result = self._values.get("word_cloud_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WordCloudAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WordCloudOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cloud_layout": "cloudLayout",
            "maximum_string_length": "maximumStringLength",
            "word_casing": "wordCasing",
            "word_orientation": "wordOrientation",
            "word_padding": "wordPadding",
            "word_scaling": "wordScaling",
        },
    )
    class WordCloudOptionsProperty:
        def __init__(
            self,
            *,
            cloud_layout: typing.Optional[builtins.str] = None,
            maximum_string_length: typing.Optional[jsii.Number] = None,
            word_casing: typing.Optional[builtins.str] = None,
            word_orientation: typing.Optional[builtins.str] = None,
            word_padding: typing.Optional[builtins.str] = None,
            word_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The word cloud options for a word cloud visual.

            :param cloud_layout: The cloud layout options (fluid, normal) of a word cloud.
            :param maximum_string_length: The length limit of each word from 1-100.
            :param word_casing: The word casing options (lower_case, existing_case) for the words in a word cloud.
            :param word_orientation: The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
            :param word_padding: The word padding options (none, small, medium, large) for the words in a word cloud.
            :param word_scaling: The word scaling options (emphasize, normal) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_options_property = quicksight.CfnDashboard.WordCloudOptionsProperty(
                    cloud_layout="cloudLayout",
                    maximum_string_length=123,
                    word_casing="wordCasing",
                    word_orientation="wordOrientation",
                    word_padding="wordPadding",
                    word_scaling="wordScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fbad8b50c079132b521ad82f4c1022a67f3b526b160bcba5cc31714d634d459b)
                check_type(argname="argument cloud_layout", value=cloud_layout, expected_type=type_hints["cloud_layout"])
                check_type(argname="argument maximum_string_length", value=maximum_string_length, expected_type=type_hints["maximum_string_length"])
                check_type(argname="argument word_casing", value=word_casing, expected_type=type_hints["word_casing"])
                check_type(argname="argument word_orientation", value=word_orientation, expected_type=type_hints["word_orientation"])
                check_type(argname="argument word_padding", value=word_padding, expected_type=type_hints["word_padding"])
                check_type(argname="argument word_scaling", value=word_scaling, expected_type=type_hints["word_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cloud_layout is not None:
                self._values["cloud_layout"] = cloud_layout
            if maximum_string_length is not None:
                self._values["maximum_string_length"] = maximum_string_length
            if word_casing is not None:
                self._values["word_casing"] = word_casing
            if word_orientation is not None:
                self._values["word_orientation"] = word_orientation
            if word_padding is not None:
                self._values["word_padding"] = word_padding
            if word_scaling is not None:
                self._values["word_scaling"] = word_scaling

        @builtins.property
        def cloud_layout(self) -> typing.Optional[builtins.str]:
            '''The cloud layout options (fluid, normal) of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-cloudlayout
            '''
            result = self._values.get("cloud_layout")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def maximum_string_length(self) -> typing.Optional[jsii.Number]:
            '''The length limit of each word from 1-100.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-maximumstringlength
            '''
            result = self._values.get("maximum_string_length")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def word_casing(self) -> typing.Optional[builtins.str]:
            '''The word casing options (lower_case, existing_case) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordcasing
            '''
            result = self._values.get("word_casing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_orientation(self) -> typing.Optional[builtins.str]:
            '''The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordorientation
            '''
            result = self._values.get("word_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_padding(self) -> typing.Optional[builtins.str]:
            '''The word padding options (none, small, medium, large) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordpadding
            '''
            result = self._values.get("word_padding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_scaling(self) -> typing.Optional[builtins.str]:
            '''The word scaling options (emphasize, normal) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordscaling
            '''
            result = self._values.get("word_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WordCloudSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WordCloudSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a word cloud visual.

            :param category_items_limit: The limit on the number of groups that are displayed in a word cloud.
            :param category_sort: The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_sort_configuration_property = quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2db42bea1b63adf70edc7df9fafeab1155924f97464512a7128e1eb21629c85d)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of groups that are displayed in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html#cfn-quicksight-dashboard-wordcloudsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html#cfn-quicksight-dashboard-wordcloudsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDashboard.WordCloudVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WordCloudVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.WordCloudChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_visual_property = quicksight.CfnDashboard.WordCloudVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                            word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                            category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                            cloud_layout="cloudLayout",
                            maximum_string_length=123,
                            word_casing="wordCasing",
                            word_orientation="wordOrientation",
                            word_padding="wordPadding",
                            word_scaling="wordScaling"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6893d595258b35ca2601959ff1157114d6f0d510f1b678b362c3b1887507e658)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WordCloudChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.WordCloudChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDashboard.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="@aws-cdk/aws-quicksight.CfnDashboardProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "dashboard_id": "dashboardId",
        "name": "name",
        "dashboard_publish_options": "dashboardPublishOptions",
        "definition": "definition",
        "parameters": "parameters",
        "permissions": "permissions",
        "source_entity": "sourceEntity",
        "tags": "tags",
        "theme_arn": "themeArn",
        "version_description": "versionDescription",
    },
)
class CfnDashboardProps:
    def __init__(
        self,
        *,
        aws_account_id: builtins.str,
        dashboard_id: builtins.str,
        name: builtins.str,
        dashboard_publish_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DashboardPublishOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        definition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DashboardVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        source_entity: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DashboardSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
        theme_arn: typing.Optional[builtins.str] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnDashboard``.

        :param aws_account_id: The ID of the AWS account where you want to create the dashboard.
        :param dashboard_id: The ID for the dashboard, also added to the IAM policy.
        :param name: The display name of the dashboard.
        :param dashboard_publish_options: Options for publishing the dashboard when you create it:. - ``AvailabilityStatus`` for ``AdHocFilteringOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . When this is set to ``DISABLED`` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is ``ENABLED`` by default. - ``AvailabilityStatus`` for ``ExportToCSVOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . The visual option to export data to .CSV format isn't enabled when this is set to ``DISABLED`` . This option is ``ENABLED`` by default. - ``VisibilityState`` for ``SheetControlsOption`` - This visibility state can be either ``COLLAPSED`` or ``EXPANDED`` . This option is ``COLLAPSED`` by default.
        :param definition: ``AWS::QuickSight::Dashboard.Definition``.
        :param parameters: The parameters for the creation of the dashboard, which you want to use to override the default settings. A dashboard can have any type of parameters, and some parameters might accept multiple values.
        :param permissions: A structure that contains the permissions of the dashboard. You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN. To specify no permissions, omit the permissions list.
        :param source_entity: The entity that you are using as a source when you create the dashboard. In ``SourceEntity`` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a ``SourceTemplate`` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the ``CreateTemplate`` API operation. For ``SourceTemplate`` , specify the Amazon Resource Name (ARN) of the source template. The ``SourceTemplate`` ARN can contain any AWS account; and any QuickSight-supported AWS Region . Use the ``DataSetReferences`` entity within ``SourceTemplate`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.
        :param theme_arn: The Amazon Resource Name (ARN) of the theme that is being used for this dashboard. If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.
        :param version_description: A description for the first version of the dashboard being created.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            import aws_cdk.aws_quicksight as quicksight
            
            # data_driven: Any
            
            cfn_dashboard_props = quicksight.CfnDashboardProps(
                aws_account_id="awsAccountId",
                dashboard_id="dashboardId",
                name="name",
            
                # the properties below are optional
                dashboard_publish_options=quicksight.CfnDashboard.DashboardPublishOptionsProperty(
                    ad_hoc_filtering_option=quicksight.CfnDashboard.AdHocFilteringOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_drill_up_down_option=quicksight.CfnDashboard.DataPointDrillUpDownOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_menu_label_option=quicksight.CfnDashboard.DataPointMenuLabelOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_tooltip_option=quicksight.CfnDashboard.DataPointTooltipOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    export_to_csv_option=quicksight.CfnDashboard.ExportToCSVOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    export_with_hidden_fields_option=quicksight.CfnDashboard.ExportWithHiddenFieldsOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    sheet_controls_option=quicksight.CfnDashboard.SheetControlsOptionProperty(
                        visibility_state="visibilityState"
                    ),
                    sheet_layout_element_maximization_option=quicksight.CfnDashboard.SheetLayoutElementMaximizationOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_axis_sort_option=quicksight.CfnDashboard.VisualAxisSortOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_menu_option=quicksight.CfnDashboard.VisualMenuOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_publish_options=quicksight.CfnDashboard.DashboardVisualPublishOptionsProperty(
                        export_hidden_fields_option=quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty(
                            availability_status="availabilityStatus"
                        )
                    )
                ),
                definition=quicksight.CfnDashboard.DashboardVersionDefinitionProperty(
                    data_set_identifier_declarations=[quicksight.CfnDashboard.DataSetIdentifierDeclarationProperty(
                        data_set_arn="dataSetArn",
                        identifier="identifier"
                    )],
            
                    # the properties below are optional
                    analysis_defaults=quicksight.CfnDashboard.AnalysisDefaultsProperty(
                        default_new_sheet_configuration=quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty(
                            interactive_layout_configuration=quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                                free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            ),
                            paginated_layout_configuration=quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                                section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    )
                                )
                            ),
                            sheet_content_type="sheetContentType"
                        )
                    ),
                    calculated_fields=[quicksight.CfnDashboard.CalculatedFieldProperty(
                        data_set_identifier="dataSetIdentifier",
                        expression="expression",
                        name="name"
                    )],
                    column_configurations=[quicksight.CfnDashboard.ColumnConfigurationProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
            
                        # the properties below are optional
                        colors_configuration=quicksight.CfnDashboard.ColorsConfigurationProperty(
                            custom_colors=[quicksight.CfnDashboard.CustomColorProperty(
                                color="color",
            
                                # the properties below are optional
                                field_value="fieldValue",
                                special_value="specialValue"
                            )]
                        ),
                        format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        role="role"
                    )],
                    filter_groups=[quicksight.CfnDashboard.FilterGroupProperty(
                        cross_dataset="crossDataset",
                        filter_group_id="filterGroupId",
                        filters=[quicksight.CfnDashboard.FilterProperty(
                            category_filter=quicksight.CfnDashboard.CategoryFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                                    custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
            
                                        # the properties below are optional
                                        category_value="categoryValue",
                                        parameter_name="parameterName",
                                        select_all_options="selectAllOptions"
                                    ),
                                    custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
            
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    ),
                                    filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                                        match_operator="matchOperator",
            
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    )
                                ),
                                filter_id="filterId"
                            ),
                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                match_operator="matchOperator",
                                null_option="nullOption",
            
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions",
                                value=123
                            ),
                            numeric_range_filter=quicksight.CfnDashboard.NumericRangeFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
            
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                select_all_options="selectAllOptions"
                            ),
                            relative_dates_filter=quicksight.CfnDashboard.RelativeDatesFilterProperty(
                                anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                                    anchor_option="anchorOption",
                                    parameter_name="parameterName"
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                                relative_date_type="relativeDateType",
                                time_granularity="timeGranularity",
            
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
            
                                    # the properties below are optional
                                    status="status"
                                ),
                                minimum_granularity="minimumGranularity",
                                parameter_name="parameterName",
                                relative_date_value=123
                            ),
                            time_equality_filter=quicksight.CfnDashboard.TimeEqualityFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
            
                                # the properties below are optional
                                parameter_name="parameterName",
                                time_granularity="timeGranularity",
                                value="value"
                            ),
                            time_range_filter=quicksight.CfnDashboard.TimeRangeFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
            
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
            
                                    # the properties below are optional
                                    status="status"
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                        expression="expression",
            
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                        expression="expression",
            
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                time_granularity="timeGranularity"
                            ),
                            top_bottom_filter=quicksight.CfnDashboard.TopBottomFilterProperty(
                                aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    sort_direction="sortDirection"
                                )],
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
            
                                # the properties below are optional
                                limit=123,
                                parameter_name="parameterName",
                                time_granularity="timeGranularity"
                            )
                        )],
                        scope_configuration=quicksight.CfnDashboard.FilterScopeConfigurationProperty(
                            selected_sheets=quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                                sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                                    scope="scope",
                                    sheet_id="sheetId",
            
                                    # the properties below are optional
                                    visual_ids=["visualIds"]
                                )]
                            )
                        ),
            
                        # the properties below are optional
                        status="status"
                    )],
                    parameter_declarations=[quicksight.CfnDashboard.ParameterDeclarationProperty(
                        date_time_parameter_declaration=quicksight.CfnDashboard.DateTimeParameterDeclarationProperty(
                            name="name",
            
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
            
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            time_granularity="timeGranularity",
                            value_when_unset=quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        decimal_parameter_declaration=quicksight.CfnDashboard.DecimalParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        integer_parameter_declaration=quicksight.CfnDashboard.IntegerParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        string_parameter_declaration=quicksight.CfnDashboard.StringParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.StringDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        )
                    )],
                    sheets=[quicksight.CfnDashboard.SheetDefinitionProperty(
                        sheet_id="sheetId",
            
                        # the properties below are optional
                        content_type="contentType",
                        description="description",
                        filter_controls=[quicksight.CfnDashboard.FilterControlProperty(
                            date_time_picker=quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            dropdown=quicksight.CfnDashboard.FilterDropDownControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnDashboard.FilterListControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            relative_date_time=quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            slider=quicksight.CfnDashboard.FilterSliderControlProperty(
                                filter_control_id="filterControlId",
                                maximum_value=123,
                                minimum_value=123,
                                source_filter_id="sourceFilterId",
                                step_size=123,
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            text_area=quicksight.CfnDashboard.FilterTextAreaControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnDashboard.FilterTextFieldControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        layouts=[quicksight.CfnDashboard.LayoutProperty(
                            configuration=quicksight.CfnDashboard.LayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
            
                                        # the properties below are optional
                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
            
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                                    body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                                        content=quicksight.CfnDashboard.BodySectionContentProperty(
                                            layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                                free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                        element_id="elementId",
                                                        element_type="elementType",
                                                        height="height",
                                                        width="width",
                                                        x_axis_location="xAxisLocation",
                                                        y_axis_location="yAxisLocation",
            
                                                        # the properties below are optional
                                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                            visibility="visibility"
                                                        ),
                                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                                visibility="visibility"
                                                            ),
                                                            expression="expression"
                                                        )],
                                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        visibility="visibility"
                                                    )]
                                                )
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                            after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                                status="status"
                                            )
                                        ),
                                        style=quicksight.CfnDashboard.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    ),
                                    footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
            
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        style=quicksight.CfnDashboard.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
            
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        style=quicksight.CfnDashboard.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )]
                                )
                            )
                        )],
                        name="name",
                        parameter_controls=[quicksight.CfnDashboard.ParameterControlProperty(
                            date_time_picker=quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            dropdown=quicksight.CfnDashboard.ParameterDropDownControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnDashboard.ParameterListControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            slider=quicksight.CfnDashboard.ParameterSliderControlProperty(
                                maximum_value=123,
                                minimum_value=123,
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                step_size=123,
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_area=quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        sheet_control_layouts=[quicksight.CfnDashboard.SheetControlLayoutProperty(
                            configuration=quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                                grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
            
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            )
                        )],
                        text_boxes=[quicksight.CfnDashboard.SheetTextBoxProperty(
                            sheet_text_box_id="sheetTextBoxId",
            
                            # the properties below are optional
                            content="content"
                        )],
                        title="title",
                        visuals=[quicksight.CfnDashboard.VisualProperty(
                            bar_chart_visual=quicksight.CfnDashboard.BarChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.BarChartConfigurationProperty(
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                                        bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    orientation="orientation",
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            box_plot_visual=quicksight.CfnDashboard.BoxPlotVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                                    box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                                        all_data_points_visibility="allDataPointsVisibility",
                                        outlier_visibility="outlierVisibility",
                                        style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                                            fill_style="fillStyle"
                                        )
                                    ),
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                                        box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        )
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            combo_chart_visual=quicksight.CfnDashboard.ComboChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.ComboChartConfigurationProperty(
                                    bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                                        combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                                            bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            custom_content_visual=quicksight.CfnDashboard.CustomContentVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.CustomContentConfigurationProperty(
                                    content_type="contentType",
                                    content_url="contentUrl",
                                    image_scaling="imageScaling"
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            empty_visual=quicksight.CfnDashboard.EmptyVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )]
                            ),
                            filled_map_visual=quicksight.CfnDashboard.FilledMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.FilledMapConfigurationProperty(
                                    field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                                        filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                                            geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                                        shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            funnel_chart_visual=quicksight.CfnDashboard.FunnelChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        label_color="labelColor",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_data_label_style="measureDataLabelStyle",
                                        measure_label_visibility="measureLabelVisibility",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                                        funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            gauge_chart_visual=quicksight.CfnDashboard.GaugeChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                                        target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                                        arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                                            arc_angle=123,
                                            arc_thickness="arcThickness"
                                        ),
                                        arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                                            range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                                max=123,
                                                min=123
                                            ),
                                            reserve_range=123
                                        ),
                                        comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    ),
                                    tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                conditional_formatting=quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                                        arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
            
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            geospatial_map_visual=quicksight.CfnDashboard.GeospatialMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                                    field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                                        geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                                        cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                                            cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                                simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                                    color="color"
                                                )
                                            )
                                        ),
                                        selected_point_style="selectedPointStyle"
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            heat_map_visual=quicksight.CfnDashboard.HeatMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.HeatMapConfigurationProperty(
                                    color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
            
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                                        heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                                        heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            histogram_visual=quicksight.CfnDashboard.HistogramVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.HistogramConfigurationProperty(
                                    bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                                        bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                                            value=123
                                        ),
                                        bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                                            bin_count_limit=123,
                                            value=123
                                        ),
                                        selected_bin_type="selectedBinType",
                                        start_value=123
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                                        histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    )
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            insight_visual=quicksight.CfnDashboard.InsightVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                insight_configuration=quicksight.CfnDashboard.InsightConfigurationProperty(
                                    computations=[quicksight.CfnDashboard.ComputationProperty(
                                        forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            custom_seasonality_value=123,
                                            lower_boundary=123,
                                            name="name",
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality="seasonality",
                                            upper_boundary=123,
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            period_size=123,
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
            
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                                            computation_id="computationId",
                                            from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            period_time_granularity="periodTimeGranularity",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
            
                                            # the properties below are optional
                                            mover_size=123,
                                            name="name",
                                            sort_order="sortOrder",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            type="type",
            
                                            # the properties below are optional
                                            name="name",
                                            result_size=123,
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                                            computation_id="computationId",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
            
                                            # the properties below are optional
                                            name="name"
                                        )
                                    )],
                                    custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                                        narrative="narrative"
                                    )
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            kpi_visual=quicksight.CfnDashboard.KPIVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.KPIConfigurationProperty(
                                    field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                                        target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                                        comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                                        trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                                        primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
            
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            line_chart_visual=quicksight.CfnDashboard.LineChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.LineChartConfigurationProperty(
                                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                                        axis_binding="axisBinding",
                                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                                        line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                                        forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                                            lower_boundary=123,
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality=123,
                                            upper_boundary=123
                                        ),
                                        scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                                            what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                                date="date",
                                                value=123
                                            ),
                                            what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                                end_date="endDate",
                                                start_date="startDate",
                                                value=123
                                            )
                                        )
                                    )],
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    series=[quicksight.CfnDashboard.SeriesItemProperty(
                                        data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            field_value="fieldValue",
                                            settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        ),
                                        field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                                        category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    type="type",
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pie_chart_visual=quicksight.CfnDashboard.PieChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.PieChartConfigurationProperty(
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                                        arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                                            arc_thickness="arcThickness"
                                        ),
                                        donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                                            label_visibility="labelVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                                        pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pivot_table_visual=quicksight.CfnDashboard.PivotTableVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.PivotTableConfigurationProperty(
                                    field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                                        data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                                            data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )],
            
                                            # the properties below are optional
                                            width="width"
                                        )],
                                        selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            visibility="visibility"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                                        pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                                        field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                                            field_id="fieldId",
                                            sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                                column=quicksight.CfnDashboard.ColumnSortProperty(
                                                    direction="direction",
                                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    )
                                                ),
                                                data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                                    direction="direction",
                                                    sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                                        field_id="fieldId",
                                                        field_value="fieldValue"
                                                    )]
                                                ),
                                                field=quicksight.CfnDashboard.FieldSortProperty(
                                                    direction="direction",
                                                    field_id="fieldId"
                                                )
                                            )
                                        )]
                                    ),
                                    table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                                        cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_names_visibility="columnNamesVisibility",
                                        metric_placement="metricPlacement",
                                        row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        ),
                                        row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        single_metric_visibility="singleMetricVisibility",
                                        toggle_buttons_visibility="toggleButtonsVisibility"
                                    ),
                                    total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                                        column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    )
                                ),
                                conditional_formatting=quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                                role="role"
                                            ),
                                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
            
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            radar_chart_visual=quicksight.CfnDashboard.RadarChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.RadarChartConfigurationProperty(
                                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                                    alternate_band_even_color="alternateBandEvenColor",
                                    alternate_band_odd_color="alternateBandOddColor",
                                    base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                                        area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                                        radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    shape="shape",
                                    sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    start_angle=123,
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            sankey_diagram_visual=quicksight.CfnDashboard.SankeyDiagramVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                                        sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                                            destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                                        destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            scatter_plot_visual=quicksight.CfnDashboard.ScatterPlotVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            table_visual=quicksight.CfnDashboard.TableVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.TableConfigurationProperty(
                                    field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                                        order=["order"],
                                        selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                                image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                                    sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                    )
                                                ),
                                                link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                                    content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                                        custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                                            icon="icon"
                                                        ),
                                                        custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                                font_color="fontColor",
                                                                font_decoration="fontDecoration",
                                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                                    relative="relative"
                                                                ),
                                                                font_style="fontStyle",
                                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                                    name="name"
                                                                )
                                                            ),
            
                                                            # the properties below are optional
                                                            value="value"
                                                        )
                                                    ),
                                                    target="target"
                                                )
                                            ),
                                            visibility="visibility",
                                            width="width"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                                        table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                                            values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                                    date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                                        pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        ),
                                        row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                                        data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            negative_color="negativeColor",
                                            positive_color="positiveColor"
                                        )
                                    )],
                                    table_options=quicksight.CfnDashboard.TableOptionsProperty(
                                        cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        orientation="orientation",
                                        row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        )
                                    ),
                                    total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                                        custom_label="customLabel",
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility"
                                    )
                                ),
                                conditional_formatting=quicksight.CfnDashboard.TableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
            
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        ),
                                        row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            tree_map_visual=quicksight.CfnDashboard.TreeMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.TreeMapConfigurationProperty(
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
            
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                                        tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                                        tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            waterfall_visual=quicksight.CfnDashboard.WaterfallVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                                    category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                                        waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                                            breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                                        breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                                        total_bar_label="totalBarLabel"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            word_cloud_visual=quicksight.CfnDashboard.WordCloudVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                                        word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                                        cloud_layout="cloudLayout",
                                        maximum_string_length=123,
                                        word_casing="wordCasing",
                                        word_orientation="wordOrientation",
                                        word_padding="wordPadding",
                                        word_scaling="wordScaling"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )]
                    )]
                ),
                parameters=quicksight.CfnDashboard.ParametersProperty(
                    date_time_parameters=[quicksight.CfnDashboard.DateTimeParameterProperty(
                        name="name",
                        values=["values"]
                    )],
                    decimal_parameters=[quicksight.CfnDashboard.DecimalParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    integer_parameters=[quicksight.CfnDashboard.IntegerParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    string_parameters=[quicksight.CfnDashboard.StringParameterProperty(
                        name="name",
                        values=["values"]
                    )]
                ),
                permissions=[quicksight.CfnDashboard.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
            
                    # the properties below are optional
                    resource="resource"
                )],
                source_entity=quicksight.CfnDashboard.DashboardSourceEntityProperty(
                    source_template=quicksight.CfnDashboard.DashboardSourceTemplateProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnDashboard.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    )
                ),
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                theme_arn="themeArn",
                version_description="versionDescription"
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ebd4d588b1b5be67c06ed4aac3804f644242e7a1998e888aba4708f7a2a0483f)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument dashboard_id", value=dashboard_id, expected_type=type_hints["dashboard_id"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument dashboard_publish_options", value=dashboard_publish_options, expected_type=type_hints["dashboard_publish_options"])
            check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
            check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument source_entity", value=source_entity, expected_type=type_hints["source_entity"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument theme_arn", value=theme_arn, expected_type=type_hints["theme_arn"])
            check_type(argname="argument version_description", value=version_description, expected_type=type_hints["version_description"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aws_account_id": aws_account_id,
            "dashboard_id": dashboard_id,
            "name": name,
        }
        if dashboard_publish_options is not None:
            self._values["dashboard_publish_options"] = dashboard_publish_options
        if definition is not None:
            self._values["definition"] = definition
        if parameters is not None:
            self._values["parameters"] = parameters
        if permissions is not None:
            self._values["permissions"] = permissions
        if source_entity is not None:
            self._values["source_entity"] = source_entity
        if tags is not None:
            self._values["tags"] = tags
        if theme_arn is not None:
            self._values["theme_arn"] = theme_arn
        if version_description is not None:
            self._values["version_description"] = version_description

    @builtins.property
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you want to create the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        assert result is not None, "Required property 'aws_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dashboard_id(self) -> builtins.str:
        '''The ID for the dashboard, also added to the IAM policy.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardid
        '''
        result = self._values.get("dashboard_id")
        assert result is not None, "Required property 'dashboard_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The display name of the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-name
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dashboard_publish_options(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.DashboardPublishOptionsProperty]]:
        '''Options for publishing the dashboard when you create it:.

        - ``AvailabilityStatus`` for ``AdHocFilteringOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . When this is set to ``DISABLED`` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is ``ENABLED`` by default.
        - ``AvailabilityStatus`` for ``ExportToCSVOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . The visual option to export data to .CSV format isn't enabled when this is set to ``DISABLED`` . This option is ``ENABLED`` by default.
        - ``VisibilityState`` for ``SheetControlsOption`` - This visibility state can be either ``COLLAPSED`` or ``EXPANDED`` . This option is ``COLLAPSED`` by default.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardpublishoptions
        '''
        result = self._values.get("dashboard_publish_options")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.DashboardPublishOptionsProperty]], result)

    @builtins.property
    def definition(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.DashboardVersionDefinitionProperty]]:
        '''``AWS::QuickSight::Dashboard.Definition``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-definition
        '''
        result = self._values.get("definition")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.DashboardVersionDefinitionProperty]], result)

    @builtins.property
    def parameters(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.ParametersProperty]]:
        '''The parameters for the creation of the dashboard, which you want to use to override the default settings.

        A dashboard can have any type of parameters, and some parameters might accept multiple values.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-parameters
        '''
        result = self._values.get("parameters")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.ParametersProperty]], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.ResourcePermissionProperty]]]]:
        '''A structure that contains the permissions of the dashboard.

        You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN.

        To specify no permissions, omit the permissions list.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.ResourcePermissionProperty]]]], result)

    @builtins.property
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.DashboardSourceEntityProperty]]:
        '''The entity that you are using as a source when you create the dashboard.

        In ``SourceEntity`` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a ``SourceTemplate`` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the ``CreateTemplate`` API operation. For ``SourceTemplate`` , specify the Amazon Resource Name (ARN) of the source template. The ``SourceTemplate`` ARN can contain any AWS account; and any QuickSight-supported AWS Region .

        Use the ``DataSetReferences`` entity within ``SourceTemplate`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-sourceentity
        '''
        result = self._values.get("source_entity")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.DashboardSourceEntityProperty]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]], result)

    @builtins.property
    def theme_arn(self) -> typing.Optional[builtins.str]:
        '''The Amazon Resource Name (ARN) of the theme that is being used for this dashboard.

        If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-themearn
        '''
        result = self._values.get("theme_arn")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description for the first version of the dashboard being created.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-versiondescription
        '''
        result = self._values.get("version_description")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnDashboardProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_aws_cdk_core_f4b25747.IInspectable)
class CfnDataSet(
    _aws_cdk_core_f4b25747.CfnResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@aws-cdk/aws-quicksight.CfnDataSet",
):
    '''A CloudFormation ``AWS::QuickSight::DataSet``.

    Creates a dataset. This operation doesn't support datasets that include uploaded files as a source.

    :cloudformationResource: AWS::QuickSight::DataSet
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        import aws_cdk.aws_quicksight as quicksight
        
        cfn_data_set = quicksight.CfnDataSet(self, "MyCfnDataSet",
            aws_account_id="awsAccountId",
            column_groups=[quicksight.CfnDataSet.ColumnGroupProperty(
                geo_spatial_column_group=quicksight.CfnDataSet.GeoSpatialColumnGroupProperty(
                    columns=["columns"],
                    name="name",
        
                    # the properties below are optional
                    country_code="countryCode"
                )
            )],
            column_level_permission_rules=[quicksight.CfnDataSet.ColumnLevelPermissionRuleProperty(
                column_names=["columnNames"],
                principals=["principals"]
            )],
            data_set_id="dataSetId",
            data_set_usage_configuration=quicksight.CfnDataSet.DataSetUsageConfigurationProperty(
                disable_use_as_direct_query_source=False,
                disable_use_as_imported_source=False
            ),
            field_folders={
                "field_folders_key": quicksight.CfnDataSet.FieldFolderProperty(
                    columns=["columns"],
                    description="description"
                )
            },
            import_mode="importMode",
            ingestion_wait_policy=quicksight.CfnDataSet.IngestionWaitPolicyProperty(
                ingestion_wait_time_in_hours=123,
                wait_for_spice_ingestion=False
            ),
            logical_table_map={
                "logical_table_map_key": quicksight.CfnDataSet.LogicalTableProperty(
                    alias="alias",
                    source=quicksight.CfnDataSet.LogicalTableSourceProperty(
                        data_set_arn="dataSetArn",
                        join_instruction=quicksight.CfnDataSet.JoinInstructionProperty(
                            left_operand="leftOperand",
                            on_clause="onClause",
                            right_operand="rightOperand",
                            type="type",
        
                            # the properties below are optional
                            left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                unique_key=False
                            ),
                            right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                unique_key=False
                            )
                        ),
                        physical_table_id="physicalTableId"
                    ),
        
                    # the properties below are optional
                    data_transforms=[quicksight.CfnDataSet.TransformOperationProperty(
                        cast_column_type_operation=quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                            column_name="columnName",
                            new_column_type="newColumnType",
        
                            # the properties below are optional
                            format="format"
                        ),
                        create_columns_operation=quicksight.CfnDataSet.CreateColumnsOperationProperty(
                            columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                                column_id="columnId",
                                column_name="columnName",
                                expression="expression"
                            )]
                        ),
                        filter_operation=quicksight.CfnDataSet.FilterOperationProperty(
                            condition_expression="conditionExpression"
                        ),
                        project_operation=quicksight.CfnDataSet.ProjectOperationProperty(
                            projected_columns=["projectedColumns"]
                        ),
                        rename_column_operation=quicksight.CfnDataSet.RenameColumnOperationProperty(
                            column_name="columnName",
                            new_column_name="newColumnName"
                        ),
                        tag_column_operation=quicksight.CfnDataSet.TagColumnOperationProperty(
                            column_name="columnName",
                            tags=[quicksight.CfnDataSet.ColumnTagProperty(
                                column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                                    text="text"
                                ),
                                column_geographic_role="columnGeographicRole"
                            )]
                        )
                    )]
                )
            },
            name="name",
            permissions=[quicksight.CfnDataSet.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal"
            )],
            physical_table_map={
                "physical_table_map_key": quicksight.CfnDataSet.PhysicalTableProperty(
                    custom_sql=quicksight.CfnDataSet.CustomSqlProperty(
                        columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type"
                        )],
                        data_source_arn="dataSourceArn",
                        name="name",
                        sql_query="sqlQuery"
                    ),
                    relational_table=quicksight.CfnDataSet.RelationalTableProperty(
                        data_source_arn="dataSourceArn",
                        input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type"
                        )],
                        name="name",
        
                        # the properties below are optional
                        catalog="catalog",
                        schema="schema"
                    ),
                    s3_source=quicksight.CfnDataSet.S3SourceProperty(
                        data_source_arn="dataSourceArn",
                        input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type"
                        )],
        
                        # the properties below are optional
                        upload_settings=quicksight.CfnDataSet.UploadSettingsProperty(
                            contains_header=False,
                            delimiter="delimiter",
                            format="format",
                            start_from_row=123,
                            text_qualifier="textQualifier"
                        )
                    )
                )
            },
            row_level_permission_data_set=quicksight.CfnDataSet.RowLevelPermissionDataSetProperty(
                arn="arn",
                permission_policy="permissionPolicy",
        
                # the properties below are optional
                format_version="formatVersion",
                namespace="namespace"
            ),
            tags=[CfnTag(
                key="key",
                value="value"
            )]
        )
    '''

    def __init__(
        self,
        scope: _aws_cdk_core_f4b25747.Construct,
        id: builtins.str,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        column_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.ColumnGroupProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        column_level_permission_rules: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.ColumnLevelPermissionRuleProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        data_set_id: typing.Optional[builtins.str] = None,
        data_set_usage_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.DataSetUsageConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        field_folders: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.FieldFolderProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        import_mode: typing.Optional[builtins.str] = None,
        ingestion_wait_policy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.IngestionWaitPolicyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        logical_table_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.LogicalTableProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        physical_table_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.PhysicalTableProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        row_level_permission_data_set: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.RowLevelPermissionDataSetProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::DataSet``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param aws_account_id: The AWS account ID.
        :param column_groups: Groupings of columns that work together in certain Amazon QuickSight features. Currently, only geospatial hierarchy is supported.
        :param column_level_permission_rules: A set of one or more definitions of a ``ColumnLevelPermissionRule`` .
        :param data_set_id: An ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.
        :param data_set_usage_configuration: The usage configuration to apply to child datasets that reference this dataset as a source.
        :param field_folders: The folder that contains fields and nested subfolders for your dataset.
        :param import_mode: Indicates whether you want to import the data into SPICE.
        :param ingestion_wait_policy: The wait policy to use when creating or updating a Dataset. The default is to wait for SPICE ingestion to finish with timeout of 36 hours.
        :param logical_table_map: Configures the combination and transformation of the data from the physical tables.
        :param name: The display name for the dataset.
        :param permissions: A list of resource permissions on the dataset.
        :param physical_table_map: Declares the physical tables that are available in the underlying data sources.
        :param row_level_permission_data_set: The row-level security configuration for the data that you want to create.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b60768091e5a671e526cc5a7dda7550dd47b97301923414d78b174459017a08e)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnDataSetProps(
            aws_account_id=aws_account_id,
            column_groups=column_groups,
            column_level_permission_rules=column_level_permission_rules,
            data_set_id=data_set_id,
            data_set_usage_configuration=data_set_usage_configuration,
            field_folders=field_folders,
            import_mode=import_mode,
            ingestion_wait_policy=ingestion_wait_policy,
            logical_table_map=logical_table_map,
            name=name,
            permissions=permissions,
            physical_table_map=physical_table_map,
            row_level_permission_data_set=row_level_permission_data_set,
            tags=tags,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _aws_cdk_core_f4b25747.TreeInspector) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6a40c2923ac931adc9e5227fd27d9e0ce2e06f9f0adca9a5fc258f274c8c0b41)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__319c243491c3ebe14fd56a4b2912534df5743a01fc01559881202892cbfd54fd)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the dataset.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrConsumedSpiceCapacityInBytes")
    def attr_consumed_spice_capacity_in_bytes(
        self,
    ) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: ConsumedSpiceCapacityInBytes
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrConsumedSpiceCapacityInBytes"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time this dataset version was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time this dataset version was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrOutputColumns")
    def attr_output_columns(self) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: OutputColumns
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrOutputColumns"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _aws_cdk_core_f4b25747.TagManager:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-tags
        '''
        return typing.cast(_aws_cdk_core_f4b25747.TagManager, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-awsaccountid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b83eb4dea8999ae93ebd0d3bd44b1ca109a2bfcce5e24968589ea02fd90b61e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="columnGroups")
    def column_groups(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.ColumnGroupProperty"]]]]:
        '''Groupings of columns that work together in certain Amazon QuickSight features.

        Currently, only geospatial hierarchy is supported.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columngroups
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.ColumnGroupProperty"]]]], jsii.get(self, "columnGroups"))

    @column_groups.setter
    def column_groups(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.ColumnGroupProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f5aec14e835e4d6d3b06f4d5541b80ff40279c65718c511193db749adfbebe86)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "columnGroups", value)

    @builtins.property
    @jsii.member(jsii_name="columnLevelPermissionRules")
    def column_level_permission_rules(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.ColumnLevelPermissionRuleProperty"]]]]:
        '''A set of one or more definitions of a ``ColumnLevelPermissionRule`` .

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columnlevelpermissionrules
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.ColumnLevelPermissionRuleProperty"]]]], jsii.get(self, "columnLevelPermissionRules"))

    @column_level_permission_rules.setter
    def column_level_permission_rules(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.ColumnLevelPermissionRuleProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a0500f9998edc54331818183988a5c4ce83851a226fa22a6b7b44864700579cb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "columnLevelPermissionRules", value)

    @builtins.property
    @jsii.member(jsii_name="dataSetId")
    def data_set_id(self) -> typing.Optional[builtins.str]:
        '''An ID for the dataset that you want to create.

        This ID is unique per AWS Region for each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSetId"))

    @data_set_id.setter
    def data_set_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fd9d855654a0270244190d342a624aa942a07051615fc31f99c457e8ce43d082)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSetId", value)

    @builtins.property
    @jsii.member(jsii_name="dataSetUsageConfiguration")
    def data_set_usage_configuration(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.DataSetUsageConfigurationProperty"]]:
        '''The usage configuration to apply to child datasets that reference this dataset as a source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetusageconfiguration
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.DataSetUsageConfigurationProperty"]], jsii.get(self, "dataSetUsageConfiguration"))

    @data_set_usage_configuration.setter
    def data_set_usage_configuration(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.DataSetUsageConfigurationProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__46c86cdd228671c5da2b73e9d5351d6c18704726524549fedadd681d94fec1ea)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSetUsageConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="fieldFolders")
    def field_folders(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.FieldFolderProperty"]]]]:
        '''The folder that contains fields and nested subfolders for your dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-fieldfolders
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.FieldFolderProperty"]]]], jsii.get(self, "fieldFolders"))

    @field_folders.setter
    def field_folders(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.FieldFolderProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0995afd66a6884d0ea14633c1a526bb05a96f915f4e3312e7ce61819272c8352)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "fieldFolders", value)

    @builtins.property
    @jsii.member(jsii_name="importMode")
    def import_mode(self) -> typing.Optional[builtins.str]:
        '''Indicates whether you want to import the data into SPICE.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-importmode
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "importMode"))

    @import_mode.setter
    def import_mode(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3fd8afbfafe61e453080ae45095cdc0c7e5cb58fa1269605c34cea9d8dc9d0b4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "importMode", value)

    @builtins.property
    @jsii.member(jsii_name="ingestionWaitPolicy")
    def ingestion_wait_policy(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.IngestionWaitPolicyProperty"]]:
        '''The wait policy to use when creating or updating a Dataset.

        The default is to wait for SPICE ingestion to finish with timeout of 36 hours.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-ingestionwaitpolicy
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.IngestionWaitPolicyProperty"]], jsii.get(self, "ingestionWaitPolicy"))

    @ingestion_wait_policy.setter
    def ingestion_wait_policy(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.IngestionWaitPolicyProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__561f931d4fcb887480f49ac733f8f5ab2c5136f51afedff875a7c9ccc5ddb0e3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "ingestionWaitPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="logicalTableMap")
    def logical_table_map(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.LogicalTableProperty"]]]]:
        '''Configures the combination and transformation of the data from the physical tables.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-logicaltablemap
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.LogicalTableProperty"]]]], jsii.get(self, "logicalTableMap"))

    @logical_table_map.setter
    def logical_table_map(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.LogicalTableProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e1fcf758419d721a50e21698fd94afd5a6c143dfea11275f2ba383876dcf6aa5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "logicalTableMap", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''The display name for the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-name
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d4c2c85757bba744cf2014537580e4b79a7e1a25506969e089fa702c57703d4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.ResourcePermissionProperty"]]]]:
        '''A list of resource permissions on the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-permissions
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.ResourcePermissionProperty"]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.ResourcePermissionProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afd9de662f1472bb8ac9b5758802152ae4a250a848184bc446fee20811c50266)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="physicalTableMap")
    def physical_table_map(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.PhysicalTableProperty"]]]]:
        '''Declares the physical tables that are available in the underlying data sources.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-physicaltablemap
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.PhysicalTableProperty"]]]], jsii.get(self, "physicalTableMap"))

    @physical_table_map.setter
    def physical_table_map(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.PhysicalTableProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb2792fe0665cf6fb08e32620b92ac1869915cdeb976d7efaf3cec63c793021b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "physicalTableMap", value)

    @builtins.property
    @jsii.member(jsii_name="rowLevelPermissionDataSet")
    def row_level_permission_data_set(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.RowLevelPermissionDataSetProperty"]]:
        '''The row-level security configuration for the data that you want to create.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.RowLevelPermissionDataSetProperty"]], jsii.get(self, "rowLevelPermissionDataSet"))

    @row_level_permission_data_set.setter
    def row_level_permission_data_set(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.RowLevelPermissionDataSetProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4feb8d280630a7b48de18e43f020242fac00be3f3cef6f16ef919d43cd86dcaf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "rowLevelPermissionDataSet", value)

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.CalculatedColumnProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_id": "columnId",
            "column_name": "columnName",
            "expression": "expression",
        },
    )
    class CalculatedColumnProperty:
        def __init__(
            self,
            *,
            column_id: builtins.str,
            column_name: builtins.str,
            expression: builtins.str,
        ) -> None:
            '''A calculated column for a dataset.

            :param column_id: A unique ID to identify a calculated column. During a dataset update, if the column ID of a calculated column matches that of an existing calculated column, Amazon QuickSight preserves the existing calculated column.
            :param column_name: Column name.
            :param expression: An expression that defines the calculated column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                calculated_column_property = quicksight.CfnDataSet.CalculatedColumnProperty(
                    column_id="columnId",
                    column_name="columnName",
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__af1719501244769800de67dfec86ce6daea34bc0e70210fb4ec9037ec71243c6)
                check_type(argname="argument column_id", value=column_id, expected_type=type_hints["column_id"])
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_id": column_id,
                "column_name": column_name,
                "expression": expression,
            }

        @builtins.property
        def column_id(self) -> builtins.str:
            '''A unique ID to identify a calculated column.

            During a dataset update, if the column ID of a calculated column matches that of an existing calculated column, Amazon QuickSight preserves the existing calculated column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-columnid
            '''
            result = self._values.get("column_id")
            assert result is not None, "Required property 'column_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def column_name(self) -> builtins.str:
            '''Column name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''An expression that defines the calculated column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedColumnProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.CastColumnTypeOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "new_column_type": "newColumnType",
            "format": "format",
        },
    )
    class CastColumnTypeOperationProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            new_column_type: builtins.str,
            format: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A transform operation that casts a column to a different type.

            :param column_name: Column name.
            :param new_column_type: New column data type.
            :param format: When casting a column from string to datetime type, you can supply a string in a format supported by Amazon QuickSight to denote the source data format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                cast_column_type_operation_property = quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                    column_name="columnName",
                    new_column_type="newColumnType",
                
                    # the properties below are optional
                    format="format"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__090e4129dffeaf2101fb71ebe6d856e695d7f5ef04229f4572353551767ea19b)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument new_column_type", value=new_column_type, expected_type=type_hints["new_column_type"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "new_column_type": new_column_type,
            }
            if format is not None:
                self._values["format"] = format

        @builtins.property
        def column_name(self) -> builtins.str:
            '''Column name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def new_column_type(self) -> builtins.str:
            '''New column data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-newcolumntype
            '''
            result = self._values.get("new_column_type")
            assert result is not None, "Required property 'new_column_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format(self) -> typing.Optional[builtins.str]:
            '''When casting a column from string to datetime type, you can supply a string in a format supported by Amazon QuickSight to denote the source data format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CastColumnTypeOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.ColumnDescriptionProperty",
        jsii_struct_bases=[],
        name_mapping={"text": "text"},
    )
    class ColumnDescriptionProperty:
        def __init__(self, *, text: typing.Optional[builtins.str] = None) -> None:
            '''Metadata that contains a description for a column.

            :param text: The text of a description for a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columndescription.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_description_property = quicksight.CfnDataSet.ColumnDescriptionProperty(
                    text="text"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cec012f9226ebaa351555c768bd98193287d0cba5e3a3650fd3eedd8550629f2)
                check_type(argname="argument text", value=text, expected_type=type_hints["text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if text is not None:
                self._values["text"] = text

        @builtins.property
        def text(self) -> typing.Optional[builtins.str]:
            '''The text of a description for a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columndescription.html#cfn-quicksight-dataset-columndescription-text
            '''
            result = self._values.get("text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnDescriptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.ColumnGroupProperty",
        jsii_struct_bases=[],
        name_mapping={"geo_spatial_column_group": "geoSpatialColumnGroup"},
    )
    class ColumnGroupProperty:
        def __init__(
            self,
            *,
            geo_spatial_column_group: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.GeoSpatialColumnGroupProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Groupings of columns that work together in certain Amazon QuickSight features.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param geo_spatial_column_group: Geospatial column group that denotes a hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columngroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_group_property = quicksight.CfnDataSet.ColumnGroupProperty(
                    geo_spatial_column_group=quicksight.CfnDataSet.GeoSpatialColumnGroupProperty(
                        columns=["columns"],
                        name="name",
                
                        # the properties below are optional
                        country_code="countryCode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__60c324296ed6e68a860b9d5af28df5fac62b156bb058fc972a341baea3a425ab)
                check_type(argname="argument geo_spatial_column_group", value=geo_spatial_column_group, expected_type=type_hints["geo_spatial_column_group"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geo_spatial_column_group is not None:
                self._values["geo_spatial_column_group"] = geo_spatial_column_group

        @builtins.property
        def geo_spatial_column_group(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.GeoSpatialColumnGroupProperty"]]:
            '''Geospatial column group that denotes a hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columngroup.html#cfn-quicksight-dataset-columngroup-geospatialcolumngroup
            '''
            result = self._values.get("geo_spatial_column_group")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.GeoSpatialColumnGroupProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.ColumnLevelPermissionRuleProperty",
        jsii_struct_bases=[],
        name_mapping={"column_names": "columnNames", "principals": "principals"},
    )
    class ColumnLevelPermissionRuleProperty:
        def __init__(
            self,
            *,
            column_names: typing.Optional[typing.Sequence[builtins.str]] = None,
            principals: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A rule defined to grant access on one or more restricted columns.

            Each dataset can have multiple rules. To create a restricted column, you add it to one or more rules. Each rule must contain at least one column and at least one user or group. To be able to see a restricted column, a user or group needs to be added to a rule for that column.

            :param column_names: An array of column names.
            :param principals: An array of Amazon Resource Names (ARNs) for Amazon QuickSight users or groups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_level_permission_rule_property = quicksight.CfnDataSet.ColumnLevelPermissionRuleProperty(
                    column_names=["columnNames"],
                    principals=["principals"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__889c97f307ddd676262e819e966d136c1cb1a172a75fe6e6c46140c9e78a254f)
                check_type(argname="argument column_names", value=column_names, expected_type=type_hints["column_names"])
                check_type(argname="argument principals", value=principals, expected_type=type_hints["principals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_names is not None:
                self._values["column_names"] = column_names
            if principals is not None:
                self._values["principals"] = principals

        @builtins.property
        def column_names(self) -> typing.Optional[typing.List[builtins.str]]:
            '''An array of column names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html#cfn-quicksight-dataset-columnlevelpermissionrule-columnnames
            '''
            result = self._values.get("column_names")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def principals(self) -> typing.Optional[typing.List[builtins.str]]:
            '''An array of Amazon Resource Names (ARNs) for Amazon QuickSight users or groups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html#cfn-quicksight-dataset-columnlevelpermissionrule-principals
            '''
            result = self._values.get("principals")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnLevelPermissionRuleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.ColumnTagProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_description": "columnDescription",
            "column_geographic_role": "columnGeographicRole",
        },
    )
    class ColumnTagProperty:
        def __init__(
            self,
            *,
            column_description: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.ColumnDescriptionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_geographic_role: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A tag for a column in a ``[TagColumnOperation](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_TagColumnOperation.html)`` structure. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param column_description: A description for a column.
            :param column_geographic_role: A geospatial role for a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_tag_property = quicksight.CfnDataSet.ColumnTagProperty(
                    column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                        text="text"
                    ),
                    column_geographic_role="columnGeographicRole"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a9253df21023b03f198cc86b4d3438e2489ebccd7947fdcd50d8a2aecfd872c8)
                check_type(argname="argument column_description", value=column_description, expected_type=type_hints["column_description"])
                check_type(argname="argument column_geographic_role", value=column_geographic_role, expected_type=type_hints["column_geographic_role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_description is not None:
                self._values["column_description"] = column_description
            if column_geographic_role is not None:
                self._values["column_geographic_role"] = column_geographic_role

        @builtins.property
        def column_description(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.ColumnDescriptionProperty"]]:
            '''A description for a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html#cfn-quicksight-dataset-columntag-columndescription
            '''
            result = self._values.get("column_description")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.ColumnDescriptionProperty"]], result)

        @builtins.property
        def column_geographic_role(self) -> typing.Optional[builtins.str]:
            '''A geospatial role for a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html#cfn-quicksight-dataset-columntag-columngeographicrole
            '''
            result = self._values.get("column_geographic_role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnTagProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.CreateColumnsOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns"},
    )
    class CreateColumnsOperationProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.CalculatedColumnProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''A transform operation that creates calculated columns.

            Columns created in one such operation form a lexical closure.

            :param columns: Calculated columns to create.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-createcolumnsoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                create_columns_operation_property = quicksight.CfnDataSet.CreateColumnsOperationProperty(
                    columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                        column_id="columnId",
                        column_name="columnName",
                        expression="expression"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a073e1a889a9c00a3055d4ef193240bade4cf95f7b52e0d0d21e13489db9ade8)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
            }

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.CalculatedColumnProperty"]]]:
            '''Calculated columns to create.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-createcolumnsoperation.html#cfn-quicksight-dataset-createcolumnsoperation-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.CalculatedColumnProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CreateColumnsOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.CustomSqlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "data_source_arn": "dataSourceArn",
            "name": "name",
            "sql_query": "sqlQuery",
        },
    )
    class CustomSqlProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.InputColumnProperty", typing.Dict[builtins.str, typing.Any]]]]],
            data_source_arn: builtins.str,
            name: builtins.str,
            sql_query: builtins.str,
        ) -> None:
            '''A physical table type built from the results of the custom SQL query.

            :param columns: The column schema from the SQL query result set.
            :param data_source_arn: The Amazon Resource Name (ARN) of the data source.
            :param name: A display name for the SQL query result.
            :param sql_query: The SQL query.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_sql_property = quicksight.CfnDataSet.CustomSqlProperty(
                    columns=[quicksight.CfnDataSet.InputColumnProperty(
                        name="name",
                        type="type"
                    )],
                    data_source_arn="dataSourceArn",
                    name="name",
                    sql_query="sqlQuery"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ca22e03c50cdde617978058830a93fd3af716a6093f540bca60d7b904c4b06f6)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument data_source_arn", value=data_source_arn, expected_type=type_hints["data_source_arn"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sql_query", value=sql_query, expected_type=type_hints["sql_query"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "data_source_arn": data_source_arn,
                "name": name,
                "sql_query": sql_query,
            }

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.InputColumnProperty"]]]:
            '''The column schema from the SQL query result set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.InputColumnProperty"]]], result)

        @builtins.property
        def data_source_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-datasourcearn
            '''
            result = self._values.get("data_source_arn")
            assert result is not None, "Required property 'data_source_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the SQL query result.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sql_query(self) -> builtins.str:
            '''The SQL query.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-sqlquery
            '''
            result = self._values.get("sql_query")
            assert result is not None, "Required property 'sql_query' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomSqlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.DataSetUsageConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "disable_use_as_direct_query_source": "disableUseAsDirectQuerySource",
            "disable_use_as_imported_source": "disableUseAsImportedSource",
        },
    )
    class DataSetUsageConfigurationProperty:
        def __init__(
            self,
            *,
            disable_use_as_direct_query_source: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            disable_use_as_imported_source: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
        ) -> None:
            '''The usage configuration to apply to child datasets that reference this dataset as a source.

            :param disable_use_as_direct_query_source: An option that controls whether a child dataset of a direct query can use this dataset as a source.
            :param disable_use_as_imported_source: An option that controls whether a child dataset that's stored in QuickSight can use this dataset as a source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_set_usage_configuration_property = quicksight.CfnDataSet.DataSetUsageConfigurationProperty(
                    disable_use_as_direct_query_source=False,
                    disable_use_as_imported_source=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55ea54d1cf4ad4affd7316c2a516ce101239d73a9fb8ca45d26b1c4b2826b0f9)
                check_type(argname="argument disable_use_as_direct_query_source", value=disable_use_as_direct_query_source, expected_type=type_hints["disable_use_as_direct_query_source"])
                check_type(argname="argument disable_use_as_imported_source", value=disable_use_as_imported_source, expected_type=type_hints["disable_use_as_imported_source"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if disable_use_as_direct_query_source is not None:
                self._values["disable_use_as_direct_query_source"] = disable_use_as_direct_query_source
            if disable_use_as_imported_source is not None:
                self._values["disable_use_as_imported_source"] = disable_use_as_imported_source

        @builtins.property
        def disable_use_as_direct_query_source(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''An option that controls whether a child dataset of a direct query can use this dataset as a source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html#cfn-quicksight-dataset-datasetusageconfiguration-disableuseasdirectquerysource
            '''
            result = self._values.get("disable_use_as_direct_query_source")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def disable_use_as_imported_source(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''An option that controls whether a child dataset that's stored in QuickSight can use this dataset as a source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html#cfn-quicksight-dataset-datasetusageconfiguration-disableuseasimportedsource
            '''
            result = self._values.get("disable_use_as_imported_source")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetUsageConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.FieldFolderProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "description": "description"},
    )
    class FieldFolderProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Sequence[builtins.str]] = None,
            description: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A FieldFolder element is a folder that contains fields and nested subfolders.

            :param columns: A folder has a list of columns. A column can only be in one folder.
            :param description: The description for a field folder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_folder_property = quicksight.CfnDataSet.FieldFolderProperty(
                    columns=["columns"],
                    description="description"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a44f9b379451fd15a0c906b4c9e904d7781d3a3c509ec4dcba34d4c0b51bd51f)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if description is not None:
                self._values["description"] = description

        @builtins.property
        def columns(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A folder has a list of columns.

            A column can only be in one folder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html#cfn-quicksight-dataset-fieldfolder-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''The description for a field folder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html#cfn-quicksight-dataset-fieldfolder-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldFolderProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.FilterOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"condition_expression": "conditionExpression"},
    )
    class FilterOperationProperty:
        def __init__(self, *, condition_expression: builtins.str) -> None:
            '''A transform operation that filters rows based on a condition.

            :param condition_expression: An expression that must evaluate to a Boolean value. Rows for which the expression evaluates to true are kept in the dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-filteroperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_operation_property = quicksight.CfnDataSet.FilterOperationProperty(
                    condition_expression="conditionExpression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7ad0f80474f66de8a1500c6bf656c4ad11348f2c425feea5f74488cd530a597d)
                check_type(argname="argument condition_expression", value=condition_expression, expected_type=type_hints["condition_expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "condition_expression": condition_expression,
            }

        @builtins.property
        def condition_expression(self) -> builtins.str:
            '''An expression that must evaluate to a Boolean value.

            Rows for which the expression evaluates to true are kept in the dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-filteroperation.html#cfn-quicksight-dataset-filteroperation-conditionexpression
            '''
            result = self._values.get("condition_expression")
            assert result is not None, "Required property 'condition_expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.GeoSpatialColumnGroupProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "name": "name",
            "country_code": "countryCode",
        },
    )
    class GeoSpatialColumnGroupProperty:
        def __init__(
            self,
            *,
            columns: typing.Sequence[builtins.str],
            name: builtins.str,
            country_code: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Geospatial column group that denotes a hierarchy.

            :param columns: Columns in this hierarchy.
            :param name: A display name for the hierarchy.
            :param country_code: Country code.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geo_spatial_column_group_property = quicksight.CfnDataSet.GeoSpatialColumnGroupProperty(
                    columns=["columns"],
                    name="name",
                
                    # the properties below are optional
                    country_code="countryCode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7a826b85f8c0c0f3d10def461de935e3ec613e73ae9b812ffcc9a6902250b760)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument country_code", value=country_code, expected_type=type_hints["country_code"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "name": name,
            }
            if country_code is not None:
                self._values["country_code"] = country_code

        @builtins.property
        def columns(self) -> typing.List[builtins.str]:
            '''Columns in this hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def country_code(self) -> typing.Optional[builtins.str]:
            '''Country code.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-countrycode
            '''
            result = self._values.get("country_code")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeoSpatialColumnGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.IngestionWaitPolicyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "ingestion_wait_time_in_hours": "ingestionWaitTimeInHours",
            "wait_for_spice_ingestion": "waitForSpiceIngestion",
        },
    )
    class IngestionWaitPolicyProperty:
        def __init__(
            self,
            *,
            ingestion_wait_time_in_hours: typing.Optional[jsii.Number] = None,
            wait_for_spice_ingestion: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
        ) -> None:
            '''The wait policy to use when creating or updating a Dataset.

            The default is to wait for SPICE ingestion to finish with timeout of 36 hours.

            :param ingestion_wait_time_in_hours: The maximum time (in hours) to wait for Ingestion to complete. Default timeout is 36 hours. Applicable only when ``DataSetImportMode`` mode is set to SPICE and ``WaitForSpiceIngestion`` is set to true.
            :param wait_for_spice_ingestion: Wait for SPICE ingestion to finish to mark dataset creation or update as successful. Default (true). Applicable only when ``DataSetImportMode`` mode is set to SPICE.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                ingestion_wait_policy_property = quicksight.CfnDataSet.IngestionWaitPolicyProperty(
                    ingestion_wait_time_in_hours=123,
                    wait_for_spice_ingestion=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93de8c7bbda46ee21caec20fb2d7e25b7a5395ba3bfca341abede936ea6a440b)
                check_type(argname="argument ingestion_wait_time_in_hours", value=ingestion_wait_time_in_hours, expected_type=type_hints["ingestion_wait_time_in_hours"])
                check_type(argname="argument wait_for_spice_ingestion", value=wait_for_spice_ingestion, expected_type=type_hints["wait_for_spice_ingestion"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if ingestion_wait_time_in_hours is not None:
                self._values["ingestion_wait_time_in_hours"] = ingestion_wait_time_in_hours
            if wait_for_spice_ingestion is not None:
                self._values["wait_for_spice_ingestion"] = wait_for_spice_ingestion

        @builtins.property
        def ingestion_wait_time_in_hours(self) -> typing.Optional[jsii.Number]:
            '''The maximum time (in hours) to wait for Ingestion to complete.

            Default timeout is 36 hours. Applicable only when ``DataSetImportMode`` mode is set to SPICE and ``WaitForSpiceIngestion`` is set to true.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html#cfn-quicksight-dataset-ingestionwaitpolicy-ingestionwaittimeinhours
            '''
            result = self._values.get("ingestion_wait_time_in_hours")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def wait_for_spice_ingestion(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Wait for SPICE ingestion to finish to mark dataset creation or update as successful.

            Default (true). Applicable only when ``DataSetImportMode`` mode is set to SPICE.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html#cfn-quicksight-dataset-ingestionwaitpolicy-waitforspiceingestion
            '''
            result = self._values.get("wait_for_spice_ingestion")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IngestionWaitPolicyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.InputColumnProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "type": "type"},
    )
    class InputColumnProperty:
        def __init__(self, *, name: builtins.str, type: builtins.str) -> None:
            '''Metadata for a column that is used as the input of a transform operation.

            :param name: The name of this column in the underlying data source.
            :param type: The data type of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                input_column_property = quicksight.CfnDataSet.InputColumnProperty(
                    name="name",
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c49cacb381f8dd7a1af6d82e58b62448aeda1654cee21c5da8b2f541448da651)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "type": type,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of this column in the underlying data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html#cfn-quicksight-dataset-inputcolumn-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The data type of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html#cfn-quicksight-dataset-inputcolumn-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InputColumnProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.JoinInstructionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "left_operand": "leftOperand",
            "on_clause": "onClause",
            "right_operand": "rightOperand",
            "type": "type",
            "left_join_key_properties": "leftJoinKeyProperties",
            "right_join_key_properties": "rightJoinKeyProperties",
        },
    )
    class JoinInstructionProperty:
        def __init__(
            self,
            *,
            left_operand: builtins.str,
            on_clause: builtins.str,
            right_operand: builtins.str,
            type: builtins.str,
            left_join_key_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.JoinKeyPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            right_join_key_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.JoinKeyPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The instructions associated with a join.

            :param left_operand: The operand on the left side of a join.
            :param on_clause: The join instructions provided in the ``ON`` clause of a join.
            :param right_operand: The operand on the right side of a join.
            :param type: The type of join that it is.
            :param left_join_key_properties: Join key properties of the left operand.
            :param right_join_key_properties: Join key properties of the right operand.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                join_instruction_property = quicksight.CfnDataSet.JoinInstructionProperty(
                    left_operand="leftOperand",
                    on_clause="onClause",
                    right_operand="rightOperand",
                    type="type",
                
                    # the properties below are optional
                    left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                        unique_key=False
                    ),
                    right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                        unique_key=False
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__500cfe81cf37d061378f405204a5c0acaf0ddbd036e04dfcebca986b656ade9f)
                check_type(argname="argument left_operand", value=left_operand, expected_type=type_hints["left_operand"])
                check_type(argname="argument on_clause", value=on_clause, expected_type=type_hints["on_clause"])
                check_type(argname="argument right_operand", value=right_operand, expected_type=type_hints["right_operand"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument left_join_key_properties", value=left_join_key_properties, expected_type=type_hints["left_join_key_properties"])
                check_type(argname="argument right_join_key_properties", value=right_join_key_properties, expected_type=type_hints["right_join_key_properties"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "left_operand": left_operand,
                "on_clause": on_clause,
                "right_operand": right_operand,
                "type": type,
            }
            if left_join_key_properties is not None:
                self._values["left_join_key_properties"] = left_join_key_properties
            if right_join_key_properties is not None:
                self._values["right_join_key_properties"] = right_join_key_properties

        @builtins.property
        def left_operand(self) -> builtins.str:
            '''The operand on the left side of a join.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-leftoperand
            '''
            result = self._values.get("left_operand")
            assert result is not None, "Required property 'left_operand' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def on_clause(self) -> builtins.str:
            '''The join instructions provided in the ``ON`` clause of a join.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-onclause
            '''
            result = self._values.get("on_clause")
            assert result is not None, "Required property 'on_clause' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def right_operand(self) -> builtins.str:
            '''The operand on the right side of a join.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-rightoperand
            '''
            result = self._values.get("right_operand")
            assert result is not None, "Required property 'right_operand' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of join that it is.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def left_join_key_properties(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.JoinKeyPropertiesProperty"]]:
            '''Join key properties of the left operand.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-leftjoinkeyproperties
            '''
            result = self._values.get("left_join_key_properties")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.JoinKeyPropertiesProperty"]], result)

        @builtins.property
        def right_join_key_properties(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.JoinKeyPropertiesProperty"]]:
            '''Join key properties of the right operand.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-rightjoinkeyproperties
            '''
            result = self._values.get("right_join_key_properties")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.JoinKeyPropertiesProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "JoinInstructionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.JoinKeyPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={"unique_key": "uniqueKey"},
    )
    class JoinKeyPropertiesProperty:
        def __init__(
            self,
            *,
            unique_key: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
        ) -> None:
            '''Properties associated with the columns participating in a join.

            :param unique_key: A value that indicates that a row in a table is uniquely identified by the columns in a join key. This is used by Amazon QuickSight to optimize query performance.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joinkeyproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                join_key_properties_property = quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                    unique_key=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fff8b069a5e4c44b9eacfc019e023aa191dfce1c4b34d2d8867ec0e66bb0eaf0)
                check_type(argname="argument unique_key", value=unique_key, expected_type=type_hints["unique_key"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if unique_key is not None:
                self._values["unique_key"] = unique_key

        @builtins.property
        def unique_key(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''A value that indicates that a row in a table is uniquely identified by the columns in a join key.

            This is used by Amazon QuickSight to optimize query performance.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joinkeyproperties.html#cfn-quicksight-dataset-joinkeyproperties-uniquekey
            '''
            result = self._values.get("unique_key")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "JoinKeyPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.LogicalTableProperty",
        jsii_struct_bases=[],
        name_mapping={
            "alias": "alias",
            "source": "source",
            "data_transforms": "dataTransforms",
        },
    )
    class LogicalTableProperty:
        def __init__(
            self,
            *,
            alias: builtins.str,
            source: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.LogicalTableSourceProperty", typing.Dict[builtins.str, typing.Any]]],
            data_transforms: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.TransformOperationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A *logical table* is a unit that joins and that data transformations operate on.

            A logical table has a source, which can be either a physical table or result of a join. When a logical table points to a physical table, the logical table acts as a mutable copy of that physical table through transform operations.

            :param alias: A display name for the logical table.
            :param source: Source of this logical table.
            :param data_transforms: Transform operations that act on this logical table. For this structure to be valid, only one of the attributes can be non-null.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                logical_table_property = quicksight.CfnDataSet.LogicalTableProperty(
                    alias="alias",
                    source=quicksight.CfnDataSet.LogicalTableSourceProperty(
                        data_set_arn="dataSetArn",
                        join_instruction=quicksight.CfnDataSet.JoinInstructionProperty(
                            left_operand="leftOperand",
                            on_clause="onClause",
                            right_operand="rightOperand",
                            type="type",
                
                            # the properties below are optional
                            left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                unique_key=False
                            ),
                            right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                unique_key=False
                            )
                        ),
                        physical_table_id="physicalTableId"
                    ),
                
                    # the properties below are optional
                    data_transforms=[quicksight.CfnDataSet.TransformOperationProperty(
                        cast_column_type_operation=quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                            column_name="columnName",
                            new_column_type="newColumnType",
                
                            # the properties below are optional
                            format="format"
                        ),
                        create_columns_operation=quicksight.CfnDataSet.CreateColumnsOperationProperty(
                            columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                                column_id="columnId",
                                column_name="columnName",
                                expression="expression"
                            )]
                        ),
                        filter_operation=quicksight.CfnDataSet.FilterOperationProperty(
                            condition_expression="conditionExpression"
                        ),
                        project_operation=quicksight.CfnDataSet.ProjectOperationProperty(
                            projected_columns=["projectedColumns"]
                        ),
                        rename_column_operation=quicksight.CfnDataSet.RenameColumnOperationProperty(
                            column_name="columnName",
                            new_column_name="newColumnName"
                        ),
                        tag_column_operation=quicksight.CfnDataSet.TagColumnOperationProperty(
                            column_name="columnName",
                            tags=[quicksight.CfnDataSet.ColumnTagProperty(
                                column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                                    text="text"
                                ),
                                column_geographic_role="columnGeographicRole"
                            )]
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0af103483ba2616564ee2031b6e942f91b914e8c6a9980305c5533b1f1326572)
                check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
                check_type(argname="argument source", value=source, expected_type=type_hints["source"])
                check_type(argname="argument data_transforms", value=data_transforms, expected_type=type_hints["data_transforms"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "alias": alias,
                "source": source,
            }
            if data_transforms is not None:
                self._values["data_transforms"] = data_transforms

        @builtins.property
        def alias(self) -> builtins.str:
            '''A display name for the logical table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-alias
            '''
            result = self._values.get("alias")
            assert result is not None, "Required property 'alias' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.LogicalTableSourceProperty"]:
            '''Source of this logical table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-source
            '''
            result = self._values.get("source")
            assert result is not None, "Required property 'source' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.LogicalTableSourceProperty"], result)

        @builtins.property
        def data_transforms(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.TransformOperationProperty"]]]]:
            '''Transform operations that act on this logical table.

            For this structure to be valid, only one of the attributes can be non-null.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-datatransforms
            '''
            result = self._values.get("data_transforms")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.TransformOperationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LogicalTableProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.LogicalTableSourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_arn": "dataSetArn",
            "join_instruction": "joinInstruction",
            "physical_table_id": "physicalTableId",
        },
    )
    class LogicalTableSourceProperty:
        def __init__(
            self,
            *,
            data_set_arn: typing.Optional[builtins.str] = None,
            join_instruction: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.JoinInstructionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            physical_table_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Information about the source of a logical table.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param data_set_arn: The Amazon Resource Number (ARN) of the parent dataset.
            :param join_instruction: Specifies the result of a join of two logical tables.
            :param physical_table_id: Physical table ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                logical_table_source_property = quicksight.CfnDataSet.LogicalTableSourceProperty(
                    data_set_arn="dataSetArn",
                    join_instruction=quicksight.CfnDataSet.JoinInstructionProperty(
                        left_operand="leftOperand",
                        on_clause="onClause",
                        right_operand="rightOperand",
                        type="type",
                
                        # the properties below are optional
                        left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                            unique_key=False
                        ),
                        right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                            unique_key=False
                        )
                    ),
                    physical_table_id="physicalTableId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0eadb4b1d6b6f9b53d8d626c1546ba3c400b4b9c6aa0325f3961c7f6886b6e63)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument join_instruction", value=join_instruction, expected_type=type_hints["join_instruction"])
                check_type(argname="argument physical_table_id", value=physical_table_id, expected_type=type_hints["physical_table_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_set_arn is not None:
                self._values["data_set_arn"] = data_set_arn
            if join_instruction is not None:
                self._values["join_instruction"] = join_instruction
            if physical_table_id is not None:
                self._values["physical_table_id"] = physical_table_id

        @builtins.property
        def data_set_arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Number (ARN) of the parent dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-datasetarn
            '''
            result = self._values.get("data_set_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def join_instruction(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.JoinInstructionProperty"]]:
            '''Specifies the result of a join of two logical tables.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-joininstruction
            '''
            result = self._values.get("join_instruction")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.JoinInstructionProperty"]], result)

        @builtins.property
        def physical_table_id(self) -> typing.Optional[builtins.str]:
            '''Physical table ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-physicaltableid
            '''
            result = self._values.get("physical_table_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LogicalTableSourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.OutputColumnProperty",
        jsii_struct_bases=[],
        name_mapping={"description": "description", "name": "name", "type": "type"},
    )
    class OutputColumnProperty:
        def __init__(
            self,
            *,
            description: typing.Optional[builtins.str] = None,
            name: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Output column.

            :param description: A description for a column.
            :param name: A display name for the dataset.
            :param type: Type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                output_column_property = quicksight.CfnDataSet.OutputColumnProperty(
                    description="description",
                    name="name",
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b2a1f411cff111a5ef319caab8e1aee77d3274375e6d155b27c95e6330be75a1)
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if description is not None:
                self._values["description"] = description
            if name is not None:
                self._values["name"] = name
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''A description for a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''A display name for the dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "OutputColumnProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.PhysicalTableProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_sql": "customSql",
            "relational_table": "relationalTable",
            "s3_source": "s3Source",
        },
    )
    class PhysicalTableProperty:
        def __init__(
            self,
            *,
            custom_sql: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.CustomSqlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relational_table: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.RelationalTableProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            s3_source: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.S3SourceProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A view of a data source that contains information about the shape of the data in the underlying source.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param custom_sql: A physical table type built from the results of the custom SQL query.
            :param relational_table: A physical table type for relational data sources.
            :param s3_source: A physical table type for as S3 data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                physical_table_property = quicksight.CfnDataSet.PhysicalTableProperty(
                    custom_sql=quicksight.CfnDataSet.CustomSqlProperty(
                        columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type"
                        )],
                        data_source_arn="dataSourceArn",
                        name="name",
                        sql_query="sqlQuery"
                    ),
                    relational_table=quicksight.CfnDataSet.RelationalTableProperty(
                        data_source_arn="dataSourceArn",
                        input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type"
                        )],
                        name="name",
                
                        # the properties below are optional
                        catalog="catalog",
                        schema="schema"
                    ),
                    s3_source=quicksight.CfnDataSet.S3SourceProperty(
                        data_source_arn="dataSourceArn",
                        input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type"
                        )],
                
                        # the properties below are optional
                        upload_settings=quicksight.CfnDataSet.UploadSettingsProperty(
                            contains_header=False,
                            delimiter="delimiter",
                            format="format",
                            start_from_row=123,
                            text_qualifier="textQualifier"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b478d6488c84c8f07f8d928a31b31cb753c4820693c6fb84826577173f7397b)
                check_type(argname="argument custom_sql", value=custom_sql, expected_type=type_hints["custom_sql"])
                check_type(argname="argument relational_table", value=relational_table, expected_type=type_hints["relational_table"])
                check_type(argname="argument s3_source", value=s3_source, expected_type=type_hints["s3_source"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_sql is not None:
                self._values["custom_sql"] = custom_sql
            if relational_table is not None:
                self._values["relational_table"] = relational_table
            if s3_source is not None:
                self._values["s3_source"] = s3_source

        @builtins.property
        def custom_sql(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.CustomSqlProperty"]]:
            '''A physical table type built from the results of the custom SQL query.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-customsql
            '''
            result = self._values.get("custom_sql")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.CustomSqlProperty"]], result)

        @builtins.property
        def relational_table(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.RelationalTableProperty"]]:
            '''A physical table type for relational data sources.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-relationaltable
            '''
            result = self._values.get("relational_table")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.RelationalTableProperty"]], result)

        @builtins.property
        def s3_source(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.S3SourceProperty"]]:
            '''A physical table type for as S3 data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-s3source
            '''
            result = self._values.get("s3_source")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.S3SourceProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PhysicalTableProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.ProjectOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"projected_columns": "projectedColumns"},
    )
    class ProjectOperationProperty:
        def __init__(self, *, projected_columns: typing.Sequence[builtins.str]) -> None:
            '''A transform operation that projects columns.

            Operations that come after a projection can only refer to projected columns.

            :param projected_columns: Projected columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-projectoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                project_operation_property = quicksight.CfnDataSet.ProjectOperationProperty(
                    projected_columns=["projectedColumns"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1f63ace7dc442bffff3145824b1d411600b0d2be5f27a7831288a2e29358b98a)
                check_type(argname="argument projected_columns", value=projected_columns, expected_type=type_hints["projected_columns"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "projected_columns": projected_columns,
            }

        @builtins.property
        def projected_columns(self) -> typing.List[builtins.str]:
            '''Projected columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-projectoperation.html#cfn-quicksight-dataset-projectoperation-projectedcolumns
            '''
            result = self._values.get("projected_columns")
            assert result is not None, "Required property 'projected_columns' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ProjectOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.RelationalTableProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_source_arn": "dataSourceArn",
            "input_columns": "inputColumns",
            "name": "name",
            "catalog": "catalog",
            "schema": "schema",
        },
    )
    class RelationalTableProperty:
        def __init__(
            self,
            *,
            data_source_arn: builtins.str,
            input_columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.InputColumnProperty", typing.Dict[builtins.str, typing.Any]]]]],
            name: builtins.str,
            catalog: typing.Optional[builtins.str] = None,
            schema: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A physical table type for relational data sources.

            :param data_source_arn: The Amazon Resource Name (ARN) for the data source.
            :param input_columns: The column schema of the table.
            :param name: The name of the relational table.
            :param catalog: ``CfnDataSet.RelationalTableProperty.Catalog``.
            :param schema: The schema name. This name applies to certain relational database engines.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                relational_table_property = quicksight.CfnDataSet.RelationalTableProperty(
                    data_source_arn="dataSourceArn",
                    input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                        name="name",
                        type="type"
                    )],
                    name="name",
                
                    # the properties below are optional
                    catalog="catalog",
                    schema="schema"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__63c6398c1e03f6f97af7c39a5a8bf71d034458dfdf49a45eff5bfee15e0c9ed5)
                check_type(argname="argument data_source_arn", value=data_source_arn, expected_type=type_hints["data_source_arn"])
                check_type(argname="argument input_columns", value=input_columns, expected_type=type_hints["input_columns"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument catalog", value=catalog, expected_type=type_hints["catalog"])
                check_type(argname="argument schema", value=schema, expected_type=type_hints["schema"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_source_arn": data_source_arn,
                "input_columns": input_columns,
                "name": name,
            }
            if catalog is not None:
                self._values["catalog"] = catalog
            if schema is not None:
                self._values["schema"] = schema

        @builtins.property
        def data_source_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) for the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-datasourcearn
            '''
            result = self._values.get("data_source_arn")
            assert result is not None, "Required property 'data_source_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def input_columns(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.InputColumnProperty"]]]:
            '''The column schema of the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-inputcolumns
            '''
            result = self._values.get("input_columns")
            assert result is not None, "Required property 'input_columns' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.InputColumnProperty"]]], result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the relational table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def catalog(self) -> typing.Optional[builtins.str]:
            '''``CfnDataSet.RelationalTableProperty.Catalog``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-catalog
            '''
            result = self._values.get("catalog")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def schema(self) -> typing.Optional[builtins.str]:
            '''The schema name.

            This name applies to certain relational database engines.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-schema
            '''
            result = self._values.get("schema")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelationalTableProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.RenameColumnOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"column_name": "columnName", "new_column_name": "newColumnName"},
    )
    class RenameColumnOperationProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            new_column_name: builtins.str,
        ) -> None:
            '''A transform operation that renames a column.

            :param column_name: The name of the column to be renamed.
            :param new_column_name: The new name for the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                rename_column_operation_property = quicksight.CfnDataSet.RenameColumnOperationProperty(
                    column_name="columnName",
                    new_column_name="newColumnName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__052ef03e0a3ca92993865d2a4c8ff5ad7e85a71766fa9b9dde412e2c78bb06b8)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument new_column_name", value=new_column_name, expected_type=type_hints["new_column_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "new_column_name": new_column_name,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The name of the column to be renamed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html#cfn-quicksight-dataset-renamecolumnoperation-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def new_column_name(self) -> builtins.str:
            '''The new name for the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html#cfn-quicksight-dataset-renamecolumnoperation-newcolumnname
            '''
            result = self._values.get("new_column_name")
            assert result is not None, "Required property 'new_column_name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RenameColumnOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={"actions": "actions", "principal": "principal"},
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permisions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnDataSet.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0d4deeda6c6363d3071db20dc0c07cc29dcf0dbd0fecdca54d465128f4339d22)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permisions on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html#cfn-quicksight-dataset-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html#cfn-quicksight-dataset-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.RowLevelPermissionDataSetProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arn": "arn",
            "permission_policy": "permissionPolicy",
            "format_version": "formatVersion",
            "namespace": "namespace",
        },
    )
    class RowLevelPermissionDataSetProperty:
        def __init__(
            self,
            *,
            arn: builtins.str,
            permission_policy: builtins.str,
            format_version: typing.Optional[builtins.str] = None,
            namespace: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Information about a dataset that contains permissions for row-level security (RLS).

            The permissions dataset maps fields to users or groups. For more information, see `Using Row-Level Security (RLS) to Restrict Access to a Dataset <https://docs.aws.amazon.com/quicksight/latest/user/restrict-access-to-a-data-set-using-row-level-security.html>`_ in the *Amazon QuickSight User Guide* .

            The option to deny permissions by setting ``PermissionPolicy`` to ``DENY_ACCESS`` is not supported for new RLS datasets.

            :param arn: The Amazon Resource Name (ARN) of the dataset that contains permissions for RLS.
            :param permission_policy: The type of permissions to use when interpreting the permissions for RLS. ``DENY_ACCESS`` is included for backward compatibility only.
            :param format_version: The user or group rules associated with the dataset that contains permissions for RLS. By default, ``FormatVersion`` is ``VERSION_1`` . When ``FormatVersion`` is ``VERSION_1`` , ``UserName`` and ``GroupName`` are required. When ``FormatVersion`` is ``VERSION_2`` , ``UserARN`` and ``GroupARN`` are required, and ``Namespace`` must not exist.
            :param namespace: The namespace associated with the dataset that contains permissions for RLS.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                row_level_permission_data_set_property = quicksight.CfnDataSet.RowLevelPermissionDataSetProperty(
                    arn="arn",
                    permission_policy="permissionPolicy",
                
                    # the properties below are optional
                    format_version="formatVersion",
                    namespace="namespace"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__24c0fa4af4b60f9c767899dd6ebf7a66c0e97f69e9d2f3aca4a47d9bd9070f29)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument permission_policy", value=permission_policy, expected_type=type_hints["permission_policy"])
                check_type(argname="argument format_version", value=format_version, expected_type=type_hints["format_version"])
                check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
                "permission_policy": permission_policy,
            }
            if format_version is not None:
                self._values["format_version"] = format_version
            if namespace is not None:
                self._values["namespace"] = namespace

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the dataset that contains permissions for RLS.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def permission_policy(self) -> builtins.str:
            '''The type of permissions to use when interpreting the permissions for RLS.

            ``DENY_ACCESS`` is included for backward compatibility only.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-permissionpolicy
            '''
            result = self._values.get("permission_policy")
            assert result is not None, "Required property 'permission_policy' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_version(self) -> typing.Optional[builtins.str]:
            '''The user or group rules associated with the dataset that contains permissions for RLS.

            By default, ``FormatVersion`` is ``VERSION_1`` . When ``FormatVersion`` is ``VERSION_1`` , ``UserName`` and ``GroupName`` are required. When ``FormatVersion`` is ``VERSION_2`` , ``UserARN`` and ``GroupARN`` are required, and ``Namespace`` must not exist.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-formatversion
            '''
            result = self._values.get("format_version")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def namespace(self) -> typing.Optional[builtins.str]:
            '''The namespace associated with the dataset that contains permissions for RLS.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-namespace
            '''
            result = self._values.get("namespace")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowLevelPermissionDataSetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.S3SourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_source_arn": "dataSourceArn",
            "input_columns": "inputColumns",
            "upload_settings": "uploadSettings",
        },
    )
    class S3SourceProperty:
        def __init__(
            self,
            *,
            data_source_arn: builtins.str,
            input_columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.InputColumnProperty", typing.Dict[builtins.str, typing.Any]]]]],
            upload_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.UploadSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A physical table type for an S3 data source.

            :param data_source_arn: The Amazon Resource Name (ARN) for the data source.
            :param input_columns: A physical table type for an S3 data source. .. epigraph:: For files that aren't JSON, only ``STRING`` data types are supported in input columns.
            :param upload_settings: Information about the format for the S3 source file or files.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                s3_source_property = quicksight.CfnDataSet.S3SourceProperty(
                    data_source_arn="dataSourceArn",
                    input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                        name="name",
                        type="type"
                    )],
                
                    # the properties below are optional
                    upload_settings=quicksight.CfnDataSet.UploadSettingsProperty(
                        contains_header=False,
                        delimiter="delimiter",
                        format="format",
                        start_from_row=123,
                        text_qualifier="textQualifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2696fa0e8bed8e448723968db7b8df0b7e2aec74152f37816a006deac506525f)
                check_type(argname="argument data_source_arn", value=data_source_arn, expected_type=type_hints["data_source_arn"])
                check_type(argname="argument input_columns", value=input_columns, expected_type=type_hints["input_columns"])
                check_type(argname="argument upload_settings", value=upload_settings, expected_type=type_hints["upload_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_source_arn": data_source_arn,
                "input_columns": input_columns,
            }
            if upload_settings is not None:
                self._values["upload_settings"] = upload_settings

        @builtins.property
        def data_source_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) for the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-datasourcearn
            '''
            result = self._values.get("data_source_arn")
            assert result is not None, "Required property 'data_source_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def input_columns(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.InputColumnProperty"]]]:
            '''A physical table type for an S3 data source.

            .. epigraph::

               For files that aren't JSON, only ``STRING`` data types are supported in input columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-inputcolumns
            '''
            result = self._values.get("input_columns")
            assert result is not None, "Required property 'input_columns' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.InputColumnProperty"]]], result)

        @builtins.property
        def upload_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.UploadSettingsProperty"]]:
            '''Information about the format for the S3 source file or files.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-uploadsettings
            '''
            result = self._values.get("upload_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.UploadSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "S3SourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.TagColumnOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"column_name": "columnName", "tags": "tags"},
    )
    class TagColumnOperationProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            tags: typing.Sequence[typing.Union["CfnDataSet.ColumnTagProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A transform operation that tags a column with additional information.

            :param column_name: The column that this operation acts on.
            :param tags: The dataset column tag, currently only used for geospatial type tagging. .. epigraph:: This is not tags for the AWS tagging feature.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tag_column_operation_property = quicksight.CfnDataSet.TagColumnOperationProperty(
                    column_name="columnName",
                    tags=[quicksight.CfnDataSet.ColumnTagProperty(
                        column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                            text="text"
                        ),
                        column_geographic_role="columnGeographicRole"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a770588a436f94a35d54e160d1676536abe7fe7ab2fcf3a54212bbf26de58f8)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "tags": tags,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The column that this operation acts on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html#cfn-quicksight-dataset-tagcolumnoperation-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def tags(self) -> typing.List["CfnDataSet.ColumnTagProperty"]:
            '''The dataset column tag, currently only used for geospatial type tagging.

            .. epigraph::

               This is not tags for the AWS tagging feature.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html#cfn-quicksight-dataset-tagcolumnoperation-tags
            '''
            result = self._values.get("tags")
            assert result is not None, "Required property 'tags' is missing"
            return typing.cast(typing.List["CfnDataSet.ColumnTagProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TagColumnOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.TransformOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cast_column_type_operation": "castColumnTypeOperation",
            "create_columns_operation": "createColumnsOperation",
            "filter_operation": "filterOperation",
            "project_operation": "projectOperation",
            "rename_column_operation": "renameColumnOperation",
            "tag_column_operation": "tagColumnOperation",
        },
    )
    class TransformOperationProperty:
        def __init__(
            self,
            *,
            cast_column_type_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.CastColumnTypeOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            create_columns_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.CreateColumnsOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filter_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.FilterOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            project_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.ProjectOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rename_column_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.RenameColumnOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tag_column_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSet.TagColumnOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A data transformation on a logical table.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param cast_column_type_operation: A transform operation that casts a column to a different type.
            :param create_columns_operation: An operation that creates calculated columns. Columns created in one such operation form a lexical closure.
            :param filter_operation: An operation that filters rows based on some condition.
            :param project_operation: An operation that projects columns. Operations that come after a projection can only refer to projected columns.
            :param rename_column_operation: An operation that renames a column.
            :param tag_column_operation: An operation that tags a column with additional information.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                transform_operation_property = quicksight.CfnDataSet.TransformOperationProperty(
                    cast_column_type_operation=quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                        column_name="columnName",
                        new_column_type="newColumnType",
                
                        # the properties below are optional
                        format="format"
                    ),
                    create_columns_operation=quicksight.CfnDataSet.CreateColumnsOperationProperty(
                        columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                            column_id="columnId",
                            column_name="columnName",
                            expression="expression"
                        )]
                    ),
                    filter_operation=quicksight.CfnDataSet.FilterOperationProperty(
                        condition_expression="conditionExpression"
                    ),
                    project_operation=quicksight.CfnDataSet.ProjectOperationProperty(
                        projected_columns=["projectedColumns"]
                    ),
                    rename_column_operation=quicksight.CfnDataSet.RenameColumnOperationProperty(
                        column_name="columnName",
                        new_column_name="newColumnName"
                    ),
                    tag_column_operation=quicksight.CfnDataSet.TagColumnOperationProperty(
                        column_name="columnName",
                        tags=[quicksight.CfnDataSet.ColumnTagProperty(
                            column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                                text="text"
                            ),
                            column_geographic_role="columnGeographicRole"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__549ab51e8fad83714a826238566b12c5ebc44b9fdf44e7d1d61c754cb4da2752)
                check_type(argname="argument cast_column_type_operation", value=cast_column_type_operation, expected_type=type_hints["cast_column_type_operation"])
                check_type(argname="argument create_columns_operation", value=create_columns_operation, expected_type=type_hints["create_columns_operation"])
                check_type(argname="argument filter_operation", value=filter_operation, expected_type=type_hints["filter_operation"])
                check_type(argname="argument project_operation", value=project_operation, expected_type=type_hints["project_operation"])
                check_type(argname="argument rename_column_operation", value=rename_column_operation, expected_type=type_hints["rename_column_operation"])
                check_type(argname="argument tag_column_operation", value=tag_column_operation, expected_type=type_hints["tag_column_operation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cast_column_type_operation is not None:
                self._values["cast_column_type_operation"] = cast_column_type_operation
            if create_columns_operation is not None:
                self._values["create_columns_operation"] = create_columns_operation
            if filter_operation is not None:
                self._values["filter_operation"] = filter_operation
            if project_operation is not None:
                self._values["project_operation"] = project_operation
            if rename_column_operation is not None:
                self._values["rename_column_operation"] = rename_column_operation
            if tag_column_operation is not None:
                self._values["tag_column_operation"] = tag_column_operation

        @builtins.property
        def cast_column_type_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.CastColumnTypeOperationProperty"]]:
            '''A transform operation that casts a column to a different type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-castcolumntypeoperation
            '''
            result = self._values.get("cast_column_type_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.CastColumnTypeOperationProperty"]], result)

        @builtins.property
        def create_columns_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.CreateColumnsOperationProperty"]]:
            '''An operation that creates calculated columns.

            Columns created in one such operation form a lexical closure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-createcolumnsoperation
            '''
            result = self._values.get("create_columns_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.CreateColumnsOperationProperty"]], result)

        @builtins.property
        def filter_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.FilterOperationProperty"]]:
            '''An operation that filters rows based on some condition.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-filteroperation
            '''
            result = self._values.get("filter_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.FilterOperationProperty"]], result)

        @builtins.property
        def project_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.ProjectOperationProperty"]]:
            '''An operation that projects columns.

            Operations that come after a projection can only refer to projected columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-projectoperation
            '''
            result = self._values.get("project_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.ProjectOperationProperty"]], result)

        @builtins.property
        def rename_column_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.RenameColumnOperationProperty"]]:
            '''An operation that renames a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-renamecolumnoperation
            '''
            result = self._values.get("rename_column_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.RenameColumnOperationProperty"]], result)

        @builtins.property
        def tag_column_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.TagColumnOperationProperty"]]:
            '''An operation that tags a column with additional information.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-tagcolumnoperation
            '''
            result = self._values.get("tag_column_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSet.TagColumnOperationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TransformOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSet.UploadSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contains_header": "containsHeader",
            "delimiter": "delimiter",
            "format": "format",
            "start_from_row": "startFromRow",
            "text_qualifier": "textQualifier",
        },
    )
    class UploadSettingsProperty:
        def __init__(
            self,
            *,
            contains_header: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            delimiter: typing.Optional[builtins.str] = None,
            format: typing.Optional[builtins.str] = None,
            start_from_row: typing.Optional[jsii.Number] = None,
            text_qualifier: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Information about the format for a source file or files.

            :param contains_header: Whether the file has a header row, or the files each have a header row.
            :param delimiter: The delimiter between values in the file.
            :param format: File format.
            :param start_from_row: A row number to start reading data from.
            :param text_qualifier: Text qualifier.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                upload_settings_property = quicksight.CfnDataSet.UploadSettingsProperty(
                    contains_header=False,
                    delimiter="delimiter",
                    format="format",
                    start_from_row=123,
                    text_qualifier="textQualifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__59c4869e0939c2288fa4786c1bb023ab228cf0b894282e94c501ab4041b6753d)
                check_type(argname="argument contains_header", value=contains_header, expected_type=type_hints["contains_header"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
                check_type(argname="argument start_from_row", value=start_from_row, expected_type=type_hints["start_from_row"])
                check_type(argname="argument text_qualifier", value=text_qualifier, expected_type=type_hints["text_qualifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if contains_header is not None:
                self._values["contains_header"] = contains_header
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if format is not None:
                self._values["format"] = format
            if start_from_row is not None:
                self._values["start_from_row"] = start_from_row
            if text_qualifier is not None:
                self._values["text_qualifier"] = text_qualifier

        @builtins.property
        def contains_header(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Whether the file has a header row, or the files each have a header row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-containsheader
            '''
            result = self._values.get("contains_header")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter between values in the file.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format(self) -> typing.Optional[builtins.str]:
            '''File format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_from_row(self) -> typing.Optional[jsii.Number]:
            '''A row number to start reading data from.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-startfromrow
            '''
            result = self._values.get("start_from_row")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def text_qualifier(self) -> typing.Optional[builtins.str]:
            '''Text qualifier.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-textqualifier
            '''
            result = self._values.get("text_qualifier")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UploadSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="@aws-cdk/aws-quicksight.CfnDataSetProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "column_groups": "columnGroups",
        "column_level_permission_rules": "columnLevelPermissionRules",
        "data_set_id": "dataSetId",
        "data_set_usage_configuration": "dataSetUsageConfiguration",
        "field_folders": "fieldFolders",
        "import_mode": "importMode",
        "ingestion_wait_policy": "ingestionWaitPolicy",
        "logical_table_map": "logicalTableMap",
        "name": "name",
        "permissions": "permissions",
        "physical_table_map": "physicalTableMap",
        "row_level_permission_data_set": "rowLevelPermissionDataSet",
        "tags": "tags",
    },
)
class CfnDataSetProps:
    def __init__(
        self,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        column_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.ColumnGroupProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        column_level_permission_rules: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.ColumnLevelPermissionRuleProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        data_set_id: typing.Optional[builtins.str] = None,
        data_set_usage_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.DataSetUsageConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        field_folders: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.FieldFolderProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        import_mode: typing.Optional[builtins.str] = None,
        ingestion_wait_policy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.IngestionWaitPolicyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        logical_table_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.LogicalTableProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        physical_table_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.PhysicalTableProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        row_level_permission_data_set: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.RowLevelPermissionDataSetProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''Properties for defining a ``CfnDataSet``.

        :param aws_account_id: The AWS account ID.
        :param column_groups: Groupings of columns that work together in certain Amazon QuickSight features. Currently, only geospatial hierarchy is supported.
        :param column_level_permission_rules: A set of one or more definitions of a ``ColumnLevelPermissionRule`` .
        :param data_set_id: An ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.
        :param data_set_usage_configuration: The usage configuration to apply to child datasets that reference this dataset as a source.
        :param field_folders: The folder that contains fields and nested subfolders for your dataset.
        :param import_mode: Indicates whether you want to import the data into SPICE.
        :param ingestion_wait_policy: The wait policy to use when creating or updating a Dataset. The default is to wait for SPICE ingestion to finish with timeout of 36 hours.
        :param logical_table_map: Configures the combination and transformation of the data from the physical tables.
        :param name: The display name for the dataset.
        :param permissions: A list of resource permissions on the dataset.
        :param physical_table_map: Declares the physical tables that are available in the underlying data sources.
        :param row_level_permission_data_set: The row-level security configuration for the data that you want to create.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            import aws_cdk.aws_quicksight as quicksight
            
            cfn_data_set_props = quicksight.CfnDataSetProps(
                aws_account_id="awsAccountId",
                column_groups=[quicksight.CfnDataSet.ColumnGroupProperty(
                    geo_spatial_column_group=quicksight.CfnDataSet.GeoSpatialColumnGroupProperty(
                        columns=["columns"],
                        name="name",
            
                        # the properties below are optional
                        country_code="countryCode"
                    )
                )],
                column_level_permission_rules=[quicksight.CfnDataSet.ColumnLevelPermissionRuleProperty(
                    column_names=["columnNames"],
                    principals=["principals"]
                )],
                data_set_id="dataSetId",
                data_set_usage_configuration=quicksight.CfnDataSet.DataSetUsageConfigurationProperty(
                    disable_use_as_direct_query_source=False,
                    disable_use_as_imported_source=False
                ),
                field_folders={
                    "field_folders_key": quicksight.CfnDataSet.FieldFolderProperty(
                        columns=["columns"],
                        description="description"
                    )
                },
                import_mode="importMode",
                ingestion_wait_policy=quicksight.CfnDataSet.IngestionWaitPolicyProperty(
                    ingestion_wait_time_in_hours=123,
                    wait_for_spice_ingestion=False
                ),
                logical_table_map={
                    "logical_table_map_key": quicksight.CfnDataSet.LogicalTableProperty(
                        alias="alias",
                        source=quicksight.CfnDataSet.LogicalTableSourceProperty(
                            data_set_arn="dataSetArn",
                            join_instruction=quicksight.CfnDataSet.JoinInstructionProperty(
                                left_operand="leftOperand",
                                on_clause="onClause",
                                right_operand="rightOperand",
                                type="type",
            
                                # the properties below are optional
                                left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                    unique_key=False
                                ),
                                right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                    unique_key=False
                                )
                            ),
                            physical_table_id="physicalTableId"
                        ),
            
                        # the properties below are optional
                        data_transforms=[quicksight.CfnDataSet.TransformOperationProperty(
                            cast_column_type_operation=quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                                column_name="columnName",
                                new_column_type="newColumnType",
            
                                # the properties below are optional
                                format="format"
                            ),
                            create_columns_operation=quicksight.CfnDataSet.CreateColumnsOperationProperty(
                                columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                                    column_id="columnId",
                                    column_name="columnName",
                                    expression="expression"
                                )]
                            ),
                            filter_operation=quicksight.CfnDataSet.FilterOperationProperty(
                                condition_expression="conditionExpression"
                            ),
                            project_operation=quicksight.CfnDataSet.ProjectOperationProperty(
                                projected_columns=["projectedColumns"]
                            ),
                            rename_column_operation=quicksight.CfnDataSet.RenameColumnOperationProperty(
                                column_name="columnName",
                                new_column_name="newColumnName"
                            ),
                            tag_column_operation=quicksight.CfnDataSet.TagColumnOperationProperty(
                                column_name="columnName",
                                tags=[quicksight.CfnDataSet.ColumnTagProperty(
                                    column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                                        text="text"
                                    ),
                                    column_geographic_role="columnGeographicRole"
                                )]
                            )
                        )]
                    )
                },
                name="name",
                permissions=[quicksight.CfnDataSet.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )],
                physical_table_map={
                    "physical_table_map_key": quicksight.CfnDataSet.PhysicalTableProperty(
                        custom_sql=quicksight.CfnDataSet.CustomSqlProperty(
                            columns=[quicksight.CfnDataSet.InputColumnProperty(
                                name="name",
                                type="type"
                            )],
                            data_source_arn="dataSourceArn",
                            name="name",
                            sql_query="sqlQuery"
                        ),
                        relational_table=quicksight.CfnDataSet.RelationalTableProperty(
                            data_source_arn="dataSourceArn",
                            input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                                name="name",
                                type="type"
                            )],
                            name="name",
            
                            # the properties below are optional
                            catalog="catalog",
                            schema="schema"
                        ),
                        s3_source=quicksight.CfnDataSet.S3SourceProperty(
                            data_source_arn="dataSourceArn",
                            input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                                name="name",
                                type="type"
                            )],
            
                            # the properties below are optional
                            upload_settings=quicksight.CfnDataSet.UploadSettingsProperty(
                                contains_header=False,
                                delimiter="delimiter",
                                format="format",
                                start_from_row=123,
                                text_qualifier="textQualifier"
                            )
                        )
                    )
                },
                row_level_permission_data_set=quicksight.CfnDataSet.RowLevelPermissionDataSetProperty(
                    arn="arn",
                    permission_policy="permissionPolicy",
            
                    # the properties below are optional
                    format_version="formatVersion",
                    namespace="namespace"
                ),
                tags=[CfnTag(
                    key="key",
                    value="value"
                )]
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dcbf65201b1c019fd2259635b29eb8787222c3a9ee63c99c9aa3b8b9a3d370e0)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument column_groups", value=column_groups, expected_type=type_hints["column_groups"])
            check_type(argname="argument column_level_permission_rules", value=column_level_permission_rules, expected_type=type_hints["column_level_permission_rules"])
            check_type(argname="argument data_set_id", value=data_set_id, expected_type=type_hints["data_set_id"])
            check_type(argname="argument data_set_usage_configuration", value=data_set_usage_configuration, expected_type=type_hints["data_set_usage_configuration"])
            check_type(argname="argument field_folders", value=field_folders, expected_type=type_hints["field_folders"])
            check_type(argname="argument import_mode", value=import_mode, expected_type=type_hints["import_mode"])
            check_type(argname="argument ingestion_wait_policy", value=ingestion_wait_policy, expected_type=type_hints["ingestion_wait_policy"])
            check_type(argname="argument logical_table_map", value=logical_table_map, expected_type=type_hints["logical_table_map"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument physical_table_map", value=physical_table_map, expected_type=type_hints["physical_table_map"])
            check_type(argname="argument row_level_permission_data_set", value=row_level_permission_data_set, expected_type=type_hints["row_level_permission_data_set"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if column_groups is not None:
            self._values["column_groups"] = column_groups
        if column_level_permission_rules is not None:
            self._values["column_level_permission_rules"] = column_level_permission_rules
        if data_set_id is not None:
            self._values["data_set_id"] = data_set_id
        if data_set_usage_configuration is not None:
            self._values["data_set_usage_configuration"] = data_set_usage_configuration
        if field_folders is not None:
            self._values["field_folders"] = field_folders
        if import_mode is not None:
            self._values["import_mode"] = import_mode
        if ingestion_wait_policy is not None:
            self._values["ingestion_wait_policy"] = ingestion_wait_policy
        if logical_table_map is not None:
            self._values["logical_table_map"] = logical_table_map
        if name is not None:
            self._values["name"] = name
        if permissions is not None:
            self._values["permissions"] = permissions
        if physical_table_map is not None:
            self._values["physical_table_map"] = physical_table_map
        if row_level_permission_data_set is not None:
            self._values["row_level_permission_data_set"] = row_level_permission_data_set
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def column_groups(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.ColumnGroupProperty]]]]:
        '''Groupings of columns that work together in certain Amazon QuickSight features.

        Currently, only geospatial hierarchy is supported.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columngroups
        '''
        result = self._values.get("column_groups")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.ColumnGroupProperty]]]], result)

    @builtins.property
    def column_level_permission_rules(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.ColumnLevelPermissionRuleProperty]]]]:
        '''A set of one or more definitions of a ``ColumnLevelPermissionRule`` .

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columnlevelpermissionrules
        '''
        result = self._values.get("column_level_permission_rules")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.ColumnLevelPermissionRuleProperty]]]], result)

    @builtins.property
    def data_set_id(self) -> typing.Optional[builtins.str]:
        '''An ID for the dataset that you want to create.

        This ID is unique per AWS Region for each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetid
        '''
        result = self._values.get("data_set_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def data_set_usage_configuration(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.DataSetUsageConfigurationProperty]]:
        '''The usage configuration to apply to child datasets that reference this dataset as a source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetusageconfiguration
        '''
        result = self._values.get("data_set_usage_configuration")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.DataSetUsageConfigurationProperty]], result)

    @builtins.property
    def field_folders(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.FieldFolderProperty]]]]:
        '''The folder that contains fields and nested subfolders for your dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-fieldfolders
        '''
        result = self._values.get("field_folders")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.FieldFolderProperty]]]], result)

    @builtins.property
    def import_mode(self) -> typing.Optional[builtins.str]:
        '''Indicates whether you want to import the data into SPICE.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-importmode
        '''
        result = self._values.get("import_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ingestion_wait_policy(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.IngestionWaitPolicyProperty]]:
        '''The wait policy to use when creating or updating a Dataset.

        The default is to wait for SPICE ingestion to finish with timeout of 36 hours.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-ingestionwaitpolicy
        '''
        result = self._values.get("ingestion_wait_policy")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.IngestionWaitPolicyProperty]], result)

    @builtins.property
    def logical_table_map(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.LogicalTableProperty]]]]:
        '''Configures the combination and transformation of the data from the physical tables.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-logicaltablemap
        '''
        result = self._values.get("logical_table_map")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.LogicalTableProperty]]]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The display name for the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.ResourcePermissionProperty]]]]:
        '''A list of resource permissions on the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.ResourcePermissionProperty]]]], result)

    @builtins.property
    def physical_table_map(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.PhysicalTableProperty]]]]:
        '''Declares the physical tables that are available in the underlying data sources.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-physicaltablemap
        '''
        result = self._values.get("physical_table_map")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.PhysicalTableProperty]]]], result)

    @builtins.property
    def row_level_permission_data_set(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.RowLevelPermissionDataSetProperty]]:
        '''The row-level security configuration for the data that you want to create.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset
        '''
        result = self._values.get("row_level_permission_data_set")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.RowLevelPermissionDataSetProperty]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnDataSetProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_aws_cdk_core_f4b25747.IInspectable)
class CfnDataSource(
    _aws_cdk_core_f4b25747.CfnResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@aws-cdk/aws-quicksight.CfnDataSource",
):
    '''A CloudFormation ``AWS::QuickSight::DataSource``.

    Creates a data source.

    :cloudformationResource: AWS::QuickSight::DataSource
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        import aws_cdk.aws_quicksight as quicksight
        
        cfn_data_source = quicksight.CfnDataSource(self, "MyCfnDataSource",
            alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                    domain="domain"
                ),
                amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                    domain="domain"
                ),
                athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                    work_group="workGroup"
                ),
                aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                    host="host",
                    port=123,
                    sql_endpoint_path="sqlEndpointPath"
                ),
                maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123
                ),
                rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                    database="database",
                    instance_id="instanceId"
                ),
                redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                    database="database",
        
                    # the properties below are optional
                    cluster_id="clusterId",
                    host="host",
                    port=123
                ),
                s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                    manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                        bucket="bucket",
                        key="key"
                    )
                ),
                snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                    database="database",
                    host="host",
                    warehouse="warehouse"
                ),
                spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                    host="host",
                    port=123
                ),
                sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            )],
            aws_account_id="awsAccountId",
            credentials=quicksight.CfnDataSource.DataSourceCredentialsProperty(
                copy_source_arn="copySourceArn",
                credential_pair=quicksight.CfnDataSource.CredentialPairProperty(
                    password="password",
                    username="username",
        
                    # the properties below are optional
                    alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                        amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                            domain="domain"
                        ),
                        amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                            domain="domain"
                        ),
                        athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                            work_group="workGroup"
                        ),
                        aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                            host="host",
                            port=123,
                            sql_endpoint_path="sqlEndpointPath"
                        ),
                        maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                            catalog="catalog",
                            host="host",
                            port=123
                        ),
                        rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                            database="database",
                            instance_id="instanceId"
                        ),
                        redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                            database="database",
        
                            # the properties below are optional
                            cluster_id="clusterId",
                            host="host",
                            port=123
                        ),
                        s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                            manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                                bucket="bucket",
                                key="key"
                            )
                        ),
                        snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                            database="database",
                            host="host",
                            warehouse="warehouse"
                        ),
                        spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                            host="host",
                            port=123
                        ),
                        sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        )
                    )]
                ),
                secret_arn="secretArn"
            ),
            data_source_id="dataSourceId",
            data_source_parameters=quicksight.CfnDataSource.DataSourceParametersProperty(
                amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                    domain="domain"
                ),
                amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                    domain="domain"
                ),
                athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                    work_group="workGroup"
                ),
                aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                    host="host",
                    port=123,
                    sql_endpoint_path="sqlEndpointPath"
                ),
                maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123
                ),
                rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                    database="database",
                    instance_id="instanceId"
                ),
                redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                    database="database",
        
                    # the properties below are optional
                    cluster_id="clusterId",
                    host="host",
                    port=123
                ),
                s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                    manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                        bucket="bucket",
                        key="key"
                    )
                ),
                snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                    database="database",
                    host="host",
                    warehouse="warehouse"
                ),
                spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                    host="host",
                    port=123
                ),
                sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            ),
            error_info=quicksight.CfnDataSource.DataSourceErrorInfoProperty(
                message="message",
                type="type"
            ),
            name="name",
            permissions=[quicksight.CfnDataSource.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal"
            )],
            ssl_properties=quicksight.CfnDataSource.SslPropertiesProperty(
                disable_ssl=False
            ),
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            type="type",
            vpc_connection_properties=quicksight.CfnDataSource.VpcConnectionPropertiesProperty(
                vpc_connection_arn="vpcConnectionArn"
            )
        )
    '''

    def __init__(
        self,
        scope: _aws_cdk_core_f4b25747.Construct,
        id: builtins.str,
        *,
        alternate_data_source_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.DataSourceParametersProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        aws_account_id: typing.Optional[builtins.str] = None,
        credentials: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.DataSourceCredentialsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        data_source_id: typing.Optional[builtins.str] = None,
        data_source_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.DataSourceParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        error_info: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.DataSourceErrorInfoProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ssl_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.SslPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
        type: typing.Optional[builtins.str] = None,
        vpc_connection_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.VpcConnectionPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::DataSource``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param alternate_data_source_parameters: A set of alternate data source parameters that you want to share for the credentials stored with this data source. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the ``AlternateDataSourceParameters`` list is null, the ``Credentials`` originally used with this ``DataSourceParameters`` are automatically allowed.
        :param aws_account_id: The AWS account ID.
        :param credentials: The credentials Amazon QuickSight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported.
        :param data_source_id: An ID for the data source. This ID is unique per AWS Region for each AWS account.
        :param data_source_parameters: The parameters that Amazon QuickSight uses to connect to your underlying source.
        :param error_info: Error information from the last update or the creation of the data source.
        :param name: A display name for the data source.
        :param permissions: A list of resource permissions on the data source.
        :param ssl_properties: Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.
        :param type: The type of the data source. To return a list of all data sources, use ``ListDataSources`` . Use ``AMAZON_ELASTICSEARCH`` for Amazon OpenSearch Service.
        :param vpc_connection_properties: Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b2823309fbedc7f2fb848996ea03167361f24d88056ab81e33c32cd89bd891c9)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnDataSourceProps(
            alternate_data_source_parameters=alternate_data_source_parameters,
            aws_account_id=aws_account_id,
            credentials=credentials,
            data_source_id=data_source_id,
            data_source_parameters=data_source_parameters,
            error_info=error_info,
            name=name,
            permissions=permissions,
            ssl_properties=ssl_properties,
            tags=tags,
            type=type,
            vpc_connection_properties=vpc_connection_properties,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _aws_cdk_core_f4b25747.TreeInspector) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__89e8c0d3bd1fb0670b423aaeca941792b2e89490ef01a70ee55ce8fe5376233a)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3fc88db1de7ba35d9c42ac18a967c192a0bdf78a9ed3a36fc8ffb95fa9d5020f)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the dataset.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time that this data source was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The last time that this data source was updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrStatus")
    def attr_status(self) -> builtins.str:
        '''The HTTP status of the request.

        :cloudformationAttribute: Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrStatus"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _aws_cdk_core_f4b25747.TagManager:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-tags
        '''
        return typing.cast(_aws_cdk_core_f4b25747.TagManager, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="alternateDataSourceParameters")
    def alternate_data_source_parameters(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceParametersProperty"]]]]:
        '''A set of alternate data source parameters that you want to share for the credentials stored with this data source.

        The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the ``AlternateDataSourceParameters`` list is null, the ``Credentials`` originally used with this ``DataSourceParameters`` are automatically allowed.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-alternatedatasourceparameters
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceParametersProperty"]]]], jsii.get(self, "alternateDataSourceParameters"))

    @alternate_data_source_parameters.setter
    def alternate_data_source_parameters(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceParametersProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3d3ba5d144819f881507eeb6bac052a7d1b41c9d52aadc3489e75d2ddddfcd4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alternateDataSourceParameters", value)

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-awsaccountid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__50e40f6e1aff54204a8abbc36569b6ac038fe1636116334f2bb5b0368becc053)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="credentials")
    def credentials(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceCredentialsProperty"]]:
        '''The credentials Amazon QuickSight that uses to connect to your underlying source.

        Currently, only credentials based on user name and password are supported.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-credentials
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceCredentialsProperty"]], jsii.get(self, "credentials"))

    @credentials.setter
    def credentials(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceCredentialsProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__174468676923c9a90a90506f0d3b0ffb499805b3427a64b1dcd65e2ea32e0319)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "credentials", value)

    @builtins.property
    @jsii.member(jsii_name="dataSourceId")
    def data_source_id(self) -> typing.Optional[builtins.str]:
        '''An ID for the data source.

        This ID is unique per AWS Region for each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceId"))

    @data_source_id.setter
    def data_source_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2993b6edd46f33cd70ac8d4a04544a0e7ea3ce4b1763701bf143b1451f7ac408)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSourceId", value)

    @builtins.property
    @jsii.member(jsii_name="dataSourceParameters")
    def data_source_parameters(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceParametersProperty"]]:
        '''The parameters that Amazon QuickSight uses to connect to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceparameters
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceParametersProperty"]], jsii.get(self, "dataSourceParameters"))

    @data_source_parameters.setter
    def data_source_parameters(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceParametersProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d581fd88e96b7834c61441560d7251d3f221d845e5fe50433634e6b5799cb8b1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSourceParameters", value)

    @builtins.property
    @jsii.member(jsii_name="errorInfo")
    def error_info(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceErrorInfoProperty"]]:
        '''Error information from the last update or the creation of the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-errorinfo
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceErrorInfoProperty"]], jsii.get(self, "errorInfo"))

    @error_info.setter
    def error_info(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceErrorInfoProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ed12f02f0af860a74d00d428e0c15c302ca4f2d3ce39474d53ef376ccb904417)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "errorInfo", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-name
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__91804e99580af8c0e0b1052149f8df6392b9f0192ce8d40d1fe2ba524132b9c3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.ResourcePermissionProperty"]]]]:
        '''A list of resource permissions on the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-permissions
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.ResourcePermissionProperty"]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.ResourcePermissionProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__27bef660e685853463e4e4a343ec3f9cb91dac14f3b79cb2bc0e161d02ac801b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="sslProperties")
    def ssl_properties(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.SslPropertiesProperty"]]:
        '''Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-sslproperties
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.SslPropertiesProperty"]], jsii.get(self, "sslProperties"))

    @ssl_properties.setter
    def ssl_properties(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.SslPropertiesProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d057ba2a3bd71a1013260cafdc3217bf3cbfd1d1fdb56f079827c511e77ab480)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sslProperties", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> typing.Optional[builtins.str]:
        '''The type of the data source. To return a list of all data sources, use ``ListDataSources`` .

        Use ``AMAZON_ELASTICSEARCH`` for Amazon OpenSearch Service.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-type
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "type"))

    @type.setter
    def type(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d1c528579ec913cac2127d6db75d6bf9f89b0fa6b10e3311629317e71dde29e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="vpcConnectionProperties")
    def vpc_connection_properties(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.VpcConnectionPropertiesProperty"]]:
        '''Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-vpcconnectionproperties
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.VpcConnectionPropertiesProperty"]], jsii.get(self, "vpcConnectionProperties"))

    @vpc_connection_properties.setter
    def vpc_connection_properties(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.VpcConnectionPropertiesProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b065dd8cefadd9a44e3e1a83439b88f994b9a5b104ed731b68ee155191e05998)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "vpcConnectionProperties", value)

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.AmazonElasticsearchParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"domain": "domain"},
    )
    class AmazonElasticsearchParametersProperty:
        def __init__(self, *, domain: builtins.str) -> None:
            '''The parameters for OpenSearch.

            :param domain: The OpenSearch domain.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonelasticsearchparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                amazon_elasticsearch_parameters_property = quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                    domain="domain"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c78a70b975494058a76aefd94d61935788fcc478f7d76e2687a52fe646f84bb1)
                check_type(argname="argument domain", value=domain, expected_type=type_hints["domain"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "domain": domain,
            }

        @builtins.property
        def domain(self) -> builtins.str:
            '''The OpenSearch domain.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonelasticsearchparameters.html#cfn-quicksight-datasource-amazonelasticsearchparameters-domain
            '''
            result = self._values.get("domain")
            assert result is not None, "Required property 'domain' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AmazonElasticsearchParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.AmazonOpenSearchParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"domain": "domain"},
    )
    class AmazonOpenSearchParametersProperty:
        def __init__(self, *, domain: builtins.str) -> None:
            '''The parameters for OpenSearch.

            :param domain: The OpenSearch domain.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonopensearchparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                amazon_open_search_parameters_property = quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                    domain="domain"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__53320c197cba357481cfb047759cc6b3aadb0c76a6ca988476e26e6d78294d24)
                check_type(argname="argument domain", value=domain, expected_type=type_hints["domain"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "domain": domain,
            }

        @builtins.property
        def domain(self) -> builtins.str:
            '''The OpenSearch domain.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonopensearchparameters.html#cfn-quicksight-datasource-amazonopensearchparameters-domain
            '''
            result = self._values.get("domain")
            assert result is not None, "Required property 'domain' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AmazonOpenSearchParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.AthenaParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"work_group": "workGroup"},
    )
    class AthenaParametersProperty:
        def __init__(self, *, work_group: typing.Optional[builtins.str] = None) -> None:
            '''Parameters for Amazon Athena.

            :param work_group: The workgroup that Amazon Athena uses.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-athenaparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                athena_parameters_property = quicksight.CfnDataSource.AthenaParametersProperty(
                    work_group="workGroup"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce3df1ee7ccde63f009c1b584a7e7ce39cf2a875955fba2dc8c18f11a471f983)
                check_type(argname="argument work_group", value=work_group, expected_type=type_hints["work_group"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if work_group is not None:
                self._values["work_group"] = work_group

        @builtins.property
        def work_group(self) -> typing.Optional[builtins.str]:
            '''The workgroup that Amazon Athena uses.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-athenaparameters.html#cfn-quicksight-datasource-athenaparameters-workgroup
            '''
            result = self._values.get("work_group")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AthenaParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.AuroraParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class AuroraParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''Parameters for Amazon Aurora.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                aurora_parameters_property = quicksight.CfnDataSource.AuroraParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f99aefcd7147350f6dd70e0db93404effbc5656252607c459741f9133edc240f)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AuroraParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class AuroraPostgreSqlParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''Parameters for Amazon Aurora PostgreSQL-Compatible Edition.

            :param database: The Amazon Aurora PostgreSQL database to connect to.
            :param host: The Amazon Aurora PostgreSQL-Compatible host to connect to.
            :param port: The port that Amazon Aurora PostgreSQL is listening on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                aurora_postgre_sql_parameters_property = quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f01882378ca0fe13cd84d2d87916916489a35767fc155559c9e5d95396ffd0bd)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''The Amazon Aurora PostgreSQL database to connect to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''The Amazon Aurora PostgreSQL-Compatible host to connect to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''The port that Amazon Aurora PostgreSQL is listening on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AuroraPostgreSqlParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.CredentialPairProperty",
        jsii_struct_bases=[],
        name_mapping={
            "password": "password",
            "username": "username",
            "alternate_data_source_parameters": "alternateDataSourceParameters",
        },
    )
    class CredentialPairProperty:
        def __init__(
            self,
            *,
            password: builtins.str,
            username: builtins.str,
            alternate_data_source_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.DataSourceParametersProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The combination of user name and password that are used as credentials.

            :param password: Password.
            :param username: User name.
            :param alternate_data_source_parameters: A set of alternate data source parameters that you want to share for these credentials. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the new data source with the existing credentials. If the ``AlternateDataSourceParameters`` list is null, the ``DataSourceParameters`` originally used with these ``Credentials`` is automatically allowed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                credential_pair_property = quicksight.CfnDataSource.CredentialPairProperty(
                    password="password",
                    username="username",
                
                    # the properties below are optional
                    alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                        amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                            domain="domain"
                        ),
                        amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                            domain="domain"
                        ),
                        athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                            work_group="workGroup"
                        ),
                        aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                            host="host",
                            port=123,
                            sql_endpoint_path="sqlEndpointPath"
                        ),
                        maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                            catalog="catalog",
                            host="host",
                            port=123
                        ),
                        rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                            database="database",
                            instance_id="instanceId"
                        ),
                        redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                            database="database",
                
                            # the properties below are optional
                            cluster_id="clusterId",
                            host="host",
                            port=123
                        ),
                        s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                            manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                                bucket="bucket",
                                key="key"
                            )
                        ),
                        snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                            database="database",
                            host="host",
                            warehouse="warehouse"
                        ),
                        spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                            host="host",
                            port=123
                        ),
                        sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__73fa5df60b6bcc6333bdebd18ccbe09835e535f164400d4ca34895cd34097169)
                check_type(argname="argument password", value=password, expected_type=type_hints["password"])
                check_type(argname="argument username", value=username, expected_type=type_hints["username"])
                check_type(argname="argument alternate_data_source_parameters", value=alternate_data_source_parameters, expected_type=type_hints["alternate_data_source_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "password": password,
                "username": username,
            }
            if alternate_data_source_parameters is not None:
                self._values["alternate_data_source_parameters"] = alternate_data_source_parameters

        @builtins.property
        def password(self) -> builtins.str:
            '''Password.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-password
            '''
            result = self._values.get("password")
            assert result is not None, "Required property 'password' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def username(self) -> builtins.str:
            '''User name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-username
            '''
            result = self._values.get("username")
            assert result is not None, "Required property 'username' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def alternate_data_source_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceParametersProperty"]]]]:
            '''A set of alternate data source parameters that you want to share for these credentials.

            The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the new data source with the existing credentials. If the ``AlternateDataSourceParameters`` list is null, the ``DataSourceParameters`` originally used with these ``Credentials`` is automatically allowed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-alternatedatasourceparameters
            '''
            result = self._values.get("alternate_data_source_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DataSourceParametersProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CredentialPairProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.DataSourceCredentialsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "copy_source_arn": "copySourceArn",
            "credential_pair": "credentialPair",
            "secret_arn": "secretArn",
        },
    )
    class DataSourceCredentialsProperty:
        def __init__(
            self,
            *,
            copy_source_arn: typing.Optional[builtins.str] = None,
            credential_pair: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.CredentialPairProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secret_arn: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Data source credentials.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param copy_source_arn: The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use. When ``CopySourceArn`` is not null, the credential pair from the data source in the ARN is used as the credentials for the ``DataSourceCredentials`` structure.
            :param credential_pair: Credential pair. For more information, see ``[CredentialPair](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CredentialPair.html)`` .
            :param secret_arn: The Amazon Resource Name (ARN) of the secret associated with the data source in AWS Secrets Manager .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_source_credentials_property = quicksight.CfnDataSource.DataSourceCredentialsProperty(
                    copy_source_arn="copySourceArn",
                    credential_pair=quicksight.CfnDataSource.CredentialPairProperty(
                        password="password",
                        username="username",
                
                        # the properties below are optional
                        alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                            amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                                domain="domain"
                            ),
                            amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                                domain="domain"
                            ),
                            athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                                work_group="workGroup"
                            ),
                            aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                                host="host",
                                port=123,
                                sql_endpoint_path="sqlEndpointPath"
                            ),
                            maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                                catalog="catalog",
                                host="host",
                                port=123
                            ),
                            rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                                database="database",
                                instance_id="instanceId"
                            ),
                            redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                                database="database",
                
                                # the properties below are optional
                                cluster_id="clusterId",
                                host="host",
                                port=123
                            ),
                            s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                                manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                                    bucket="bucket",
                                    key="key"
                                )
                            ),
                            snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                                database="database",
                                host="host",
                                warehouse="warehouse"
                            ),
                            spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                                host="host",
                                port=123
                            ),
                            sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            )
                        )]
                    ),
                    secret_arn="secretArn"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c08eaf14492fc5b951aa36b02701c4078c3e9b181410a196227087d446e1929)
                check_type(argname="argument copy_source_arn", value=copy_source_arn, expected_type=type_hints["copy_source_arn"])
                check_type(argname="argument credential_pair", value=credential_pair, expected_type=type_hints["credential_pair"])
                check_type(argname="argument secret_arn", value=secret_arn, expected_type=type_hints["secret_arn"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if copy_source_arn is not None:
                self._values["copy_source_arn"] = copy_source_arn
            if credential_pair is not None:
                self._values["credential_pair"] = credential_pair
            if secret_arn is not None:
                self._values["secret_arn"] = secret_arn

        @builtins.property
        def copy_source_arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use.

            When ``CopySourceArn`` is not null, the credential pair from the data source in the ARN is used as the credentials for the ``DataSourceCredentials`` structure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-copysourcearn
            '''
            result = self._values.get("copy_source_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def credential_pair(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.CredentialPairProperty"]]:
            '''Credential pair.

            For more information, see ``[CredentialPair](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CredentialPair.html)`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-credentialpair
            '''
            result = self._values.get("credential_pair")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.CredentialPairProperty"]], result)

        @builtins.property
        def secret_arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of the secret associated with the data source in AWS Secrets Manager .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-secretarn
            '''
            result = self._values.get("secret_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSourceCredentialsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.DataSourceErrorInfoProperty",
        jsii_struct_bases=[],
        name_mapping={"message": "message", "type": "type"},
    )
    class DataSourceErrorInfoProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Error information for the data source creation or update.

            :param message: Error message.
            :param type: Error type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_source_error_info_property = quicksight.CfnDataSource.DataSourceErrorInfoProperty(
                    message="message",
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4f982d7f6acbd7958b3cb17603d49e134aa2fbe75a371bec693e638b2c283d71)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''Error message.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html#cfn-quicksight-datasource-datasourceerrorinfo-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Error type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html#cfn-quicksight-datasource-datasourceerrorinfo-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSourceErrorInfoProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.DataSourceParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "amazon_elasticsearch_parameters": "amazonElasticsearchParameters",
            "amazon_open_search_parameters": "amazonOpenSearchParameters",
            "athena_parameters": "athenaParameters",
            "aurora_parameters": "auroraParameters",
            "aurora_postgre_sql_parameters": "auroraPostgreSqlParameters",
            "databricks_parameters": "databricksParameters",
            "maria_db_parameters": "mariaDbParameters",
            "my_sql_parameters": "mySqlParameters",
            "oracle_parameters": "oracleParameters",
            "postgre_sql_parameters": "postgreSqlParameters",
            "presto_parameters": "prestoParameters",
            "rds_parameters": "rdsParameters",
            "redshift_parameters": "redshiftParameters",
            "s3_parameters": "s3Parameters",
            "snowflake_parameters": "snowflakeParameters",
            "spark_parameters": "sparkParameters",
            "sql_server_parameters": "sqlServerParameters",
            "teradata_parameters": "teradataParameters",
        },
    )
    class DataSourceParametersProperty:
        def __init__(
            self,
            *,
            amazon_elasticsearch_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.AmazonElasticsearchParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            amazon_open_search_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.AmazonOpenSearchParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            athena_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.AthenaParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            aurora_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.AuroraParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            aurora_postgre_sql_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.AuroraPostgreSqlParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            databricks_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.DatabricksParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maria_db_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.MariaDbParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            my_sql_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.MySqlParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            oracle_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.OracleParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            postgre_sql_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.PostgreSqlParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            presto_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.PrestoParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rds_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.RdsParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            redshift_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.RedshiftParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            s3_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.S3ParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            snowflake_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.SnowflakeParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            spark_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.SparkParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sql_server_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.SqlServerParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            teradata_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.TeradataParametersProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The parameters that Amazon QuickSight uses to connect to your underlying data source.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param amazon_elasticsearch_parameters: The parameters for OpenSearch.
            :param amazon_open_search_parameters: The parameters for OpenSearch.
            :param athena_parameters: The parameters for Amazon Athena.
            :param aurora_parameters: The parameters for Amazon Aurora MySQL.
            :param aurora_postgre_sql_parameters: The parameters for Amazon Aurora.
            :param databricks_parameters: The required parameters that are needed to connect to a Databricks data source.
            :param maria_db_parameters: The parameters for MariaDB.
            :param my_sql_parameters: The parameters for MySQL.
            :param oracle_parameters: Oracle parameters.
            :param postgre_sql_parameters: The parameters for PostgreSQL.
            :param presto_parameters: The parameters for Presto.
            :param rds_parameters: The parameters for Amazon RDS.
            :param redshift_parameters: The parameters for Amazon Redshift.
            :param s3_parameters: The parameters for S3.
            :param snowflake_parameters: The parameters for Snowflake.
            :param spark_parameters: The parameters for Spark.
            :param sql_server_parameters: The parameters for SQL Server.
            :param teradata_parameters: The parameters for Teradata.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_source_parameters_property = quicksight.CfnDataSource.DataSourceParametersProperty(
                    amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                        domain="domain"
                    ),
                    amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                        domain="domain"
                    ),
                    athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                        work_group="workGroup"
                    ),
                    aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                        host="host",
                        port=123,
                        sql_endpoint_path="sqlEndpointPath"
                    ),
                    maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123
                    ),
                    rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                        database="database",
                        instance_id="instanceId"
                    ),
                    redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                        database="database",
                
                        # the properties below are optional
                        cluster_id="clusterId",
                        host="host",
                        port=123
                    ),
                    s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                        manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                            bucket="bucket",
                            key="key"
                        )
                    ),
                    snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                        database="database",
                        host="host",
                        warehouse="warehouse"
                    ),
                    spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                        host="host",
                        port=123
                    ),
                    sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__780424355b227fbe1b279c9d93cfb70511ad834edace85699baa966ef5dafed7)
                check_type(argname="argument amazon_elasticsearch_parameters", value=amazon_elasticsearch_parameters, expected_type=type_hints["amazon_elasticsearch_parameters"])
                check_type(argname="argument amazon_open_search_parameters", value=amazon_open_search_parameters, expected_type=type_hints["amazon_open_search_parameters"])
                check_type(argname="argument athena_parameters", value=athena_parameters, expected_type=type_hints["athena_parameters"])
                check_type(argname="argument aurora_parameters", value=aurora_parameters, expected_type=type_hints["aurora_parameters"])
                check_type(argname="argument aurora_postgre_sql_parameters", value=aurora_postgre_sql_parameters, expected_type=type_hints["aurora_postgre_sql_parameters"])
                check_type(argname="argument databricks_parameters", value=databricks_parameters, expected_type=type_hints["databricks_parameters"])
                check_type(argname="argument maria_db_parameters", value=maria_db_parameters, expected_type=type_hints["maria_db_parameters"])
                check_type(argname="argument my_sql_parameters", value=my_sql_parameters, expected_type=type_hints["my_sql_parameters"])
                check_type(argname="argument oracle_parameters", value=oracle_parameters, expected_type=type_hints["oracle_parameters"])
                check_type(argname="argument postgre_sql_parameters", value=postgre_sql_parameters, expected_type=type_hints["postgre_sql_parameters"])
                check_type(argname="argument presto_parameters", value=presto_parameters, expected_type=type_hints["presto_parameters"])
                check_type(argname="argument rds_parameters", value=rds_parameters, expected_type=type_hints["rds_parameters"])
                check_type(argname="argument redshift_parameters", value=redshift_parameters, expected_type=type_hints["redshift_parameters"])
                check_type(argname="argument s3_parameters", value=s3_parameters, expected_type=type_hints["s3_parameters"])
                check_type(argname="argument snowflake_parameters", value=snowflake_parameters, expected_type=type_hints["snowflake_parameters"])
                check_type(argname="argument spark_parameters", value=spark_parameters, expected_type=type_hints["spark_parameters"])
                check_type(argname="argument sql_server_parameters", value=sql_server_parameters, expected_type=type_hints["sql_server_parameters"])
                check_type(argname="argument teradata_parameters", value=teradata_parameters, expected_type=type_hints["teradata_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if amazon_elasticsearch_parameters is not None:
                self._values["amazon_elasticsearch_parameters"] = amazon_elasticsearch_parameters
            if amazon_open_search_parameters is not None:
                self._values["amazon_open_search_parameters"] = amazon_open_search_parameters
            if athena_parameters is not None:
                self._values["athena_parameters"] = athena_parameters
            if aurora_parameters is not None:
                self._values["aurora_parameters"] = aurora_parameters
            if aurora_postgre_sql_parameters is not None:
                self._values["aurora_postgre_sql_parameters"] = aurora_postgre_sql_parameters
            if databricks_parameters is not None:
                self._values["databricks_parameters"] = databricks_parameters
            if maria_db_parameters is not None:
                self._values["maria_db_parameters"] = maria_db_parameters
            if my_sql_parameters is not None:
                self._values["my_sql_parameters"] = my_sql_parameters
            if oracle_parameters is not None:
                self._values["oracle_parameters"] = oracle_parameters
            if postgre_sql_parameters is not None:
                self._values["postgre_sql_parameters"] = postgre_sql_parameters
            if presto_parameters is not None:
                self._values["presto_parameters"] = presto_parameters
            if rds_parameters is not None:
                self._values["rds_parameters"] = rds_parameters
            if redshift_parameters is not None:
                self._values["redshift_parameters"] = redshift_parameters
            if s3_parameters is not None:
                self._values["s3_parameters"] = s3_parameters
            if snowflake_parameters is not None:
                self._values["snowflake_parameters"] = snowflake_parameters
            if spark_parameters is not None:
                self._values["spark_parameters"] = spark_parameters
            if sql_server_parameters is not None:
                self._values["sql_server_parameters"] = sql_server_parameters
            if teradata_parameters is not None:
                self._values["teradata_parameters"] = teradata_parameters

        @builtins.property
        def amazon_elasticsearch_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.AmazonElasticsearchParametersProperty"]]:
            '''The parameters for OpenSearch.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-amazonelasticsearchparameters
            '''
            result = self._values.get("amazon_elasticsearch_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.AmazonElasticsearchParametersProperty"]], result)

        @builtins.property
        def amazon_open_search_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.AmazonOpenSearchParametersProperty"]]:
            '''The parameters for OpenSearch.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-amazonopensearchparameters
            '''
            result = self._values.get("amazon_open_search_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.AmazonOpenSearchParametersProperty"]], result)

        @builtins.property
        def athena_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.AthenaParametersProperty"]]:
            '''The parameters for Amazon Athena.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-athenaparameters
            '''
            result = self._values.get("athena_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.AthenaParametersProperty"]], result)

        @builtins.property
        def aurora_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.AuroraParametersProperty"]]:
            '''The parameters for Amazon Aurora MySQL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-auroraparameters
            '''
            result = self._values.get("aurora_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.AuroraParametersProperty"]], result)

        @builtins.property
        def aurora_postgre_sql_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.AuroraPostgreSqlParametersProperty"]]:
            '''The parameters for Amazon Aurora.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-aurorapostgresqlparameters
            '''
            result = self._values.get("aurora_postgre_sql_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.AuroraPostgreSqlParametersProperty"]], result)

        @builtins.property
        def databricks_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DatabricksParametersProperty"]]:
            '''The required parameters that are needed to connect to a Databricks data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-databricksparameters
            '''
            result = self._values.get("databricks_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.DatabricksParametersProperty"]], result)

        @builtins.property
        def maria_db_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.MariaDbParametersProperty"]]:
            '''The parameters for MariaDB.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-mariadbparameters
            '''
            result = self._values.get("maria_db_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.MariaDbParametersProperty"]], result)

        @builtins.property
        def my_sql_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.MySqlParametersProperty"]]:
            '''The parameters for MySQL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-mysqlparameters
            '''
            result = self._values.get("my_sql_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.MySqlParametersProperty"]], result)

        @builtins.property
        def oracle_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.OracleParametersProperty"]]:
            '''Oracle parameters.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-oracleparameters
            '''
            result = self._values.get("oracle_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.OracleParametersProperty"]], result)

        @builtins.property
        def postgre_sql_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.PostgreSqlParametersProperty"]]:
            '''The parameters for PostgreSQL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-postgresqlparameters
            '''
            result = self._values.get("postgre_sql_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.PostgreSqlParametersProperty"]], result)

        @builtins.property
        def presto_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.PrestoParametersProperty"]]:
            '''The parameters for Presto.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-prestoparameters
            '''
            result = self._values.get("presto_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.PrestoParametersProperty"]], result)

        @builtins.property
        def rds_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.RdsParametersProperty"]]:
            '''The parameters for Amazon RDS.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-rdsparameters
            '''
            result = self._values.get("rds_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.RdsParametersProperty"]], result)

        @builtins.property
        def redshift_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.RedshiftParametersProperty"]]:
            '''The parameters for Amazon Redshift.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-redshiftparameters
            '''
            result = self._values.get("redshift_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.RedshiftParametersProperty"]], result)

        @builtins.property
        def s3_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.S3ParametersProperty"]]:
            '''The parameters for S3.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-s3parameters
            '''
            result = self._values.get("s3_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.S3ParametersProperty"]], result)

        @builtins.property
        def snowflake_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.SnowflakeParametersProperty"]]:
            '''The parameters for Snowflake.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-snowflakeparameters
            '''
            result = self._values.get("snowflake_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.SnowflakeParametersProperty"]], result)

        @builtins.property
        def spark_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.SparkParametersProperty"]]:
            '''The parameters for Spark.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-sparkparameters
            '''
            result = self._values.get("spark_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.SparkParametersProperty"]], result)

        @builtins.property
        def sql_server_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.SqlServerParametersProperty"]]:
            '''The parameters for SQL Server.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-sqlserverparameters
            '''
            result = self._values.get("sql_server_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.SqlServerParametersProperty"]], result)

        @builtins.property
        def teradata_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.TeradataParametersProperty"]]:
            '''The parameters for Teradata.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-teradataparameters
            '''
            result = self._values.get("teradata_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.TeradataParametersProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSourceParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.DatabricksParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "host": "host",
            "port": "port",
            "sql_endpoint_path": "sqlEndpointPath",
        },
    )
    class DatabricksParametersProperty:
        def __init__(
            self,
            *,
            host: builtins.str,
            port: jsii.Number,
            sql_endpoint_path: builtins.str,
        ) -> None:
            '''The required parameters that are needed to connect to a Databricks data source.

            :param host: The host name of the Databricks data source.
            :param port: The port for the Databricks data source.
            :param sql_endpoint_path: The HTTP path of the Databricks data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                databricks_parameters_property = quicksight.CfnDataSource.DatabricksParametersProperty(
                    host="host",
                    port=123,
                    sql_endpoint_path="sqlEndpointPath"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d075ea456f49769f37a6897ea0bc14c6415468a232ab131754c7a103ec8f9790)
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
                check_type(argname="argument sql_endpoint_path", value=sql_endpoint_path, expected_type=type_hints["sql_endpoint_path"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "host": host,
                "port": port,
                "sql_endpoint_path": sql_endpoint_path,
            }

        @builtins.property
        def host(self) -> builtins.str:
            '''The host name of the Databricks data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''The port for the Databricks data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def sql_endpoint_path(self) -> builtins.str:
            '''The HTTP path of the Databricks data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-sqlendpointpath
            '''
            result = self._values.get("sql_endpoint_path")
            assert result is not None, "Required property 'sql_endpoint_path' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DatabricksParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.ManifestFileLocationProperty",
        jsii_struct_bases=[],
        name_mapping={"bucket": "bucket", "key": "key"},
    )
    class ManifestFileLocationProperty:
        def __init__(self, *, bucket: builtins.str, key: builtins.str) -> None:
            '''Amazon S3 manifest file location.

            :param bucket: Amazon S3 bucket.
            :param key: Amazon S3 key that identifies an object.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                manifest_file_location_property = quicksight.CfnDataSource.ManifestFileLocationProperty(
                    bucket="bucket",
                    key="key"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2f7b9e2690feb6c45f81e0532305f93e3fd718cab9fa7b2f8ef98808842c0f9b)
                check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
                check_type(argname="argument key", value=key, expected_type=type_hints["key"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "bucket": bucket,
                "key": key,
            }

        @builtins.property
        def bucket(self) -> builtins.str:
            '''Amazon S3 bucket.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html#cfn-quicksight-datasource-manifestfilelocation-bucket
            '''
            result = self._values.get("bucket")
            assert result is not None, "Required property 'bucket' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def key(self) -> builtins.str:
            '''Amazon S3 key that identifies an object.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html#cfn-quicksight-datasource-manifestfilelocation-key
            '''
            result = self._values.get("key")
            assert result is not None, "Required property 'key' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ManifestFileLocationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.MariaDbParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class MariaDbParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for MariaDB.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                maria_db_parameters_property = quicksight.CfnDataSource.MariaDbParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9529a5834b9463c6b0f9e3e7f57b6042bd5ed7f8da4e70569b728c4537c7ed33)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MariaDbParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.MySqlParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class MySqlParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for MySQL.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                my_sql_parameters_property = quicksight.CfnDataSource.MySqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__66c0f6b18de7fbff2b0506d21d94736e35a2bce78ac15ff9dff465ed9ac398a4)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MySqlParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.OracleParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class OracleParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''Oracle parameters.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                oracle_parameters_property = quicksight.CfnDataSource.OracleParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45a40014437174bcec974c37780be7e37d71f376e950bc74dd5236b01fea2a2c)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "OracleParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.PostgreSqlParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class PostgreSqlParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for PostgreSQL.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                postgre_sql_parameters_property = quicksight.CfnDataSource.PostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb85608c7a3aeefe4beea44da79a7fc9788bd701a0ce83eaa910ade63bdbf855)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PostgreSqlParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.PrestoParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"catalog": "catalog", "host": "host", "port": "port"},
    )
    class PrestoParametersProperty:
        def __init__(
            self,
            *,
            catalog: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for Presto.

            :param catalog: Catalog.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                presto_parameters_property = quicksight.CfnDataSource.PrestoParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b42d5040a0b94edd46888b36552d277c4bcc8765f146f13a7a2e1b19d60b3bf9)
                check_type(argname="argument catalog", value=catalog, expected_type=type_hints["catalog"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "catalog": catalog,
                "host": host,
                "port": port,
            }

        @builtins.property
        def catalog(self) -> builtins.str:
            '''Catalog.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-catalog
            '''
            result = self._values.get("catalog")
            assert result is not None, "Required property 'catalog' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PrestoParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.RdsParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "instance_id": "instanceId"},
    )
    class RdsParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            instance_id: builtins.str,
        ) -> None:
            '''The parameters for Amazon RDS.

            :param database: Database.
            :param instance_id: Instance ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                rds_parameters_property = quicksight.CfnDataSource.RdsParametersProperty(
                    database="database",
                    instance_id="instanceId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b41ebddca728de10b6469e12e78f7427b8459edf99685ca672ffc8c670e77c53)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "instance_id": instance_id,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html#cfn-quicksight-datasource-rdsparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def instance_id(self) -> builtins.str:
            '''Instance ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html#cfn-quicksight-datasource-rdsparameters-instanceid
            '''
            result = self._values.get("instance_id")
            assert result is not None, "Required property 'instance_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RdsParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.RedshiftParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "database": "database",
            "cluster_id": "clusterId",
            "host": "host",
            "port": "port",
        },
    )
    class RedshiftParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            cluster_id: typing.Optional[builtins.str] = None,
            host: typing.Optional[builtins.str] = None,
            port: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The parameters for Amazon Redshift.

            The ``ClusterId`` field can be blank if ``Host`` and ``Port`` are both set. The ``Host`` and ``Port`` fields can be blank if the ``ClusterId`` field is set.

            :param database: Database.
            :param cluster_id: Cluster ID. This field can be blank if the ``Host`` and ``Port`` are provided.
            :param host: Host. This field can be blank if ``ClusterId`` is provided.
            :param port: Port. This field can be blank if the ``ClusterId`` is provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                redshift_parameters_property = quicksight.CfnDataSource.RedshiftParametersProperty(
                    database="database",
                
                    # the properties below are optional
                    cluster_id="clusterId",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec48f6e654bcb73b16f85af03ad0f41ae92d5642e2ff31773b7bddd0780d7bbe)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument cluster_id", value=cluster_id, expected_type=type_hints["cluster_id"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
            }
            if cluster_id is not None:
                self._values["cluster_id"] = cluster_id
            if host is not None:
                self._values["host"] = host
            if port is not None:
                self._values["port"] = port

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cluster_id(self) -> typing.Optional[builtins.str]:
            '''Cluster ID.

            This field can be blank if the ``Host`` and ``Port`` are provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-clusterid
            '''
            result = self._values.get("cluster_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def host(self) -> typing.Optional[builtins.str]:
            '''Host.

            This field can be blank if ``ClusterId`` is provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-host
            '''
            result = self._values.get("host")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def port(self) -> typing.Optional[jsii.Number]:
            '''Port.

            This field can be blank if the ``ClusterId`` is provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-port
            '''
            result = self._values.get("port")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RedshiftParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={"actions": "actions", "principal": "principal"},
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnDataSource.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4cc52f9866bc668604aeee5b70e52707ccf62e1289170c0c845940d5f1ab6175)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html#cfn-quicksight-datasource-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html#cfn-quicksight-datasource-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.S3ParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"manifest_file_location": "manifestFileLocation"},
    )
    class S3ParametersProperty:
        def __init__(
            self,
            *,
            manifest_file_location: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnDataSource.ManifestFileLocationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The parameters for S3.

            :param manifest_file_location: Location of the Amazon S3 manifest file. This is NULL if the manifest file was uploaded into Amazon QuickSight.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-s3parameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                s3_parameters_property = quicksight.CfnDataSource.S3ParametersProperty(
                    manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                        bucket="bucket",
                        key="key"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b1714ca289a4b23686ebb2be44f562b17b08b7d6c5329beca938ec380570afb7)
                check_type(argname="argument manifest_file_location", value=manifest_file_location, expected_type=type_hints["manifest_file_location"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "manifest_file_location": manifest_file_location,
            }

        @builtins.property
        def manifest_file_location(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.ManifestFileLocationProperty"]:
            '''Location of the Amazon S3 manifest file.

            This is NULL if the manifest file was uploaded into Amazon QuickSight.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-s3parameters.html#cfn-quicksight-datasource-s3parameters-manifestfilelocation
            '''
            result = self._values.get("manifest_file_location")
            assert result is not None, "Required property 'manifest_file_location' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnDataSource.ManifestFileLocationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "S3ParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.SnowflakeParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "database": "database",
            "host": "host",
            "warehouse": "warehouse",
        },
    )
    class SnowflakeParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            warehouse: builtins.str,
        ) -> None:
            '''The parameters for Snowflake.

            :param database: Database.
            :param host: Host.
            :param warehouse: Warehouse.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                snowflake_parameters_property = quicksight.CfnDataSource.SnowflakeParametersProperty(
                    database="database",
                    host="host",
                    warehouse="warehouse"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__888588b836e98aac74e14c135c1639da470fe80385f60f0c2d67e3790dd71bec)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument warehouse", value=warehouse, expected_type=type_hints["warehouse"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "warehouse": warehouse,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def warehouse(self) -> builtins.str:
            '''Warehouse.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-warehouse
            '''
            result = self._values.get("warehouse")
            assert result is not None, "Required property 'warehouse' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SnowflakeParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.SparkParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"host": "host", "port": "port"},
    )
    class SparkParametersProperty:
        def __init__(self, *, host: builtins.str, port: jsii.Number) -> None:
            '''The parameters for Spark.

            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                spark_parameters_property = quicksight.CfnDataSource.SparkParametersProperty(
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f9af5264015696cca5256c8d9e0985174a61d64368599ea465b4b915b84b60c1)
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "host": host,
                "port": port,
            }

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html#cfn-quicksight-datasource-sparkparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html#cfn-quicksight-datasource-sparkparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SparkParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.SqlServerParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class SqlServerParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for SQL Server.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sql_server_parameters_property = quicksight.CfnDataSource.SqlServerParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a24949f80a03ed893e0ffc3b194bad3ef40aecb2529f51cdc56b2a970715c774)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SqlServerParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.SslPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={"disable_ssl": "disableSsl"},
    )
    class SslPropertiesProperty:
        def __init__(
            self,
            *,
            disable_ssl: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
        ) -> None:
            '''Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying data source.

            :param disable_ssl: A Boolean option to control whether SSL should be disabled.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sslproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                ssl_properties_property = quicksight.CfnDataSource.SslPropertiesProperty(
                    disable_ssl=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__775d6f90b457a3569b2de60c35357661ef4dcc73a60f6213b8bf4d236d0d311c)
                check_type(argname="argument disable_ssl", value=disable_ssl, expected_type=type_hints["disable_ssl"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if disable_ssl is not None:
                self._values["disable_ssl"] = disable_ssl

        @builtins.property
        def disable_ssl(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''A Boolean option to control whether SSL should be disabled.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sslproperties.html#cfn-quicksight-datasource-sslproperties-disablessl
            '''
            result = self._values.get("disable_ssl")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SslPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.TeradataParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class TeradataParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for Teradata.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                teradata_parameters_property = quicksight.CfnDataSource.TeradataParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4d81de2640a59502eb6a496d8437b0a6ab93809a68743d30bc1813304b3baf2d)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TeradataParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnDataSource.VpcConnectionPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={"vpc_connection_arn": "vpcConnectionArn"},
    )
    class VpcConnectionPropertiesProperty:
        def __init__(self, *, vpc_connection_arn: builtins.str) -> None:
            '''VPC connection properties.

            :param vpc_connection_arn: The Amazon Resource Name (ARN) for the VPC connection.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-vpcconnectionproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                vpc_connection_properties_property = quicksight.CfnDataSource.VpcConnectionPropertiesProperty(
                    vpc_connection_arn="vpcConnectionArn"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__15e41486446a7ee69c332a3d705b33346364a9e9ccb2d5860f5210072ca57cee)
                check_type(argname="argument vpc_connection_arn", value=vpc_connection_arn, expected_type=type_hints["vpc_connection_arn"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "vpc_connection_arn": vpc_connection_arn,
            }

        @builtins.property
        def vpc_connection_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) for the VPC connection.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-vpcconnectionproperties.html#cfn-quicksight-datasource-vpcconnectionproperties-vpcconnectionarn
            '''
            result = self._values.get("vpc_connection_arn")
            assert result is not None, "Required property 'vpc_connection_arn' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VpcConnectionPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="@aws-cdk/aws-quicksight.CfnDataSourceProps",
    jsii_struct_bases=[],
    name_mapping={
        "alternate_data_source_parameters": "alternateDataSourceParameters",
        "aws_account_id": "awsAccountId",
        "credentials": "credentials",
        "data_source_id": "dataSourceId",
        "data_source_parameters": "dataSourceParameters",
        "error_info": "errorInfo",
        "name": "name",
        "permissions": "permissions",
        "ssl_properties": "sslProperties",
        "tags": "tags",
        "type": "type",
        "vpc_connection_properties": "vpcConnectionProperties",
    },
)
class CfnDataSourceProps:
    def __init__(
        self,
        *,
        alternate_data_source_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        aws_account_id: typing.Optional[builtins.str] = None,
        credentials: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DataSourceCredentialsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        data_source_id: typing.Optional[builtins.str] = None,
        data_source_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        error_info: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DataSourceErrorInfoProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ssl_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.SslPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
        type: typing.Optional[builtins.str] = None,
        vpc_connection_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.VpcConnectionPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''Properties for defining a ``CfnDataSource``.

        :param alternate_data_source_parameters: A set of alternate data source parameters that you want to share for the credentials stored with this data source. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the ``AlternateDataSourceParameters`` list is null, the ``Credentials`` originally used with this ``DataSourceParameters`` are automatically allowed.
        :param aws_account_id: The AWS account ID.
        :param credentials: The credentials Amazon QuickSight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported.
        :param data_source_id: An ID for the data source. This ID is unique per AWS Region for each AWS account.
        :param data_source_parameters: The parameters that Amazon QuickSight uses to connect to your underlying source.
        :param error_info: Error information from the last update or the creation of the data source.
        :param name: A display name for the data source.
        :param permissions: A list of resource permissions on the data source.
        :param ssl_properties: Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.
        :param type: The type of the data source. To return a list of all data sources, use ``ListDataSources`` . Use ``AMAZON_ELASTICSEARCH`` for Amazon OpenSearch Service.
        :param vpc_connection_properties: Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            import aws_cdk.aws_quicksight as quicksight
            
            cfn_data_source_props = quicksight.CfnDataSourceProps(
                alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                    amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                        domain="domain"
                    ),
                    amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                        domain="domain"
                    ),
                    athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                        work_group="workGroup"
                    ),
                    aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                        host="host",
                        port=123,
                        sql_endpoint_path="sqlEndpointPath"
                    ),
                    maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123
                    ),
                    rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                        database="database",
                        instance_id="instanceId"
                    ),
                    redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                        database="database",
            
                        # the properties below are optional
                        cluster_id="clusterId",
                        host="host",
                        port=123
                    ),
                    s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                        manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                            bucket="bucket",
                            key="key"
                        )
                    ),
                    snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                        database="database",
                        host="host",
                        warehouse="warehouse"
                    ),
                    spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                        host="host",
                        port=123
                    ),
                    sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    )
                )],
                aws_account_id="awsAccountId",
                credentials=quicksight.CfnDataSource.DataSourceCredentialsProperty(
                    copy_source_arn="copySourceArn",
                    credential_pair=quicksight.CfnDataSource.CredentialPairProperty(
                        password="password",
                        username="username",
            
                        # the properties below are optional
                        alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                            amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                                domain="domain"
                            ),
                            amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                                domain="domain"
                            ),
                            athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                                work_group="workGroup"
                            ),
                            aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                                host="host",
                                port=123,
                                sql_endpoint_path="sqlEndpointPath"
                            ),
                            maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                                catalog="catalog",
                                host="host",
                                port=123
                            ),
                            rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                                database="database",
                                instance_id="instanceId"
                            ),
                            redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                                database="database",
            
                                # the properties below are optional
                                cluster_id="clusterId",
                                host="host",
                                port=123
                            ),
                            s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                                manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                                    bucket="bucket",
                                    key="key"
                                )
                            ),
                            snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                                database="database",
                                host="host",
                                warehouse="warehouse"
                            ),
                            spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                                host="host",
                                port=123
                            ),
                            sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            )
                        )]
                    ),
                    secret_arn="secretArn"
                ),
                data_source_id="dataSourceId",
                data_source_parameters=quicksight.CfnDataSource.DataSourceParametersProperty(
                    amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                        domain="domain"
                    ),
                    amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                        domain="domain"
                    ),
                    athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                        work_group="workGroup"
                    ),
                    aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                        host="host",
                        port=123,
                        sql_endpoint_path="sqlEndpointPath"
                    ),
                    maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123
                    ),
                    rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                        database="database",
                        instance_id="instanceId"
                    ),
                    redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                        database="database",
            
                        # the properties below are optional
                        cluster_id="clusterId",
                        host="host",
                        port=123
                    ),
                    s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                        manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                            bucket="bucket",
                            key="key"
                        )
                    ),
                    snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                        database="database",
                        host="host",
                        warehouse="warehouse"
                    ),
                    spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                        host="host",
                        port=123
                    ),
                    sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    )
                ),
                error_info=quicksight.CfnDataSource.DataSourceErrorInfoProperty(
                    message="message",
                    type="type"
                ),
                name="name",
                permissions=[quicksight.CfnDataSource.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )],
                ssl_properties=quicksight.CfnDataSource.SslPropertiesProperty(
                    disable_ssl=False
                ),
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                type="type",
                vpc_connection_properties=quicksight.CfnDataSource.VpcConnectionPropertiesProperty(
                    vpc_connection_arn="vpcConnectionArn"
                )
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__500be153543e40ac63afeeed0fe3978d6b99ae5d26e14bf158b05fc589f6addd)
            check_type(argname="argument alternate_data_source_parameters", value=alternate_data_source_parameters, expected_type=type_hints["alternate_data_source_parameters"])
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument credentials", value=credentials, expected_type=type_hints["credentials"])
            check_type(argname="argument data_source_id", value=data_source_id, expected_type=type_hints["data_source_id"])
            check_type(argname="argument data_source_parameters", value=data_source_parameters, expected_type=type_hints["data_source_parameters"])
            check_type(argname="argument error_info", value=error_info, expected_type=type_hints["error_info"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument ssl_properties", value=ssl_properties, expected_type=type_hints["ssl_properties"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            check_type(argname="argument vpc_connection_properties", value=vpc_connection_properties, expected_type=type_hints["vpc_connection_properties"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if alternate_data_source_parameters is not None:
            self._values["alternate_data_source_parameters"] = alternate_data_source_parameters
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if credentials is not None:
            self._values["credentials"] = credentials
        if data_source_id is not None:
            self._values["data_source_id"] = data_source_id
        if data_source_parameters is not None:
            self._values["data_source_parameters"] = data_source_parameters
        if error_info is not None:
            self._values["error_info"] = error_info
        if name is not None:
            self._values["name"] = name
        if permissions is not None:
            self._values["permissions"] = permissions
        if ssl_properties is not None:
            self._values["ssl_properties"] = ssl_properties
        if tags is not None:
            self._values["tags"] = tags
        if type is not None:
            self._values["type"] = type
        if vpc_connection_properties is not None:
            self._values["vpc_connection_properties"] = vpc_connection_properties

    @builtins.property
    def alternate_data_source_parameters(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.DataSourceParametersProperty]]]]:
        '''A set of alternate data source parameters that you want to share for the credentials stored with this data source.

        The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the ``AlternateDataSourceParameters`` list is null, the ``Credentials`` originally used with this ``DataSourceParameters`` are automatically allowed.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-alternatedatasourceparameters
        '''
        result = self._values.get("alternate_data_source_parameters")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.DataSourceParametersProperty]]]], result)

    @builtins.property
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def credentials(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.DataSourceCredentialsProperty]]:
        '''The credentials Amazon QuickSight that uses to connect to your underlying source.

        Currently, only credentials based on user name and password are supported.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-credentials
        '''
        result = self._values.get("credentials")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.DataSourceCredentialsProperty]], result)

    @builtins.property
    def data_source_id(self) -> typing.Optional[builtins.str]:
        '''An ID for the data source.

        This ID is unique per AWS Region for each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceid
        '''
        result = self._values.get("data_source_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def data_source_parameters(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.DataSourceParametersProperty]]:
        '''The parameters that Amazon QuickSight uses to connect to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceparameters
        '''
        result = self._values.get("data_source_parameters")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.DataSourceParametersProperty]], result)

    @builtins.property
    def error_info(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.DataSourceErrorInfoProperty]]:
        '''Error information from the last update or the creation of the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-errorinfo
        '''
        result = self._values.get("error_info")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.DataSourceErrorInfoProperty]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.ResourcePermissionProperty]]]]:
        '''A list of resource permissions on the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.ResourcePermissionProperty]]]], result)

    @builtins.property
    def ssl_properties(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.SslPropertiesProperty]]:
        '''Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-sslproperties
        '''
        result = self._values.get("ssl_properties")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.SslPropertiesProperty]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]], result)

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        '''The type of the data source. To return a list of all data sources, use ``ListDataSources`` .

        Use ``AMAZON_ELASTICSEARCH`` for Amazon OpenSearch Service.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-type
        '''
        result = self._values.get("type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def vpc_connection_properties(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.VpcConnectionPropertiesProperty]]:
        '''Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-vpcconnectionproperties
        '''
        result = self._values.get("vpc_connection_properties")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.VpcConnectionPropertiesProperty]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnDataSourceProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_aws_cdk_core_f4b25747.IInspectable)
class CfnRefreshSchedule(
    _aws_cdk_core_f4b25747.CfnResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@aws-cdk/aws-quicksight.CfnRefreshSchedule",
):
    '''A CloudFormation ``AWS::QuickSight::RefreshSchedule``.

    Creates a refresh schedule for a dataset in Amazon QuickSight .

    :cloudformationResource: AWS::QuickSight::RefreshSchedule
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        import aws_cdk.aws_quicksight as quicksight
        
        cfn_refresh_schedule = quicksight.CfnRefreshSchedule(self, "MyCfnRefreshSchedule",
            aws_account_id="awsAccountId",
            data_set_id="dataSetId",
            schedule=quicksight.CfnRefreshSchedule.RefreshScheduleMapProperty(
                refresh_type="refreshType",
                schedule_frequency=quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty(
                    interval="interval",
                    refresh_on_day=quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                        day_of_month="dayOfMonth",
                        day_of_week="dayOfWeek"
                    ),
                    time_of_the_day="timeOfTheDay",
                    time_zone="timeZone"
                ),
                schedule_id="scheduleId",
                start_after_date_time="startAfterDateTime"
            )
        )
    '''

    def __init__(
        self,
        scope: _aws_cdk_core_f4b25747.Construct,
        id: builtins.str,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        data_set_id: typing.Optional[builtins.str] = None,
        schedule: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnRefreshSchedule.RefreshScheduleMapProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::RefreshSchedule``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param aws_account_id: The AWS account ID of the account that you are creating a schedule in.
        :param data_set_id: The ID of the dataset that you are creating a refresh schedule for.
        :param schedule: The refresh schedule of a dataset.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ce01bf5dd377bc8da98316ba92fe442c98399d0b29f5016212fd6b5d3d32e150)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnRefreshScheduleProps(
            aws_account_id=aws_account_id, data_set_id=data_set_id, schedule=schedule
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _aws_cdk_core_f4b25747.TreeInspector) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d315cda966453045a639e9335a2a99fb6247437becad3dcba30c919da6353adf)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6c5909c0db8dfb61d048d1e2a1c59671f58b34cf2f14122435db9ddae42bddf2)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) for the refresh schedule.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID of the account that you are creating a schedule in.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-awsaccountid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9c97ba89d913c4b690d1ca28fa451501d2397b88d57172bc54c99ba0d9f3018)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="dataSetId")
    def data_set_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the dataset that you are creating a refresh schedule for.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-datasetid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSetId"))

    @data_set_id.setter
    def data_set_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf62de584fa4aed1eadd0ddae971d18ab9cad41e791c09cc472dc5bab535ce2a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSetId", value)

    @builtins.property
    @jsii.member(jsii_name="schedule")
    def schedule(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnRefreshSchedule.RefreshScheduleMapProperty"]]:
        '''The refresh schedule of a dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-schedule
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnRefreshSchedule.RefreshScheduleMapProperty"]], jsii.get(self, "schedule"))

    @schedule.setter
    def schedule(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnRefreshSchedule.RefreshScheduleMapProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f1f43b530b6702d3e3dd753d6f458e78119a143711733153fc506f556fab032)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "schedule", value)

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnRefreshSchedule.RefreshOnDayProperty",
        jsii_struct_bases=[],
        name_mapping={"day_of_month": "dayOfMonth", "day_of_week": "dayOfWeek"},
    )
    class RefreshOnDayProperty:
        def __init__(
            self,
            *,
            day_of_month: typing.Optional[builtins.str] = None,
            day_of_week: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The day that you want yout dataset to refresh.

            :param day_of_month: The day of the month that you want your dataset to refresh. This value is required for monthly refresh intervals.
            :param day_of_week: The day of the week that you want to schedule the refresh on. This value is required for weekly and monthly refresh intervals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshonday.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                refresh_on_day_property = quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                    day_of_month="dayOfMonth",
                    day_of_week="dayOfWeek"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__29a68e5761f3558bacb2b4d7fa8a0931578ec1b2d8126a0210585afb602514b0)
                check_type(argname="argument day_of_month", value=day_of_month, expected_type=type_hints["day_of_month"])
                check_type(argname="argument day_of_week", value=day_of_week, expected_type=type_hints["day_of_week"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if day_of_month is not None:
                self._values["day_of_month"] = day_of_month
            if day_of_week is not None:
                self._values["day_of_week"] = day_of_week

        @builtins.property
        def day_of_month(self) -> typing.Optional[builtins.str]:
            '''The day of the month that you want your dataset to refresh.

            This value is required for monthly refresh intervals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshonday.html#cfn-quicksight-refreshschedule-refreshonday-dayofmonth
            '''
            result = self._values.get("day_of_month")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def day_of_week(self) -> typing.Optional[builtins.str]:
            '''The day of the week that you want to schedule the refresh on.

            This value is required for weekly and monthly refresh intervals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshonday.html#cfn-quicksight-refreshschedule-refreshonday-dayofweek
            '''
            result = self._values.get("day_of_week")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RefreshOnDayProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnRefreshSchedule.RefreshScheduleMapProperty",
        jsii_struct_bases=[],
        name_mapping={
            "refresh_type": "refreshType",
            "schedule_frequency": "scheduleFrequency",
            "schedule_id": "scheduleId",
            "start_after_date_time": "startAfterDateTime",
        },
    )
    class RefreshScheduleMapProperty:
        def __init__(
            self,
            *,
            refresh_type: typing.Optional[builtins.str] = None,
            schedule_frequency: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnRefreshSchedule.ScheduleFrequencyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            schedule_id: typing.Optional[builtins.str] = None,
            start_after_date_time: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A summary of a configured refresh schedule for a dataset.

            :param refresh_type: The type of refresh that a dataset undergoes. Valid values are as follows:. - ``FULL_REFRESH`` : A complete refresh of a dataset. - ``INCREMENTAL_REFRESH`` : A partial refresh of some rows of a dataset, based on the time window specified. For more information on full and incremental refreshes, see `Refreshing SPICE data <https://docs.aws.amazon.com/quicksight/latest/user/refreshing-imported-data.html>`_ in the *Amazon QuickSight User Guide* .
            :param schedule_frequency: The frequency for the refresh schedule.
            :param schedule_id: An identifier for the refresh schedule.
            :param start_after_date_time: Time after which the refresh schedule can be started, expressed in ``YYYY-MM-DDTHH:MM:SS`` format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                refresh_schedule_map_property = quicksight.CfnRefreshSchedule.RefreshScheduleMapProperty(
                    refresh_type="refreshType",
                    schedule_frequency=quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty(
                        interval="interval",
                        refresh_on_day=quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                            day_of_month="dayOfMonth",
                            day_of_week="dayOfWeek"
                        ),
                        time_of_the_day="timeOfTheDay",
                        time_zone="timeZone"
                    ),
                    schedule_id="scheduleId",
                    start_after_date_time="startAfterDateTime"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d78e1c495104c4119265b5fce93bceeb4b1f73724b1fd472a180a659af64e9bb)
                check_type(argname="argument refresh_type", value=refresh_type, expected_type=type_hints["refresh_type"])
                check_type(argname="argument schedule_frequency", value=schedule_frequency, expected_type=type_hints["schedule_frequency"])
                check_type(argname="argument schedule_id", value=schedule_id, expected_type=type_hints["schedule_id"])
                check_type(argname="argument start_after_date_time", value=start_after_date_time, expected_type=type_hints["start_after_date_time"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if refresh_type is not None:
                self._values["refresh_type"] = refresh_type
            if schedule_frequency is not None:
                self._values["schedule_frequency"] = schedule_frequency
            if schedule_id is not None:
                self._values["schedule_id"] = schedule_id
            if start_after_date_time is not None:
                self._values["start_after_date_time"] = start_after_date_time

        @builtins.property
        def refresh_type(self) -> typing.Optional[builtins.str]:
            '''The type of refresh that a dataset undergoes. Valid values are as follows:.

            - ``FULL_REFRESH`` : A complete refresh of a dataset.
            - ``INCREMENTAL_REFRESH`` : A partial refresh of some rows of a dataset, based on the time window specified.

            For more information on full and incremental refreshes, see `Refreshing SPICE data <https://docs.aws.amazon.com/quicksight/latest/user/refreshing-imported-data.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-refreshtype
            '''
            result = self._values.get("refresh_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def schedule_frequency(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnRefreshSchedule.ScheduleFrequencyProperty"]]:
            '''The frequency for the refresh schedule.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-schedulefrequency
            '''
            result = self._values.get("schedule_frequency")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnRefreshSchedule.ScheduleFrequencyProperty"]], result)

        @builtins.property
        def schedule_id(self) -> typing.Optional[builtins.str]:
            '''An identifier for the refresh schedule.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-scheduleid
            '''
            result = self._values.get("schedule_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_after_date_time(self) -> typing.Optional[builtins.str]:
            '''Time after which the refresh schedule can be started, expressed in ``YYYY-MM-DDTHH:MM:SS`` format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-startafterdatetime
            '''
            result = self._values.get("start_after_date_time")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RefreshScheduleMapProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "interval": "interval",
            "refresh_on_day": "refreshOnDay",
            "time_of_the_day": "timeOfTheDay",
            "time_zone": "timeZone",
        },
    )
    class ScheduleFrequencyProperty:
        def __init__(
            self,
            *,
            interval: typing.Optional[builtins.str] = None,
            refresh_on_day: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnRefreshSchedule.RefreshOnDayProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_of_the_day: typing.Optional[builtins.str] = None,
            time_zone: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The frequency for the refresh schedule.

            :param interval: The interval between scheduled refreshes. Valid values are as follows:. - ``MINUTE15`` : The dataset refreshes every 15 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset. - ``MINUTE30`` : The dataset refreshes every 30 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset. - ``HOURLY`` : The dataset refreshes every hour. This interval can only be used for one schedule per dataset. - ``DAILY`` : The dataset refreshes every day. - ``WEEKLY`` : The dataset refreshes every week. - ``MONTHLY`` : The dataset refreshes every month.
            :param refresh_on_day: The day of the week that you want to schedule the refresh on. This value is required for weekly and monthly refresh intervals.
            :param time_of_the_day: The time of day that you want the dataset to refresh. This value is expressed in HH:MM format. This field is not required for schedules that refresh hourly.
            :param time_zone: The timezone that you want the refresh schedule to use. The timezone ID must match a corresponding ID found on ``java.util.time.getAvailableIDs()`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                schedule_frequency_property = quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty(
                    interval="interval",
                    refresh_on_day=quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                        day_of_month="dayOfMonth",
                        day_of_week="dayOfWeek"
                    ),
                    time_of_the_day="timeOfTheDay",
                    time_zone="timeZone"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c6a9b696733f7401d75cf9aa8eb3f20807093b6d8411a90ebda8f00a8ac932f)
                check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
                check_type(argname="argument refresh_on_day", value=refresh_on_day, expected_type=type_hints["refresh_on_day"])
                check_type(argname="argument time_of_the_day", value=time_of_the_day, expected_type=type_hints["time_of_the_day"])
                check_type(argname="argument time_zone", value=time_zone, expected_type=type_hints["time_zone"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if interval is not None:
                self._values["interval"] = interval
            if refresh_on_day is not None:
                self._values["refresh_on_day"] = refresh_on_day
            if time_of_the_day is not None:
                self._values["time_of_the_day"] = time_of_the_day
            if time_zone is not None:
                self._values["time_zone"] = time_zone

        @builtins.property
        def interval(self) -> typing.Optional[builtins.str]:
            '''The interval between scheduled refreshes. Valid values are as follows:.

            - ``MINUTE15`` : The dataset refreshes every 15 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset.
            - ``MINUTE30`` : The dataset refreshes every 30 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset.
            - ``HOURLY`` : The dataset refreshes every hour. This interval can only be used for one schedule per dataset.
            - ``DAILY`` : The dataset refreshes every day.
            - ``WEEKLY`` : The dataset refreshes every week.
            - ``MONTHLY`` : The dataset refreshes every month.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-interval
            '''
            result = self._values.get("interval")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def refresh_on_day(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnRefreshSchedule.RefreshOnDayProperty"]]:
            '''The day of the week that you want to schedule the refresh on.

            This value is required for weekly and monthly refresh intervals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-refreshonday
            '''
            result = self._values.get("refresh_on_day")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnRefreshSchedule.RefreshOnDayProperty"]], result)

        @builtins.property
        def time_of_the_day(self) -> typing.Optional[builtins.str]:
            '''The time of day that you want the dataset to refresh.

            This value is expressed in HH:MM format. This field is not required for schedules that refresh hourly.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-timeoftheday
            '''
            result = self._values.get("time_of_the_day")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_zone(self) -> typing.Optional[builtins.str]:
            '''The timezone that you want the refresh schedule to use.

            The timezone ID must match a corresponding ID found on ``java.util.time.getAvailableIDs()`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-timezone
            '''
            result = self._values.get("time_zone")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScheduleFrequencyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="@aws-cdk/aws-quicksight.CfnRefreshScheduleProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "data_set_id": "dataSetId",
        "schedule": "schedule",
    },
)
class CfnRefreshScheduleProps:
    def __init__(
        self,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        data_set_id: typing.Optional[builtins.str] = None,
        schedule: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnRefreshSchedule.RefreshScheduleMapProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''Properties for defining a ``CfnRefreshSchedule``.

        :param aws_account_id: The AWS account ID of the account that you are creating a schedule in.
        :param data_set_id: The ID of the dataset that you are creating a refresh schedule for.
        :param schedule: The refresh schedule of a dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            import aws_cdk.aws_quicksight as quicksight
            
            cfn_refresh_schedule_props = quicksight.CfnRefreshScheduleProps(
                aws_account_id="awsAccountId",
                data_set_id="dataSetId",
                schedule=quicksight.CfnRefreshSchedule.RefreshScheduleMapProperty(
                    refresh_type="refreshType",
                    schedule_frequency=quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty(
                        interval="interval",
                        refresh_on_day=quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                            day_of_month="dayOfMonth",
                            day_of_week="dayOfWeek"
                        ),
                        time_of_the_day="timeOfTheDay",
                        time_zone="timeZone"
                    ),
                    schedule_id="scheduleId",
                    start_after_date_time="startAfterDateTime"
                )
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f59d2d61b1f4f08b4c62a3293ee719c65a941d68dbefbfff51ecb56c3e993708)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument data_set_id", value=data_set_id, expected_type=type_hints["data_set_id"])
            check_type(argname="argument schedule", value=schedule, expected_type=type_hints["schedule"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if data_set_id is not None:
            self._values["data_set_id"] = data_set_id
        if schedule is not None:
            self._values["schedule"] = schedule

    @builtins.property
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID of the account that you are creating a schedule in.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def data_set_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the dataset that you are creating a refresh schedule for.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-datasetid
        '''
        result = self._values.get("data_set_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def schedule(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnRefreshSchedule.RefreshScheduleMapProperty]]:
        '''The refresh schedule of a dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-schedule
        '''
        result = self._values.get("schedule")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnRefreshSchedule.RefreshScheduleMapProperty]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnRefreshScheduleProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_aws_cdk_core_f4b25747.IInspectable)
class CfnTemplate(
    _aws_cdk_core_f4b25747.CfnResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@aws-cdk/aws-quicksight.CfnTemplate",
):
    '''A CloudFormation ``AWS::QuickSight::Template``.

    Creates a template from an existing Amazon QuickSight analysis or template. You can use the resulting template to create a dashboard.

    A *template* is an entity in Amazon QuickSight that encapsulates the metadata required to create an analysis and that you can use to create s dashboard. A template adds a layer of abstraction by using placeholders to replace the dataset associated with the analysis. You can use templates to create dashboards by replacing dataset placeholders with datasets that follow the same schema that was used to create the source analysis and template.

    :cloudformationResource: AWS::QuickSight::Template
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        import aws_cdk.aws_quicksight as quicksight
        
        # data_driven: Any
        
        cfn_template = quicksight.CfnTemplate(self, "MyCfnTemplate",
            aws_account_id="awsAccountId",
            template_id="templateId",
        
            # the properties below are optional
            definition=quicksight.CfnTemplate.TemplateVersionDefinitionProperty(
                data_set_configurations=[quicksight.CfnTemplate.DataSetConfigurationProperty(
                    column_group_schema_list=[quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                        column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                            name="name"
                        )],
                        name="name"
                    )],
                    data_set_schema=quicksight.CfnTemplate.DataSetSchemaProperty(
                        column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                            data_type="dataType",
                            geographic_role="geographicRole",
                            name="name"
                        )]
                    ),
                    placeholder="placeholder"
                )],
        
                # the properties below are optional
                analysis_defaults=quicksight.CfnTemplate.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                ),
                calculated_fields=[quicksight.CfnTemplate.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )],
                column_configurations=[quicksight.CfnTemplate.ColumnConfigurationProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
        
                    # the properties below are optional
                    colors_configuration=quicksight.CfnTemplate.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnTemplate.CustomColorProperty(
                            color="color",
        
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )],
                filter_groups=[quicksight.CfnTemplate.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnTemplate.FilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
        
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
        
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
        
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
        
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnTemplate.NumericRangeFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
        
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnTemplate.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
        
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
        
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnTemplate.TimeEqualityFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
        
                            # the properties below are optional
                            parameter_name="parameterName",
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
        
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
        
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
        
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
        
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnTemplate.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection"
                            )],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
        
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnTemplate.FilterScopeConfigurationProperty(
                        selected_sheets=quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
        
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
        
                    # the properties below are optional
                    status="status"
                )],
                parameter_declarations=[quicksight.CfnTemplate.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnTemplate.DateTimeParameterDeclarationProperty(
                        name="name",
        
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                expression="expression",
        
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnTemplate.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnTemplate.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnTemplate.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )],
                sheets=[quicksight.CfnTemplate.SheetDefinitionProperty(
                    sheet_id="sheetId",
        
                    # the properties below are optional
                    content_type="contentType",
                    description="description",
                    filter_controls=[quicksight.CfnTemplate.FilterControlProperty(
                        date_time_picker=quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        dropdown=quicksight.CfnTemplate.FilterDropDownControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnTemplate.FilterListControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        relative_date_time=quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        slider=quicksight.CfnTemplate.FilterSliderControlProperty(
                            filter_control_id="filterControlId",
                            maximum_value=123,
                            minimum_value=123,
                            source_filter_id="sourceFilterId",
                            step_size=123,
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        text_area=quicksight.CfnTemplate.FilterTextAreaControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnTemplate.FilterTextFieldControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    layouts=[quicksight.CfnTemplate.LayoutProperty(
                        configuration=quicksight.CfnTemplate.LayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
        
                                    # the properties below are optional
                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
        
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                                body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                                    content=quicksight.CfnTemplate.BodySectionContentProperty(
                                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
        
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                        after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                            status="status"
                                        )
                                    ),
                                    style=quicksight.CfnTemplate.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                ),
                                footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
        
                                                # the properties below are optional
                                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    style=quicksight.CfnTemplate.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
        
                                                # the properties below are optional
                                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    style=quicksight.CfnTemplate.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )]
                            )
                        )
                    )],
                    name="name",
                    parameter_controls=[quicksight.CfnTemplate.ParameterControlProperty(
                        date_time_picker=quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        dropdown=quicksight.CfnTemplate.ParameterDropDownControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnTemplate.ParameterListControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        slider=quicksight.CfnTemplate.ParameterSliderControlProperty(
                            maximum_value=123,
                            minimum_value=123,
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            step_size=123,
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_area=quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    sheet_control_layouts=[quicksight.CfnTemplate.SheetControlLayoutProperty(
                        configuration=quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                            grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
        
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        )
                    )],
                    text_boxes=[quicksight.CfnTemplate.SheetTextBoxProperty(
                        sheet_text_box_id="sheetTextBoxId",
        
                        # the properties below are optional
                        content="content"
                    )],
                    title="title",
                    visuals=[quicksight.CfnTemplate.VisualProperty(
                        bar_chart_visual=quicksight.CfnTemplate.BarChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.BarChartConfigurationProperty(
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                                    bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                orientation="orientation",
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        box_plot_visual=quicksight.CfnTemplate.BoxPlotVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                                box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                                    all_data_points_visibility="allDataPointsVisibility",
                                    outlier_visibility="outlierVisibility",
                                    style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                                        fill_style="fillStyle"
                                    )
                                ),
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                                    box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    )
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        combo_chart_visual=quicksight.CfnTemplate.ComboChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.ComboChartConfigurationProperty(
                                bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                                    combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                                        bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        custom_content_visual=quicksight.CfnTemplate.CustomContentVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.CustomContentConfigurationProperty(
                                content_type="contentType",
                                content_url="contentUrl",
                                image_scaling="imageScaling"
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        empty_visual=quicksight.CfnTemplate.EmptyVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )]
                        ),
                        filled_map_visual=quicksight.CfnTemplate.FilledMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.FilledMapConfigurationProperty(
                                field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                                    filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                                        geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                                    shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        funnel_chart_visual=quicksight.CfnTemplate.FunnelChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    label_color="labelColor",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_data_label_style="measureDataLabelStyle",
                                    measure_label_visibility="measureLabelVisibility",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                                    funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        gauge_chart_visual=quicksight.CfnTemplate.GaugeChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                                    target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                                    arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                                        arc_angle=123,
                                        arc_thickness="arcThickness"
                                    ),
                                    arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                                        range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                            max=123,
                                            min=123
                                        ),
                                        reserve_range=123
                                    ),
                                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                ),
                                tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            conditional_formatting=quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                                    arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
        
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        geospatial_map_visual=quicksight.CfnTemplate.GeospatialMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                                field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                                    geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                                    cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                                        cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                            simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                                color="color"
                                            )
                                        )
                                    ),
                                    selected_point_style="selectedPointStyle"
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        heat_map_visual=quicksight.CfnTemplate.HeatMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.HeatMapConfigurationProperty(
                                color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
        
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                                    heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                                    heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        histogram_visual=quicksight.CfnTemplate.HistogramVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.HistogramConfigurationProperty(
                                bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                                    bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                                        value=123
                                    ),
                                    bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                                        bin_count_limit=123,
                                        value=123
                                    ),
                                    selected_bin_type="selectedBinType",
                                    start_value=123
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                                    histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                )
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        insight_visual=quicksight.CfnTemplate.InsightVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            insight_configuration=quicksight.CfnTemplate.InsightConfigurationProperty(
                                computations=[quicksight.CfnTemplate.ComputationProperty(
                                    forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        custom_seasonality_value=123,
                                        lower_boundary=123,
                                        name="name",
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality="seasonality",
                                        upper_boundary=123,
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        period_size=123,
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
        
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                                        computation_id="computationId",
                                        from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        period_time_granularity="periodTimeGranularity",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
        
                                        # the properties below are optional
                                        mover_size=123,
                                        name="name",
                                        sort_order="sortOrder",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        type="type",
        
                                        # the properties below are optional
                                        name="name",
                                        result_size=123,
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                                        computation_id="computationId",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
        
                                        # the properties below are optional
                                        name="name"
                                    )
                                )],
                                custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                                    narrative="narrative"
                                )
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        kpi_visual=quicksight.CfnTemplate.KPIVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.KPIConfigurationProperty(
                                field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                                    target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                                    trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                                    primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
        
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        line_chart_visual=quicksight.CfnTemplate.LineChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.LineChartConfigurationProperty(
                                contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                                    axis_binding="axisBinding",
                                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                                    line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                                    forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                                        lower_boundary=123,
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality=123,
                                        upper_boundary=123
                                    ),
                                    scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                                        what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                            date="date",
                                            value=123
                                        ),
                                        what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                            end_date="endDate",
                                            start_date="startDate",
                                            value=123
                                        )
                                    )
                                )],
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                series=[quicksight.CfnTemplate.SeriesItemProperty(
                                    data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        field_value="fieldValue",
                                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    ),
                                    field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    )
                                )],
                                small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                                    category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                type="type",
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pie_chart_visual=quicksight.CfnTemplate.PieChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.PieChartConfigurationProperty(
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                                    arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                                        arc_thickness="arcThickness"
                                    ),
                                    donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                                        label_visibility="labelVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                                    pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pivot_table_visual=quicksight.CfnTemplate.PivotTableVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.PivotTableConfigurationProperty(
                                field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                                    data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                                        data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )],
        
                                        # the properties below are optional
                                        width="width"
                                    )],
                                    selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        visibility="visibility"
                                    )]
                                ),
                                field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                                    pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                                    field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                                        field_id="fieldId",
                                        sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                            column=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                                direction="direction",
                                                sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                                    field_id="fieldId",
                                                    field_value="fieldValue"
                                                )]
                                            ),
                                            field=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )
                                    )]
                                ),
                                table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_names_visibility="columnNamesVisibility",
                                    metric_placement="metricPlacement",
                                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    ),
                                    row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    single_metric_visibility="singleMetricVisibility",
                                    toggle_buttons_visibility="toggleButtonsVisibility"
                                ),
                                total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                                    column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                )
                            ),
                            conditional_formatting=quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                            role="role"
                                        ),
                                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
        
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        radar_chart_visual=quicksight.CfnTemplate.RadarChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.RadarChartConfigurationProperty(
                                alternate_band_colors_visibility="alternateBandColorsVisibility",
                                alternate_band_even_color="alternateBandEvenColor",
                                alternate_band_odd_color="alternateBandOddColor",
                                base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                                    area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                                    radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                shape="shape",
                                sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                start_angle=123,
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        sankey_diagram_visual=quicksight.CfnTemplate.SankeyDiagramVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                                    sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                                        destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                                    destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        scatter_plot_visual=quicksight.CfnTemplate.ScatterPlotVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        table_visual=quicksight.CfnTemplate.TableVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.TableConfigurationProperty(
                                field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                                    order=["order"],
                                    selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                            image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                                sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                )
                                            ),
                                            link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                                content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                                    custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                                        icon="icon"
                                                    ),
                                                    custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                            font_color="fontColor",
                                                            font_decoration="fontDecoration",
                                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                                relative="relative"
                                                            ),
                                                            font_style="fontStyle",
                                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                                name="name"
                                                            )
                                                        ),
        
                                                        # the properties below are optional
                                                        value="value"
                                                    )
                                                ),
                                                target="target"
                                            )
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    )]
                                ),
                                field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                                    table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                                        values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                                date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    ),
                                    row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                                    data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        negative_color="negativeColor",
                                        positive_color="positiveColor"
                                    )
                                )],
                                table_options=quicksight.CfnTemplate.TableOptionsProperty(
                                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    orientation="orientation",
                                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    )
                                ),
                                total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                                    custom_label="customLabel",
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility"
                                )
                            ),
                            conditional_formatting=quicksight.CfnTemplate.TableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
        
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    ),
                                    row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        tree_map_visual=quicksight.CfnTemplate.TreeMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.TreeMapConfigurationProperty(
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
        
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                                    tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                                    tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        waterfall_visual=quicksight.CfnTemplate.WaterfallVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                                category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                                    waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                                        breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                                    breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                                    total_bar_label="totalBarLabel"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        word_cloud_visual=quicksight.CfnTemplate.WordCloudVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                                    word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                                    cloud_layout="cloudLayout",
                                    maximum_string_length=123,
                                    word_casing="wordCasing",
                                    word_orientation="wordOrientation",
                                    word_padding="wordPadding",
                                    word_scaling="wordScaling"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        )
                    )]
                )]
            ),
            name="name",
            permissions=[quicksight.CfnTemplate.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal",
        
                # the properties below are optional
                resource="resource"
            )],
            source_entity=quicksight.CfnTemplate.TemplateSourceEntityProperty(
                source_analysis=quicksight.CfnTemplate.TemplateSourceAnalysisProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnTemplate.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                ),
                source_template=quicksight.CfnTemplate.TemplateSourceTemplateProperty(
                    arn="arn"
                )
            ),
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            version_description="versionDescription"
        )
    '''

    def __init__(
        self,
        scope: _aws_cdk_core_f4b25747.Construct,
        id: builtins.str,
        *,
        aws_account_id: builtins.str,
        template_id: builtins.str,
        definition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TemplateVersionDefinitionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        source_entity: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TemplateSourceEntityProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::Template``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param aws_account_id: The ID for the AWS account that the group is in. You use the ID for the AWS account that contains your Amazon QuickSight account.
        :param template_id: An ID for the template that you want to create. This template is unique per AWS Region ; in each AWS account.
        :param definition: ``AWS::QuickSight::Template.Definition``.
        :param name: A display name for the template.
        :param permissions: A list of resource permissions to be set on the template.
        :param source_entity: The entity that you are using as a source when you create the template. In ``SourceEntity`` , you specify the type of object you're using as source: ``SourceTemplate`` for a template or ``SourceAnalysis`` for an analysis. Both of these require an Amazon Resource Name (ARN). For ``SourceTemplate`` , specify the ARN of the source template. For ``SourceAnalysis`` , specify the ARN of the source analysis. The ``SourceTemplate`` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region . Use the ``DataSetReferences`` entity within ``SourceTemplate`` or ``SourceAnalysis`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder. Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.
        :param version_description: A description of the current template version being created. This API operation creates the first version of the template. Every time ``UpdateTemplate`` is called, a new version is created. Each version of the template maintains a description of the version in the ``VersionDescription`` field.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c08f232283ef62770bb6ca8b7fdf03149d3496ec705ab1e375adcd0b1bffc15a)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnTemplateProps(
            aws_account_id=aws_account_id,
            template_id=template_id,
            definition=definition,
            name=name,
            permissions=permissions,
            source_entity=source_entity,
            tags=tags,
            version_description=version_description,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _aws_cdk_core_f4b25747.TreeInspector) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6e058686f24dadbe8549c22182c3aa5054289790ee7d7630a71b2f584f6b4509)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__710fa5d208059eeaa74adcbd24d7c6e041150973a5612d5bba0a61206407b1f0)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the template.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time this template was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time this template was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionCreatedTime")
    def attr_version_created_time(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDataSetConfigurations")
    def attr_version_data_set_configurations(
        self,
    ) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: Version.DataSetConfigurations
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrVersionDataSetConfigurations"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDescription")
    def attr_version_description(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Description
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionDescription"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionErrors")
    def attr_version_errors(self) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: Version.Errors
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrVersionErrors"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionSheets")
    def attr_version_sheets(self) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: Version.Sheets
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrVersionSheets"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionSourceEntityArn")
    def attr_version_source_entity_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.SourceEntityArn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionSourceEntityArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionStatus")
    def attr_version_status(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionStatus"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionThemeArn")
    def attr_version_theme_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.ThemeArn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionThemeArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionVersionNumber")
    def attr_version_version_number(self) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: Version.VersionNumber
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrVersionVersionNumber"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _aws_cdk_core_f4b25747.TagManager:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-tags
        '''
        return typing.cast(_aws_cdk_core_f4b25747.TagManager, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> builtins.str:
        '''The ID for the AWS account that the group is in.

        You use the ID for the AWS account that contains your Amazon QuickSight account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-awsaccountid
        '''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c1122d4e8db2b42e64ff8f3a06a4c8a8537b7ca729f6654a1bf8b7e8347f4d63)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="templateId")
    def template_id(self) -> builtins.str:
        '''An ID for the template that you want to create.

        This template is unique per AWS Region ; in each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-templateid
        '''
        return typing.cast(builtins.str, jsii.get(self, "templateId"))

    @template_id.setter
    def template_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6731cd99a5b76fdee6b74bb9c2ef7aa5045d9a4fa28733a2d0cda80dd992fc95)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "templateId", value)

    @builtins.property
    @jsii.member(jsii_name="definition")
    def definition(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TemplateVersionDefinitionProperty"]]:
        '''``AWS::QuickSight::Template.Definition``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-definition
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TemplateVersionDefinitionProperty"]], jsii.get(self, "definition"))

    @definition.setter
    def definition(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TemplateVersionDefinitionProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c90190471277837f5882a6bf8def53882a450e485b66dee2a4be3d4bdf14c597)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "definition", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the template.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-name
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c497d775b7ebf2a061490d9331bb741633efde9742360d13baf635ad0dd9c7db)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ResourcePermissionProperty"]]]]:
        '''A list of resource permissions to be set on the template.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-permissions
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ResourcePermissionProperty"]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ResourcePermissionProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c600552acfd507bebf25250a4be7b48abfe7a26531c0c7b9b3858f14f559853a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="sourceEntity")
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TemplateSourceEntityProperty"]]:
        '''The entity that you are using as a source when you create the template.

        In ``SourceEntity`` , you specify the type of object you're using as source: ``SourceTemplate`` for a template or ``SourceAnalysis`` for an analysis. Both of these require an Amazon Resource Name (ARN). For ``SourceTemplate`` , specify the ARN of the source template. For ``SourceAnalysis`` , specify the ARN of the source analysis. The ``SourceTemplate`` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region .

        Use the ``DataSetReferences`` entity within ``SourceTemplate`` or ``SourceAnalysis`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.

        Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-sourceentity
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TemplateSourceEntityProperty"]], jsii.get(self, "sourceEntity"))

    @source_entity.setter
    def source_entity(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TemplateSourceEntityProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b3b16513140b56c46b024b451fcba3617e11b79b079bafa231d70826f6c74664)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sourceEntity", value)

    @builtins.property
    @jsii.member(jsii_name="versionDescription")
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description of the current template version being created.

        This API operation creates the first version of the template. Every time ``UpdateTemplate`` is called, a new version is created. Each version of the template maintains a description of the version in the ``VersionDescription`` field.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-versiondescription
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionDescription"))

    @version_description.setter
    def version_description(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__498d7ec2673fdea8392289ade3d2c51dcf7c8de22cd0dbcd0c368339cf461081)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "versionDescription", value)

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_aggregation_function": "categoricalAggregationFunction",
            "date_aggregation_function": "dateAggregationFunction",
            "numerical_aggregation_function": "numericalAggregationFunction",
        },
    )
    class AggregationFunctionProperty:
        def __init__(
            self,
            *,
            categorical_aggregation_function: typing.Optional[builtins.str] = None,
            date_aggregation_function: typing.Optional[builtins.str] = None,
            numerical_aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''An aggregation function aggregates values from a dimension or measure.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param categorical_aggregation_function: Aggregation for categorical values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            :param date_aggregation_function: Aggregation for date values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values. - ``MIN`` : Select the smallest date value. - ``MAX`` : Select the largest date value.
            :param numerical_aggregation_function: Aggregation for numerical values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                aggregation_function_property = quicksight.CfnTemplate.AggregationFunctionProperty(
                    categorical_aggregation_function="categoricalAggregationFunction",
                    date_aggregation_function="dateAggregationFunction",
                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bca736a102e974c4ebd4eebeaa17db7387fdfd11299be62187e5c5c0acdde1a9)
                check_type(argname="argument categorical_aggregation_function", value=categorical_aggregation_function, expected_type=type_hints["categorical_aggregation_function"])
                check_type(argname="argument date_aggregation_function", value=date_aggregation_function, expected_type=type_hints["date_aggregation_function"])
                check_type(argname="argument numerical_aggregation_function", value=numerical_aggregation_function, expected_type=type_hints["numerical_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_aggregation_function is not None:
                self._values["categorical_aggregation_function"] = categorical_aggregation_function
            if date_aggregation_function is not None:
                self._values["date_aggregation_function"] = date_aggregation_function
            if numerical_aggregation_function is not None:
                self._values["numerical_aggregation_function"] = numerical_aggregation_function

        @builtins.property
        def categorical_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for categorical values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-categoricalaggregationfunction
            '''
            result = self._values.get("categorical_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def date_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for date values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            - ``MIN`` : Select the smallest date value.
            - ``MAX`` : Select the largest date value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-dateaggregationfunction
            '''
            result = self._values.get("date_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def numerical_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericalAggregationFunctionProperty"]]:
            '''Aggregation for numerical values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-numericalaggregationfunction
            '''
            result = self._values.get("numerical_aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericalAggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AggregationSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_function": "aggregationFunction",
            "column": "column",
            "sort_direction": "sortDirection",
        },
    )
    class AggregationSortConfigurationProperty:
        def __init__(
            self,
            *,
            aggregation_function: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            sort_direction: builtins.str,
        ) -> None:
            '''The configuration options to sort aggregated values.

            :param aggregation_function: The function that aggregates the values in ``Column`` .
            :param column: The column that determines the sort order of aggregated values.
            :param sort_direction: The sort direction of values. - ``ASC`` : Sort in ascending order. - ``DESC`` : Sort in descending order.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                aggregation_sort_configuration_property = quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    sort_direction="sortDirection"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3a4c170f2c7886a89d1d0043f6fa5eb5280515b4b0628ee43dccc30d53ef58fb)
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument sort_direction", value=sort_direction, expected_type=type_hints["sort_direction"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_function": aggregation_function,
                "column": column,
                "sort_direction": sort_direction,
            }

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationFunctionProperty"]:
            '''The function that aggregates the values in ``Column`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            assert result is not None, "Required property 'aggregation_function' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationFunctionProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that determines the sort order of aggregated values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def sort_direction(self) -> builtins.str:
            '''The sort direction of values.

            - ``ASC`` : Sort in ascending order.
            - ``DESC`` : Sort in descending order.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-sortdirection
            '''
            result = self._values.get("sort_direction")
            assert result is not None, "Required property 'sort_direction' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AnalysisDefaultsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_new_sheet_configuration": "defaultNewSheetConfiguration",
        },
    )
    class AnalysisDefaultsProperty:
        def __init__(
            self,
            *,
            default_new_sheet_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DefaultNewSheetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The configuration for default analysis settings.

            :param default_new_sheet_configuration: The configuration for default new sheet settings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-analysisdefaults.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                analysis_defaults_property = quicksight.CfnTemplate.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ff585bda34fde512e5c2755b54bb7ea4b78c824faf15e0ae5c15bc10ef6fe418)
                check_type(argname="argument default_new_sheet_configuration", value=default_new_sheet_configuration, expected_type=type_hints["default_new_sheet_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_new_sheet_configuration": default_new_sheet_configuration,
            }

        @builtins.property
        def default_new_sheet_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DefaultNewSheetConfigurationProperty"]:
            '''The configuration for default new sheet settings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-analysisdefaults.html#cfn-quicksight-template-analysisdefaults-defaultnewsheetconfiguration
            '''
            result = self._values.get("default_new_sheet_configuration")
            assert result is not None, "Required property 'default_new_sheet_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DefaultNewSheetConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisDefaultsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AnchorDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_option": "anchorOption",
            "parameter_name": "parameterName",
        },
    )
    class AnchorDateConfigurationProperty:
        def __init__(
            self,
            *,
            anchor_option: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The date configuration of the filter.

            :param anchor_option: The options for the date configuration. Choose one of the options below:. - ``NOW``
            :param parameter_name: The name of the parameter that is used for the anchor date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                anchor_date_configuration_property = quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                    anchor_option="anchorOption",
                    parameter_name="parameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bd9c20cc67968bb3693514fd4b4b2524ab3fa8f1565c6a3f2be2b6d22e5b9fca)
                check_type(argname="argument anchor_option", value=anchor_option, expected_type=type_hints["anchor_option"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if anchor_option is not None:
                self._values["anchor_option"] = anchor_option
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name

        @builtins.property
        def anchor_option(self) -> typing.Optional[builtins.str]:
            '''The options for the date configuration. Choose one of the options below:.

            - ``NOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html#cfn-quicksight-template-anchordateconfiguration-anchoroption
            '''
            result = self._values.get("anchor_option")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The name of the parameter that is used for the anchor date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html#cfn-quicksight-template-anchordateconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnchorDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ArcAxisConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "reserve_range": "reserveRange"},
    )
    class ArcAxisConfigurationProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ArcAxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reserve_range: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :param range: The arc axis range of a ``GaugeChartVisual`` .
            :param reserve_range: The reserved range of the arc axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                arc_axis_configuration_property = quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                    range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                        max=123,
                        min=123
                    ),
                    reserve_range=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c58eec17140ba655c862f5cdfb10c3acc051fbdb0b1ae87ae38bc47f0b9edcc4)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument reserve_range", value=reserve_range, expected_type=type_hints["reserve_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if reserve_range is not None:
                self._values["reserve_range"] = reserve_range

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ArcAxisDisplayRangeProperty"]]:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html#cfn-quicksight-template-arcaxisconfiguration-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ArcAxisDisplayRangeProperty"]], result)

        @builtins.property
        def reserve_range(self) -> typing.Optional[jsii.Number]:
            '''The reserved range of the arc axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html#cfn-quicksight-template-arcaxisconfiguration-reserverange
            '''
            result = self._values.get("reserve_range")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ArcAxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"max": "max", "min": "min"},
    )
    class ArcAxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            max: typing.Optional[jsii.Number] = None,
            min: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :param max: The maximum value of the arc axis range.
            :param min: The minimum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                arc_axis_display_range_property = quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                    max=123,
                    min=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__76d317d950491bacad0685b9e125d8ac6cac4ad5f99449e4f891b3fd8cd615f7)
                check_type(argname="argument max", value=max, expected_type=type_hints["max"])
                check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max is not None:
                self._values["max"] = max
            if min is not None:
                self._values["min"] = min

        @builtins.property
        def max(self) -> typing.Optional[jsii.Number]:
            '''The maximum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html#cfn-quicksight-template-arcaxisdisplayrange-max
            '''
            result = self._values.get("max")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def min(self) -> typing.Optional[jsii.Number]:
            '''The minimum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html#cfn-quicksight-template-arcaxisdisplayrange-min
            '''
            result = self._values.get("min")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ArcConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_angle": "arcAngle", "arc_thickness": "arcThickness"},
    )
    class ArcConfigurationProperty:
        def __init__(
            self,
            *,
            arc_angle: typing.Optional[jsii.Number] = None,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :param arc_angle: The option that determines the arc angle of a ``GaugeChartVisual`` .
            :param arc_thickness: The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                arc_configuration_property = quicksight.CfnTemplate.ArcConfigurationProperty(
                    arc_angle=123,
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e45cdab6f7976fe4bd86f9215da189bc4e8ba9e52e11b23b8db35d694fac91ea)
                check_type(argname="argument arc_angle", value=arc_angle, expected_type=type_hints["arc_angle"])
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_angle is not None:
                self._values["arc_angle"] = arc_angle
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_angle(self) -> typing.Optional[jsii.Number]:
            '''The option that determines the arc angle of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html#cfn-quicksight-template-arcconfiguration-arcangle
            '''
            result = self._values.get("arc_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html#cfn-quicksight-template-arcconfiguration-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ArcOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_thickness": "arcThickness"},
    )
    class ArcOptionsProperty:
        def __init__(
            self,
            *,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :param arc_thickness: The arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                arc_options_property = quicksight.CfnTemplate.ArcOptionsProperty(
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1e24bc71ca24a797722b17fd3fbd4bdcc269e1e933e7119cac4d4cf7f843548b)
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcoptions.html#cfn-quicksight-template-arcoptions-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AxisDataOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_axis_options": "dateAxisOptions",
            "numeric_axis_options": "numericAxisOptions",
        },
    )
    class AxisDataOptionsProperty:
        def __init__(
            self,
            *,
            date_axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DateAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data options for an axis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_axis_options: The options for an axis with a date field.
            :param numeric_axis_options: The options for an axis with a numeric field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_data_options_property = quicksight.CfnTemplate.AxisDataOptionsProperty(
                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                        missing_date_visibility="missingDateVisibility"
                    ),
                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                            data_driven=data_driven,
                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                maximum=123,
                                minimum=123
                            )
                        ),
                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                step_count=123,
                                step_size=123
                            ),
                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                base=123
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__324dccf7649368ff55abd01f5eee190a710b66e0e7b71d885d29f858f97515d7)
                check_type(argname="argument date_axis_options", value=date_axis_options, expected_type=type_hints["date_axis_options"])
                check_type(argname="argument numeric_axis_options", value=numeric_axis_options, expected_type=type_hints["numeric_axis_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_axis_options is not None:
                self._values["date_axis_options"] = date_axis_options
            if numeric_axis_options is not None:
                self._values["numeric_axis_options"] = numeric_axis_options

        @builtins.property
        def date_axis_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateAxisOptionsProperty"]]:
            '''The options for an axis with a date field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html#cfn-quicksight-template-axisdataoptions-dateaxisoptions
            '''
            result = self._values.get("date_axis_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateAxisOptionsProperty"]], result)

        @builtins.property
        def numeric_axis_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericAxisOptionsProperty"]]:
            '''The options for an axis with a numeric field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html#cfn-quicksight-template-axisdataoptions-numericaxisoptions
            '''
            result = self._values.get("numeric_axis_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericAxisOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDataOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"maximum": "maximum", "minimum": "minimum"},
    )
    class AxisDisplayMinMaxRangeProperty:
        def __init__(
            self,
            *,
            maximum: typing.Optional[jsii.Number] = None,
            minimum: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The minimum and maximum setup for an axis display range.

            :param maximum: The maximum setup for an axis display range.
            :param minimum: The minimum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_display_min_max_range_property = quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                    maximum=123,
                    minimum=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__77dd09ab5da2741ff46af19d5e7bff1f72b9cebc2fadf3ee0984d7af5f2bf12b)
                check_type(argname="argument maximum", value=maximum, expected_type=type_hints["maximum"])
                check_type(argname="argument minimum", value=minimum, expected_type=type_hints["minimum"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if maximum is not None:
                self._values["maximum"] = maximum
            if minimum is not None:
                self._values["minimum"] = minimum

        @builtins.property
        def maximum(self) -> typing.Optional[jsii.Number]:
            '''The maximum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html#cfn-quicksight-template-axisdisplayminmaxrange-maximum
            '''
            result = self._values.get("maximum")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def minimum(self) -> typing.Optional[jsii.Number]:
            '''The minimum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html#cfn-quicksight-template-axisdisplayminmaxrange-minimum
            '''
            result = self._values.get("minimum")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayMinMaxRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_line_visibility": "axisLineVisibility",
            "axis_offset": "axisOffset",
            "data_options": "dataOptions",
            "grid_line_visibility": "gridLineVisibility",
            "scrollbar_options": "scrollbarOptions",
            "tick_label_options": "tickLabelOptions",
        },
    )
    class AxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_line_visibility: typing.Optional[builtins.str] = None,
            axis_offset: typing.Optional[builtins.str] = None,
            data_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDataOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid_line_visibility: typing.Optional[builtins.str] = None,
            scrollbar_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ScrollBarOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tick_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisTickLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options for the axis label.

            :param axis_line_visibility: Determines whether or not the axis line is visible.
            :param axis_offset: The offset value that determines the starting placement of the axis within a visual's bounds.
            :param data_options: The data options for an axis.
            :param grid_line_visibility: Determines whether or not the grid line is visible.
            :param scrollbar_options: The scroll bar options for an axis.
            :param tick_label_options: The tick label options of an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_options_property = quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                    axis_line_visibility="axisLineVisibility",
                    axis_offset="axisOffset",
                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                            missing_date_visibility="missingDateVisibility"
                        ),
                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                data_driven=data_driven,
                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                    maximum=123,
                                    minimum=123
                                )
                            ),
                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                    step_count=123,
                                    step_size=123
                                ),
                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                    base=123
                                )
                            )
                        )
                    ),
                    grid_line_visibility="gridLineVisibility",
                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                        visibility="visibility",
                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                from=123,
                                to=123
                            )
                        )
                    ),
                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        rotation_angle=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ae8fb016007fa5ce580eb64fca7788b0a4ed19c00aa131b1ddd847b1919f6cc4)
                check_type(argname="argument axis_line_visibility", value=axis_line_visibility, expected_type=type_hints["axis_line_visibility"])
                check_type(argname="argument axis_offset", value=axis_offset, expected_type=type_hints["axis_offset"])
                check_type(argname="argument data_options", value=data_options, expected_type=type_hints["data_options"])
                check_type(argname="argument grid_line_visibility", value=grid_line_visibility, expected_type=type_hints["grid_line_visibility"])
                check_type(argname="argument scrollbar_options", value=scrollbar_options, expected_type=type_hints["scrollbar_options"])
                check_type(argname="argument tick_label_options", value=tick_label_options, expected_type=type_hints["tick_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_line_visibility is not None:
                self._values["axis_line_visibility"] = axis_line_visibility
            if axis_offset is not None:
                self._values["axis_offset"] = axis_offset
            if data_options is not None:
                self._values["data_options"] = data_options
            if grid_line_visibility is not None:
                self._values["grid_line_visibility"] = grid_line_visibility
            if scrollbar_options is not None:
                self._values["scrollbar_options"] = scrollbar_options
            if tick_label_options is not None:
                self._values["tick_label_options"] = tick_label_options

        @builtins.property
        def axis_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the axis line is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-axislinevisibility
            '''
            result = self._values.get("axis_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def axis_offset(self) -> typing.Optional[builtins.str]:
            '''The offset value that determines the starting placement of the axis within a visual's bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-axisoffset
            '''
            result = self._values.get("axis_offset")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDataOptionsProperty"]]:
            '''The data options for an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-dataoptions
            '''
            result = self._values.get("data_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDataOptionsProperty"]], result)

        @builtins.property
        def grid_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the grid line is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-gridlinevisibility
            '''
            result = self._values.get("grid_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scrollbar_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ScrollBarOptionsProperty"]]:
            '''The scroll bar options for an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-scrollbaroptions
            '''
            result = self._values.get("scrollbar_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ScrollBarOptionsProperty"]], result)

        @builtins.property
        def tick_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisTickLabelOptionsProperty"]]:
            '''The tick label options of an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-ticklabeloptions
            '''
            result = self._values.get("tick_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisTickLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"data_driven": "dataDriven", "min_max": "minMax"},
    )
    class AxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            data_driven: typing.Any = None,
            min_max: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayMinMaxRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The range setup of a numeric axis display range.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_driven: The data-driven setup of an axis display range.
            :param min_max: The minimum and maximum setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_range_property = quicksight.CfnTemplate.AxisDisplayRangeProperty(
                    data_driven=data_driven,
                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                        maximum=123,
                        minimum=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1126f0bf66992cd44e47b78a987550b2282fcf1240d5e6cc6b0b0b467d6b807f)
                check_type(argname="argument data_driven", value=data_driven, expected_type=type_hints["data_driven"])
                check_type(argname="argument min_max", value=min_max, expected_type=type_hints["min_max"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_driven is not None:
                self._values["data_driven"] = data_driven
            if min_max is not None:
                self._values["min_max"] = min_max

        @builtins.property
        def data_driven(self) -> typing.Any:
            '''The data-driven setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html#cfn-quicksight-template-axisdisplayrange-datadriven
            '''
            result = self._values.get("data_driven")
            return typing.cast(typing.Any, result)

        @builtins.property
        def min_max(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayMinMaxRangeProperty"]]:
            '''The minimum and maximum setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html#cfn-quicksight-template-axisdisplayrange-minmax
            '''
            result = self._values.get("min_max")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayMinMaxRangeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "apply_to": "applyTo",
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
        },
    )
    class AxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            apply_to: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisLabelReferenceOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The label options for a chart axis.

            You must specify the field that the label is targeted to.

            :param apply_to: The options that indicate which field the label belongs to.
            :param custom_label: The text for the axis label.
            :param font_configuration: The font configuration of the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_label_options_property = quicksight.CfnTemplate.AxisLabelOptionsProperty(
                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId"
                    ),
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d4f035f92109f584c7f37be962e9568751ab0447739ab9354bed6ddb7a95da7d)
                check_type(argname="argument apply_to", value=apply_to, expected_type=type_hints["apply_to"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if apply_to is not None:
                self._values["apply_to"] = apply_to
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration

        @builtins.property
        def apply_to(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisLabelReferenceOptionsProperty"]]:
            '''The options that indicate which field the label belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-applyto
            '''
            result = self._values.get("apply_to")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisLabelReferenceOptionsProperty"]], result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]]:
            '''The font configuration of the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "field_id": "fieldId"},
    )
    class AxisLabelReferenceOptionsProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
        ) -> None:
            '''The reference that specifies where the axis label is applied to.

            :param column: The column that the axis label is targeted to.
            :param field_id: The field that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_label_reference_options_property = quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ae6e90d3451d56cd56f34e5dece18dde6bc255c7df2bf621f42e70f2499e1801)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html#cfn-quicksight-template-axislabelreferenceoptions-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html#cfn-quicksight-template-axislabelreferenceoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelReferenceOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AxisLinearScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"step_count": "stepCount", "step_size": "stepSize"},
    )
    class AxisLinearScaleProperty:
        def __init__(
            self,
            *,
            step_count: typing.Optional[jsii.Number] = None,
            step_size: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The liner axis scale setup.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param step_count: The step count setup of a linear axis.
            :param step_size: The step size setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_linear_scale_property = quicksight.CfnTemplate.AxisLinearScaleProperty(
                    step_count=123,
                    step_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__43034325dc93d42e9eefedc366412fe8ac2db4732666f266cbdfe94acebf9325)
                check_type(argname="argument step_count", value=step_count, expected_type=type_hints["step_count"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if step_count is not None:
                self._values["step_count"] = step_count
            if step_size is not None:
                self._values["step_size"] = step_size

        @builtins.property
        def step_count(self) -> typing.Optional[jsii.Number]:
            '''The step count setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html#cfn-quicksight-template-axislinearscale-stepcount
            '''
            result = self._values.get("step_count")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def step_size(self) -> typing.Optional[jsii.Number]:
            '''The step size setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html#cfn-quicksight-template-axislinearscale-stepsize
            '''
            result = self._values.get("step_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLinearScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AxisLogarithmicScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"base": "base"},
    )
    class AxisLogarithmicScaleProperty:
        def __init__(self, *, base: typing.Optional[jsii.Number] = None) -> None:
            '''The logarithmic axis scale setup.

            :param base: The base setup of a logarithmic axis scale.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislogarithmicscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_logarithmic_scale_property = quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                    base=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f28ae5504951aa359a2e63e6a301b25f58d1ff24b484f068b9ea4caec33e841)
                check_type(argname="argument base", value=base, expected_type=type_hints["base"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base is not None:
                self._values["base"] = base

        @builtins.property
        def base(self) -> typing.Optional[jsii.Number]:
            '''The base setup of a logarithmic axis scale.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislogarithmicscale.html#cfn-quicksight-template-axislogarithmicscale-base
            '''
            result = self._values.get("base")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLogarithmicScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AxisScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"linear": "linear", "logarithmic": "logarithmic"},
    )
    class AxisScaleProperty:
        def __init__(
            self,
            *,
            linear: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisLinearScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            logarithmic: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisLogarithmicScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The scale setup options for a numeric axis display.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param linear: The linear axis scale setup.
            :param logarithmic: The logarithmic axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_scale_property = quicksight.CfnTemplate.AxisScaleProperty(
                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                        step_count=123,
                        step_size=123
                    ),
                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                        base=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec680681351cc2fe713a15570b9648d779c243d1ec322e8c58c1b4ad774d0bd5)
                check_type(argname="argument linear", value=linear, expected_type=type_hints["linear"])
                check_type(argname="argument logarithmic", value=logarithmic, expected_type=type_hints["logarithmic"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if linear is not None:
                self._values["linear"] = linear
            if logarithmic is not None:
                self._values["logarithmic"] = logarithmic

        @builtins.property
        def linear(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisLinearScaleProperty"]]:
            '''The linear axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html#cfn-quicksight-template-axisscale-linear
            '''
            result = self._values.get("linear")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisLinearScaleProperty"]], result)

        @builtins.property
        def logarithmic(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisLogarithmicScaleProperty"]]:
            '''The logarithmic axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html#cfn-quicksight-template-axisscale-logarithmic
            '''
            result = self._values.get("logarithmic")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisLogarithmicScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.AxisTickLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "label_options": "labelOptions",
            "rotation_angle": "rotationAngle",
        },
    )
    class AxisTickLabelOptionsProperty:
        def __init__(
            self,
            *,
            label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rotation_angle: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The tick label options of an axis.

            :param label_options: Determines whether or not the axis ticks are visible.
            :param rotation_angle: The rotation angle of the axis tick labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                axis_tick_label_options_property = quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    rotation_angle=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7f57e9d9309e19e99da3a9f677a47fc09dacb1245950fadd888384dd206f1abd)
                check_type(argname="argument label_options", value=label_options, expected_type=type_hints["label_options"])
                check_type(argname="argument rotation_angle", value=rotation_angle, expected_type=type_hints["rotation_angle"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_options is not None:
                self._values["label_options"] = label_options
            if rotation_angle is not None:
                self._values["rotation_angle"] = rotation_angle

        @builtins.property
        def label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]]:
            '''Determines whether or not the axis ticks are visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html#cfn-quicksight-template-axisticklabeloptions-labeloptions
            '''
            result = self._values.get("label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]], result)

        @builtins.property
        def rotation_angle(self) -> typing.Optional[jsii.Number]:
            '''The rotation angle of the axis tick labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html#cfn-quicksight-template-axisticklabeloptions-rotationangle
            '''
            result = self._values.get("rotation_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisTickLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class BarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a bar chart.

            :param category: The category (y-axis) field well of a bar chart.
            :param colors: The color (group/color) field well of a bar chart.
            :param small_multiples: The small multiples field well of a bar chart.
            :param values: The value field wells of a bar chart. Values are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bar_chart_aggregated_field_wells_property = quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__228879262a0291170da2a8c3c16560be1fe978a4721a01f1902aea7bf9fe751c)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The category (y-axis) field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The color (group/color) field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a bar chart.

            Values are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "orientation": "orientation",
            "reference_lines": "referenceLines",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_axis": "valueAxis",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class BarChartConfigurationProperty:
        def __init__(
            self,
            *,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            orientation: typing.Optional[builtins.str] = None,
            reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``BarChartVisual`` .

            :param bars_arrangement: Determines the arrangement of the bars. The orientation and arrangement of bars determine the type of bar that is used in the visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) for bar chart category.
            :param category_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart.
            :param color_label_options: The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param orientation: The orientation of the bars in a bar chart visual. There are two valid values in this structure:. - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts. - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
            :param reference_lines: The reference line setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a ``BarChartVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param value_axis: The label display options (grid line, range, scale, axis step) for a bar chart value.
            :param value_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart value.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                bar_chart_configuration_property = quicksight.CfnTemplate.BarChartConfigurationProperty(
                    bars_arrangement="barsArrangement",
                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                        bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    orientation="orientation",
                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c5f1904e937fed8f41b78d3c3304c973478d85dbe0f8e51c9b8ae4afd6f2a55)
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_axis", value=value_axis, expected_type=type_hints["value_axis"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if orientation is not None:
                self._values["orientation"] = orientation
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_axis is not None:
                self._values["value_axis"] = value_axis
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the arrangement of the bars.

            The orientation and arrangement of bars determine the type of bar that is used in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) for bar chart category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ContributionAnalysisDefaultProperty"]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BarChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BarChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation of the bars in a bar chart visual. There are two valid values in this structure:.

            - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
            - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineProperty"]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BarChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``BarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BarChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) for a bar chart value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-valueaxis
            '''
            result = self._values.get("value_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_aggregated_field_wells": "barChartAggregatedFieldWells",
        },
    )
    class BarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``BarChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_aggregated_field_wells: The aggregated field wells of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bar_chart_field_wells_property = quicksight.CfnTemplate.BarChartFieldWellsProperty(
                    bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd8953d62059b65a38653ddcdc587ed4e2f085b03e836ecdf6f1b563add645f4)
                check_type(argname="argument bar_chart_aggregated_field_wells", value=bar_chart_aggregated_field_wells, expected_type=type_hints["bar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_aggregated_field_wells is not None:
                self._values["bar_chart_aggregated_field_wells"] = bar_chart_aggregated_field_wells

        @builtins.property
        def bar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BarChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartfieldwells.html#cfn-quicksight-template-barchartfieldwells-barchartaggregatedfieldwells
            '''
            result = self._values.get("bar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BarChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class BarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''sort-configuration-description.

            :param category_items_limit: The limit on the number of categories displayed in a bar chart.
            :param category_sort: The sort configuration of category fields.
            :param color_items_limit: The limit on the number of values displayed in a bar chart.
            :param color_sort: The sort configuration of color fields in a bar chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bar_chart_sort_configuration_property = quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__675a3d60481fa006fa07ae13625df672f4ccc44c4ab52dd5e141b9cfdd87316e)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories displayed in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of values displayed in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of color fields in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A bar chart.

            The ``BarChartVisual`` structure describes a visual that is a member of the bar chart family. The following charts can be described using this structure:

            - Horizontal bar chart
            - Vertical bar chart
            - Horizontal stacked bar chart
            - Vertical stacked bar chart
            - Horizontal stacked 100% bar chart
            - Vertical stacked 100% bar chart

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                bar_chart_visual_property = quicksight.CfnTemplate.BarChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.BarChartConfigurationProperty(
                        bars_arrangement="barsArrangement",
                        category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                            bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        orientation="orientation",
                        reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                            data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cd07b19545d756f7bbf1bb98b51d624971e2aea528b6007b6ea250d6aacd89d0)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BarChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BarChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BinCountOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class BinCountOptionsProperty:
        def __init__(self, *, value: typing.Optional[jsii.Number] = None) -> None:
            '''The options that determine the bin count of a histogram.

            :param value: The options that determine the bin count value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bincountoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bin_count_options_property = quicksight.CfnTemplate.BinCountOptionsProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__866984fd8f2ff80ad3517d851b84e6b4fd85b30ca48583a7de9c98aca8092a66)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bincountoptions.html#cfn-quicksight-template-bincountoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinCountOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BinWidthOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bin_count_limit": "binCountLimit", "value": "value"},
    )
    class BinWidthOptionsProperty:
        def __init__(
            self,
            *,
            bin_count_limit: typing.Optional[jsii.Number] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the bin width of a histogram.

            :param bin_count_limit: The options that determine the bin count limit.
            :param value: The options that determine the bin width value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                bin_width_options_property = quicksight.CfnTemplate.BinWidthOptionsProperty(
                    bin_count_limit=123,
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4aa82d4989d9c69c7fd7c9840a344ab7412b58990d2a688861699d371de4c211)
                check_type(argname="argument bin_count_limit", value=bin_count_limit, expected_type=type_hints["bin_count_limit"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count_limit is not None:
                self._values["bin_count_limit"] = bin_count_limit
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def bin_count_limit(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count limit.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html#cfn-quicksight-template-binwidthoptions-bincountlimit
            '''
            result = self._values.get("bin_count_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin width value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html#cfn-quicksight-template-binwidthoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinWidthOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BodySectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content": "content",
            "section_id": "sectionId",
            "page_break_configuration": "pageBreakConfiguration",
            "style": "style",
        },
    )
    class BodySectionConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BodySectionContentProperty", typing.Dict[builtins.str, typing.Any]]],
            section_id: builtins.str,
            page_break_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SectionPageBreakConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a body section.

            :param content: The configuration of content in a body section.
            :param section_id: The unique identifier of a body section.
            :param page_break_configuration: The configuration of a page break for a section.
            :param style: The style options of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                body_section_configuration_property = quicksight.CfnTemplate.BodySectionConfigurationProperty(
                    content=quicksight.CfnTemplate.BodySectionContentProperty(
                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                        after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                            status="status"
                        )
                    ),
                    style=quicksight.CfnTemplate.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnTemplate.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2968dea75bc9dce68c5aeaadcd6766b5a6ce8761e71a01ac65fabbfa29dbb81e)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument page_break_configuration", value=page_break_configuration, expected_type=type_hints["page_break_configuration"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "section_id": section_id,
            }
            if page_break_configuration is not None:
                self._values["page_break_configuration"] = page_break_configuration
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def content(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BodySectionContentProperty"]:
            '''The configuration of content in a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BodySectionContentProperty"], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def page_break_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionPageBreakConfigurationProperty"]]:
            '''The configuration of a page break for a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-pagebreakconfiguration
            '''
            result = self._values.get("page_break_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionPageBreakConfigurationProperty"]], result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionStyleProperty"]]:
            '''The style options of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BodySectionContentProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout"},
    )
    class BodySectionContentProperty:
        def __init__(
            self,
            *,
            layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of content in a body section.

            :param layout: The layout configuration of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectioncontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                body_section_content_property = quicksight.CfnTemplate.BodySectionContentProperty(
                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__277b091edaa72550343ffdf038b2c6b4f5709ca8f2ba5744f770e2dbe106983b)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if layout is not None:
                self._values["layout"] = layout

        @builtins.property
        def layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionLayoutConfigurationProperty"]]:
            '''The layout configuration of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectioncontent.html#cfn-quicksight-template-bodysectioncontent-layout
            '''
            result = self._values.get("layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class BoxPlotAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for a box plot.

            :param group_by: The group by field well of a box plot chart. Values are grouped based on group by fields.
            :param values: The value field well of a box plot chart. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_aggregated_field_wells_property = quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b1634c4a0acf3e776a228796f30474ad051cd00ca1fbcf6a882cb02493bd09c5)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The group by field well of a box plot chart.

            Values are grouped based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html#cfn-quicksight-template-boxplotaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field well of a box plot chart.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html#cfn-quicksight-template-boxplotaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BoxPlotChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_options": "boxPlotOptions",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class BoxPlotChartConfigurationProperty:
        def __init__(
            self,
            *,
            box_plot_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BoxPlotOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BoxPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BoxPlotSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``BoxPlotVisual`` .

            :param box_plot_options: The box plot chart options for a box plot visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param category_label_options: The label options (label text, label visibility and sort Icon visibility) of a box plot category.
            :param field_wells: The field wells of the visual.
            :param legend: ``CfnTemplate.BoxPlotChartConfigurationProperty.Legend``.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param primary_y_axis_label_options: The label options (label text, label visibility and sort icon visibility) of a box plot value.
            :param reference_lines: The reference line setup of the visual.
            :param sort_configuration: The sort configuration of a ``BoxPlotVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                box_plot_chart_configuration_property = quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                    box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                        all_data_points_visibility="allDataPointsVisibility",
                        outlier_visibility="outlierVisibility",
                        style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                            fill_style="fillStyle"
                        )
                    ),
                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                        box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                            page_number=123,
                            page_size=123
                        )
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__146508bc46e215e9d9014da0d66f86caa364cc19b0211f0bf10f8219dfcdda21)
                check_type(argname="argument box_plot_options", value=box_plot_options, expected_type=type_hints["box_plot_options"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_options is not None:
                self._values["box_plot_options"] = box_plot_options
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def box_plot_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotOptionsProperty"]]:
            '''The box plot chart options for a box plot visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-boxplotoptions
            '''
            result = self._values.get("box_plot_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotOptionsProperty"]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort Icon visibility) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]]:
            '''``CfnTemplate.BoxPlotChartConfigurationProperty.Legend``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility and sort icon visibility) of a box plot value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineProperty"]]]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotSortConfigurationProperty"]]:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BoxPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_aggregated_field_wells": "boxPlotAggregatedFieldWells",
        },
    )
    class BoxPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            box_plot_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BoxPlotAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``BoxPlotVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param box_plot_aggregated_field_wells: The aggregated field wells of a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_field_wells_property = quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                    box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f2f6ff9c64d9aefb16c98fd7159fdcfe41836245311ffe735b395df0ca9b8482)
                check_type(argname="argument box_plot_aggregated_field_wells", value=box_plot_aggregated_field_wells, expected_type=type_hints["box_plot_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_aggregated_field_wells is not None:
                self._values["box_plot_aggregated_field_wells"] = box_plot_aggregated_field_wells

        @builtins.property
        def box_plot_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotfieldwells.html#cfn-quicksight-template-boxplotfieldwells-boxplotaggregatedfieldwells
            '''
            result = self._values.get("box_plot_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BoxPlotOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "all_data_points_visibility": "allDataPointsVisibility",
            "outlier_visibility": "outlierVisibility",
            "style_options": "styleOptions",
        },
    )
    class BoxPlotOptionsProperty:
        def __init__(
            self,
            *,
            all_data_points_visibility: typing.Optional[builtins.str] = None,
            outlier_visibility: typing.Optional[builtins.str] = None,
            style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BoxPlotStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options of a box plot visual.

            :param all_data_points_visibility: Determines the visibility of all data points of the box plot.
            :param outlier_visibility: Determines the visibility of the outlier in a box plot.
            :param style_options: The style options of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_options_property = quicksight.CfnTemplate.BoxPlotOptionsProperty(
                    all_data_points_visibility="allDataPointsVisibility",
                    outlier_visibility="outlierVisibility",
                    style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                        fill_style="fillStyle"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__26113e083824abcbdb2ae7faf9668ed8608ac650f95a303f5fb7b7632e1e1b5a)
                check_type(argname="argument all_data_points_visibility", value=all_data_points_visibility, expected_type=type_hints["all_data_points_visibility"])
                check_type(argname="argument outlier_visibility", value=outlier_visibility, expected_type=type_hints["outlier_visibility"])
                check_type(argname="argument style_options", value=style_options, expected_type=type_hints["style_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if all_data_points_visibility is not None:
                self._values["all_data_points_visibility"] = all_data_points_visibility
            if outlier_visibility is not None:
                self._values["outlier_visibility"] = outlier_visibility
            if style_options is not None:
                self._values["style_options"] = style_options

        @builtins.property
        def all_data_points_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of all data points of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-alldatapointsvisibility
            '''
            result = self._values.get("all_data_points_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def outlier_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the outlier in a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-outliervisibility
            '''
            result = self._values.get("outlier_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotStyleOptionsProperty"]]:
            '''The style options of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-styleoptions
            '''
            result = self._values.get("style_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotStyleOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BoxPlotSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_sort": "categorySort",
            "pagination_configuration": "paginationConfiguration",
        },
    )
    class BoxPlotSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            pagination_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :param category_sort: The sort configuration of a group by fields.
            :param pagination_configuration: The pagination configuration of a table visual or box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_sort_configuration_property = quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cd8e9a59dd393f52015fa11754bae31ce72890cc96c25a05af5092a0844ed38f)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of a group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html#cfn-quicksight-template-boxplotsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PaginationConfigurationProperty"]]:
            '''The pagination configuration of a table visual or box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html#cfn-quicksight-template-boxplotsortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PaginationConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BoxPlotStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"fill_style": "fillStyle"},
    )
    class BoxPlotStyleOptionsProperty:
        def __init__(self, *, fill_style: typing.Optional[builtins.str] = None) -> None:
            '''The style options of the box plot.

            :param fill_style: The fill styles (solid, transparent) of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                box_plot_style_options_property = quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                    fill_style="fillStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__94465dfd5110a4ced8423c53437d72c14f7d1ef1be37fd77a6125bd464d376ee)
                check_type(argname="argument fill_style", value=fill_style, expected_type=type_hints["fill_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if fill_style is not None:
                self._values["fill_style"] = fill_style

        @builtins.property
        def fill_style(self) -> typing.Optional[builtins.str]:
            '''The fill styles (solid, transparent) of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotstyleoptions.html#cfn-quicksight-template-boxplotstyleoptions-fillstyle
            '''
            result = self._values.get("fill_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.BoxPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BoxPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BoxPlotChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                box_plot_visual_property = quicksight.CfnTemplate.BoxPlotVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                        box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                            all_data_points_visibility="allDataPointsVisibility",
                            outlier_visibility="outlierVisibility",
                            style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                                fill_style="fillStyle"
                            )
                        ),
                        category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                            box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                            data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                page_number=123,
                                page_size=123
                            )
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__36a6bcada7aa89455101e555072f2759e63ae5ebc5ac9a6b69a59748ef9f4de0)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CalculatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "expression": "expression",
            "name": "name",
        },
    )
    class CalculatedFieldProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            expression: builtins.str,
            name: builtins.str,
        ) -> None:
            '''The calculated field of an analysis.

            :param data_set_identifier: The data set that is used in this calculated field.
            :param expression: The expression of the calculated field.
            :param name: The name of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                calculated_field_property = quicksight.CfnTemplate.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3becd3c6f032461ed699605f6c64a3dbeca6202c5adc4fc68b2bfe470186c5cd)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "expression": expression,
                "name": name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in this calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CalculatedMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "field_id": "fieldId"},
    )
    class CalculatedMeasureFieldProperty:
        def __init__(self, *, expression: builtins.str, field_id: builtins.str) -> None:
            '''The table calculation measure field for pivot tables.

            :param expression: The expression in the table calculation.
            :param field_id: The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                calculated_measure_field_property = quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                    expression="expression",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0041a15252d178abf67ba4ae71735a9a3d64f7829a339f06d0d099418614fa25)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "field_id": field_id,
            }

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression in the table calculation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html#cfn-quicksight-template-calculatedmeasurefield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html#cfn-quicksight-template-calculatedmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CascadingControlConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"source_controls": "sourceControls"},
    )
    class CascadingControlConfigurationProperty:
        def __init__(
            self,
            *,
            source_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CascadingControlSourceProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :param source_controls: A list of source controls that determine the values that are used in the current control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                cascading_control_configuration_property = quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        source_sheet_control_id="sourceSheetControlId"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__38cf3170013e51f12ee5f8fbd42c570af6bee33d4debe9d6d720623d1976fc73)
                check_type(argname="argument source_controls", value=source_controls, expected_type=type_hints["source_controls"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_controls is not None:
                self._values["source_controls"] = source_controls

        @builtins.property
        def source_controls(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CascadingControlSourceProperty"]]]]:
            '''A list of source controls that determine the values that are used in the current control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolconfiguration.html#cfn-quicksight-template-cascadingcontrolconfiguration-sourcecontrols
            '''
            result = self._values.get("source_controls")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CascadingControlSourceProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CascadingControlSourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_to_match": "columnToMatch",
            "source_sheet_control_id": "sourceSheetControlId",
        },
    )
    class CascadingControlSourceProperty:
        def __init__(
            self,
            *,
            column_to_match: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_sheet_control_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The source controls that are used in a ``CascadingControlConfiguration`` .

            :param column_to_match: The column identifier that determines which column to look up for the source sheet control.
            :param source_sheet_control_id: The source sheet control ID of a ``CascadingControlSource`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                cascading_control_source_property = quicksight.CfnTemplate.CascadingControlSourceProperty(
                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    source_sheet_control_id="sourceSheetControlId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ae7680fbd080e0cfdd2045c30c0a3edee435c10a44c9c39e5a921dd96816070d)
                check_type(argname="argument column_to_match", value=column_to_match, expected_type=type_hints["column_to_match"])
                check_type(argname="argument source_sheet_control_id", value=source_sheet_control_id, expected_type=type_hints["source_sheet_control_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_to_match is not None:
                self._values["column_to_match"] = column_to_match
            if source_sheet_control_id is not None:
                self._values["source_sheet_control_id"] = source_sheet_control_id

        @builtins.property
        def column_to_match(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]]:
            '''The column identifier that determines which column to look up for the source sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html#cfn-quicksight-template-cascadingcontrolsource-columntomatch
            '''
            result = self._values.get("column_to_match")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]], result)

        @builtins.property
        def source_sheet_control_id(self) -> typing.Optional[builtins.str]:
            '''The source sheet control ID of a ``CascadingControlSource`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html#cfn-quicksight-template-cascadingcontrolsource-sourcesheetcontrolid
            '''
            result = self._values.get("source_sheet_control_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlSourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CategoricalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class CategoricalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with categorical type columns..

            :param column: The column that is used in the ``CategoricalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                categorical_dimension_field_property = quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d68d5fbe1945068a8a6df6b2de8abe55cd64f05d6d715564bcf840bdf9518a4f)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``CategoricalDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.StringFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.StringFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CategoricalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class CategoricalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with categorical type columns.

            :param column: The column that is used in the ``CategoricalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                categorical_measure_field_property = quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__801f1a2e3bc6937e71d7c8276f80e2f7636c8461da87a6437d8ea147143a94dc)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``CategoricalMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.StringFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.StringFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CategoryDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"category_values": "categoryValues", "column": "column"},
    )
    class CategoryDrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_values: typing.Sequence[builtins.str],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The numeric equality type drill down filter.

            :param category_values: A list of the string inputs that are the values of the category drill down filter.
            :param column: The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                category_drill_down_filter_property = quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                    category_values=["categoryValues"],
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e9e786b12869b337cbfe28a369c6c3681e7af21140b7cd96a4d96a700ac9f8e5)
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category_values": category_values,
                "column": column,
            }

        @builtins.property
        def category_values(self) -> typing.List[builtins.str]:
            '''A list of the string inputs that are the values of the category drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html#cfn-quicksight-template-categorydrilldownfilter-categoryvalues
            '''
            result = self._values.get("category_values")
            assert result is not None, "Required property 'category_values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html#cfn-quicksight-template-categorydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CategoryFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_filter_configuration": "customFilterConfiguration",
            "custom_filter_list_configuration": "customFilterListConfiguration",
            "filter_list_configuration": "filterListConfiguration",
        },
    )
    class CategoryFilterConfigurationProperty:
        def __init__(
            self,
            *,
            custom_filter_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CustomFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_filter_list_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CustomFilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filter_list_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``CategoryFilter`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_filter_configuration: A custom filter that filters based on a single value. This filter can be partially matched.
            :param custom_filter_list_configuration: A list of custom filter values. In the Amazon QuickSight console, this filter type is called a custom filter list.
            :param filter_list_configuration: A list of filter configurations. In the Amazon QuickSight console, this filter type is called a filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                category_filter_configuration_property = quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                    custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_value="categoryValue",
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions"
                    ),
                    custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    ),
                    filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                        match_operator="matchOperator",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__67d686bcc0963d7f63271b55f8baf47c856066e633095000abf5e739e9905107)
                check_type(argname="argument custom_filter_configuration", value=custom_filter_configuration, expected_type=type_hints["custom_filter_configuration"])
                check_type(argname="argument custom_filter_list_configuration", value=custom_filter_list_configuration, expected_type=type_hints["custom_filter_list_configuration"])
                check_type(argname="argument filter_list_configuration", value=filter_list_configuration, expected_type=type_hints["filter_list_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_filter_configuration is not None:
                self._values["custom_filter_configuration"] = custom_filter_configuration
            if custom_filter_list_configuration is not None:
                self._values["custom_filter_list_configuration"] = custom_filter_list_configuration
            if filter_list_configuration is not None:
                self._values["filter_list_configuration"] = filter_list_configuration

        @builtins.property
        def custom_filter_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomFilterConfigurationProperty"]]:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-customfilterconfiguration
            '''
            result = self._values.get("custom_filter_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomFilterConfigurationProperty"]], result)

        @builtins.property
        def custom_filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomFilterListConfigurationProperty"]]:
            '''A list of custom filter values.

            In the Amazon QuickSight console, this filter type is called a custom filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-customfilterlistconfiguration
            '''
            result = self._values.get("custom_filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomFilterListConfigurationProperty"]], result)

        @builtins.property
        def filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterListConfigurationProperty"]]:
            '''A list of filter configurations.

            In the Amazon QuickSight console, this filter type is called a filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-filterlistconfiguration
            '''
            result = self._values.get("filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterListConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CategoryFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "configuration": "configuration",
            "filter_id": "filterId",
        },
    )
    class CategoryFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CategoryFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
        ) -> None:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :param column: The column that the filter is applied to.
            :param configuration: The configuration for a ``CategoryFilter`` .
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                category_filter_property = quicksight.CfnTemplate.CategoryFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                        custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_value="categoryValue",
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions"
                        ),
                        custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        ),
                        filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                            match_operator="matchOperator",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        )
                    ),
                    filter_id="filterId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__193111083f72ca0c8e0db585677c8623e33804df0618c2c7e1a439b51c5c440e)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "configuration": configuration,
                "filter_id": filter_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CategoryFilterConfigurationProperty"]:
            '''The configuration for a ``CategoryFilter`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CategoryFilterConfigurationProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ChartAxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_label_options": "axisLabelOptions",
            "sort_icon_visibility": "sortIconVisibility",
            "visibility": "visibility",
        },
    )
    class ChartAxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sort_icon_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options for an axis on a chart.

            :param axis_label_options: The label options for a chart axis.
            :param sort_icon_visibility: The visibility configuration of the sort icon on a chart's axis label.
            :param visibility: The visibility of an axis label on a chart. Choose one of the following options:. - ``VISIBLE`` : Shows the axis. - ``HIDDEN`` : Hides the axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                chart_axis_label_options_property = quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId"
                        ),
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        )
                    )],
                    sort_icon_visibility="sortIconVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__de6a551c022ce53830f235913ae5f23385b88d80920f9fd2a6e1b9e63c296d88)
                check_type(argname="argument axis_label_options", value=axis_label_options, expected_type=type_hints["axis_label_options"])
                check_type(argname="argument sort_icon_visibility", value=sort_icon_visibility, expected_type=type_hints["sort_icon_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_label_options is not None:
                self._values["axis_label_options"] = axis_label_options
            if sort_icon_visibility is not None:
                self._values["sort_icon_visibility"] = sort_icon_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisLabelOptionsProperty"]]]]:
            '''The label options for a chart axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-axislabeloptions
            '''
            result = self._values.get("axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisLabelOptionsProperty"]]]], result)

        @builtins.property
        def sort_icon_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the sort icon on a chart's axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-sorticonvisibility
            '''
            result = self._values.get("sort_icon_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an axis label on a chart. Choose one of the following options:.

            - ``VISIBLE`` : Shows the axis.
            - ``HIDDEN`` : Hides the axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ChartAxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ClusterMarkerConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"cluster_marker": "clusterMarker"},
    )
    class ClusterMarkerConfigurationProperty:
        def __init__(
            self,
            *,
            cluster_marker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cluster marker configuration of the geospatial map selected point style.

            :param cluster_marker: The cluster marker that is a part of the cluster marker configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarkerconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                cluster_marker_configuration_property = quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                    cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                        simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3998b75924ef54725ce8414f762be2375ce677bd5db69037ea1d34e45725516e)
                check_type(argname="argument cluster_marker", value=cluster_marker, expected_type=type_hints["cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker is not None:
                self._values["cluster_marker"] = cluster_marker

        @builtins.property
        def cluster_marker(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ClusterMarkerProperty"]]:
            '''The cluster marker that is a part of the cluster marker configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarkerconfiguration.html#cfn-quicksight-template-clustermarkerconfiguration-clustermarker
            '''
            result = self._values.get("cluster_marker")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ClusterMarkerProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"simple_cluster_marker": "simpleClusterMarker"},
    )
    class ClusterMarkerProperty:
        def __init__(
            self,
            *,
            simple_cluster_marker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SimpleClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cluster marker that is a part of the cluster marker configuration.

            :param simple_cluster_marker: The simple cluster marker of the cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                cluster_marker_property = quicksight.CfnTemplate.ClusterMarkerProperty(
                    simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dbce481cb1723044761d85f2ef123d4c87fe2b062cc1fbfaf1e73bf0efe719de)
                check_type(argname="argument simple_cluster_marker", value=simple_cluster_marker, expected_type=type_hints["simple_cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_cluster_marker is not None:
                self._values["simple_cluster_marker"] = simple_cluster_marker

        @builtins.property
        def simple_cluster_marker(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SimpleClusterMarkerProperty"]]:
            '''The simple cluster marker of the cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarker.html#cfn-quicksight-template-clustermarker-simpleclustermarker
            '''
            result = self._values.get("simple_cluster_marker")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SimpleClusterMarkerProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ColorScaleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_fill_type": "colorFillType",
            "colors": "colors",
            "null_value_color": "nullValueColor",
        },
    )
    class ColorScaleProperty:
        def __init__(
            self,
            *,
            color_fill_type: builtins.str,
            colors: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataColorProperty", typing.Dict[builtins.str, typing.Any]]]]],
            null_value_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the color scale that is applied to the visual.

            :param color_fill_type: Determines the color fill type.
            :param colors: Determines the list of colors that are applied to the visual.
            :param null_value_color: Determines the color that is applied to null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                color_scale_property = quicksight.CfnTemplate.ColorScaleProperty(
                    color_fill_type="colorFillType",
                    colors=[quicksight.CfnTemplate.DataColorProperty(
                        color="color",
                        data_value=123
                    )],
                
                    # the properties below are optional
                    null_value_color=quicksight.CfnTemplate.DataColorProperty(
                        color="color",
                        data_value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__92b8b530a6cba82f7f27ddcfbf439aa8b510f61290b8c4d0c4286fa928ddb22c)
                check_type(argname="argument color_fill_type", value=color_fill_type, expected_type=type_hints["color_fill_type"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument null_value_color", value=null_value_color, expected_type=type_hints["null_value_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color_fill_type": color_fill_type,
                "colors": colors,
            }
            if null_value_color is not None:
                self._values["null_value_color"] = null_value_color

        @builtins.property
        def color_fill_type(self) -> builtins.str:
            '''Determines the color fill type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-colorfilltype
            '''
            result = self._values.get("color_fill_type")
            assert result is not None, "Required property 'color_fill_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataColorProperty"]]]:
            '''Determines the list of colors that are applied to the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-colors
            '''
            result = self._values.get("colors")
            assert result is not None, "Required property 'colors' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataColorProperty"]]], result)

        @builtins.property
        def null_value_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataColorProperty"]]:
            '''Determines the color that is applied to null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-nullvaluecolor
            '''
            result = self._values.get("null_value_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ColorsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_colors": "customColors"},
    )
    class ColorsConfigurationProperty:
        def __init__(
            self,
            *,
            custom_colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CustomColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''
            :param custom_colors: ``CfnTemplate.ColorsConfigurationProperty.CustomColors``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                colors_configuration_property = quicksight.CfnTemplate.ColorsConfigurationProperty(
                    custom_colors=[quicksight.CfnTemplate.CustomColorProperty(
                        color="color",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        special_value="specialValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a2b59a58184dfa937fe2b39a6d5d2308c7bdbc34a78e0384842438ee16ae5efa)
                check_type(argname="argument custom_colors", value=custom_colors, expected_type=type_hints["custom_colors"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_colors is not None:
                self._values["custom_colors"] = custom_colors

        @builtins.property
        def custom_colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomColorProperty"]]]]:
            '''``CfnTemplate.ColorsConfigurationProperty.CustomColors``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorsconfiguration.html#cfn-quicksight-template-colorsconfiguration-customcolors
            '''
            result = self._values.get("custom_colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ColumnConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "colors_configuration": "colorsConfiguration",
            "format_configuration": "formatConfiguration",
            "role": "role",
        },
    )
    class ColumnConfigurationProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            colors_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColorsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            role: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The general configuration of a column.

            :param column: The column.
            :param colors_configuration: ``CfnTemplate.ColumnConfigurationProperty.ColorsConfiguration``.
            :param format_configuration: The format configuration of a column.
            :param role: The role of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_configuration_property = quicksight.CfnTemplate.ColumnConfigurationProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    colors_configuration=quicksight.CfnTemplate.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnTemplate.CustomColorProperty(
                            color="color",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__618fd4b4cd30164fd1598ab7fe964a4cfc8850dab1114b4b66f7f77b2894dfde)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument colors_configuration", value=colors_configuration, expected_type=type_hints["colors_configuration"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if colors_configuration is not None:
                self._values["colors_configuration"] = colors_configuration
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def colors_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColorsConfigurationProperty"]]:
            '''``CfnTemplate.ColumnConfigurationProperty.ColorsConfiguration``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-colorsconfiguration
            '''
            result = self._values.get("colors_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColorsConfigurationProperty"]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FormatConfigurationProperty"]]:
            '''The format configuration of a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FormatConfigurationProperty"]], result)

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name"},
    )
    class ColumnGroupColumnSchemaProperty:
        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
            '''A structure describing the name, data type, and geographic role of the columns.

            :param name: The name of the column group's column schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupcolumnschema.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_group_column_schema_property = quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8b81549adbf6e858cea83b88cfc48e761688566651fb936976502f5a6eb7f264)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the column group's column schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupcolumnschema.html#cfn-quicksight-template-columngroupcolumnschema-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnGroupColumnSchemaProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ColumnGroupSchemaProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_group_column_schema_list": "columnGroupColumnSchemaList",
            "name": "name",
        },
    )
    class ColumnGroupSchemaProperty:
        def __init__(
            self,
            *,
            column_group_column_schema_list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnGroupColumnSchemaProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The column group schema.

            :param column_group_column_schema_list: A structure containing the list of schemas for column group columns.
            :param name: The name of the column group schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_group_schema_property = quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                    column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                        name="name"
                    )],
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2a3ed3450a74311d41c5c6a30bb8e212f06230d096c8178c8fe66b78c13d53d4)
                check_type(argname="argument column_group_column_schema_list", value=column_group_column_schema_list, expected_type=type_hints["column_group_column_schema_list"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_group_column_schema_list is not None:
                self._values["column_group_column_schema_list"] = column_group_column_schema_list
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def column_group_column_schema_list(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnGroupColumnSchemaProperty"]]]]:
            '''A structure containing the list of schemas for column group columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html#cfn-quicksight-template-columngroupschema-columngroupcolumnschemalist
            '''
            result = self._values.get("column_group_column_schema_list")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnGroupColumnSchemaProperty"]]]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the column group schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html#cfn-quicksight-template-columngroupschema-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnGroupSchemaProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ColumnHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_hierarchy": "dateTimeHierarchy",
            "explicit_hierarchy": "explicitHierarchy",
            "predefined_hierarchy": "predefinedHierarchy",
        },
    )
    class ColumnHierarchyProperty:
        def __init__(
            self,
            *,
            date_time_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DateTimeHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            explicit_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ExplicitHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            predefined_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PredefinedHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields for a visual element.

            :param date_time_hierarchy: The option that determines the hierarchy of any ``DateTime`` fields.
            :param explicit_hierarchy: The option that determines the hierarchy of the fields that are built within a visual's field wells. These fields can't be duplicated to other visuals.
            :param predefined_hierarchy: The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_hierarchy_property = quicksight.CfnTemplate.ColumnHierarchyProperty(
                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3df84fa3e2f14715431731e0fdd199be04f72bfcd2bacc5843bd3120313a0458)
                check_type(argname="argument date_time_hierarchy", value=date_time_hierarchy, expected_type=type_hints["date_time_hierarchy"])
                check_type(argname="argument explicit_hierarchy", value=explicit_hierarchy, expected_type=type_hints["explicit_hierarchy"])
                check_type(argname="argument predefined_hierarchy", value=predefined_hierarchy, expected_type=type_hints["predefined_hierarchy"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_hierarchy is not None:
                self._values["date_time_hierarchy"] = date_time_hierarchy
            if explicit_hierarchy is not None:
                self._values["explicit_hierarchy"] = explicit_hierarchy
            if predefined_hierarchy is not None:
                self._values["predefined_hierarchy"] = predefined_hierarchy

        @builtins.property
        def date_time_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeHierarchyProperty"]]:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-datetimehierarchy
            '''
            result = self._values.get("date_time_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeHierarchyProperty"]], result)

        @builtins.property
        def explicit_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ExplicitHierarchyProperty"]]:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-explicithierarchy
            '''
            result = self._values.get("explicit_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ExplicitHierarchyProperty"]], result)

        @builtins.property
        def predefined_hierarchy(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PredefinedHierarchyProperty"]]:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-predefinedhierarchy
            '''
            result = self._values.get("predefined_hierarchy")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PredefinedHierarchyProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ColumnIdentifierProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class ColumnIdentifierProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            data_set_identifier: builtins.str,
        ) -> None:
            '''A column of a data set.

            :param column_name: The name of the column.
            :param data_set_identifier: The data set that the column belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_identifier_property = quicksight.CfnTemplate.ColumnIdentifierProperty(
                    column_name="columnName",
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cfdbc26567352f389f32b02d05f44b827fbb299843bc2d0848d3d1263612604b)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "data_set_identifier": data_set_identifier,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The name of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html#cfn-quicksight-template-columnidentifier-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that the column belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html#cfn-quicksight-template-columnidentifier-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnIdentifierProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ColumnSchemaProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_type": "dataType",
            "geographic_role": "geographicRole",
            "name": "name",
        },
    )
    class ColumnSchemaProperty:
        def __init__(
            self,
            *,
            data_type: typing.Optional[builtins.str] = None,
            geographic_role: typing.Optional[builtins.str] = None,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The column schema.

            :param data_type: The data type of the column schema.
            :param geographic_role: The geographic role of the column schema.
            :param name: The name of the column schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_schema_property = quicksight.CfnTemplate.ColumnSchemaProperty(
                    data_type="dataType",
                    geographic_role="geographicRole",
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6acf2d66a5d348079ce145b4fdbc4e53c109a373c43b2e6522d8e12b76957f3b)
                check_type(argname="argument data_type", value=data_type, expected_type=type_hints["data_type"])
                check_type(argname="argument geographic_role", value=geographic_role, expected_type=type_hints["geographic_role"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_type is not None:
                self._values["data_type"] = data_type
            if geographic_role is not None:
                self._values["geographic_role"] = geographic_role
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def data_type(self) -> typing.Optional[builtins.str]:
            '''The data type of the column schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-datatype
            '''
            result = self._values.get("data_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def geographic_role(self) -> typing.Optional[builtins.str]:
            '''The geographic role of the column schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-geographicrole
            '''
            result = self._values.get("geographic_role")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the column schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnSchemaProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ColumnSortProperty",
        jsii_struct_bases=[],
        name_mapping={
            "direction": "direction",
            "sort_by": "sortBy",
            "aggregation_function": "aggregationFunction",
        },
    )
    class ColumnSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_by: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort configuration for a column that is not used in a field well.

            :param direction: The sort direction.
            :param sort_by: ``CfnTemplate.ColumnSortProperty.SortBy``.
            :param aggregation_function: The aggregation function that is defined in the column sort.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_sort_property = quicksight.CfnTemplate.ColumnSortProperty(
                    direction="direction",
                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6ed9d7062fd6aa35a8664f4d58837faad0809f75f48b0d56c2638c037a3d50ca)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_by": sort_by,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''``CfnTemplate.ColumnSortProperty.SortBy``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationFunctionProperty"]]:
            '''The aggregation function that is defined in the column sort.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationFunctionProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ColumnTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "aggregation": "aggregation",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class ColumnTooltipItemProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the columns that are not part of a field well.

            :param column: The target column of the tooltip item.
            :param aggregation: The aggregation function of the column tooltip item.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                column_tooltip_item_property = quicksight.CfnTemplate.ColumnTooltipItemProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fcc9abb3242726d2964931cfea6b38cf2b9a0cc3c281f728401bc5f72d2cfed4)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The target column of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def aggregation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationFunctionProperty"]]:
            '''The aggregation function of the column tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationFunctionProperty"]], result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_values": "barValues",
            "category": "category",
            "colors": "colors",
            "line_values": "lineValues",
        },
    )
    class ComboChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            line_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a combo chart.

            :param bar_values: The aggregated ``BarValues`` field well of a combo chart.
            :param category: The aggregated category field wells of a combo chart.
            :param colors: The aggregated colors field well of a combo chart.
            :param line_values: The aggregated ``LineValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                combo_chart_aggregated_field_wells_property = quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                    bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a5a8faa7b3ba337b9bff361c9dcdfd9fa23f730f4aace1ddb75dceec870164b8)
                check_type(argname="argument bar_values", value=bar_values, expected_type=type_hints["bar_values"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument line_values", value=line_values, expected_type=type_hints["line_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_values is not None:
                self._values["bar_values"] = bar_values
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if line_values is not None:
                self._values["line_values"] = line_values

        @builtins.property
        def bar_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The aggregated ``BarValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-barvalues
            '''
            result = self._values.get("bar_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The aggregated category field wells of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The aggregated colors field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def line_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The aggregated ``LineValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-linevalues
            '''
            result = self._values.get("line_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ComboChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_data_labels": "barDataLabels",
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "line_data_labels": "lineDataLabels",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class ComboChartConfigurationProperty:
        def __init__(
            self,
            *,
            bar_data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ComboChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            line_data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ComboChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``ComboChartVisual`` .

            :param bar_data_labels: The options that determine if visual data labels are displayed. The data label options for a bar in a combo chart.
            :param bars_arrangement: Determines the bar arrangement in a combo chart. The following are valid values in this structure:. - ``CLUSTERED`` : For clustered bar combo charts. - ``STACKED`` : For stacked bar combo charts. - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.
            :param category_axis: The category axis of a combo chart.
            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
            :param color_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param line_data_labels: The options that determine if visual data labels are displayed. The data label options for a line in a combo chart.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
            :param primary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
            :param reference_lines: The reference line setup of the visual.
            :param secondary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
            :param secondary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
            :param sort_configuration: The sort configuration of a ``ComboChartVisual`` .
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                combo_chart_configuration_property = quicksight.CfnTemplate.ComboChartConfigurationProperty(
                    bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    bars_arrangement="barsArrangement",
                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                        combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                            bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__37ba57ab5c5963a6ddfe7d866ab5b035543466285dc586127aeb1fd0423228ed)
                check_type(argname="argument bar_data_labels", value=bar_data_labels, expected_type=type_hints["bar_data_labels"])
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument line_data_labels", value=line_data_labels, expected_type=type_hints["line_data_labels"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_data_labels is not None:
                self._values["bar_data_labels"] = bar_data_labels
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if line_data_labels is not None:
                self._values["line_data_labels"] = line_data_labels
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bar_data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a bar in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-bardatalabels
            '''
            result = self._values.get("bar_data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the bar arrangement in a combo chart. The following are valid values in this structure:.

            - ``CLUSTERED`` : For clustered bar combo charts.
            - ``STACKED`` : For stacked bar combo charts.
            - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The category axis of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComboChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComboChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def line_data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a line in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-linedatalabels
            '''
            result = self._values.get("line_data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineProperty"]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineProperty"]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComboChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``ComboChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComboChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ComboChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "combo_chart_aggregated_field_wells": "comboChartAggregatedFieldWells",
        },
    )
    class ComboChartFieldWellsProperty:
        def __init__(
            self,
            *,
            combo_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ComboChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of the visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param combo_chart_aggregated_field_wells: The aggregated field wells of a combo chart. Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                combo_chart_field_wells_property = quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                    combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                        bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c815bb9dd99e3137c7320a7f6dfcabca2bfd720e186637ef988437941af7e46)
                check_type(argname="argument combo_chart_aggregated_field_wells", value=combo_chart_aggregated_field_wells, expected_type=type_hints["combo_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if combo_chart_aggregated_field_wells is not None:
                self._values["combo_chart_aggregated_field_wells"] = combo_chart_aggregated_field_wells

        @builtins.property
        def combo_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComboChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a combo chart.

            Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartfieldwells.html#cfn-quicksight-template-combochartfieldwells-combochartaggregatedfieldwells
            '''
            result = self._values.get("combo_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComboChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ComboChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class ComboChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``ComboChartVisual`` .

            :param category_items_limit: The item limit configuration for the category field well of a combo chart.
            :param category_sort: The sort configuration of the category field well in a combo chart.
            :param color_items_limit: The item limit configuration of the color field well in a combo chart.
            :param color_sort: The sort configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                combo_chart_sort_configuration_property = quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c0c1f8bbb928329d8d5d4b4dd6a77831266b19568b446c7c905bed64347065e4)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The item limit configuration for the category field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The item limit configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ComboChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ComboChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ComboChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A combo chart.

            The ``ComboChartVisual`` includes stacked bar combo charts and clustered bar combo charts

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                combo_chart_visual_property = quicksight.CfnTemplate.ComboChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.ComboChartConfigurationProperty(
                        bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        bars_arrangement="barsArrangement",
                        category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                            combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                                bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                            data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__718a036498db68fdd0013a044ece3386ead6ba989512d8fa9b83fbe773056ae7)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComboChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComboChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ComparisonConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison_format": "comparisonFormat",
            "comparison_method": "comparisonMethod",
        },
    )
    class ComparisonConfigurationProperty:
        def __init__(
            self,
            *,
            comparison_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ComparisonFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison_method: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The comparison display configuration of a KPI or gauge chart.

            :param comparison_format: The format of the comparison.
            :param comparison_method: The method of the comparison. Choose from the following options:. - ``DIFFERENCE`` - ``PERCENT_DIFFERENCE`` - ``PERCENT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                comparison_configuration_property = quicksight.CfnTemplate.ComparisonConfigurationProperty(
                    comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    comparison_method="comparisonMethod"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fcf54bb706e50464d827b9acf7683c33c7e9ec1c5c781cd91076efaa5d694709)
                check_type(argname="argument comparison_format", value=comparison_format, expected_type=type_hints["comparison_format"])
                check_type(argname="argument comparison_method", value=comparison_method, expected_type=type_hints["comparison_method"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison_format is not None:
                self._values["comparison_format"] = comparison_format
            if comparison_method is not None:
                self._values["comparison_method"] = comparison_method

        @builtins.property
        def comparison_format(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComparisonFormatConfigurationProperty"]]:
            '''The format of the comparison.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html#cfn-quicksight-template-comparisonconfiguration-comparisonformat
            '''
            result = self._values.get("comparison_format")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComparisonFormatConfigurationProperty"]], result)

        @builtins.property
        def comparison_method(self) -> typing.Optional[builtins.str]:
            '''The method of the comparison. Choose from the following options:.

            - ``DIFFERENCE``
            - ``PERCENT_DIFFERENCE``
            - ``PERCENT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html#cfn-quicksight-template-comparisonconfiguration-comparisonmethod
            '''
            result = self._values.get("comparison_method")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ComparisonFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class ComparisonFormatConfigurationProperty:
        def __init__(
            self,
            *,
            number_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The format of the comparison.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param number_display_format_configuration: The number display format.
            :param percentage_display_format_configuration: The percentage display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                comparison_format_configuration_property = quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__23184dd9b5c54ee7dbdbce0037545c8ecc56f5be7d097ee4ac2d0c866e4149f1)
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumberDisplayFormatConfigurationProperty"]]:
            '''The number display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html#cfn-quicksight-template-comparisonformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumberDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PercentageDisplayFormatConfigurationProperty"]]:
            '''The percentage display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html#cfn-quicksight-template-comparisonformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PercentageDisplayFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast": "forecast",
            "growth_rate": "growthRate",
            "maximum_minimum": "maximumMinimum",
            "metric_comparison": "metricComparison",
            "period_over_period": "periodOverPeriod",
            "period_to_date": "periodToDate",
            "top_bottom_movers": "topBottomMovers",
            "top_bottom_ranked": "topBottomRanked",
            "total_aggregation": "totalAggregation",
            "unique_values": "uniqueValues",
        },
    )
    class ComputationProperty:
        def __init__(
            self,
            *,
            forecast: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ForecastComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            growth_rate: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GrowthRateComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maximum_minimum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MaximumMinimumComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            metric_comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MetricComparisonComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            period_over_period: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PeriodOverPeriodComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            period_to_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PeriodToDateComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_movers: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TopBottomMoversComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_ranked: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TopBottomRankedComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TotalAggregationComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            unique_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.UniqueValuesComputationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The computation union that is used in an insight visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param forecast: The forecast computation configuration.
            :param growth_rate: The growth rate computation configuration.
            :param maximum_minimum: The maximum and minimum computation configuration.
            :param metric_comparison: The metric comparison computation configuration.
            :param period_over_period: The period over period computation configuration.
            :param period_to_date: The period to ``DataSetIdentifier`` computation configuration.
            :param top_bottom_movers: The top movers and bottom movers computation configuration.
            :param top_bottom_ranked: The top ranked and bottom ranked computation configuration.
            :param total_aggregation: The total aggregation computation configuration.
            :param unique_values: The unique values computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                computation_property = quicksight.CfnTemplate.ComputationProperty(
                    forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        custom_seasonality_value=123,
                        lower_boundary=123,
                        name="name",
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality="seasonality",
                        upper_boundary=123,
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        period_size=123,
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        type="type",
                
                        # the properties below are optional
                        name="name",
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                        computation_id="computationId",
                        from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                        target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name"
                    ),
                    period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        period_time_granularity="periodTimeGranularity",
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        type="type",
                
                        # the properties below are optional
                        mover_size=123,
                        name="name",
                        sort_order="sortOrder",
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                        type="type",
                
                        # the properties below are optional
                        name="name",
                        result_size=123,
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                        computation_id="computationId",
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                
                        # the properties below are optional
                        name="name"
                    ),
                    unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                
                        # the properties below are optional
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a10857186d93b7285c0c96e12581d53440cff5bbcccf8dc79a4bf0807da36fc1)
                check_type(argname="argument forecast", value=forecast, expected_type=type_hints["forecast"])
                check_type(argname="argument growth_rate", value=growth_rate, expected_type=type_hints["growth_rate"])
                check_type(argname="argument maximum_minimum", value=maximum_minimum, expected_type=type_hints["maximum_minimum"])
                check_type(argname="argument metric_comparison", value=metric_comparison, expected_type=type_hints["metric_comparison"])
                check_type(argname="argument period_over_period", value=period_over_period, expected_type=type_hints["period_over_period"])
                check_type(argname="argument period_to_date", value=period_to_date, expected_type=type_hints["period_to_date"])
                check_type(argname="argument top_bottom_movers", value=top_bottom_movers, expected_type=type_hints["top_bottom_movers"])
                check_type(argname="argument top_bottom_ranked", value=top_bottom_ranked, expected_type=type_hints["top_bottom_ranked"])
                check_type(argname="argument total_aggregation", value=total_aggregation, expected_type=type_hints["total_aggregation"])
                check_type(argname="argument unique_values", value=unique_values, expected_type=type_hints["unique_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast is not None:
                self._values["forecast"] = forecast
            if growth_rate is not None:
                self._values["growth_rate"] = growth_rate
            if maximum_minimum is not None:
                self._values["maximum_minimum"] = maximum_minimum
            if metric_comparison is not None:
                self._values["metric_comparison"] = metric_comparison
            if period_over_period is not None:
                self._values["period_over_period"] = period_over_period
            if period_to_date is not None:
                self._values["period_to_date"] = period_to_date
            if top_bottom_movers is not None:
                self._values["top_bottom_movers"] = top_bottom_movers
            if top_bottom_ranked is not None:
                self._values["top_bottom_ranked"] = top_bottom_ranked
            if total_aggregation is not None:
                self._values["total_aggregation"] = total_aggregation
            if unique_values is not None:
                self._values["unique_values"] = unique_values

        @builtins.property
        def forecast(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ForecastComputationProperty"]]:
            '''The forecast computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-forecast
            '''
            result = self._values.get("forecast")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ForecastComputationProperty"]], result)

        @builtins.property
        def growth_rate(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GrowthRateComputationProperty"]]:
            '''The growth rate computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-growthrate
            '''
            result = self._values.get("growth_rate")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GrowthRateComputationProperty"]], result)

        @builtins.property
        def maximum_minimum(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MaximumMinimumComputationProperty"]]:
            '''The maximum and minimum computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-maximumminimum
            '''
            result = self._values.get("maximum_minimum")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MaximumMinimumComputationProperty"]], result)

        @builtins.property
        def metric_comparison(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MetricComparisonComputationProperty"]]:
            '''The metric comparison computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-metriccomparison
            '''
            result = self._values.get("metric_comparison")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MetricComparisonComputationProperty"]], result)

        @builtins.property
        def period_over_period(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PeriodOverPeriodComputationProperty"]]:
            '''The period over period computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-periodoverperiod
            '''
            result = self._values.get("period_over_period")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PeriodOverPeriodComputationProperty"]], result)

        @builtins.property
        def period_to_date(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PeriodToDateComputationProperty"]]:
            '''The period to ``DataSetIdentifier`` computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-periodtodate
            '''
            result = self._values.get("period_to_date")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PeriodToDateComputationProperty"]], result)

        @builtins.property
        def top_bottom_movers(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TopBottomMoversComputationProperty"]]:
            '''The top movers and bottom movers computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-topbottommovers
            '''
            result = self._values.get("top_bottom_movers")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TopBottomMoversComputationProperty"]], result)

        @builtins.property
        def top_bottom_ranked(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TopBottomRankedComputationProperty"]]:
            '''The top ranked and bottom ranked computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-topbottomranked
            '''
            result = self._values.get("top_bottom_ranked")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TopBottomRankedComputationProperty"]], result)

        @builtins.property
        def total_aggregation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TotalAggregationComputationProperty"]]:
            '''The total aggregation computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-totalaggregation
            '''
            result = self._values.get("total_aggregation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TotalAggregationComputationProperty"]], result)

        @builtins.property
        def unique_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.UniqueValuesComputationProperty"]]:
            '''The unique values computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-uniquevalues
            '''
            result = self._values.get("unique_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.UniqueValuesComputationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ConditionalFormattingColorProperty",
        jsii_struct_bases=[],
        name_mapping={"gradient": "gradient", "solid": "solid"},
    )
    class ConditionalFormattingColorProperty:
        def __init__(
            self,
            *,
            gradient: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingGradientColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            solid: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingSolidColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for the color.

            :param gradient: Formatting configuration for gradient color.
            :param solid: Formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_color_property = quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                        color=quicksight.CfnTemplate.GradientColorProperty(
                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                gradient_offset=123,
                
                                # the properties below are optional
                                color="color",
                                data_value=123
                            )]
                        ),
                        expression="expression"
                    ),
                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                        expression="expression",
                
                        # the properties below are optional
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9f84cefa451d59b1421256a0de111b071dd1faa81a78363f0f55dba2b4ec219d)
                check_type(argname="argument gradient", value=gradient, expected_type=type_hints["gradient"])
                check_type(argname="argument solid", value=solid, expected_type=type_hints["solid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if gradient is not None:
                self._values["gradient"] = gradient
            if solid is not None:
                self._values["solid"] = solid

        @builtins.property
        def gradient(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingGradientColorProperty"]]:
            '''Formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html#cfn-quicksight-template-conditionalformattingcolor-gradient
            '''
            result = self._values.get("gradient")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingGradientColorProperty"]], result)

        @builtins.property
        def solid(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingSolidColorProperty"]]:
            '''Formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html#cfn-quicksight-template-conditionalformattingcolor-solid
            '''
            result = self._values.get("solid")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingSolidColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "icon_options": "iconOptions",
            "color": "color",
            "display_configuration": "displayConfiguration",
        },
    )
    class ConditionalFormattingCustomIconConditionProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingCustomIconOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
            color: typing.Optional[builtins.str] = None,
            display_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the custom condition for an icon set.

            :param expression: The expression that determines the condition of the icon set.
            :param icon_options: Custom icon options for an icon set.
            :param color: Determines the color of the icon.
            :param display_configuration: Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_condition_property = quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                    expression="expression",
                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                        icon="icon",
                        unicode_icon="unicodeIcon"
                    ),
                
                    # the properties below are optional
                    color="color",
                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                        icon_display_option="iconDisplayOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f2d5607f67b8ccfde571e80706984c5deece104228a3e6a8f9e848bd91e79425)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_options", value=icon_options, expected_type=type_hints["icon_options"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument display_configuration", value=display_configuration, expected_type=type_hints["display_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "icon_options": icon_options,
            }
            if color is not None:
                self._values["color"] = color
            if display_configuration is not None:
                self._values["display_configuration"] = display_configuration

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the condition of the icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingCustomIconOptionsProperty"]:
            '''Custom icon options for an icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-iconoptions
            '''
            result = self._values.get("icon_options")
            assert result is not None, "Required property 'icon_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingCustomIconOptionsProperty"], result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty"]]:
            '''Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-displayconfiguration
            '''
            result = self._values.get("display_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconConditionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "unicode_icon": "unicodeIcon"},
    )
    class ConditionalFormattingCustomIconOptionsProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[builtins.str] = None,
            unicode_icon: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Custom icon options for an icon set.

            :param icon: Determines the type of icon.
            :param unicode_icon: Determines the Unicode icon type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_options_property = quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                    icon="icon",
                    unicode_icon="unicodeIcon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__84311484592ee5b6cff536f72855def52c41af5d4b8800671667710245ee227b)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument unicode_icon", value=unicode_icon, expected_type=type_hints["unicode_icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if unicode_icon is not None:
                self._values["unicode_icon"] = unicode_icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''Determines the type of icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html#cfn-quicksight-template-conditionalformattingcustomiconoptions-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def unicode_icon(self) -> typing.Optional[builtins.str]:
            '''Determines the Unicode icon type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html#cfn-quicksight-template-conditionalformattingcustomiconoptions-unicodeicon
            '''
            result = self._values.get("unicode_icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "expression": "expression"},
    )
    class ConditionalFormattingGradientColorProperty:
        def __init__(
            self,
            *,
            color: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GradientColorProperty", typing.Dict[builtins.str, typing.Any]]],
            expression: builtins.str,
        ) -> None:
            '''Formatting configuration for gradient color.

            :param color: Determines the color.
            :param expression: The expression that determines the formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_gradient_color_property = quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                    color=quicksight.CfnTemplate.GradientColorProperty(
                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                            gradient_offset=123,
                
                            # the properties below are optional
                            color="color",
                            data_value=123
                        )]
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__334da1d63cbfb714bfe523c71cc068c5d48d5e3d6899d629b2aa797e86b73e7c)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "expression": expression,
            }

        @builtins.property
        def color(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GradientColorProperty"]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html#cfn-quicksight-template-conditionalformattinggradientcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GradientColorProperty"], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html#cfn-quicksight-template-conditionalformattinggradientcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingGradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"icon_display_option": "iconDisplayOption"},
    )
    class ConditionalFormattingIconDisplayConfigurationProperty:
        def __init__(
            self,
            *,
            icon_display_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the icon display configuration.

            :param icon_display_option: Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicondisplayconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_icon_display_configuration_property = quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                    icon_display_option="iconDisplayOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5b91d20806766016269f184aa1a2bd71a3ba4830c3ce68904995c1dd1c7aef3b)
                check_type(argname="argument icon_display_option", value=icon_display_option, expected_type=type_hints["icon_display_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon_display_option is not None:
                self._values["icon_display_option"] = icon_display_option

        @builtins.property
        def icon_display_option(self) -> typing.Optional[builtins.str]:
            '''Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-template-conditionalformattingicondisplayconfiguration-icondisplayoption
            '''
            result = self._values.get("icon_display_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconDisplayConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ConditionalFormattingIconProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_condition": "customCondition", "icon_set": "iconSet"},
    )
    class ConditionalFormattingIconProperty:
        def __init__(
            self,
            *,
            custom_condition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingCustomIconConditionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            icon_set: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingIconSetProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for the icon.

            :param custom_condition: Determines the custom condition for an icon set.
            :param icon_set: Formatting configuration for icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_icon_property = quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                        expression="expression",
                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                            icon="icon",
                            unicode_icon="unicodeIcon"
                        ),
                
                        # the properties below are optional
                        color="color",
                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                            icon_display_option="iconDisplayOption"
                        )
                    ),
                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                        expression="expression",
                
                        # the properties below are optional
                        icon_set_type="iconSetType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__05c4e3b8b645273a768a6242d3f174d7aa2c4a547bca2d37e0d3105a5836ff58)
                check_type(argname="argument custom_condition", value=custom_condition, expected_type=type_hints["custom_condition"])
                check_type(argname="argument icon_set", value=icon_set, expected_type=type_hints["icon_set"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_condition is not None:
                self._values["custom_condition"] = custom_condition
            if icon_set is not None:
                self._values["icon_set"] = icon_set

        @builtins.property
        def custom_condition(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingCustomIconConditionProperty"]]:
            '''Determines the custom condition for an icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html#cfn-quicksight-template-conditionalformattingicon-customcondition
            '''
            result = self._values.get("custom_condition")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingCustomIconConditionProperty"]], result)

        @builtins.property
        def icon_set(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingIconSetProperty"]]:
            '''Formatting configuration for icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html#cfn-quicksight-template-conditionalformattingicon-iconset
            '''
            result = self._values.get("icon_set")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingIconSetProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ConditionalFormattingIconSetProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "icon_set_type": "iconSetType"},
    )
    class ConditionalFormattingIconSetProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_set_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for icon set.

            :param expression: The expression that determines the formatting configuration for the icon set.
            :param icon_set_type: Determines the icon set type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_icon_set_property = quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                    expression="expression",
                
                    # the properties below are optional
                    icon_set_type="iconSetType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6a4ef380bf073d063686423013eca7f5b7cc0349c96886111bfa6bc5e5d6417b)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_set_type", value=icon_set_type, expected_type=type_hints["icon_set_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if icon_set_type is not None:
                self._values["icon_set_type"] = icon_set_type

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for the icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html#cfn-quicksight-template-conditionalformattingiconset-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_set_type(self) -> typing.Optional[builtins.str]:
            '''Determines the icon set type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html#cfn-quicksight-template-conditionalformattingiconset-iconsettype
            '''
            result = self._values.get("icon_set_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconSetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "color": "color"},
    )
    class ConditionalFormattingSolidColorProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for solid color.

            :param expression: The expression that determines the formatting configuration for solid color.
            :param color: Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                conditional_formatting_solid_color_property = quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                    expression="expression",
                
                    # the properties below are optional
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d84ff0b8fef317df7351191245c37208e1adceca84f939ea1be960fe59d85a7b)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html#cfn-quicksight-template-conditionalformattingsolidcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html#cfn-quicksight-template-conditionalformattingsolidcolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingSolidColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ContributionAnalysisDefaultProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contributor_dimensions": "contributorDimensions",
            "measure_field_id": "measureFieldId",
        },
    )
    class ContributionAnalysisDefaultProperty:
        def __init__(
            self,
            *,
            contributor_dimensions: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            measure_field_id: builtins.str,
        ) -> None:
            '''The contribution analysis visual display for a line, pie, or bar chart.

            :param contributor_dimensions: The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .
            :param measure_field_id: The measure field that is used in the contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                contribution_analysis_default_property = quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    measure_field_id="measureFieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__44b439d4bd14e21bca7e0651f9b5d8a68e3ac42c224d8e6f0c67eab154f610cf)
                check_type(argname="argument contributor_dimensions", value=contributor_dimensions, expected_type=type_hints["contributor_dimensions"])
                check_type(argname="argument measure_field_id", value=measure_field_id, expected_type=type_hints["measure_field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "contributor_dimensions": contributor_dimensions,
                "measure_field_id": measure_field_id,
            }

        @builtins.property
        def contributor_dimensions(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]]]:
            '''The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html#cfn-quicksight-template-contributionanalysisdefault-contributordimensions
            '''
            result = self._values.get("contributor_dimensions")
            assert result is not None, "Required property 'contributor_dimensions' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def measure_field_id(self) -> builtins.str:
            '''The measure field that is used in the contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html#cfn-quicksight-template-contributionanalysisdefault-measurefieldid
            '''
            result = self._values.get("measure_field_id")
            assert result is not None, "Required property 'measure_field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ContributionAnalysisDefaultProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
            "symbol": "symbol",
        },
    )
    class CurrencyDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
            symbol: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the currency display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value for the currency format.
            :param prefix: Determines the prefix value of the currency format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the currency format.
            :param symbol: Determines the symbol for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                currency_display_format_configuration_property = quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix",
                    symbol="symbol"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__35866f69ea5e5a9775ec48ce393a451c3a04b00f7da59d2811a73ede322b2b5b)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix
            if symbol is not None:
                self._values["symbol"] = symbol

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the symbol for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CurrencyDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CustomActionFilterOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_fields_configuration": "selectedFieldsConfiguration",
            "target_visuals_configuration": "targetVisualsConfiguration",
        },
    )
    class CustomActionFilterOperationProperty:
        def __init__(
            self,
            *,
            selected_fields_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            target_visuals_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterOperationTargetVisualsConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :param selected_fields_configuration: The configuration that chooses the fields to be filtered.
            :param target_visuals_configuration: The configuration that chooses the target visuals to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_action_filter_operation_property = quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                        selected_field_options="selectedFieldOptions",
                        selected_fields=["selectedFields"]
                    ),
                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                            target_visual_options="targetVisualOptions",
                            target_visuals=["targetVisuals"]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2dbca890f9b1d41fcdd23103d058715cd57d9855daf9a6a9fb525e6759ad32c3)
                check_type(argname="argument selected_fields_configuration", value=selected_fields_configuration, expected_type=type_hints["selected_fields_configuration"])
                check_type(argname="argument target_visuals_configuration", value=target_visuals_configuration, expected_type=type_hints["target_visuals_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "selected_fields_configuration": selected_fields_configuration,
                "target_visuals_configuration": target_visuals_configuration,
            }

        @builtins.property
        def selected_fields_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty"]:
            '''The configuration that chooses the fields to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html#cfn-quicksight-template-customactionfilteroperation-selectedfieldsconfiguration
            '''
            result = self._values.get("selected_fields_configuration")
            assert result is not None, "Required property 'selected_fields_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty"], result)

        @builtins.property
        def target_visuals_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterOperationTargetVisualsConfigurationProperty"]:
            '''The configuration that chooses the target visuals to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html#cfn-quicksight-template-customactionfilteroperation-targetvisualsconfiguration
            '''
            result = self._values.get("target_visuals_configuration")
            assert result is not None, "Required property 'target_visuals_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterOperationTargetVisualsConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionFilterOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CustomActionNavigationOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "local_navigation_configuration": "localNavigationConfiguration",
        },
    )
    class CustomActionNavigationOperationProperty:
        def __init__(
            self,
            *,
            local_navigation_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LocalNavigationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The navigation operation that navigates between different sheets in the same analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param local_navigation_configuration: The configuration that chooses the navigation target.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionnavigationoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_action_navigation_operation_property = quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                        target_sheet_id="targetSheetId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__71265bfa90f418743597f20509b0be0e4a265eea4cdd0668571de7646ea32330)
                check_type(argname="argument local_navigation_configuration", value=local_navigation_configuration, expected_type=type_hints["local_navigation_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if local_navigation_configuration is not None:
                self._values["local_navigation_configuration"] = local_navigation_configuration

        @builtins.property
        def local_navigation_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LocalNavigationConfigurationProperty"]]:
            '''The configuration that chooses the navigation target.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionnavigationoperation.html#cfn-quicksight-template-customactionnavigationoperation-localnavigationconfiguration
            '''
            result = self._values.get("local_navigation_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LocalNavigationConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionNavigationOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CustomActionSetParametersOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_value_configurations": "parameterValueConfigurations",
        },
    )
    class CustomActionSetParametersOperationProperty:
        def __init__(
            self,
            *,
            parameter_value_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SetParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The set parameter operation that sets parameters in custom action.

            :param parameter_value_configurations: The parameter that determines the value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionsetparametersoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_action_set_parameters_operation_property = quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                        destination_parameter_name="destinationParameterName",
                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                    date_time_values=["dateTimeValues"],
                                    decimal_values=[123],
                                    integer_values=[123],
                                    string_values=["stringValues"]
                                ),
                
                                # the properties below are optional
                                include_null_value=False
                            ),
                            select_all_value_options="selectAllValueOptions",
                            source_field="sourceField",
                            source_parameter_name="sourceParameterName"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fa896f606093feeb32862e21def32c40f3edb217950321cdb733b21900da0f74)
                check_type(argname="argument parameter_value_configurations", value=parameter_value_configurations, expected_type=type_hints["parameter_value_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_value_configurations": parameter_value_configurations,
            }

        @builtins.property
        def parameter_value_configurations(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SetParameterValueConfigurationProperty"]]]:
            '''The parameter that determines the value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionsetparametersoperation.html#cfn-quicksight-template-customactionsetparametersoperation-parametervalueconfigurations
            '''
            result = self._values.get("parameter_value_configurations")
            assert result is not None, "Required property 'parameter_value_configurations' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SetParameterValueConfigurationProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionSetParametersOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CustomActionURLOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"url_target": "urlTarget", "url_template": "urlTemplate"},
    )
    class CustomActionURLOperationProperty:
        def __init__(
            self,
            *,
            url_target: builtins.str,
            url_template: builtins.str,
        ) -> None:
            '''The URL operation that opens a link to another webpage.

            :param url_target: The target of the ``CustomActionURLOperation`` . Valid values are defined as follows: - ``NEW_TAB`` : Opens the target URL in a new browser tab. - ``NEW_WINDOW`` : Opens the target URL in a new browser window. - ``SAME_TAB`` : Opens the target URL in the same browser tab.
            :param url_template: THe URL link of the ``CustomActionURLOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_action_uRLOperation_property = quicksight.CfnTemplate.CustomActionURLOperationProperty(
                    url_target="urlTarget",
                    url_template="urlTemplate"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e3905cdc777f3d421ca70eeec079f818709b64afe652daf8955f3f9dcc942231)
                check_type(argname="argument url_target", value=url_target, expected_type=type_hints["url_target"])
                check_type(argname="argument url_template", value=url_template, expected_type=type_hints["url_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "url_target": url_target,
                "url_template": url_template,
            }

        @builtins.property
        def url_target(self) -> builtins.str:
            '''The target of the ``CustomActionURLOperation`` .

            Valid values are defined as follows:

            - ``NEW_TAB`` : Opens the target URL in a new browser tab.
            - ``NEW_WINDOW`` : Opens the target URL in a new browser window.
            - ``SAME_TAB`` : Opens the target URL in the same browser tab.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html#cfn-quicksight-template-customactionurloperation-urltarget
            '''
            result = self._values.get("url_target")
            assert result is not None, "Required property 'url_target' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def url_template(self) -> builtins.str:
            '''THe URL link of the ``CustomActionURLOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html#cfn-quicksight-template-customactionurloperation-urltemplate
            '''
            result = self._values.get("url_template")
            assert result is not None, "Required property 'url_template' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionURLOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CustomColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "field_value": "fieldValue",
            "special_value": "specialValue",
        },
    )
    class CustomColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            special_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''
            :param color: ``CfnTemplate.CustomColorProperty.Color``.
            :param field_value: ``CfnTemplate.CustomColorProperty.FieldValue``.
            :param special_value: ``CfnTemplate.CustomColorProperty.SpecialValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_color_property = quicksight.CfnTemplate.CustomColorProperty(
                    color="color",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    special_value="specialValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__86b447be87a4286c5e6da4f7a822239e043e7fbf0be1e4b35487b8235e47e6ac)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument special_value", value=special_value, expected_type=type_hints["special_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if special_value is not None:
                self._values["special_value"] = special_value

        @builtins.property
        def color(self) -> builtins.str:
            '''``CfnTemplate.CustomColorProperty.Color``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''``CfnTemplate.CustomColorProperty.FieldValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def special_value(self) -> typing.Optional[builtins.str]:
            '''``CfnTemplate.CustomColorProperty.SpecialValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-specialvalue
            '''
            result = self._values.get("special_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CustomContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content_type": "contentType",
            "content_url": "contentUrl",
            "image_scaling": "imageScaling",
        },
    )
    class CustomContentConfigurationProperty:
        def __init__(
            self,
            *,
            content_type: typing.Optional[builtins.str] = None,
            content_url: typing.Optional[builtins.str] = None,
            image_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of a ``CustomContentVisual`` .

            :param content_type: The content type of the custom content visual. You can use this to have the visual render as an image.
            :param content_url: The input URL that links to the custom content that you want in the custom visual.
            :param image_scaling: The sizing options for the size of the custom content visual. This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_content_configuration_property = quicksight.CfnTemplate.CustomContentConfigurationProperty(
                    content_type="contentType",
                    content_url="contentUrl",
                    image_scaling="imageScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1b3665367f48d01c090b5e82bc199992e85d3029e99058e8d07546aaa5337c83)
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument content_url", value=content_url, expected_type=type_hints["content_url"])
                check_type(argname="argument image_scaling", value=image_scaling, expected_type=type_hints["image_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if content_type is not None:
                self._values["content_type"] = content_type
            if content_url is not None:
                self._values["content_url"] = content_url
            if image_scaling is not None:
                self._values["image_scaling"] = image_scaling

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The content type of the custom content visual.

            You can use this to have the visual render as an image.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def content_url(self) -> typing.Optional[builtins.str]:
            '''The input URL that links to the custom content that you want in the custom visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-contenturl
            '''
            result = self._values.get("content_url")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def image_scaling(self) -> typing.Optional[builtins.str]:
            '''The sizing options for the size of the custom content visual.

            This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-imagescaling
            '''
            result = self._values.get("image_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CustomContentVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class CustomContentVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CustomContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used to create the custom content visual. You can't create a visual without a dataset.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``CustomContentVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_content_visual_property = quicksight.CfnTemplate.CustomContentVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.CustomContentConfigurationProperty(
                        content_type="contentType",
                        content_url="contentUrl",
                        image_scaling="imageScaling"
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4b6f4e6fccaea5fe90032081ed01f025445e6a08fd499b177693844ebf07ea63)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used to create the custom content visual.

            You can't create a visual without a dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomContentConfigurationProperty"]]:
            '''The configuration of a ``CustomContentVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomContentConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CustomFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_value": "categoryValue",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_value: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_value: The category value for the filter. This field is mutually exclusive to ``ParameterName`` .
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``CategoryValue`` .
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_filter_configuration_property = quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_value="categoryValue",
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aac370beb48c7214eada3944205cbd7384ef584924e51d6bbe66c51a76045665)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_value", value=category_value, expected_type=type_hints["category_value"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_value is not None:
                self._values["category_value"] = category_value
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_value(self) -> typing.Optional[builtins.str]:
            '''The category value for the filter.

            This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-categoryvalue
            '''
            result = self._values.get("category_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``CategoryValue`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CustomFilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of custom filter values.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_filter_list_configuration_property = quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__419300a6e62f9bd1656e74e6cdfc2e83448a9def0678d2bf1b65cd9e0c0e55cb)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CustomNarrativeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"narrative": "narrative"},
    )
    class CustomNarrativeOptionsProperty:
        def __init__(self, *, narrative: builtins.str) -> None:
            '''The custom narrative options.

            :param narrative: The string input of custom narrative.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customnarrativeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_narrative_options_property = quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                    narrative="narrative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2f20410afa339ec2e3473bf69d658651f62333dae661239e4ac27702f036dbf0)
                check_type(argname="argument narrative", value=narrative, expected_type=type_hints["narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "narrative": narrative,
            }

        @builtins.property
        def narrative(self) -> builtins.str:
            '''The string input of custom narrative.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customnarrativeoptions.html#cfn-quicksight-template-customnarrativeoptions-narrative
            '''
            result = self._values.get("narrative")
            assert result is not None, "Required property 'narrative' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomNarrativeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CustomParameterValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_values": "dateTimeValues",
            "decimal_values": "decimalValues",
            "integer_values": "integerValues",
            "string_values": "stringValues",
        },
    )
    class CustomParameterValuesProperty:
        def __init__(
            self,
            *,
            date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            decimal_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
            integer_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
            string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The customized parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_values: A list of datetime-type parameter values.
            :param decimal_values: A list of decimal-type parameter values.
            :param integer_values: A list of integer-type parameter values.
            :param string_values: A list of string-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_parameter_values_property = quicksight.CfnTemplate.CustomParameterValuesProperty(
                    date_time_values=["dateTimeValues"],
                    decimal_values=[123],
                    integer_values=[123],
                    string_values=["stringValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9270e3bdeb9ea15491d2347767ba04d5ddfdbc74d3cef52640ef39545b0f4d8)
                check_type(argname="argument date_time_values", value=date_time_values, expected_type=type_hints["date_time_values"])
                check_type(argname="argument decimal_values", value=decimal_values, expected_type=type_hints["decimal_values"])
                check_type(argname="argument integer_values", value=integer_values, expected_type=type_hints["integer_values"])
                check_type(argname="argument string_values", value=string_values, expected_type=type_hints["string_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_values is not None:
                self._values["date_time_values"] = date_time_values
            if decimal_values is not None:
                self._values["decimal_values"] = decimal_values
            if integer_values is not None:
                self._values["integer_values"] = integer_values
            if string_values is not None:
                self._values["string_values"] = string_values

        @builtins.property
        def date_time_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of datetime-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-datetimevalues
            '''
            result = self._values.get("date_time_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def decimal_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]]:
            '''A list of decimal-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-decimalvalues
            '''
            result = self._values.get("decimal_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]], result)

        @builtins.property
        def integer_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]]:
            '''A list of integer-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-integervalues
            '''
            result = self._values.get("integer_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]], result)

        @builtins.property
        def string_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of string-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-stringvalues
            '''
            result = self._values.get("string_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomParameterValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.CustomValuesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values": "customValues",
            "include_null_value": "includeNullValue",
        },
    )
    class CustomValuesConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CustomParameterValuesProperty", typing.Dict[builtins.str, typing.Any]]],
            include_null_value: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
        ) -> None:
            '''The configuration of custom values for the destination parameter in ``DestinationParameterValueConfiguration`` .

            :param custom_values: ``CfnTemplate.CustomValuesConfigurationProperty.CustomValues``.
            :param include_null_value: Includes the null value in custom action parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                custom_values_configuration_property = quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                        date_time_values=["dateTimeValues"],
                        decimal_values=[123],
                        integer_values=[123],
                        string_values=["stringValues"]
                    ),
                
                    # the properties below are optional
                    include_null_value=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec0a8cca92efae20221632074e4996bbf4e8ed0dfe51823c8c25f4d12a6629c6)
                check_type(argname="argument custom_values", value=custom_values, expected_type=type_hints["custom_values"])
                check_type(argname="argument include_null_value", value=include_null_value, expected_type=type_hints["include_null_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_values": custom_values,
            }
            if include_null_value is not None:
                self._values["include_null_value"] = include_null_value

        @builtins.property
        def custom_values(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomParameterValuesProperty"]:
            '''``CfnTemplate.CustomValuesConfigurationProperty.CustomValues``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html#cfn-quicksight-template-customvaluesconfiguration-customvalues
            '''
            result = self._values.get("custom_values")
            assert result is not None, "Required property 'custom_values' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomParameterValuesProperty"], result)

        @builtins.property
        def include_null_value(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Includes the null value in custom action parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html#cfn-quicksight-template-customvaluesconfiguration-includenullvalue
            '''
            result = self._values.get("include_null_value")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomValuesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DataBarsOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "negative_color": "negativeColor",
            "positive_color": "positiveColor",
        },
    )
    class DataBarsOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            negative_color: typing.Optional[builtins.str] = None,
            positive_color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for data bars.

            :param field_id: The field ID for the data bars options.
            :param negative_color: The color of the negative data bar.
            :param positive_color: The color of the positive data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_bars_options_property = quicksight.CfnTemplate.DataBarsOptionsProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    negative_color="negativeColor",
                    positive_color="positiveColor"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c5ac3c82d586bc6dda02d57afd47f0c6e157b749d3572b8f200afd84a8febdf)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument negative_color", value=negative_color, expected_type=type_hints["negative_color"])
                check_type(argname="argument positive_color", value=positive_color, expected_type=type_hints["positive_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if negative_color is not None:
                self._values["negative_color"] = negative_color
            if positive_color is not None:
                self._values["positive_color"] = positive_color

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the data bars options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def negative_color(self) -> typing.Optional[builtins.str]:
            '''The color of the negative data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-negativecolor
            '''
            result = self._values.get("negative_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def positive_color(self) -> typing.Optional[builtins.str]:
            '''The color of the positive data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-positivecolor
            '''
            result = self._values.get("positive_color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataBarsOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DataColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "data_value": "dataValue"},
    )
    class DataColorProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the color that is applied to a particular data value.

            :param color: The color that is applied to the data value.
            :param data_value: The data value that the color is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_color_property = quicksight.CfnTemplate.DataColorProperty(
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ccb08f3731d5b3fa644c0cd8a5443d0938c28947e03b29cc8ed32020d157b0a6)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color that is applied to the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html#cfn-quicksight-template-datacolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''The data value that the color is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html#cfn-quicksight-template-datacolor-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DataFieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "settings": "settings",
        },
    )
    class DataFieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field that you are setting the axis binding to.
            :param field_value: The field value of the field that you are setting the axis binding to.
            :param settings: The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_field_series_item_property = quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__50427e728ed393f2152d27c18e60aca9343932d14fd62d3e1f884d9c8e0d3ea0)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that you are setting the axis binding to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The field value of the field that you are setting the axis binding to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartSeriesSettingsProperty"]]:
            '''The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartSeriesSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataFieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "data_label_types": "dataLabelTypes",
            "label_color": "labelColor",
            "label_content": "labelContent",
            "label_font_configuration": "labelFontConfiguration",
            "measure_label_visibility": "measureLabelVisibility",
            "overlap": "overlap",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class DataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            data_label_types: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_content: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            overlap: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: Determines the visibility of the category field labels.
            :param data_label_types: The option that determines the data label type.
            :param label_color: Determines the color of the data labels.
            :param label_content: Determines the content of the data labels.
            :param label_font_configuration: Determines the font configuration of the data labels.
            :param measure_label_visibility: Determines the visibility of the measure field labels.
            :param overlap: Determines whether overlap is enabled or disabled for the data labels.
            :param position: Determines the position of the data labels.
            :param visibility: Determines the visibility of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_label_options_property = quicksight.CfnTemplate.DataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                            field_id="fieldId",
                            field_value="fieldValue",
                            visibility="visibility"
                        ),
                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                            field_id="fieldId",
                            visibility="visibility"
                        ),
                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                            visibility="visibility"
                        )
                    )],
                    label_color="labelColor",
                    label_content="labelContent",
                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_label_visibility="measureLabelVisibility",
                    overlap="overlap",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd2fb6c1cc4eb1b465f11913556054c5a12be76bf75b2a1bb7ca18a900966382)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument data_label_types", value=data_label_types, expected_type=type_hints["data_label_types"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_content", value=label_content, expected_type=type_hints["label_content"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument overlap", value=overlap, expected_type=type_hints["overlap"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if data_label_types is not None:
                self._values["data_label_types"] = data_label_types
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_content is not None:
                self._values["label_content"] = label_content
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if overlap is not None:
                self._values["overlap"] = overlap
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the category field labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_label_types(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelTypeProperty"]]]]:
            '''The option that determines the data label type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-datalabeltypes
            '''
            result = self._values.get("data_label_types")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelTypeProperty"]]]], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_content(self) -> typing.Optional[builtins.str]:
            '''Determines the content of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelcontent
            '''
            result = self._values.get("label_content")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]]:
            '''Determines the font configuration of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the measure field labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def overlap(self) -> typing.Optional[builtins.str]:
            '''Determines whether overlap is enabled or disabled for the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-overlap
            '''
            result = self._values.get("overlap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the position of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DataLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_label_type": "dataPathLabelType",
            "field_label_type": "fieldLabelType",
            "maximum_label_type": "maximumLabelType",
            "minimum_label_type": "minimumLabelType",
            "range_ends_label_type": "rangeEndsLabelType",
        },
    )
    class DataLabelTypeProperty:
        def __init__(
            self,
            *,
            data_path_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataPathLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            maximum_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MaximumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            minimum_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MinimumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_ends_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RangeEndsLabelTypeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The option that determines the data label type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_path_label_type: The option that specifies individual data values for labels.
            :param field_label_type: Determines the label configuration for the entire field.
            :param maximum_label_type: Determines the label configuration for the maximum value in a visual.
            :param minimum_label_type: Determines the label configuration for the minimum value in a visual.
            :param range_ends_label_type: Determines the label configuration for range end value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_label_type_property = quicksight.CfnTemplate.DataLabelTypeProperty(
                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                        field_id="fieldId",
                        field_value="fieldValue",
                        visibility="visibility"
                    ),
                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                        field_id="fieldId",
                        visibility="visibility"
                    ),
                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__be715575992cef3d2b1173c30472e2ef7483b7da69b1402b10708e0479de7803)
                check_type(argname="argument data_path_label_type", value=data_path_label_type, expected_type=type_hints["data_path_label_type"])
                check_type(argname="argument field_label_type", value=field_label_type, expected_type=type_hints["field_label_type"])
                check_type(argname="argument maximum_label_type", value=maximum_label_type, expected_type=type_hints["maximum_label_type"])
                check_type(argname="argument minimum_label_type", value=minimum_label_type, expected_type=type_hints["minimum_label_type"])
                check_type(argname="argument range_ends_label_type", value=range_ends_label_type, expected_type=type_hints["range_ends_label_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_label_type is not None:
                self._values["data_path_label_type"] = data_path_label_type
            if field_label_type is not None:
                self._values["field_label_type"] = field_label_type
            if maximum_label_type is not None:
                self._values["maximum_label_type"] = maximum_label_type
            if minimum_label_type is not None:
                self._values["minimum_label_type"] = minimum_label_type
            if range_ends_label_type is not None:
                self._values["range_ends_label_type"] = range_ends_label_type

        @builtins.property
        def data_path_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataPathLabelTypeProperty"]]:
            '''The option that specifies individual data values for labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-datapathlabeltype
            '''
            result = self._values.get("data_path_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataPathLabelTypeProperty"]], result)

        @builtins.property
        def field_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldLabelTypeProperty"]]:
            '''Determines the label configuration for the entire field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-fieldlabeltype
            '''
            result = self._values.get("field_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldLabelTypeProperty"]], result)

        @builtins.property
        def maximum_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MaximumLabelTypeProperty"]]:
            '''Determines the label configuration for the maximum value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-maximumlabeltype
            '''
            result = self._values.get("maximum_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MaximumLabelTypeProperty"]], result)

        @builtins.property
        def minimum_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MinimumLabelTypeProperty"]]:
            '''Determines the label configuration for the minimum value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-minimumlabeltype
            '''
            result = self._values.get("minimum_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MinimumLabelTypeProperty"]], result)

        @builtins.property
        def range_ends_label_type(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RangeEndsLabelTypeProperty"]]:
            '''Determines the label configuration for range end value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-rangeendslabeltype
            '''
            result = self._values.get("range_ends_label_type")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RangeEndsLabelTypeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DataPathColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "element": "element",
            "time_granularity": "timeGranularity",
        },
    )
    class DataPathColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            element: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]],
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The color map that determines the color options for a particular element.

            :param color: The color that needs to be applied to the element.
            :param element: The element that the color needs to be applied to.
            :param time_granularity: The time granularity of the field that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_path_color_property = quicksight.CfnTemplate.DataPathColorProperty(
                    color="color",
                    element=quicksight.CfnTemplate.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    ),
                
                    # the properties below are optional
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eb770cde4584050ed058e8bbcf44462271bbf72f79f90c1dba88783d22903b49)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument element", value=element, expected_type=type_hints["element"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "element": element,
            }
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def color(self) -> builtins.str:
            '''The color that needs to be applied to the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataPathValueProperty"]:
            '''The element that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-element
            '''
            result = self._values.get("element")
            assert result is not None, "Required property 'element' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataPathValueProperty"], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity of the field that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DataPathLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "visibility": "visibility",
        },
    )
    class DataPathLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            field_value: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The option that specifies individual data values for labels.

            :param field_id: The field ID of the field that the data label needs to be applied to.
            :param field_value: The actual value of the field that is labeled.
            :param visibility: The visibility of the data label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_path_label_type_property = quicksight.CfnTemplate.DataPathLabelTypeProperty(
                    field_id="fieldId",
                    field_value="fieldValue",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7f80304bcc13ed287866c1e1083f1da65fe6b58d704bad60be6d24303bae5ef4)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if field_value is not None:
                self._values["field_value"] = field_value
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the field that the data label needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The actual value of the field that is labeled.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DataPathSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "sort_paths": "sortPaths"},
    )
    class DataPathSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_paths: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''Allows data paths to be sorted by a specific data value.

            :param direction: Determines the sort direction.
            :param sort_paths: The list of data paths that need to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_path_sort_property = quicksight.CfnTemplate.DataPathSortProperty(
                    direction="direction",
                    sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__511cb2652464ad6c056f67338d2cdf388e86cec972c384c00c2c03d7bed811b9)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_paths", value=sort_paths, expected_type=type_hints["sort_paths"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_paths": sort_paths,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''Determines the sort direction.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html#cfn-quicksight-template-datapathsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_paths(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataPathValueProperty"]]]:
            '''The list of data paths that need to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html#cfn-quicksight-template-datapathsort-sortpaths
            '''
            result = self._values.get("sort_paths")
            assert result is not None, "Required property 'sort_paths' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataPathValueProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DataPathValueProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "field_value": "fieldValue"},
    )
    class DataPathValueProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            field_value: builtins.str,
        ) -> None:
            '''The data path that needs to be sorted.

            :param field_id: The field ID of the field that needs to be sorted.
            :param field_value: The actual value of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_path_value_property = quicksight.CfnTemplate.DataPathValueProperty(
                    field_id="fieldId",
                    field_value="fieldValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57c4fe2cdf05e1dda3879629ad9e5bb024a415091501b8a1378be449c42f0aaa)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "field_value": field_value,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html#cfn-quicksight-template-datapathvalue-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> builtins.str:
            '''The actual value of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html#cfn-quicksight-template-datapathvalue-fieldvalue
            '''
            result = self._values.get("field_value")
            assert result is not None, "Required property 'field_value' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DataSetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_group_schema_list": "columnGroupSchemaList",
            "data_set_schema": "dataSetSchema",
            "placeholder": "placeholder",
        },
    )
    class DataSetConfigurationProperty:
        def __init__(
            self,
            *,
            column_group_schema_list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnGroupSchemaProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_set_schema: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataSetSchemaProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placeholder: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Dataset configuration.

            :param column_group_schema_list: A structure containing the list of column group schemas.
            :param data_set_schema: Dataset schema.
            :param placeholder: Placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_set_configuration_property = quicksight.CfnTemplate.DataSetConfigurationProperty(
                    column_group_schema_list=[quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                        column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                            name="name"
                        )],
                        name="name"
                    )],
                    data_set_schema=quicksight.CfnTemplate.DataSetSchemaProperty(
                        column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                            data_type="dataType",
                            geographic_role="geographicRole",
                            name="name"
                        )]
                    ),
                    placeholder="placeholder"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6fb20bbdd428b399e64f3adbe5e196f67508800750e6019ad43b4a4991ab9299)
                check_type(argname="argument column_group_schema_list", value=column_group_schema_list, expected_type=type_hints["column_group_schema_list"])
                check_type(argname="argument data_set_schema", value=data_set_schema, expected_type=type_hints["data_set_schema"])
                check_type(argname="argument placeholder", value=placeholder, expected_type=type_hints["placeholder"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_group_schema_list is not None:
                self._values["column_group_schema_list"] = column_group_schema_list
            if data_set_schema is not None:
                self._values["data_set_schema"] = data_set_schema
            if placeholder is not None:
                self._values["placeholder"] = placeholder

        @builtins.property
        def column_group_schema_list(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnGroupSchemaProperty"]]]]:
            '''A structure containing the list of column group schemas.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-columngroupschemalist
            '''
            result = self._values.get("column_group_schema_list")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnGroupSchemaProperty"]]]], result)

        @builtins.property
        def data_set_schema(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataSetSchemaProperty"]]:
            '''Dataset schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-datasetschema
            '''
            result = self._values.get("data_set_schema")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataSetSchemaProperty"]], result)

        @builtins.property
        def placeholder(self) -> typing.Optional[builtins.str]:
            '''Placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-placeholder
            '''
            result = self._values.get("placeholder")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DataSetReferenceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_arn": "dataSetArn",
            "data_set_placeholder": "dataSetPlaceholder",
        },
    )
    class DataSetReferenceProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            data_set_placeholder: builtins.str,
        ) -> None:
            '''Dataset reference.

            :param data_set_arn: Dataset Amazon Resource Name (ARN).
            :param data_set_placeholder: Dataset placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_set_reference_property = quicksight.CfnTemplate.DataSetReferenceProperty(
                    data_set_arn="dataSetArn",
                    data_set_placeholder="dataSetPlaceholder"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2ba4c8c1fcae4b9202917e98005bf43450a15ea5b2e8455b7d2bdad01d3260bb)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument data_set_placeholder", value=data_set_placeholder, expected_type=type_hints["data_set_placeholder"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "data_set_placeholder": data_set_placeholder,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''Dataset Amazon Resource Name (ARN).

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html#cfn-quicksight-template-datasetreference-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_placeholder(self) -> builtins.str:
            '''Dataset placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html#cfn-quicksight-template-datasetreference-datasetplaceholder
            '''
            result = self._values.get("data_set_placeholder")
            assert result is not None, "Required property 'data_set_placeholder' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetReferenceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DataSetSchemaProperty",
        jsii_struct_bases=[],
        name_mapping={"column_schema_list": "columnSchemaList"},
    )
    class DataSetSchemaProperty:
        def __init__(
            self,
            *,
            column_schema_list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnSchemaProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Dataset schema.

            :param column_schema_list: A structure containing the list of column schemas.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetschema.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_set_schema_property = quicksight.CfnTemplate.DataSetSchemaProperty(
                    column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                        data_type="dataType",
                        geographic_role="geographicRole",
                        name="name"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d2e8ef32cee6fa921535a37b6107d588b4b42aa9cb0c2860ceb9678457df1b54)
                check_type(argname="argument column_schema_list", value=column_schema_list, expected_type=type_hints["column_schema_list"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_schema_list is not None:
                self._values["column_schema_list"] = column_schema_list

        @builtins.property
        def column_schema_list(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnSchemaProperty"]]]]:
            '''A structure containing the list of column schemas.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetschema.html#cfn-quicksight-template-datasetschema-columnschemalist
            '''
            result = self._values.get("column_schema_list")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnSchemaProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetSchemaProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DateAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"missing_date_visibility": "missingDateVisibility"},
    )
    class DateAxisOptionsProperty:
        def __init__(
            self,
            *,
            missing_date_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine how a date axis is displayed.

            :param missing_date_visibility: Determines whether or not missing dates are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dateaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_axis_options_property = quicksight.CfnTemplate.DateAxisOptionsProperty(
                    missing_date_visibility="missingDateVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2adddb2d43b0d25f5e41d1036f21ee3a6d29566b02fb3ff652513bba5692577e)
                check_type(argname="argument missing_date_visibility", value=missing_date_visibility, expected_type=type_hints["missing_date_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if missing_date_visibility is not None:
                self._values["missing_date_visibility"] = missing_date_visibility

        @builtins.property
        def missing_date_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not missing dates are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dateaxisoptions.html#cfn-quicksight-template-dateaxisoptions-missingdatevisibility
            '''
            result = self._values.get("missing_date_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DateDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "date_granularity": "dateGranularity",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class DateDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            date_granularity: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with date type columns.

            :param column: The column that is used in the ``DateDimensionField`` .
            :param field_id: The custom field ID.
            :param date_granularity: The date granularity of the ``DateDimensionField`` . Choose one of the following options:. - ``YEAR`` - ``QUARTER`` - ``MONTH`` - ``WEEK`` - ``DAY`` - ``HOUR`` - ``MINUTE`` - ``SECOND`` - ``MILLISECOND``
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_dimension_field_property = quicksight.CfnTemplate.DateDimensionFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    date_granularity="dateGranularity",
                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aa0dde336e0c17194877d50a73192255a3dc5b75fbff570baf27fe17d000c893)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument date_granularity", value=date_granularity, expected_type=type_hints["date_granularity"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if date_granularity is not None:
                self._values["date_granularity"] = date_granularity
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``DateDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def date_granularity(self) -> typing.Optional[builtins.str]:
            '''The date granularity of the ``DateDimensionField`` . Choose one of the following options:.

            - ``YEAR``
            - ``QUARTER``
            - ``MONTH``
            - ``WEEK``
            - ``DAY``
            - ``HOUR``
            - ``MINUTE``
            - ``SECOND``
            - ``MILLISECOND``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-dategranularity
            '''
            result = self._values.get("date_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DateMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class DateMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with date type columns.

            :param column: The column that is used in the ``DateMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_measure_field_property = quicksight.CfnTemplate.DateMeasureFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__895d788f63729f22aaebb7a57e370c3a4f9c3eecdfcc9694bfb9c24704cb5cde)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``DateMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DateTimeDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "rolling_date": "rollingDate",
            "static_values": "staticValues",
        },
    )
    class DateTimeDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rolling_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``DateTimeParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DataTimeDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param rolling_date: The rolling date of the ``DataTimeDefaultValues`` . The date is determined from the dataset based on input expression.
            :param static_values: The static values of the ``DataTimeDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_default_values_property = quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                    dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__df9318b2e9c3b327d108bf2fdc4dbebb37a16d29ff1dcbcced9132c2bbf815db)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``DataTimeDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RollingDateConfigurationProperty"]]:
            '''The rolling date of the ``DataTimeDefaultValues`` .

            The date is determined from the dataset based on input expression.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DataTimeDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DateTimeFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class DateTimeFormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for ``DateTime`` fields.

            :param date_time_format: Determines the ``DateTime`` format.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_format_configuration_property = quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                    date_time_format="dateTimeFormat",
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7cccbdeb3164414b43a1ad0bf25b7c9f9084d3fe70a9c617cb5ca462b16096d7)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Determines the ``DateTime`` format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericFormatConfigurationProperty"]]:
            '''The formatting configuration for numeric ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DateTimeHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class DateTimeHierarchyProperty:
        def __init__(
            self,
            *,
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :param hierarchy_id: The hierarchy ID of the ``DateTime`` hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_hierarchy_property = quicksight.CfnTemplate.DateTimeHierarchyProperty(
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ef4a5e8b1f1ab7a8866cf418311c833400b6191e639ded1617cc8534577ffcb0)
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html#cfn-quicksight-template-datetimehierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html#cfn-quicksight-template-datetimehierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DateTimeParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "time_granularity": "timeGranularity",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DateTimeParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DateTimeDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``DateTime`` data type.

            :param name: The name of the parameter that is being declared.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnTemplate.DateTimeParameterDeclarationProperty.MappedDataSetParameters``.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value_when_unset: The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_parameter_declaration_property = quicksight.CfnTemplate.DateTimeParameterDeclarationProperty(
                    name="name",
                
                    # the properties below are optional
                    default_values=quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                        dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    time_granularity="timeGranularity",
                    value_when_unset=quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__225a36d9a707cb3ae605212fc2d3eccbb8b1e5fe90992f4a048fe67281208cca)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MappedDataSetParameterProperty"]]]]:
            '''``CfnTemplate.DateTimeParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "title_options": "titleOptions",
        },
    )
    class DateTimePickerControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_picker_control_display_options_property = quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__389e07f22530a84ba49ac79f8aad47a0f3f5fa61a1d112178da1e0ddccaaa38c)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html#cfn-quicksight-template-datetimepickercontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html#cfn-quicksight-template-datetimepickercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimePickerControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DateTimeValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                date_time_value_when_unset_configuration_property = quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3087afe17e01b47da180b50650f9eaa52bb9539c877b6a4911fd3d702a1d9cfe)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-template-datetimevaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-template-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DecimalDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class DecimalDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``DecimalParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DecimalDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_default_values_property = quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                    dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1df706d7f22fc92dbd972382c61a3b5decd3b80a0ec349b5c3a913b116269b0d)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``DecimalDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html#cfn-quicksight-template-decimaldefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html#cfn-quicksight-template-decimaldefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DecimalParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DecimalParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DecimalDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DecimalValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``Decimal`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnTemplate.DecimalParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_parameter_declaration_property = quicksight.CfnTemplate.DecimalParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                        dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__49461cc852a7d9640a8caf8412b8cb2f3337411471e87bd5c64b1efb83da9946)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DecimalDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DecimalDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MappedDataSetParameterProperty"]]]]:
            '''``CfnTemplate.DecimalParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DecimalValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DecimalValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DecimalPlacesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"decimal_places": "decimalPlaces"},
    )
    class DecimalPlacesConfigurationProperty:
        def __init__(self, *, decimal_places: jsii.Number) -> None:
            '''The option that determines the decimal places configuration.

            :param decimal_places: The values of the decimal places.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalplacesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_places_configuration_property = quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                    decimal_places=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2b9075101cdfafd046072b8aa836c8f7373e7965827f55e1eecc5d313c0cbabf)
                check_type(argname="argument decimal_places", value=decimal_places, expected_type=type_hints["decimal_places"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "decimal_places": decimal_places,
            }

        @builtins.property
        def decimal_places(self) -> jsii.Number:
            '''The values of the decimal places.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalplacesconfiguration.html#cfn-quicksight-template-decimalplacesconfiguration-decimalplaces
            '''
            result = self._values.get("decimal_places")
            assert result is not None, "Required property 'decimal_places' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalPlacesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DecimalValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                decimal_value_when_unset_configuration_property = quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3eae603c7b03821556e2dd0d89528ed3f46684a5cfe1db94ea6c0d264510b065)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-template-decimalvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-template-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultFreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings of a free-form layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultfreeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_free_form_layout_configuration_property = quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c58d8c49bd0cf7077825ff6c5937ba7b4c3e7633a968e8991aa318b84ac8809e)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultfreeformlayoutconfiguration.html#cfn-quicksight-template-defaultfreeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultFreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultGridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings for a grid layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultgridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_grid_layout_configuration_property = quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__477d429d0129bed2a679c9d19f0d3e31b6a19cdbe772c76aa9f4bc4689c67f67)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GridLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultgridlayoutconfiguration.html#cfn-quicksight-template-defaultgridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GridLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultGridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form": "freeForm", "grid": "grid"},
    )
    class DefaultInteractiveLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DefaultFreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DefaultGridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default settings for interactive layout configuration.

            :param free_form: The options that determine the default settings of a free-form layout configuration.
            :param grid: The options that determine the default settings for a grid layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_interactive_layout_configuration_property = quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                    free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__168bc0edea090be759c0b1ae2615d7f9a3c9b599e6f2bff9e8e2acc0ec69f100)
                check_type(argname="argument free_form", value=free_form, expected_type=type_hints["free_form"])
                check_type(argname="argument grid", value=grid, expected_type=type_hints["grid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form is not None:
                self._values["free_form"] = free_form
            if grid is not None:
                self._values["grid"] = grid

        @builtins.property
        def free_form(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DefaultFreeFormLayoutConfigurationProperty"]]:
            '''The options that determine the default settings of a free-form layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html#cfn-quicksight-template-defaultinteractivelayoutconfiguration-freeform
            '''
            result = self._values.get("free_form")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DefaultFreeFormLayoutConfigurationProperty"]], result)

        @builtins.property
        def grid(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DefaultGridLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a grid layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html#cfn-quicksight-template-defaultinteractivelayoutconfiguration-grid
            '''
            result = self._values.get("grid")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DefaultGridLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultInteractiveLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "interactive_layout_configuration": "interactiveLayoutConfiguration",
            "paginated_layout_configuration": "paginatedLayoutConfiguration",
            "sheet_content_type": "sheetContentType",
        },
    )
    class DefaultNewSheetConfigurationProperty:
        def __init__(
            self,
            *,
            interactive_layout_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DefaultInteractiveLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_layout_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DefaultPaginatedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sheet_content_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration for default new sheet settings.

            :param interactive_layout_configuration: The options that determine the default settings for interactive layout configuration.
            :param paginated_layout_configuration: The options that determine the default settings for a paginated layout configuration.
            :param sheet_content_type: The option that determines the sheet content type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_new_sheet_configuration_property = quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty(
                    interactive_layout_configuration=quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                        free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    ),
                    paginated_layout_configuration=quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                        section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            )
                        )
                    ),
                    sheet_content_type="sheetContentType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c06fdf76c43ffbff3d43cba1b52b666e581fb511e987dcc578d11edca379643)
                check_type(argname="argument interactive_layout_configuration", value=interactive_layout_configuration, expected_type=type_hints["interactive_layout_configuration"])
                check_type(argname="argument paginated_layout_configuration", value=paginated_layout_configuration, expected_type=type_hints["paginated_layout_configuration"])
                check_type(argname="argument sheet_content_type", value=sheet_content_type, expected_type=type_hints["sheet_content_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if interactive_layout_configuration is not None:
                self._values["interactive_layout_configuration"] = interactive_layout_configuration
            if paginated_layout_configuration is not None:
                self._values["paginated_layout_configuration"] = paginated_layout_configuration
            if sheet_content_type is not None:
                self._values["sheet_content_type"] = sheet_content_type

        @builtins.property
        def interactive_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DefaultInteractiveLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for interactive layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-interactivelayoutconfiguration
            '''
            result = self._values.get("interactive_layout_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DefaultInteractiveLayoutConfigurationProperty"]], result)

        @builtins.property
        def paginated_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DefaultPaginatedLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a paginated layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-paginatedlayoutconfiguration
            '''
            result = self._values.get("paginated_layout_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DefaultPaginatedLayoutConfigurationProperty"]], result)

        @builtins.property
        def sheet_content_type(self) -> typing.Optional[builtins.str]:
            '''The option that determines the sheet content type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-sheetcontenttype
            '''
            result = self._values.get("sheet_content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultNewSheetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"section_based": "sectionBased"},
    )
    class DefaultPaginatedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            section_based: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default settings for a paginated layout configuration.

            :param section_based: The options that determine the default settings for a section-based layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultpaginatedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_paginated_layout_configuration_property = quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                    section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ff451f2060d067be4aff2f960adb7a091ff765483aa9cf2c2656b7d6c6cdef1a)
                check_type(argname="argument section_based", value=section_based, expected_type=type_hints["section_based"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if section_based is not None:
                self._values["section_based"] = section_based

        @builtins.property
        def section_based(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty"]]:
            '''The options that determine the default settings for a section-based layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-template-defaultpaginatedlayoutconfiguration-sectionbased
            '''
            result = self._values.get("section_based")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultPaginatedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultSectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The options that determine the default settings for a section-based layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultsectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                default_section_based_layout_configuration_property = quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__52602085f257c8df2b384d5ad0e230c4dfcc961f87d1b549b829bdc8b90f3458)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty"]:
            '''Determines the screen canvas size options for a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-template-defaultsectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultSectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values_configuration": "customValuesConfiguration",
            "select_all_value_options": "selectAllValueOptions",
            "source_field": "sourceField",
            "source_parameter_name": "sourceParameterName",
        },
    )
    class DestinationParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CustomValuesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_value_options: typing.Optional[builtins.str] = None,
            source_field: typing.Optional[builtins.str] = None,
            source_parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of destination parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_values_configuration: The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .
            :param select_all_value_options: The configuration that selects all options.
            :param source_field: The source field ID of the destination parameter.
            :param source_parameter_name: The source parameter name of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                destination_parameter_value_configuration_property = quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                            date_time_values=["dateTimeValues"],
                            decimal_values=[123],
                            integer_values=[123],
                            string_values=["stringValues"]
                        ),
                
                        # the properties below are optional
                        include_null_value=False
                    ),
                    select_all_value_options="selectAllValueOptions",
                    source_field="sourceField",
                    source_parameter_name="sourceParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1b300c210f681c858dab377186a03d6c5077acb77776345e9a6c5b4f55c94359)
                check_type(argname="argument custom_values_configuration", value=custom_values_configuration, expected_type=type_hints["custom_values_configuration"])
                check_type(argname="argument select_all_value_options", value=select_all_value_options, expected_type=type_hints["select_all_value_options"])
                check_type(argname="argument source_field", value=source_field, expected_type=type_hints["source_field"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_values_configuration is not None:
                self._values["custom_values_configuration"] = custom_values_configuration
            if select_all_value_options is not None:
                self._values["select_all_value_options"] = select_all_value_options
            if source_field is not None:
                self._values["source_field"] = source_field
            if source_parameter_name is not None:
                self._values["source_parameter_name"] = source_parameter_name

        @builtins.property
        def custom_values_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomValuesConfigurationProperty"]]:
            '''The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-customvaluesconfiguration
            '''
            result = self._values.get("custom_values_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomValuesConfigurationProperty"]], result)

        @builtins.property
        def select_all_value_options(self) -> typing.Optional[builtins.str]:
            '''The configuration that selects all options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-selectallvalueoptions
            '''
            result = self._values.get("select_all_value_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_field(self) -> typing.Optional[builtins.str]:
            '''The source field ID of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-sourcefield
            '''
            result = self._values.get("source_field")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_parameter_name(self) -> typing.Optional[builtins.str]:
            '''The source parameter name of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DestinationParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_dimension_field": "categoricalDimensionField",
            "date_dimension_field": "dateDimensionField",
            "numerical_dimension_field": "numericalDimensionField",
        },
    )
    class DimensionFieldProperty:
        def __init__(
            self,
            *,
            categorical_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CategoricalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            date_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DateDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numerical_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The dimension type field.

            :param categorical_dimension_field: The dimension type field with categorical type columns.
            :param date_dimension_field: The dimension type field with date type columns.
            :param numerical_dimension_field: The dimension type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                dimension_field_property = quicksight.CfnTemplate.DimensionFieldProperty(
                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        date_granularity="dateGranularity",
                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6dff4d99031668281be73d0999e19566d6656aaafd6317951c7237b7b7e0aa6b)
                check_type(argname="argument categorical_dimension_field", value=categorical_dimension_field, expected_type=type_hints["categorical_dimension_field"])
                check_type(argname="argument date_dimension_field", value=date_dimension_field, expected_type=type_hints["date_dimension_field"])
                check_type(argname="argument numerical_dimension_field", value=numerical_dimension_field, expected_type=type_hints["numerical_dimension_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_dimension_field is not None:
                self._values["categorical_dimension_field"] = categorical_dimension_field
            if date_dimension_field is not None:
                self._values["date_dimension_field"] = date_dimension_field
            if numerical_dimension_field is not None:
                self._values["numerical_dimension_field"] = numerical_dimension_field

        @builtins.property
        def categorical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CategoricalDimensionFieldProperty"]]:
            '''The dimension type field with categorical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-categoricaldimensionfield
            '''
            result = self._values.get("categorical_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CategoricalDimensionFieldProperty"]], result)

        @builtins.property
        def date_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateDimensionFieldProperty"]]:
            '''The dimension type field with date type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-datedimensionfield
            '''
            result = self._values.get("date_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateDimensionFieldProperty"]], result)

        @builtins.property
        def numerical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericalDimensionFieldProperty"]]:
            '''The dimension type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-numericaldimensionfield
            '''
            result = self._values.get("numerical_dimension_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericalDimensionFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DonutCenterOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"label_visibility": "labelVisibility"},
    )
    class DonutCenterOptionsProperty:
        def __init__(
            self,
            *,
            label_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :param label_visibility: Determines the visibility of the label in a donut chart. In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutcenteroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                donut_center_options_property = quicksight.CfnTemplate.DonutCenterOptionsProperty(
                    label_visibility="labelVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c028c2dc51e48adeabd977627e64630f3dee5f728262dfea3b18dc0fe1c9665a)
                check_type(argname="argument label_visibility", value=label_visibility, expected_type=type_hints["label_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_visibility is not None:
                self._values["label_visibility"] = label_visibility

        @builtins.property
        def label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the label in a donut chart.

            In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutcenteroptions.html#cfn-quicksight-template-donutcenteroptions-labelvisibility
            '''
            result = self._values.get("label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutCenterOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DonutOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc_options": "arcOptions",
            "donut_center_options": "donutCenterOptions",
        },
    )
    class DonutOptionsProperty:
        def __init__(
            self,
            *,
            arc_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ArcOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            donut_center_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DonutCenterOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for configuring a donut chart or pie chart.

            :param arc_options: The option for define the arc of the chart shape. Valid values are as follows:. - ``WHOLE`` - A pie chart - ``SMALL`` - A small-sized donut chart - ``MEDIUM`` - A medium-sized donut chart - ``LARGE`` - A large-sized donut chart
            :param donut_center_options: The label options of the label that is displayed in the center of a donut chart. This option isn't available for pie charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                donut_options_property = quicksight.CfnTemplate.DonutOptionsProperty(
                    arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                        arc_thickness="arcThickness"
                    ),
                    donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                        label_visibility="labelVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__51435b1f0dc0ca9cb48249f6f589c613305aca4b0f3efb76d054f7910e375ffc)
                check_type(argname="argument arc_options", value=arc_options, expected_type=type_hints["arc_options"])
                check_type(argname="argument donut_center_options", value=donut_center_options, expected_type=type_hints["donut_center_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_options is not None:
                self._values["arc_options"] = arc_options
            if donut_center_options is not None:
                self._values["donut_center_options"] = donut_center_options

        @builtins.property
        def arc_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ArcOptionsProperty"]]:
            '''The option for define the arc of the chart shape. Valid values are as follows:.

            - ``WHOLE`` - A pie chart
            - ``SMALL`` - A small-sized donut chart
            - ``MEDIUM`` - A medium-sized donut chart
            - ``LARGE`` - A large-sized donut chart

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html#cfn-quicksight-template-donutoptions-arcoptions
            '''
            result = self._values.get("arc_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ArcOptionsProperty"]], result)

        @builtins.property
        def donut_center_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DonutCenterOptionsProperty"]]:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html#cfn-quicksight-template-donutoptions-donutcenteroptions
            '''
            result = self._values.get("donut_center_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DonutCenterOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "time_range_filter": "timeRangeFilter",
        },
    )
    class DrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CategoryDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericEqualityDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TimeRangeDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The drill down filter for the column hierarchies.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: The category type drill down filter. This filter is used for string type columns.
            :param numeric_equality_filter: The numeric equality type drill down filter. This filter is used for number type columns.
            :param time_range_filter: The time range drill down filter. This filter is used for date time columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                drill_down_filter_property = quicksight.CfnTemplate.DrillDownFilterProperty(
                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                        category_values=["categoryValues"],
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        value=123
                    ),
                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        range_maximum="rangeMaximum",
                        range_minimum="rangeMinimum",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ff487a66989ec72fbf6bdc52e0d6dbf76a356fd75ac22351481916d206ee2f1)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CategoryDrillDownFilterProperty"]]:
            '''The category type drill down filter.

            This filter is used for string type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CategoryDrillDownFilterProperty"]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericEqualityDrillDownFilterProperty"]]:
            '''The numeric equality type drill down filter.

            This filter is used for number type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericEqualityDrillDownFilterProperty"]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TimeRangeDrillDownFilterProperty"]]:
            '''The time range drill down filter.

            This filter is used for date time columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TimeRangeDrillDownFilterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class DropDownControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            select_all_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param select_all_options: The configuration of the ``Select all`` options in a dropdown control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                drop_down_control_display_options_property = quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7ef40a0e6751ee1b5aed3ede0077fa01624b9b9150e9e5267a5ad0d40ba6ad8a)
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ListControlSelectAllOptionsProperty"]]:
            '''The configuration of the ``Select all`` options in a dropdown control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html#cfn-quicksight-template-dropdowncontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ListControlSelectAllOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html#cfn-quicksight-template-dropdowncontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DropDownControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.DynamicDefaultValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_value_column": "defaultValueColumn",
            "group_name_column": "groupNameColumn",
            "user_name_column": "userNameColumn",
        },
    )
    class DynamicDefaultValueProperty:
        def __init__(
            self,
            *,
            default_value_column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            group_name_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            user_name_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Defines different defaults to the users or groups based on mapping.

            :param default_value_column: The column that contains the default value of each user or group.
            :param group_name_column: The column that contains the group name.
            :param user_name_column: The column that contains the username.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                dynamic_default_value_property = quicksight.CfnTemplate.DynamicDefaultValueProperty(
                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ed451a7a26579021c7d598bfa9759ca125b245e13d45d88c40eafc691fedc49)
                check_type(argname="argument default_value_column", value=default_value_column, expected_type=type_hints["default_value_column"])
                check_type(argname="argument group_name_column", value=group_name_column, expected_type=type_hints["group_name_column"])
                check_type(argname="argument user_name_column", value=user_name_column, expected_type=type_hints["user_name_column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_value_column": default_value_column,
            }
            if group_name_column is not None:
                self._values["group_name_column"] = group_name_column
            if user_name_column is not None:
                self._values["user_name_column"] = user_name_column

        @builtins.property
        def default_value_column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that contains the default value of each user or group.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-defaultvaluecolumn
            '''
            result = self._values.get("default_value_column")
            assert result is not None, "Required property 'default_value_column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def group_name_column(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]]:
            '''The column that contains the group name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-groupnamecolumn
            '''
            result = self._values.get("group_name_column")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]], result)

        @builtins.property
        def user_name_column(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]]:
            '''The column that contains the username.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-usernamecolumn
            '''
            result = self._values.get("user_name_column")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DynamicDefaultValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.EmptyVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
        },
    )
    class EmptyVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''An empty visual.

            Empty visuals are used in layouts but have not been configured to show any data. A new visual created in the Amazon QuickSight console is considered an ``EmptyVisual`` until a visual type is selected.

            :param data_set_identifier: The data set that is used in the empty visual. Every visual requires a dataset to render.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                empty_visual_property = quicksight.CfnTemplate.EmptyVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c8a6a6cf0027f224316a45467207b76ac3ce15e6067d819b3447ec6cbce5373a)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in the empty visual.

            Every visual requires a dataset to render.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EmptyVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.EntityProperty",
        jsii_struct_bases=[],
        name_mapping={"path": "path"},
    )
    class EntityProperty:
        def __init__(self, *, path: typing.Optional[builtins.str] = None) -> None:
            '''An object, structure, or sub-structure of an analysis, template, or dashboard.

            :param path: The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-entity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                entity_property = quicksight.CfnTemplate.EntityProperty(
                    path="path"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a7255ff5d8a18eb8e710ebd09fdb30b43e574e7c63f691c001c5fddb3777b34c)
                check_type(argname="argument path", value=path, expected_type=type_hints["path"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if path is not None:
                self._values["path"] = path

        @builtins.property
        def path(self) -> typing.Optional[builtins.str]:
            '''The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-entity.html#cfn-quicksight-template-entity-path
            '''
            result = self._values.get("path")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ExcludePeriodConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "amount": "amount",
            "granularity": "granularity",
            "status": "status",
        },
    )
    class ExcludePeriodConfigurationProperty:
        def __init__(
            self,
            *,
            amount: jsii.Number,
            granularity: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The exclude period of ``TimeRangeFilter`` or ``RelativeDatesFilter`` .

            :param amount: The amount or number of the exclude period.
            :param granularity: The granularity or unit (day, month, year) of the exclude period.
            :param status: The status of the exclude period. Choose from the following options:. - ``ENABLED`` - ``DISABLED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                exclude_period_configuration_property = quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                    amount=123,
                    granularity="granularity",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d4066e36eddfeaffe28bbeef8e0a8e8b1a6dd9c7b84104362d9fcd9991902993)
                check_type(argname="argument amount", value=amount, expected_type=type_hints["amount"])
                check_type(argname="argument granularity", value=granularity, expected_type=type_hints["granularity"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "amount": amount,
                "granularity": granularity,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def amount(self) -> jsii.Number:
            '''The amount or number of the exclude period.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-amount
            '''
            result = self._values.get("amount")
            assert result is not None, "Required property 'amount' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def granularity(self) -> builtins.str:
            '''The granularity or unit (day, month, year) of the exclude period.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-granularity
            '''
            result = self._values.get("granularity")
            assert result is not None, "Required property 'granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the exclude period. Choose from the following options:.

            - ``ENABLED``
            - ``DISABLED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExcludePeriodConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ExplicitHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class ExplicitHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :param columns: The list of columns that define the explicit hierarchy.
            :param hierarchy_id: The hierarchy ID of the explicit hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                explicit_hierarchy_property = quicksight.CfnTemplate.ExplicitHierarchyProperty(
                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__862204e2225433449748256e80a021791c4d9855c721b2c829809b5b235d075c)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]]]:
            '''The list of columns that define the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExplicitHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FieldBasedTooltipProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_visibility": "aggregationVisibility",
            "tooltip_fields": "tooltipFields",
            "tooltip_title_type": "tooltipTitleType",
        },
    )
    class FieldBasedTooltipProperty:
        def __init__(
            self,
            *,
            aggregation_visibility: typing.Optional[builtins.str] = None,
            tooltip_fields: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            tooltip_title_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The setup for the detailed tooltip.

            :param aggregation_visibility: The visibility of ``Show aggregations`` .
            :param tooltip_fields: The fields configuration in the tooltip.
            :param tooltip_title_type: The type for the >tooltip title. Choose one of the following options:. - ``NONE`` : Doesn't use the primary value as the title. - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_based_tooltip_property = quicksight.CfnTemplate.FieldBasedTooltipProperty(
                    aggregation_visibility="aggregationVisibility",
                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            label="label",
                            visibility="visibility"
                        ),
                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            label="label",
                            visibility="visibility"
                        )
                    )],
                    tooltip_title_type="tooltipTitleType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0502d5f0ee1aa82fccbb0f79f85f2959aa94cb85b055d9221fc4315ade6a7dc)
                check_type(argname="argument aggregation_visibility", value=aggregation_visibility, expected_type=type_hints["aggregation_visibility"])
                check_type(argname="argument tooltip_fields", value=tooltip_fields, expected_type=type_hints["tooltip_fields"])
                check_type(argname="argument tooltip_title_type", value=tooltip_title_type, expected_type=type_hints["tooltip_title_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if aggregation_visibility is not None:
                self._values["aggregation_visibility"] = aggregation_visibility
            if tooltip_fields is not None:
                self._values["tooltip_fields"] = tooltip_fields
            if tooltip_title_type is not None:
                self._values["tooltip_title_type"] = tooltip_title_type

        @builtins.property
        def aggregation_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of ``Show aggregations`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-aggregationvisibility
            '''
            result = self._values.get("aggregation_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_fields(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipItemProperty"]]]]:
            '''The fields configuration in the tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-tooltipfields
            '''
            result = self._values.get("tooltip_fields")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipItemProperty"]]]], result)

        @builtins.property
        def tooltip_title_type(self) -> typing.Optional[builtins.str]:
            '''The type for the >tooltip title. Choose one of the following options:.

            - ``NONE`` : Doesn't use the primary value as the title.
            - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-tooltiptitletype
            '''
            result = self._values.get("tooltip_title_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldBasedTooltipProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FieldLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "visibility": "visibility"},
    )
    class FieldLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The field label type.

            :param field_id: Indicates the field that is targeted by the field label.
            :param visibility: The visibility of the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_label_type_property = quicksight.CfnTemplate.FieldLabelTypeProperty(
                    field_id="fieldId",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8c5ae9ffd7f203ed969d4d4547474d681259e315870ae717eb42714495c2c92b)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''Indicates the field that is targeted by the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html#cfn-quicksight-template-fieldlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html#cfn-quicksight-template-fieldlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "settings": "settings",
        },
    )
    class FieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field for which you are setting the axis binding.
            :param settings: The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_series_item_property = quicksight.CfnTemplate.FieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1228af396d112514e9a85bb85589877701d67921c200425d86589a1a44c9aab0)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field for which you are setting the axis binding.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartSeriesSettingsProperty"]]:
            '''The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartSeriesSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column_sort": "columnSort", "field_sort": "fieldSort"},
    )
    class FieldSortOptionsProperty:
        def __init__(
            self,
            *,
            column_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field sort options in a chart configuration.

            :param column_sort: The sort configuration for a column that is not used in a field well.
            :param field_sort: The sort configuration for a field in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_sort_options_property = quicksight.CfnTemplate.FieldSortOptionsProperty(
                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2a3aebe1113ae40fc6f2455a96751374f501ff3bf1d866cad03b69338676e3ca)
                check_type(argname="argument column_sort", value=column_sort, expected_type=type_hints["column_sort"])
                check_type(argname="argument field_sort", value=field_sort, expected_type=type_hints["field_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_sort is not None:
                self._values["column_sort"] = column_sort
            if field_sort is not None:
                self._values["field_sort"] = field_sort

        @builtins.property
        def column_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnSortProperty"]]:
            '''The sort configuration for a column that is not used in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html#cfn-quicksight-template-fieldsortoptions-columnsort
            '''
            result = self._values.get("column_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnSortProperty"]], result)

        @builtins.property
        def field_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortProperty"]]:
            '''The sort configuration for a field in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html#cfn-quicksight-template-fieldsortoptions-fieldsort
            '''
            result = self._values.get("field_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FieldSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "field_id": "fieldId"},
    )
    class FieldSortProperty:
        def __init__(self, *, direction: builtins.str, field_id: builtins.str) -> None:
            '''The sort configuration for a field in a field well.

            :param direction: The sort direction. Choose one of the following options:. - ``ASC`` : Ascending - ``DESC`` : Descending
            :param field_id: The sort configuration target field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_sort_property = quicksight.CfnTemplate.FieldSortProperty(
                    direction="direction",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b6f98265bf68daac1ac32731b8f4404494bb847fdb5dc2c626dfdb47121bcd7f)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "field_id": field_id,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction. Choose one of the following options:.

            - ``ASC`` : Ascending
            - ``DESC`` : Descending

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html#cfn-quicksight-template-fieldsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The sort configuration target field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html#cfn-quicksight-template-fieldsort-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FieldTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class FieldTooltipItemProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the fields.

            :param field_id: The unique ID of the field that is targeted by the tooltip.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                field_tooltip_item_property = quicksight.CfnTemplate.FieldTooltipItemProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce7c2a9e2a1c2a6cff3b8436cb488739ab56f7bfe9be25b191e8bff2434c7d44)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The unique ID of the field that is targeted by the tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"geospatial": "geospatial", "values": "values"},
    )
    class FilledMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well of the filled map.

            :param geospatial: The aggregated location field well of the filled map. Values are grouped by location fields.
            :param values: The aggregated color field well of a filled map. Values are aggregated based on location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_aggregated_field_wells_property = quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                    geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b17bd0c26f859897e9855fd375c3c8038475b467833e5fc3738e2920f55445c2)
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The aggregated location field well of the filled map.

            Values are grouped by location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html#cfn-quicksight-template-filledmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The aggregated color field well of a filled map.

            Values are aggregated based on location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html#cfn-quicksight-template-filledmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"shape": "shape"},
    )
    class FilledMapConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            shape: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilledMapShapeConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :param shape: The conditional formatting that determines the shape of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_conditional_formatting_option_property = quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                    shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f8be42be278d7afe0a28ac77adf04aaf8d13645241f2c421d791e18a172f7d1e)
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "shape": shape,
            }

        @builtins.property
        def shape(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapShapeConditionalFormattingProperty"]:
            '''The conditional formatting that determines the shape of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformattingoption.html#cfn-quicksight-template-filledmapconditionalformattingoption-shape
            '''
            result = self._values.get("shape")
            assert result is not None, "Required property 'shape' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapShapeConditionalFormattingProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilledMapConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class FilledMapConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilledMapConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_conditional_formatting_property = quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                        shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0aaa85f1dd40e4d9c8e08d328e8f858885176c828e21d05b1b9dc47324328abb)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "conditional_formatting_options": conditional_formatting_options,
            }

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapConditionalFormattingOptionProperty"]]]:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformatting.html#cfn-quicksight-template-filledmapconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            assert result is not None, "Required property 'conditional_formatting_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapConditionalFormattingOptionProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilledMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "window_options": "windowOptions",
        },
    )
    class FilledMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilledMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilledMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            window_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``FilledMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the filled map visual.
            :param sort_configuration: The sort configuration of a ``FilledMapVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param window_options: The window options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_configuration_property = quicksight.CfnTemplate.FilledMapConfigurationProperty(
                    field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                        filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                            geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                        base_map_style="baseMapStyle"
                    ),
                    sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                        bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                            east=123,
                            north=123,
                            south=123,
                            west=123
                        ),
                        map_zoom_mode="mapZoomMode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__20d8468ca519646bc0674fbe85f5ef07694c20e245ecad5b2d6ab728d0216abf)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialMapStyleOptionsProperty"]]:
            '''The map style options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialMapStyleOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapSortConfigurationProperty"]]:
            '''The sort configuration of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialWindowOptionsProperty"]]:
            '''The window options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialWindowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilledMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filled_map_aggregated_field_wells": "filledMapAggregatedFieldWells",
        },
    )
    class FilledMapFieldWellsProperty:
        def __init__(
            self,
            *,
            filled_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilledMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``FilledMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filled_map_aggregated_field_wells: The aggregated field well of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_field_wells_property = quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                    filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                        geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b2a8c99356003321b6881316c38748c0d680b3402aee167111947b62e8ad6e6a)
                check_type(argname="argument filled_map_aggregated_field_wells", value=filled_map_aggregated_field_wells, expected_type=type_hints["filled_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filled_map_aggregated_field_wells is not None:
                self._values["filled_map_aggregated_field_wells"] = filled_map_aggregated_field_wells

        @builtins.property
        def filled_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field well of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapfieldwells.html#cfn-quicksight-template-filledmapfieldwells-filledmapaggregatedfieldwells
            '''
            result = self._values.get("filled_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "format": "format"},
    )
    class FilledMapShapeConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ShapeConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting that determines the shape of the filled map.

            :param field_id: The field ID of the filled map shape.
            :param format: The conditional formatting that determines the background color of a filled map's shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_shape_conditional_formatting_property = quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ed8166621531b597cd5df0331e368f78092c667d8a79e86cf99e0dcbd9dce83f)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if format is not None:
                self._values["format"] = format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the filled map shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html#cfn-quicksight-template-filledmapshapeconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ShapeConditionalFormatProperty"]]:
            '''The conditional formatting that determines the background color of a filled map's shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html#cfn-quicksight-template-filledmapshapeconditionalformatting-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ShapeConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapShapeConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilledMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"category_sort": "categorySort"},
    )
    class FilledMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FilledMapVisual`` .

            :param category_sort: The sort configuration of the location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_sort_configuration_property = quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f20907e589c35d0395b77ec271fc2a0b6ae61d1f6873d26299deeb15b46baa8)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapsortconfiguration.html#cfn-quicksight-template-filledmapsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilledMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FilledMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilledMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilledMapConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a ``FilledMapVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filled_map_visual_property = quicksight.CfnTemplate.FilledMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.FilledMapConfigurationProperty(
                        field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                            filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                                geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                            base_map_style="baseMapStyle"
                        ),
                        sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                            bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                east=123,
                                north=123,
                                south=123,
                                west=123
                            ),
                            map_zoom_mode="mapZoomMode"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    conditional_formatting=quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                            shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e8d2f624efcc1f66daf3dab610af4db6216ad3e25095ef75821fcbc9f8f2f3d2)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapConditionalFormattingProperty"]]:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "relative_date_time": "relativeDateTime",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class FilterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            dropdown: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterListControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_date_time: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterRelativeDateTimeControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            slider: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterSliderControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_area: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The control of a filter that is used to interact with a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date filter that is used to specify date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list of buttons or boxes. This is used to select either a single value or multiple values.
            :param relative_date_time: A control from a date filter that is used to specify the relative date.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_control_property = quicksight.CfnTemplate.FilterControlProperty(
                    date_time_picker=quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    dropdown=quicksight.CfnTemplate.FilterDropDownControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                            select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnTemplate.FilterListControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                            search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    relative_date_time=quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    slider=quicksight.CfnTemplate.FilterSliderControlProperty(
                        filter_control_id="filterControlId",
                        maximum_value=123,
                        minimum_value=123,
                        source_filter_id="sourceFilterId",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    text_area=quicksight.CfnTemplate.FilterTextAreaControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnTemplate.FilterTextFieldControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4087b1f61095b937615929533f156ac331874afe0c355d29e4a4ad286ecd5096)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument relative_date_time", value=relative_date_time, expected_type=type_hints["relative_date_time"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if relative_date_time is not None:
                self._values["relative_date_time"] = relative_date_time
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterDateTimePickerControlProperty"]]:
            '''A control from a date filter that is used to specify date and time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterDateTimePickerControlProperty"]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterDropDownControlProperty"]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterDropDownControlProperty"]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterListControlProperty"]]:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterListControlProperty"]], result)

        @builtins.property
        def relative_date_time(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterRelativeDateTimeControlProperty"]]:
            '''A control from a date filter that is used to specify the relative date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-relativedatetime
            '''
            result = self._values.get("relative_date_time")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterRelativeDateTimeControlProperty"]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterSliderControlProperty"]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterSliderControlProperty"]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterTextAreaControlProperty"]]:
            '''A control to display a text box that is used to enter multiple entries.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterTextAreaControlProperty"]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterTextFieldControlProperty"]]:
            '''A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterTextFieldControlProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control from a date filter that is used to specify date and time.

            :param filter_control_id: The ID of the ``FilterDateTimePickerControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDateTimePickerControl`` .
            :param title: The title of the ``FilterDateTimePickerControl`` .
            :param display_options: The display options of a control.
            :param type: The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:. - ``SINGLE_VALUED`` : The filter condition is a fixed date. - ``DATE_RANGE`` : The filter condition is a date time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_date_time_picker_control_property = quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__69f308bbb31f6a38a080ae1a844349b53ef12b615710164b2c96a3be68170e81)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimePickerControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimePickerControlDisplayOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:.

            - ``SINGLE_VALUED`` : The filter condition is a fixed date.
            - ``DATE_RANGE`` : The filter condition is a date time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterDropDownControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param filter_control_id: The ID of the ``FilterDropDownControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDropDownControl`` .
            :param title: The title of the ``FilterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of the ``FilterDropDownControl`` .
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of the ``FilterDropDownControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu. - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_drop_down_control_property = quicksight.CfnTemplate.FilterDropDownControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                        select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__133b32a5c8eafb26d508d9d6eb3377ededa86fb064eae298d65d827b3c11d22c)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DropDownControlDisplayOptionsProperty"]]:
            '''The display options of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DropDownControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of the ``FilterDropDownControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu.
            - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterGroupProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cross_dataset": "crossDataset",
            "filter_group_id": "filterGroupId",
            "filters": "filters",
            "scope_configuration": "scopeConfiguration",
            "status": "status",
        },
    )
    class FilterGroupProperty:
        def __init__(
            self,
            *,
            cross_dataset: builtins.str,
            filter_group_id: builtins.str,
            filters: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterProperty", typing.Dict[builtins.str, typing.Any]]]]],
            scope_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A grouping of individual filters. Filter groups are applied to the same group of visuals.

            For more information, see `Adding filter conditions (group filters) with AND and OR operators <https://docs.aws.amazon.com/quicksight/latest/user/add-a-compound-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :param cross_dataset: The filter new feature which can apply filter group to all data sets. Choose one of the following options:. - ``ALL_DATASETS`` - ``SINGLE_DATASET``
            :param filter_group_id: The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.
            :param filters: The list of filters that are present in a ``FilterGroup`` .
            :param scope_configuration: The configuration that specifies what scope to apply to a ``FilterGroup`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param status: The status of the ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_group_property = quicksight.CfnTemplate.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnTemplate.FilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnTemplate.NumericRangeFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnTemplate.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnTemplate.TimeEqualityFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            parameter_name="parameterName",
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnTemplate.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection"
                            )],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnTemplate.FilterScopeConfigurationProperty(
                        selected_sheets=quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
                
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5bc0b71cd813e6c43bb6413c5cb28414320bde2fe24f8605de90cebeece9fe3f)
                check_type(argname="argument cross_dataset", value=cross_dataset, expected_type=type_hints["cross_dataset"])
                check_type(argname="argument filter_group_id", value=filter_group_id, expected_type=type_hints["filter_group_id"])
                check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
                check_type(argname="argument scope_configuration", value=scope_configuration, expected_type=type_hints["scope_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "cross_dataset": cross_dataset,
                "filter_group_id": filter_group_id,
                "filters": filters,
                "scope_configuration": scope_configuration,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def cross_dataset(self) -> builtins.str:
            '''The filter new feature which can apply filter group to all data sets. Choose one of the following options:.

            - ``ALL_DATASETS``
            - ``SINGLE_DATASET``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-crossdataset
            '''
            result = self._values.get("cross_dataset")
            assert result is not None, "Required property 'cross_dataset' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filter_group_id(self) -> builtins.str:
            '''The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-filtergroupid
            '''
            result = self._values.get("filter_group_id")
            assert result is not None, "Required property 'filter_group_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filters(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterProperty"]]]:
            '''The list of filters that are present in a ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-filters
            '''
            result = self._values.get("filters")
            assert result is not None, "Required property 'filters' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterProperty"]]], result)

        @builtins.property
        def scope_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterScopeConfigurationProperty"]:
            '''The configuration that specifies what scope to apply to a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-scopeconfiguration
            '''
            result = self._values.get("scope_configuration")
            assert result is not None, "Required property 'scope_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterScopeConfigurationProperty"], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class FilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of filter configurations.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_list_configuration_property = quicksight.CfnTemplate.FilterListConfigurationProperty(
                    match_operator="matchOperator",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3bef5e799f602df9fdba8eee76d93e2c85d9f2441e36739fa7fdc9c75b5ad0ad)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterListControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :param filter_control_id: The ID of the ``FilterListControl`` .
            :param source_filter_id: The source filter ID of the ``FilterListControl`` .
            :param title: The title of the ``FilterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``FilterListControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from the list. - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_list_control_property = quicksight.CfnTemplate.FilterListControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                        search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dcc2ca0575422258b194e4ed1f63bcb273d8a97da2edda7e88d5605c074578a9)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ListControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ListControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterListControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from the list.
            - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_field_options": "selectedFieldOptions",
            "selected_fields": "selectedFields",
        },
    )
    class FilterOperationSelectedFieldsConfigurationProperty:
        def __init__(
            self,
            *,
            selected_field_options: typing.Optional[builtins.str] = None,
            selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of selected fields in the ``CustomActionFilterOperation`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_field_options: A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` . Valid values are defined as follows: - ``ALL_FIELDS`` : Applies the filter operation to all fields.
            :param selected_fields: Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_operation_selected_fields_configuration_property = quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                    selected_field_options="selectedFieldOptions",
                    selected_fields=["selectedFields"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e4cc556166da14a47318e9220c3ed50d5c587b5b77b70bc22b2ea7bb8403d753)
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
                check_type(argname="argument selected_fields", value=selected_fields, expected_type=type_hints["selected_fields"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options
            if selected_fields is not None:
                self._values["selected_fields"] = selected_fields

        @builtins.property
        def selected_field_options(self) -> typing.Optional[builtins.str]:
            '''A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` .

            Valid values are defined as follows:

            - ``ALL_FIELDS`` : Applies the filter operation to all fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-template-filteroperationselectedfieldsconfiguration-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def selected_fields(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-template-filteroperationselectedfieldsconfiguration-selectedfields
            '''
            result = self._values.get("selected_fields")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationSelectedFieldsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "same_sheet_target_visual_configuration": "sameSheetTargetVisualConfiguration",
        },
    )
    class FilterOperationTargetVisualsConfigurationProperty:
        def __init__(
            self,
            *,
            same_sheet_target_visual_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SameSheetTargetVisualConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param same_sheet_target_visual_configuration: The configuration of the same-sheet target visuals that you want to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationtargetvisualsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_operation_target_visuals_configuration_property = quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                        target_visual_options="targetVisualOptions",
                        target_visuals=["targetVisuals"]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__09143b1471f0755e8470022a206aa646843a177c101ac495a451736dd533d1b8)
                check_type(argname="argument same_sheet_target_visual_configuration", value=same_sheet_target_visual_configuration, expected_type=type_hints["same_sheet_target_visual_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if same_sheet_target_visual_configuration is not None:
                self._values["same_sheet_target_visual_configuration"] = same_sheet_target_visual_configuration

        @builtins.property
        def same_sheet_target_visual_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SameSheetTargetVisualConfigurationProperty"]]:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-template-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
            '''
            result = self._values.get("same_sheet_target_visual_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SameSheetTargetVisualConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationTargetVisualsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "numeric_range_filter": "numericRangeFilter",
            "relative_dates_filter": "relativeDatesFilter",
            "time_equality_filter": "timeEqualityFilter",
            "time_range_filter": "timeRangeFilter",
            "top_bottom_filter": "topBottomFilter",
        },
    )
    class FilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CategoryFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_dates_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RelativeDatesFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TimeEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TimeRangeFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top_bottom_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TopBottomFilterProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''With a ``Filter`` , you can remove portions of data from a particular visual or view.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: A ``CategoryFilter`` filters text values. For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .
            :param numeric_equality_filter: A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.
            :param numeric_range_filter: A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.
            :param relative_dates_filter: A ``RelativeDatesFilter`` filters date values that are relative to a given date.
            :param time_equality_filter: A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.
            :param time_range_filter: A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.
            :param top_bottom_filter: A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_property = quicksight.CfnTemplate.FilterProperty(
                    category_filter=quicksight.CfnTemplate.CategoryFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                            custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_value="categoryValue",
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions"
                            ),
                            custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            ),
                            filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                                match_operator="matchOperator",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            )
                        ),
                        filter_id="filterId"
                    ),
                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions",
                        value=123
                    ),
                    numeric_range_filter=quicksight.CfnTemplate.NumericRangeFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        select_all_options="selectAllOptions"
                    ),
                    relative_dates_filter=quicksight.CfnTemplate.RelativeDatesFilterProperty(
                        anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                            anchor_option="anchorOption",
                            parameter_name="parameterName"
                        ),
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                        relative_date_type="relativeDateType",
                        time_granularity="timeGranularity",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        minimum_granularity="minimumGranularity",
                        parameter_name="parameterName",
                        relative_date_value=123
                    ),
                    time_equality_filter=quicksight.CfnTemplate.TimeEqualityFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        parameter_name="parameterName",
                        time_granularity="timeGranularity",
                        value="value"
                    ),
                    time_range_filter=quicksight.CfnTemplate.TimeRangeFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        time_granularity="timeGranularity"
                    ),
                    top_bottom_filter=quicksight.CfnTemplate.TopBottomFilterProperty(
                        aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            sort_direction="sortDirection"
                        )],
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        limit=123,
                        parameter_name="parameterName",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3ec5a99450848761dbc20aff6b28bc43ab55bc4127935b14c2a95054f338f063)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument numeric_range_filter", value=numeric_range_filter, expected_type=type_hints["numeric_range_filter"])
                check_type(argname="argument relative_dates_filter", value=relative_dates_filter, expected_type=type_hints["relative_dates_filter"])
                check_type(argname="argument time_equality_filter", value=time_equality_filter, expected_type=type_hints["time_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
                check_type(argname="argument top_bottom_filter", value=top_bottom_filter, expected_type=type_hints["top_bottom_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if numeric_range_filter is not None:
                self._values["numeric_range_filter"] = numeric_range_filter
            if relative_dates_filter is not None:
                self._values["relative_dates_filter"] = relative_dates_filter
            if time_equality_filter is not None:
                self._values["time_equality_filter"] = time_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter
            if top_bottom_filter is not None:
                self._values["top_bottom_filter"] = top_bottom_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CategoryFilterProperty"]]:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CategoryFilterProperty"]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericEqualityFilterProperty"]]:
            '''A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericEqualityFilterProperty"]], result)

        @builtins.property
        def numeric_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericRangeFilterProperty"]]:
            '''A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-numericrangefilter
            '''
            result = self._values.get("numeric_range_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericRangeFilterProperty"]], result)

        @builtins.property
        def relative_dates_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RelativeDatesFilterProperty"]]:
            '''A ``RelativeDatesFilter`` filters date values that are relative to a given date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-relativedatesfilter
            '''
            result = self._values.get("relative_dates_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RelativeDatesFilterProperty"]], result)

        @builtins.property
        def time_equality_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TimeEqualityFilterProperty"]]:
            '''A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-timeequalityfilter
            '''
            result = self._values.get("time_equality_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TimeEqualityFilterProperty"]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TimeRangeFilterProperty"]]:
            '''A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TimeRangeFilterProperty"]], result)

        @builtins.property
        def top_bottom_filter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TopBottomFilterProperty"]]:
            '''A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-topbottomfilter
            '''
            result = self._values.get("top_bottom_filter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TopBottomFilterProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterRelativeDateTimeControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control from a date filter that is used to specify the relative date.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_relative_date_time_control_property = quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3dd156c2ccfd172c1f279e4ff573a8b224b2f7974b02eb48a474228a4578910d)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterRelativeDateTimeControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"selected_sheets": "selectedSheets"},
    )
    class FilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            selected_sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The scope configuration for a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_sheets: The configuration for applying a filter to specific sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_scope_configuration_property = quicksight.CfnTemplate.FilterScopeConfigurationProperty(
                    selected_sheets=quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                        sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                            scope="scope",
                            sheet_id="sheetId",
                
                            # the properties below are optional
                            visual_ids=["visualIds"]
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__554bb7b9489a1f3886d98c5a487dc270094a52ed60c9f3fd219646ec46db9b8f)
                check_type(argname="argument selected_sheets", value=selected_sheets, expected_type=type_hints["selected_sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_sheets is not None:
                self._values["selected_sheets"] = selected_sheets

        @builtins.property
        def selected_sheets(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty"]]:
            '''The configuration for applying a filter to specific sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterscopeconfiguration.html#cfn-quicksight-template-filterscopeconfiguration-selectedsheets
            '''
            result = self._values.get("selected_sheets")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class FilterSelectableValuesProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param values: The values that are used in the ``FilterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_selectable_values_property = quicksight.CfnTemplate.FilterSelectableValuesProperty(
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__17b9da45d06573b1f392848224dd4ba9b1b0f793950b41a3cee9966f7d65b8fb)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in the ``FilterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterselectablevalues.html#cfn-quicksight-template-filterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "source_filter_id": "sourceFilterId",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterSliderControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            source_filter_id: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param filter_control_id: The ID of the ``FilterSliderControl`` .
            :param maximum_value: The smaller value that is displayed at the left of the slider.
            :param minimum_value: The larger value that is displayed at the right of the slider.
            :param source_filter_id: The source filter ID of the ``FilterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into.
            :param title: The title of the ``FilterSliderControl`` .
            :param display_options: The display options of a control.
            :param type: The type of ``FilterSliderControl`` . Choose one of the following options:. - ``SINGLE_POINT`` : Filter against(equals) a single data point. - ``RANGE`` : Filter data that is in a specified range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_slider_control_property = quicksight.CfnTemplate.FilterSliderControlProperty(
                    filter_control_id="filterControlId",
                    maximum_value=123,
                    minimum_value=123,
                    source_filter_id="sourceFilterId",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4b6184fc335cff27ba8cf40123a108542197349935c4213fd24ff3d23f505291)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "source_filter_id": source_filter_id,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SliderControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SliderControlDisplayOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterSliderControl`` . Choose one of the following options:.

            - ``SINGLE_POINT`` : Filter against(equals) a single data point.
            - ``RANGE`` : Filter data that is in a specified range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class FilterTextAreaControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_text_area_control_property = quicksight.CfnTemplate.FilterTextAreaControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f6d146a8d1122cf1ee77c523826f0ad659a4d958170d438d79a7e11ac4b11a8c)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextAreaControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextAreaControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FilterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterTextFieldControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param filter_control_id: The ID of the ``FilterTextFieldControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextFieldControl`` .
            :param title: The title of the ``FilterTextFieldControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                filter_text_field_control_property = quicksight.CfnTemplate.FilterTextFieldControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e1341a520c19f789ef12132e35f9f54a63cbb80312e837cdc7fc7b85a5b1a6b9)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextFieldControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextFieldControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FontConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_color": "fontColor",
            "font_decoration": "fontDecoration",
            "font_size": "fontSize",
            "font_style": "fontStyle",
            "font_weight": "fontWeight",
        },
    )
    class FontConfigurationProperty:
        def __init__(
            self,
            *,
            font_color: typing.Optional[builtins.str] = None,
            font_decoration: typing.Optional[builtins.str] = None,
            font_size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FontSizeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_style: typing.Optional[builtins.str] = None,
            font_weight: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FontWeightProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configures the display properties of the given text.

            :param font_color: Determines the color of the text.
            :param font_decoration: Determines the appearance of decorative lines on the text.
            :param font_size: The option that determines the text display size.
            :param font_style: Determines the text display face that is inherited by the given font family.
            :param font_weight: The option that determines the text display weight, or boldness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                font_configuration_property = quicksight.CfnTemplate.FontConfigurationProperty(
                    font_color="fontColor",
                    font_decoration="fontDecoration",
                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                        relative="relative"
                    ),
                    font_style="fontStyle",
                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e03f62c2e8ac902b473e35ef139bb14bea3bfd39bd6a8a2a93726bd5cbc486de)
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_decoration", value=font_decoration, expected_type=type_hints["font_decoration"])
                check_type(argname="argument font_size", value=font_size, expected_type=type_hints["font_size"])
                check_type(argname="argument font_style", value=font_style, expected_type=type_hints["font_style"])
                check_type(argname="argument font_weight", value=font_weight, expected_type=type_hints["font_weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_decoration is not None:
                self._values["font_decoration"] = font_decoration
            if font_size is not None:
                self._values["font_size"] = font_size
            if font_style is not None:
                self._values["font_style"] = font_style
            if font_weight is not None:
                self._values["font_weight"] = font_weight

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_decoration(self) -> typing.Optional[builtins.str]:
            '''Determines the appearance of decorative lines on the text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontdecoration
            '''
            result = self._values.get("font_decoration")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_size(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontSizeProperty"]]:
            '''The option that determines the text display size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontsize
            '''
            result = self._values.get("font_size")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontSizeProperty"]], result)

        @builtins.property
        def font_style(self) -> typing.Optional[builtins.str]:
            '''Determines the text display face that is inherited by the given font family.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontstyle
            '''
            result = self._values.get("font_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_weight(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontWeightProperty"]]:
            '''The option that determines the text display weight, or boldness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontweight
            '''
            result = self._values.get("font_weight")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontWeightProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FontSizeProperty",
        jsii_struct_bases=[],
        name_mapping={"relative": "relative"},
    )
    class FontSizeProperty:
        def __init__(self, *, relative: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display size.

            :param relative: The lexical name for the text size, proportional to its surrounding context.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontsize.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                font_size_property = quicksight.CfnTemplate.FontSizeProperty(
                    relative="relative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6db4bbc42adf3a3dcb5d030c2a3df53940974b59d0b0a7d3d9360d2a29bdb0bc)
                check_type(argname="argument relative", value=relative, expected_type=type_hints["relative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if relative is not None:
                self._values["relative"] = relative

        @builtins.property
        def relative(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the text size, proportional to its surrounding context.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontsize.html#cfn-quicksight-template-fontsize-relative
            '''
            result = self._values.get("relative")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontSizeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FontWeightProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name"},
    )
    class FontWeightProperty:
        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display weight, or boldness.

            :param name: The lexical name for the level of boldness of the text display.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontweight.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                font_weight_property = quicksight.CfnTemplate.FontWeightProperty(
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c560da72c16c3efa25771054d6f29355f4fcbd0c9bebd5ca99ac67358c7d16ac)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the level of boldness of the text display.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontweight.html#cfn-quicksight-template-fontweight-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontWeightProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ForecastComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "custom_seasonality_value": "customSeasonalityValue",
            "lower_boundary": "lowerBoundary",
            "name": "name",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
            "value": "value",
        },
    )
    class ForecastComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            custom_seasonality_value: typing.Optional[jsii.Number] = None,
            lower_boundary: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[builtins.str] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param custom_seasonality_value: The custom seasonality value setup of a forecast computation.
            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param name: The name of a computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``AUTOMATIC`` - ``CUSTOM`` : Checks the custom seasonality value.
            :param upper_boundary: The upper boundary setup of a forecast computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                forecast_computation_property = quicksight.CfnTemplate.ForecastComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    custom_seasonality_value=123,
                    lower_boundary=123,
                    name="name",
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality="seasonality",
                    upper_boundary=123,
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e6583cbf3deb2a29de7d9db02e9a55272252fea5fe53a16e18e3c3216eb57aa)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument custom_seasonality_value", value=custom_seasonality_value, expected_type=type_hints["custom_seasonality_value"])
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if custom_seasonality_value is not None:
                self._values["custom_seasonality_value"] = custom_seasonality_value
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if name is not None:
                self._values["name"] = name
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"], result)

        @builtins.property
        def custom_seasonality_value(self) -> typing.Optional[jsii.Number]:
            '''The custom seasonality value setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-customseasonalityvalue
            '''
            result = self._values.get("custom_seasonality_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[builtins.str]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``AUTOMATIC``
            - ``CUSTOM`` : Checks the custom seasonality value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ForecastConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast_properties": "forecastProperties",
            "scenario": "scenario",
        },
    )
    class ForecastConfigurationProperty:
        def __init__(
            self,
            *,
            forecast_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TimeBasedForecastPropertiesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ForecastScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast configuration that is used in a line chart's display properties.

            :param forecast_properties: The forecast properties setup of a forecast in the line chart.
            :param scenario: The forecast scenario of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                forecast_configuration_property = quicksight.CfnTemplate.ForecastConfigurationProperty(
                    forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                        lower_boundary=123,
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality=123,
                        upper_boundary=123
                    ),
                    scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                        what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                            date="date",
                            value=123
                        ),
                        what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                            end_date="endDate",
                            start_date="startDate",
                            value=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee7361a10d7e81122664be5f86da8d58244fed20ffd2bdd6bcb4f7c46dfd14e1)
                check_type(argname="argument forecast_properties", value=forecast_properties, expected_type=type_hints["forecast_properties"])
                check_type(argname="argument scenario", value=scenario, expected_type=type_hints["scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast_properties is not None:
                self._values["forecast_properties"] = forecast_properties
            if scenario is not None:
                self._values["scenario"] = scenario

        @builtins.property
        def forecast_properties(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TimeBasedForecastPropertiesProperty"]]:
            '''The forecast properties setup of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html#cfn-quicksight-template-forecastconfiguration-forecastproperties
            '''
            result = self._values.get("forecast_properties")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TimeBasedForecastPropertiesProperty"]], result)

        @builtins.property
        def scenario(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ForecastScenarioProperty"]]:
            '''The forecast scenario of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html#cfn-quicksight-template-forecastconfiguration-scenario
            '''
            result = self._values.get("scenario")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ForecastScenarioProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ForecastScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "what_if_point_scenario": "whatIfPointScenario",
            "what_if_range_scenario": "whatIfRangeScenario",
        },
    )
    class ForecastScenarioProperty:
        def __init__(
            self,
            *,
            what_if_point_scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WhatIfPointScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            what_if_range_scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WhatIfRangeScenarioProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The forecast scenario of a forecast in the line chart.

            :param what_if_point_scenario: The what-if analysis forecast setup with the target date.
            :param what_if_range_scenario: The what-if analysis forecast setup with the date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                forecast_scenario_property = quicksight.CfnTemplate.ForecastScenarioProperty(
                    what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                        date="date",
                        value=123
                    ),
                    what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                        end_date="endDate",
                        start_date="startDate",
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0eb36afd6273ed8efe73cd7bb158dbd9d6b3dd15c93a324186e9b59a682671b6)
                check_type(argname="argument what_if_point_scenario", value=what_if_point_scenario, expected_type=type_hints["what_if_point_scenario"])
                check_type(argname="argument what_if_range_scenario", value=what_if_range_scenario, expected_type=type_hints["what_if_range_scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if what_if_point_scenario is not None:
                self._values["what_if_point_scenario"] = what_if_point_scenario
            if what_if_range_scenario is not None:
                self._values["what_if_range_scenario"] = what_if_range_scenario

        @builtins.property
        def what_if_point_scenario(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WhatIfPointScenarioProperty"]]:
            '''The what-if analysis forecast setup with the target date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html#cfn-quicksight-template-forecastscenario-whatifpointscenario
            '''
            result = self._values.get("what_if_point_scenario")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WhatIfPointScenarioProperty"]], result)

        @builtins.property
        def what_if_range_scenario(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WhatIfRangeScenarioProperty"]]:
            '''The what-if analysis forecast setup with the date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html#cfn-quicksight-template-forecastscenario-whatifrangescenario
            '''
            result = self._values.get("what_if_range_scenario")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WhatIfRangeScenarioProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format_configuration": "dateTimeFormatConfiguration",
            "number_format_configuration": "numberFormatConfiguration",
            "string_format_configuration": "stringFormatConfiguration",
        },
    )
    class FormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            string_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The formatting configuration for all types of field.

            :param date_time_format_configuration: Formatting configuration for ``DateTime`` fields.
            :param number_format_configuration: Formatting configuration for number fields.
            :param string_format_configuration: Formatting configuration for string fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                format_configuration_property = quicksight.CfnTemplate.FormatConfigurationProperty(
                    date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9aa788421208ed3acb9cfdfb628214920ae043c154b65d6ffad598860bab8e97)
                check_type(argname="argument date_time_format_configuration", value=date_time_format_configuration, expected_type=type_hints["date_time_format_configuration"])
                check_type(argname="argument number_format_configuration", value=number_format_configuration, expected_type=type_hints["number_format_configuration"])
                check_type(argname="argument string_format_configuration", value=string_format_configuration, expected_type=type_hints["string_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format_configuration is not None:
                self._values["date_time_format_configuration"] = date_time_format_configuration
            if number_format_configuration is not None:
                self._values["number_format_configuration"] = number_format_configuration
            if string_format_configuration is not None:
                self._values["string_format_configuration"] = string_format_configuration

        @builtins.property
        def date_time_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeFormatConfigurationProperty"]]:
            '''Formatting configuration for ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-datetimeformatconfiguration
            '''
            result = self._values.get("date_time_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeFormatConfigurationProperty"]], result)

        @builtins.property
        def number_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumberFormatConfigurationProperty"]]:
            '''Formatting configuration for number fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-numberformatconfiguration
            '''
            result = self._values.get("number_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumberFormatConfigurationProperty"]], result)

        @builtins.property
        def string_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.StringFormatConfigurationProperty"]]:
            '''Formatting configuration for string fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-stringformatconfiguration
            '''
            result = self._values.get("string_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.StringFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class FreeFormLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configuration options for the canvas of a free-form layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_canvas_size_options_property = quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__00f82d4351fe9c4a98a2d0644f4c081c08fbfbfbf9f37b8a1aa477a373f359e3)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty"]]:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutcanvassizeoptions.html#cfn-quicksight-template-freeformlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class FreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a free-form layout.

            :param elements: The elements that are included in a free-form layout.
            :param canvas_size_options: ``CfnTemplate.FreeFormLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_configuration_property = quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb6e06eb52123fe604adbbe5eff621d7e8600f25ebaa35f10b560bcf4b6a55b5)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutElementProperty"]]]:
            '''The elements that are included in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html#cfn-quicksight-template-freeformlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutElementProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty"]]:
            '''``CfnTemplate.FreeFormLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html#cfn-quicksight-template-freeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBackgroundStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The background color of a free-form layout element.
            :param visibility: The background visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_element_background_style_property = quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ce797b4bd061c3fc0bbbdfd278986d32d68abd6e47951e989f935ad61cf7a33)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The background color of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-template-freeformlayoutelementbackgroundstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The background visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-template-freeformlayoutelementbackgroundstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBackgroundStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBorderStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The border color of a free-form layout element.
            :param visibility: The border visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_element_border_style_property = quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3172bc924e440e70fd5cb0f16dd7c3cd1c19549a5359bf9a0f6f8dfff3c6582f)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The border color of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html#cfn-quicksight-template-freeformlayoutelementborderstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The border visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html#cfn-quicksight-template-freeformlayoutelementborderstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBorderStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FreeFormLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "element_id": "elementId",
            "element_type": "elementType",
            "height": "height",
            "width": "width",
            "x_axis_location": "xAxisLocation",
            "y_axis_location": "yAxisLocation",
            "background_style": "backgroundStyle",
            "border_style": "borderStyle",
            "loading_animation": "loadingAnimation",
            "rendering_rules": "renderingRules",
            "selected_border_style": "selectedBorderStyle",
            "visibility": "visibility",
        },
    )
    class FreeFormLayoutElementProperty:
        def __init__(
            self,
            *,
            element_id: builtins.str,
            element_type: builtins.str,
            height: builtins.str,
            width: builtins.str,
            x_axis_location: builtins.str,
            y_axis_location: builtins.str,
            background_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            border_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            loading_animation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LoadingAnimationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            rendering_rules: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SheetElementRenderingRuleProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_border_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An element within a free-form layout.

            :param element_id: A unique identifier for an element within a free-form layout.
            :param element_type: The type of element.
            :param height: The height of an element within a free-form layout.
            :param width: The width of an element within a free-form layout.
            :param x_axis_location: The x-axis coordinate of the element.
            :param y_axis_location: The y-axis coordinate of the element.
            :param background_style: The background style configuration of a free-form layout element.
            :param border_style: The border style configuration of a free-form layout element.
            :param loading_animation: The loading animation configuration of a free-form layout element.
            :param rendering_rules: The rendering rules that determine when an element should be displayed within a free-form layout.
            :param selected_border_style: The border style configuration of a free-form layout element. This border style is used when the element is selected.
            :param visibility: The visibility of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_element_property = quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                    element_id="elementId",
                    element_type="elementType",
                    height="height",
                    width="width",
                    x_axis_location="xAxisLocation",
                    y_axis_location="yAxisLocation",
                
                    # the properties below are optional
                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                        visibility="visibility"
                    ),
                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                            visibility="visibility"
                        ),
                        expression="expression"
                    )],
                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c1b1dd79c9c21cd7d6ede8626e36c7d6cc5db6972f51663b30caa88556bef7e)
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
                check_type(argname="argument x_axis_location", value=x_axis_location, expected_type=type_hints["x_axis_location"])
                check_type(argname="argument y_axis_location", value=y_axis_location, expected_type=type_hints["y_axis_location"])
                check_type(argname="argument background_style", value=background_style, expected_type=type_hints["background_style"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument loading_animation", value=loading_animation, expected_type=type_hints["loading_animation"])
                check_type(argname="argument rendering_rules", value=rendering_rules, expected_type=type_hints["rendering_rules"])
                check_type(argname="argument selected_border_style", value=selected_border_style, expected_type=type_hints["selected_border_style"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "element_id": element_id,
                "element_type": element_type,
                "height": height,
                "width": width,
                "x_axis_location": x_axis_location,
                "y_axis_location": y_axis_location,
            }
            if background_style is not None:
                self._values["background_style"] = background_style
            if border_style is not None:
                self._values["border_style"] = border_style
            if loading_animation is not None:
                self._values["loading_animation"] = loading_animation
            if rendering_rules is not None:
                self._values["rendering_rules"] = rendering_rules
            if selected_border_style is not None:
                self._values["selected_border_style"] = selected_border_style
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def height(self) -> builtins.str:
            '''The height of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-height
            '''
            result = self._values.get("height")
            assert result is not None, "Required property 'height' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def width(self) -> builtins.str:
            '''The width of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-width
            '''
            result = self._values.get("width")
            assert result is not None, "Required property 'width' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def x_axis_location(self) -> builtins.str:
            '''The x-axis coordinate of the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-xaxislocation
            '''
            result = self._values.get("x_axis_location")
            assert result is not None, "Required property 'x_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def y_axis_location(self) -> builtins.str:
            '''The y-axis coordinate of the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-yaxislocation
            '''
            result = self._values.get("y_axis_location")
            assert result is not None, "Required property 'y_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def background_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty"]]:
            '''The background style configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-backgroundstyle
            '''
            result = self._values.get("background_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty"]], result)

        @builtins.property
        def border_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutElementBorderStyleProperty"]]:
            '''The border style configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutElementBorderStyleProperty"]], result)

        @builtins.property
        def loading_animation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LoadingAnimationProperty"]]:
            '''The loading animation configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-loadinganimation
            '''
            result = self._values.get("loading_animation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LoadingAnimationProperty"]], result)

        @builtins.property
        def rendering_rules(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetElementRenderingRuleProperty"]]]]:
            '''The rendering rules that determine when an element should be displayed within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-renderingrules
            '''
            result = self._values.get("rendering_rules")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetElementRenderingRuleProperty"]]]], result)

        @builtins.property
        def selected_border_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutElementBorderStyleProperty"]]:
            '''The border style configuration of a free-form layout element.

            This border style is used when the element is selected.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-selectedborderstyle
            '''
            result = self._values.get("selected_border_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutElementBorderStyleProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"optimized_view_port_width": "optimizedViewPortWidth"},
    )
    class FreeFormLayoutScreenCanvasSizeOptionsProperty:
        def __init__(self, *, optimized_view_port_width: builtins.str) -> None:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_layout_screen_canvas_size_options_property = quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a5a8782d0b88dafcdd737da7b6388e805c9afd098072d42b60bbbfffc8ea665e)
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "optimized_view_port_width": optimized_view_port_width,
            }

        @builtins.property
        def optimized_view_port_width(self) -> builtins.str:
            '''The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-template-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            assert result is not None, "Required property 'optimized_view_port_width' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"elements": "elements"},
    )
    class FreeFormSectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The free-form layout configuration of a section.

            :param elements: The elements that are included in the free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformsectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                free_form_section_layout_configuration_property = quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33532fecf59a8fd1b2559844246b823f12aa903e8c3f3962bfc33c454c5a074e)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutElementProperty"]]]:
            '''The elements that are included in the free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformsectionlayoutconfiguration.html#cfn-quicksight-template-freeformsectionlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutElementProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormSectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "values": "values"},
    )
    class FunnelChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :param category: The category field wells of a funnel chart. Values are grouped by category fields.
            :param values: The value field wells of a funnel chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_aggregated_field_wells_property = quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57d6b58316a87596e0b1dfdf02593c19d149cf9a1a4a0452e14506c574afeac7)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The category field wells of a funnel chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html#cfn-quicksight-template-funnelchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a funnel chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html#cfn-quicksight-template-funnelchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FunnelChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "data_label_options": "dataLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class FunnelChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FunnelChartDataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FunnelChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FunnelChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``FunnelChartVisual`` .

            :param category_label_options: The label options of the categories that are displayed in a ``FunnelChartVisual`` .
            :param data_label_options: The options that determine the presentation of the data labels.
            :param field_wells: The field well configuration of a ``FunnelChartVisual`` .
            :param sort_configuration: The sort configuration of a ``FunnelChartVisual`` .
            :param tooltip: The tooltip configuration of a ``FunnelChartVisual`` .
            :param value_label_options: The label options for the values that are displayed in a ``FunnelChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_configuration_property = quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        label_color="labelColor",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_data_label_style="measureDataLabelStyle",
                        measure_label_visibility="measureLabelVisibility",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                        funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7894bea9eefaa198de81159a2875591a22c4cc0213f032dfb54fd7c4db79e65)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument data_label_options", value=data_label_options, expected_type=type_hints["data_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if data_label_options is not None:
                self._values["data_label_options"] = data_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the categories that are displayed in a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FunnelChartDataLabelOptionsProperty"]]:
            '''The options that determine the presentation of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-datalabeloptions
            '''
            result = self._values.get("data_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FunnelChartDataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FunnelChartFieldWellsProperty"]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FunnelChartFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FunnelChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FunnelChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options for the values that are displayed in a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]]:
            '''The visual palette configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "label_color": "labelColor",
            "label_font_configuration": "labelFontConfiguration",
            "measure_data_label_style": "measureDataLabelStyle",
            "measure_label_visibility": "measureLabelVisibility",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class FunnelChartDataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            measure_data_label_style: typing.Optional[builtins.str] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: The visibility of the category labels within the data labels.
            :param label_color: The color of the data label text.
            :param label_font_configuration: The font configuration for the data labels. Only the ``FontSize`` attribute of the font configuration is used for data labels.
            :param measure_data_label_style: Determines the style of the metric labels.
            :param measure_label_visibility: The visibility of the measure labels within the data labels.
            :param position: Determines the positioning of the data label relative to a section of the funnel.
            :param visibility: The visibility option that determines if data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_data_label_options_property = quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    label_color="labelColor",
                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_data_label_style="measureDataLabelStyle",
                    measure_label_visibility="measureLabelVisibility",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c0a9788225d95e58712597cdd15ec6d4922ce1b8a67da91ae63f3d65c3231381)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_data_label_style", value=measure_data_label_style, expected_type=type_hints["measure_data_label_style"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_data_label_style is not None:
                self._values["measure_data_label_style"] = measure_data_label_style
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the category labels within the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''The color of the data label text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]]:
            '''The font configuration for the data labels.

            Only the ``FontSize`` attribute of the font configuration is used for data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def measure_data_label_style(self) -> typing.Optional[builtins.str]:
            '''Determines the style of the metric labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-measuredatalabelstyle
            '''
            result = self._values.get("measure_data_label_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the measure labels within the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the positioning of the data label relative to a section of the funnel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility option that determines if data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartDataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FunnelChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "funnel_chart_aggregated_field_wells": "funnelChartAggregatedFieldWells",
        },
    )
    class FunnelChartFieldWellsProperty:
        def __init__(
            self,
            *,
            funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FunnelChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param funnel_chart_aggregated_field_wells: The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_field_wells_property = quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                    funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6b3e4967b8870e2f9aeba35ed1817cf62dc1858604baf2b17eb18a5e2345d284)
                check_type(argname="argument funnel_chart_aggregated_field_wells", value=funnel_chart_aggregated_field_wells, expected_type=type_hints["funnel_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if funnel_chart_aggregated_field_wells is not None:
                self._values["funnel_chart_aggregated_field_wells"] = funnel_chart_aggregated_field_wells

        @builtins.property
        def funnel_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FunnelChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartfieldwells.html#cfn-quicksight-template-funnelchartfieldwells-funnelchartaggregatedfieldwells
            '''
            result = self._values.get("funnel_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FunnelChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FunnelChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class FunnelChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :param category_items_limit: The limit on the number of categories displayed.
            :param category_sort: The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_sort_configuration_property = quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b32b57a19e5c94c2982de4233918ecc99b8492b0629104c22f62ee69a3b95678)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html#cfn-quicksight-template-funnelchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html#cfn-quicksight-template-funnelchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.FunnelChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FunnelChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FunnelChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``FunnelChartVisual`` .
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                funnel_chart_visual_property = quicksight.CfnTemplate.FunnelChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            label_color="labelColor",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_data_label_style="measureDataLabelStyle",
                            measure_label_visibility="measureLabelVisibility",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                            funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6071461d6d44ae1f5921c023b13ce02eacd3007ed4afdda1b560733b9a3e4ea5)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FunnelChartConfigurationProperty"]]:
            '''The configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FunnelChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class GaugeChartArcConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :param foreground_color: The conditional formatting of the arc foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartarcconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_arc_conditional_formatting_property = quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                    foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c3814212b35ce4db426938b8e933d076da21546f5930c38c9a4d6a5577d7df55)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the arc foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartarcconditionalformatting.html#cfn-quicksight-template-gaugechartarcconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartArcConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"arc": "arc", "primary_value": "primaryValue"},
    )
    class GaugeChartConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GaugeChartArcConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :param arc: The options that determine the presentation of the arc of a ``GaugeChartVisual`` .
            :param primary_value: The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_option_property = quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                    arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9ea0d075e2f7a419bd65fa799057076c4284749eb54920acd176a09b478e9394)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if primary_value is not None:
                self._values["primary_value"] = primary_value

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartArcConditionalFormattingProperty"]]:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html#cfn-quicksight-template-gaugechartconditionalformattingoption-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartArcConditionalFormattingProperty"]], result)

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html#cfn-quicksight-template-gaugechartconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class GaugeChartConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GaugeChartConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_property = quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                        arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57311cca522979452f32997947e94350eeb4a1a43f9a41e5c08bb67cc8b85a96)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformatting.html#cfn-quicksight-template-gaugechartconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GaugeChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "gauge_chart_options": "gaugeChartOptions",
            "tooltip_options": "tooltipOptions",
            "visual_palette": "visualPalette",
        },
    )
    class GaugeChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GaugeChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            gauge_chart_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GaugeChartOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``GaugeChartVisual`` .

            :param data_labels: The data label configuration of a ``GaugeChartVisual`` .
            :param field_wells: The field well configuration of a ``GaugeChartVisual`` .
            :param gauge_chart_options: The options that determine the presentation of the ``GaugeChartVisual`` .
            :param tooltip_options: The tooltip configuration of a ``GaugeChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_configuration_property = quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                        target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                        arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                            arc_angle=123,
                            arc_thickness="arcThickness"
                        ),
                        arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                            range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                max=123,
                                min=123
                            ),
                            reserve_range=123
                        ),
                        comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                            comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            comparison_method="comparisonMethod"
                        ),
                        primary_value_display_type="primaryValueDisplayType",
                        primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        )
                    ),
                    tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__16c88c5a72a584244b501470b218910adf497f2fdb65dd782c8555222114d4da)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument gauge_chart_options", value=gauge_chart_options, expected_type=type_hints["gauge_chart_options"])
                check_type(argname="argument tooltip_options", value=tooltip_options, expected_type=type_hints["tooltip_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if gauge_chart_options is not None:
                self._values["gauge_chart_options"] = gauge_chart_options
            if tooltip_options is not None:
                self._values["tooltip_options"] = tooltip_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The data label configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartFieldWellsProperty"]]:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartFieldWellsProperty"]], result)

        @builtins.property
        def gauge_chart_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartOptionsProperty"]]:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-gaugechartoptions
            '''
            result = self._values.get("gauge_chart_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartOptionsProperty"]], result)

        @builtins.property
        def tooltip_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-tooltipoptions
            '''
            result = self._values.get("tooltip_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]]:
            '''The visual palette configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GaugeChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"target_values": "targetValues", "values": "values"},
    )
    class GaugeChartFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :param target_values: The target value field wells of a ``GaugeChartVisual`` .
            :param values: The value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_field_wells_property = quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                    target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f65304a46f589455003fa2a86d986dd89fbde900828af97a83b14ec102ab073)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The target value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html#cfn-quicksight-template-gaugechartfieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html#cfn-quicksight-template-gaugechartfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GaugeChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc": "arc",
            "arc_axis": "arcAxis",
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
        },
    )
    class GaugeChartOptionsProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ArcConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            arc_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ArcAxisConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :param arc: The arc configuration of a ``GaugeChartVisual`` .
            :param arc_axis: The arc axis configuration of a ``GaugeChartVisual`` .
            :param comparison: The comparison configuration of a ``GaugeChartVisual`` .
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_options_property = quicksight.CfnTemplate.GaugeChartOptionsProperty(
                    arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                        arc_angle=123,
                        arc_thickness="arcThickness"
                    ),
                    arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                        range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                            max=123,
                            min=123
                        ),
                        reserve_range=123
                    ),
                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee6c2ce6efe15f57b996163b9204eb061a8012f34a94ae9c82b015f5376f0127)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument arc_axis", value=arc_axis, expected_type=type_hints["arc_axis"])
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if arc_axis is not None:
                self._values["arc_axis"] = arc_axis
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ArcConfigurationProperty"]]:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ArcConfigurationProperty"]], result)

        @builtins.property
        def arc_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ArcAxisConfigurationProperty"]]:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-arcaxis
            '''
            result = self._values.get("arc_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ArcAxisConfigurationProperty"]], result)

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComparisonConfigurationProperty"]]:
            '''The comparison configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComparisonConfigurationProperty"]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]]:
            '''The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class GaugeChartPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :param icon: The conditional formatting of the primary value icon.
            :param text_color: The conditional formatting of the primary value text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_primary_value_conditional_formatting_property = quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__691f985cb25589eecf18cc6406f6dedbfc2fde876e9cd2a30cbc5a2eb83ec404)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the primary value icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-template-gaugechartprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the primary value text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-template-gaugechartprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GaugeChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GaugeChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GaugeChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GaugeChartConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``GaugeChartVisual`` .
            :param conditional_formatting: The conditional formatting of a ``GaugeChartVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gauge_chart_visual_property = quicksight.CfnTemplate.GaugeChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                            target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                            arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                                arc_angle=123,
                                arc_thickness="arcThickness"
                            ),
                            arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                                range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                    max=123,
                                    min=123
                                ),
                                reserve_range=123
                            ),
                            comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                comparison_method="comparisonMethod"
                            ),
                            primary_value_display_type="primaryValueDisplayType",
                            primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        ),
                        tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    conditional_formatting=quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                            arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                                foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            ),
                            primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55e199338bbd91a61a0542a1cd7cb461c653243b00e7f7cd831a8a9dd939b0dd)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartConfigurationProperty"]]:
            '''The configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartConditionalFormattingProperty"]]:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "east": "east",
            "north": "north",
            "south": "south",
            "west": "west",
        },
    )
    class GeospatialCoordinateBoundsProperty:
        def __init__(
            self,
            *,
            east: jsii.Number,
            north: jsii.Number,
            south: jsii.Number,
            west: jsii.Number,
        ) -> None:
            '''The bound options (north, south, west, east) of the geospatial window options.

            :param east: The longitude of the east bound of the geospatial coordinate bounds.
            :param north: The latitude of the north bound of the geospatial coordinate bounds.
            :param south: The latitude of the south bound of the geospatial coordinate bounds.
            :param west: The longitude of the west bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_coordinate_bounds_property = quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                    east=123,
                    north=123,
                    south=123,
                    west=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e522f75057544989433e42dc7a8890f432dc8921bf0ce4900c3bd02a8f871306)
                check_type(argname="argument east", value=east, expected_type=type_hints["east"])
                check_type(argname="argument north", value=north, expected_type=type_hints["north"])
                check_type(argname="argument south", value=south, expected_type=type_hints["south"])
                check_type(argname="argument west", value=west, expected_type=type_hints["west"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "east": east,
                "north": north,
                "south": south,
                "west": west,
            }

        @builtins.property
        def east(self) -> jsii.Number:
            '''The longitude of the east bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-east
            '''
            result = self._values.get("east")
            assert result is not None, "Required property 'east' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def north(self) -> jsii.Number:
            '''The latitude of the north bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-north
            '''
            result = self._values.get("north")
            assert result is not None, "Required property 'north' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def south(self) -> jsii.Number:
            '''The latitude of the south bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-south
            '''
            result = self._values.get("south")
            assert result is not None, "Required property 'south' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def west(self) -> jsii.Number:
            '''The longitude of the west bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-west
            '''
            result = self._values.get("west")
            assert result is not None, "Required property 'west' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialCoordinateBoundsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "colors": "colors",
            "geospatial": "geospatial",
            "values": "values",
        },
    )
    class GeospatialMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            geospatial: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells for a geospatial map.

            :param colors: The color field wells of a geospatial map.
            :param geospatial: The geospatial field wells of a geospatial map. Values are grouped by geospatial fields.
            :param values: The size field wells of a geospatial map. Values are aggregated based on geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_aggregated_field_wells_property = quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd4160bf08ccc6687eb96e90ad18f8efbe27a3881713e0237828399a522fb2b2)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The color field wells of a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The geospatial field wells of a geospatial map.

            Values are grouped by geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The size field wells of a geospatial map.

            Values are aggregated based on geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GeospatialMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "point_style_options": "pointStyleOptions",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "window_options": "windowOptions",
        },
    )
    class GeospatialMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GeospatialMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            point_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GeospatialPointStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            window_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``GeospatialMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the geospatial map.
            :param point_style_options: The point style options of the geospatial map.
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: ``CfnTemplate.GeospatialMapConfigurationProperty.VisualPalette``.
            :param window_options: The window options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_configuration_property = quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                    field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                        geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                        base_map_style="baseMapStyle"
                    ),
                    point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                        cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                            cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                    color="color"
                                )
                            )
                        ),
                        selected_point_style="selectedPointStyle"
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                        bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                            east=123,
                            north=123,
                            south=123,
                            west=123
                        ),
                        map_zoom_mode="mapZoomMode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a4df968e87fff955904704defcb9dfaef1f61cd7a3457ad4e0e073a3942343b2)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument point_style_options", value=point_style_options, expected_type=type_hints["point_style_options"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if point_style_options is not None:
                self._values["point_style_options"] = point_style_options
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialMapStyleOptionsProperty"]]:
            '''The map style options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialMapStyleOptionsProperty"]], result)

        @builtins.property
        def point_style_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialPointStyleOptionsProperty"]]:
            '''The point style options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-pointstyleoptions
            '''
            result = self._values.get("point_style_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialPointStyleOptionsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]]:
            '''``CfnTemplate.GeospatialMapConfigurationProperty.VisualPalette``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialWindowOptionsProperty"]]:
            '''The window options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialWindowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GeospatialMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "geospatial_map_aggregated_field_wells": "geospatialMapAggregatedFieldWells",
        },
    )
    class GeospatialMapFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GeospatialMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a ``GeospatialMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param geospatial_map_aggregated_field_wells: The aggregated field well for a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_field_wells_property = quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                    geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c4001044275eb482560b80f5fdfde01d1972c41d2ff127b4f8e6b211c4eea2cd)
                check_type(argname="argument geospatial_map_aggregated_field_wells", value=geospatial_map_aggregated_field_wells, expected_type=type_hints["geospatial_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial_map_aggregated_field_wells is not None:
                self._values["geospatial_map_aggregated_field_wells"] = geospatial_map_aggregated_field_wells

        @builtins.property
        def geospatial_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapfieldwells.html#cfn-quicksight-template-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
            '''
            result = self._values.get("geospatial_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"base_map_style": "baseMapStyle"},
    )
    class GeospatialMapStyleOptionsProperty:
        def __init__(
            self,
            *,
            base_map_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The map style options of the geospatial map.

            :param base_map_style: The base map style of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_style_options_property = quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                    base_map_style="baseMapStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f78a7c7a89324910652df3168c75316283365fbe16b1aea6b2729d1c520359f1)
                check_type(argname="argument base_map_style", value=base_map_style, expected_type=type_hints["base_map_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base_map_style is not None:
                self._values["base_map_style"] = base_map_style

        @builtins.property
        def base_map_style(self) -> typing.Optional[builtins.str]:
            '''The base map style of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapstyleoptions.html#cfn-quicksight-template-geospatialmapstyleoptions-basemapstyle
            '''
            result = self._values.get("base_map_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GeospatialMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GeospatialMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GeospatialMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_map_visual_property = quicksight.CfnTemplate.GeospatialMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                        field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                            geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                                colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                            base_map_style="baseMapStyle"
                        ),
                        point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                            cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                                cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                    simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                        color="color"
                                    )
                                )
                            ),
                            selected_point_style="selectedPointStyle"
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                            bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                east=123,
                                north=123,
                                south=123,
                                west=123
                            ),
                            map_zoom_mode="mapZoomMode"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c634669eda1265acb83611d745ab058b78ddbb3fb91d5d8825f44067be8d913)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cluster_marker_configuration": "clusterMarkerConfiguration",
            "selected_point_style": "selectedPointStyle",
        },
    )
    class GeospatialPointStyleOptionsProperty:
        def __init__(
            self,
            *,
            cluster_marker_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ClusterMarkerConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_point_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The point style of the geospatial map.

            :param cluster_marker_configuration: The cluster marker configuration of the geospatial point style.
            :param selected_point_style: The selected point styles (point, cluster) of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_point_style_options_property = quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                    cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                        cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                            simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                color="color"
                            )
                        )
                    ),
                    selected_point_style="selectedPointStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a233dbb2e5660f13ba7ef4c47d20ea0421ca09be116482dd51ce5d5b16e9d602)
                check_type(argname="argument cluster_marker_configuration", value=cluster_marker_configuration, expected_type=type_hints["cluster_marker_configuration"])
                check_type(argname="argument selected_point_style", value=selected_point_style, expected_type=type_hints["selected_point_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker_configuration is not None:
                self._values["cluster_marker_configuration"] = cluster_marker_configuration
            if selected_point_style is not None:
                self._values["selected_point_style"] = selected_point_style

        @builtins.property
        def cluster_marker_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ClusterMarkerConfigurationProperty"]]:
            '''The cluster marker configuration of the geospatial point style.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html#cfn-quicksight-template-geospatialpointstyleoptions-clustermarkerconfiguration
            '''
            result = self._values.get("cluster_marker_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ClusterMarkerConfigurationProperty"]], result)

        @builtins.property
        def selected_point_style(self) -> typing.Optional[builtins.str]:
            '''The selected point styles (point, cluster) of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html#cfn-quicksight-template-geospatialpointstyleoptions-selectedpointstyle
            '''
            result = self._values.get("selected_point_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialPointStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GeospatialWindowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bounds": "bounds", "map_zoom_mode": "mapZoomMode"},
    )
    class GeospatialWindowOptionsProperty:
        def __init__(
            self,
            *,
            bounds: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GeospatialCoordinateBoundsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            map_zoom_mode: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The window options of the geospatial map visual.

            :param bounds: The bounds options (north, south, west, east) of the geospatial window options.
            :param map_zoom_mode: The map zoom modes (manual, auto) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                geospatial_window_options_property = quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                    bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                        east=123,
                        north=123,
                        south=123,
                        west=123
                    ),
                    map_zoom_mode="mapZoomMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a0c472835de8e3d2ac8d01cf338efdf00edbf1f051544b6fb1b22a3d5dbd11e4)
                check_type(argname="argument bounds", value=bounds, expected_type=type_hints["bounds"])
                check_type(argname="argument map_zoom_mode", value=map_zoom_mode, expected_type=type_hints["map_zoom_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bounds is not None:
                self._values["bounds"] = bounds
            if map_zoom_mode is not None:
                self._values["map_zoom_mode"] = map_zoom_mode

        @builtins.property
        def bounds(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialCoordinateBoundsProperty"]]:
            '''The bounds options (north, south, west, east) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html#cfn-quicksight-template-geospatialwindowoptions-bounds
            '''
            result = self._values.get("bounds")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialCoordinateBoundsProperty"]], result)

        @builtins.property
        def map_zoom_mode(self) -> typing.Optional[builtins.str]:
            '''The map zoom modes (manual, auto) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html#cfn-quicksight-template-geospatialwindowoptions-mapzoommode
            '''
            result = self._values.get("map_zoom_mode")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialWindowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GlobalTableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "side_specific_border": "sideSpecificBorder",
            "uniform_border": "uniformBorder",
        },
    )
    class GlobalTableBorderOptionsProperty:
        def __init__(
            self,
            *,
            side_specific_border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableSideBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            uniform_border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Determines the border options for a table visual.

            :param side_specific_border: Determines the options for side specific border.
            :param uniform_border: Determines the options for uniform border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                global_table_border_options_property = quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dbc95f3cf2b0b1a710fd02d2beb65902ef5d3392a351f8c9c0b8359ee01d54f7)
                check_type(argname="argument side_specific_border", value=side_specific_border, expected_type=type_hints["side_specific_border"])
                check_type(argname="argument uniform_border", value=uniform_border, expected_type=type_hints["uniform_border"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if side_specific_border is not None:
                self._values["side_specific_border"] = side_specific_border
            if uniform_border is not None:
                self._values["uniform_border"] = uniform_border

        @builtins.property
        def side_specific_border(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableSideBorderOptionsProperty"]]:
            '''Determines the options for side specific border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html#cfn-quicksight-template-globaltableborderoptions-sidespecificborder
            '''
            result = self._values.get("side_specific_border")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableSideBorderOptionsProperty"]], result)

        @builtins.property
        def uniform_border(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''Determines the options for uniform border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html#cfn-quicksight-template-globaltableborderoptions-uniformborder
            '''
            result = self._values.get("uniform_border")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GlobalTableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"stops": "stops"},
    )
    class GradientColorProperty:
        def __init__(
            self,
            *,
            stops: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GradientStopProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Determines the gradient color settings.

            :param stops: The list of gradient color stops.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gradient_color_property = quicksight.CfnTemplate.GradientColorProperty(
                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                        gradient_offset=123,
                
                        # the properties below are optional
                        color="color",
                        data_value=123
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2776d0b0bb49448cca8076e504ce1bfdbd727a1b40b6b20f7279eb43f7842b6b)
                check_type(argname="argument stops", value=stops, expected_type=type_hints["stops"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if stops is not None:
                self._values["stops"] = stops

        @builtins.property
        def stops(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GradientStopProperty"]]]]:
            '''The list of gradient color stops.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientcolor.html#cfn-quicksight-template-gradientcolor-stops
            '''
            result = self._values.get("stops")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GradientStopProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GradientStopProperty",
        jsii_struct_bases=[],
        name_mapping={
            "gradient_offset": "gradientOffset",
            "color": "color",
            "data_value": "dataValue",
        },
    )
    class GradientStopProperty:
        def __init__(
            self,
            *,
            gradient_offset: jsii.Number,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the gradient stop configuration.

            :param gradient_offset: Determines gradient offset value.
            :param color: Determines the color.
            :param data_value: Determines the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gradient_stop_property = quicksight.CfnTemplate.GradientStopProperty(
                    gradient_offset=123,
                
                    # the properties below are optional
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__015b1dcb0f6e7a9d65caf924c62ede6640cd584bb904886667028b592d7cede6)
                check_type(argname="argument gradient_offset", value=gradient_offset, expected_type=type_hints["gradient_offset"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "gradient_offset": gradient_offset,
            }
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def gradient_offset(self) -> jsii.Number:
            '''Determines gradient offset value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-gradientoffset
            '''
            result = self._values.get("gradient_offset")
            assert result is not None, "Required property 'gradient_offset' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''Determines the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientStopProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class GridLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Configuration options for the canvas of a grid layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                grid_layout_canvas_size_options_property = quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                        resize_option="resizeOption",
                
                        # the properties below are optional
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e58938d73e03b6025c0a575cddae61679efb92a4a8ae44597fe83babd0b3d9da)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty"]]:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutcanvassizeoptions.html#cfn-quicksight-template-gridlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class GridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GridLayoutElementProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a grid layout. Also called a tiled layout.

            Visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size.

            :param elements: The elements that are included in a grid layout.
            :param canvas_size_options: ``CfnTemplate.GridLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                grid_layout_configuration_property = quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                    elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                        column_span=123,
                        element_id="elementId",
                        element_type="elementType",
                        row_span=123,
                
                        # the properties below are optional
                        column_index=123,
                        row_index=123
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__21bc265609484c37c9e13436e7c6cc5d5f9ec43695b283f93355f6f03b676ce7)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GridLayoutElementProperty"]]]:
            '''The elements that are included in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html#cfn-quicksight-template-gridlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GridLayoutElementProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GridLayoutCanvasSizeOptionsProperty"]]:
            '''``CfnTemplate.GridLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html#cfn-quicksight-template-gridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GridLayoutCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GridLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_span": "columnSpan",
            "element_id": "elementId",
            "element_type": "elementType",
            "row_span": "rowSpan",
            "column_index": "columnIndex",
            "row_index": "rowIndex",
        },
    )
    class GridLayoutElementProperty:
        def __init__(
            self,
            *,
            column_span: jsii.Number,
            element_id: builtins.str,
            element_type: builtins.str,
            row_span: jsii.Number,
            column_index: typing.Optional[jsii.Number] = None,
            row_index: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An element within a grid layout.

            :param column_span: The width of a grid element expressed as a number of grid columns.
            :param element_id: A unique identifier for an element within a grid layout.
            :param element_type: The type of element.
            :param row_span: The height of a grid element expressed as a number of grid rows.
            :param column_index: The column index for the upper left corner of an element.
            :param row_index: The row index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                grid_layout_element_property = quicksight.CfnTemplate.GridLayoutElementProperty(
                    column_span=123,
                    element_id="elementId",
                    element_type="elementType",
                    row_span=123,
                
                    # the properties below are optional
                    column_index=123,
                    row_index=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__863f2614b6770ae1b4676c3297edfb57a0e0047dee678ccebc8410e0eddd9634)
                check_type(argname="argument column_span", value=column_span, expected_type=type_hints["column_span"])
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument row_span", value=row_span, expected_type=type_hints["row_span"])
                check_type(argname="argument column_index", value=column_index, expected_type=type_hints["column_index"])
                check_type(argname="argument row_index", value=row_index, expected_type=type_hints["row_index"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_span": column_span,
                "element_id": element_id,
                "element_type": element_type,
                "row_span": row_span,
            }
            if column_index is not None:
                self._values["column_index"] = column_index
            if row_index is not None:
                self._values["row_index"] = row_index

        @builtins.property
        def column_span(self) -> jsii.Number:
            '''The width of a grid element expressed as a number of grid columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-columnspan
            '''
            result = self._values.get("column_span")
            assert result is not None, "Required property 'column_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def row_span(self) -> jsii.Number:
            '''The height of a grid element expressed as a number of grid rows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-rowspan
            '''
            result = self._values.get("row_span")
            assert result is not None, "Required property 'row_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def column_index(self) -> typing.Optional[jsii.Number]:
            '''The column index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-columnindex
            '''
            result = self._values.get("column_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def row_index(self) -> typing.Optional[jsii.Number]:
            '''The row index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-rowindex
            '''
            result = self._values.get("row_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "resize_option": "resizeOption",
            "optimized_view_port_width": "optimizedViewPortWidth",
        },
    )
    class GridLayoutScreenCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            resize_option: builtins.str,
            optimized_view_port_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :param resize_option: This value determines the layout behavior when the viewport is resized. - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` . - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .
            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                grid_layout_screen_canvas_size_options_property = quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                    resize_option="resizeOption",
                
                    # the properties below are optional
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b2d6273484ab22bf05075d65358f1f38554c9cb280c42deb853291616137c3a9)
                check_type(argname="argument resize_option", value=resize_option, expected_type=type_hints["resize_option"])
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "resize_option": resize_option,
            }
            if optimized_view_port_width is not None:
                self._values["optimized_view_port_width"] = optimized_view_port_width

        @builtins.property
        def resize_option(self) -> builtins.str:
            '''This value determines the layout behavior when the viewport is resized.

            - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` .
            - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-template-gridlayoutscreencanvassizeoptions-resizeoption
            '''
            result = self._values.get("resize_option")
            assert result is not None, "Required property 'resize_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def optimized_view_port_width(self) -> typing.Optional[builtins.str]:
            '''The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-template-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.GrowthRateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "period_size": "periodSize",
            "value": "value",
        },
    )
    class GrowthRateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
            period_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The growth rate computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param period_size: The period size setup of a growth rate computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                growth_rate_computation_property = quicksight.CfnTemplate.GrowthRateComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    period_size=123,
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__84701fc23f7aa63650c22ca7d92d199af3ea8567210fc9b9e0bd555f61cebaca)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_size", value=period_size, expected_type=type_hints["period_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if period_size is not None:
                self._values["period_size"] = period_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_size(self) -> typing.Optional[jsii.Number]:
            '''The period size setup of a growth rate computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-periodsize
            '''
            result = self._values.get("period_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GrowthRateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout", "section_id": "sectionId", "style": "style"},
    )
    class HeaderFooterSectionConfigurationProperty:
        def __init__(
            self,
            *,
            layout: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            section_id: builtins.str,
            style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a header or footer section.

            :param layout: The layout configuration of the header or footer section.
            :param section_id: The unique identifier of the header or footer section.
            :param style: The style options of a header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                header_footer_section_configuration_property = quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    style=quicksight.CfnTemplate.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnTemplate.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ef94c3a3e8e7dbabd73669efa7416593fe4f324525684fbb7ff75b11bc48f3a)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "layout": layout,
                "section_id": section_id,
            }
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def layout(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionLayoutConfigurationProperty"]:
            '''The layout configuration of the header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-layout
            '''
            result = self._values.get("layout")
            assert result is not None, "Required property 'layout' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionLayoutConfigurationProperty"], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of the header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionStyleProperty"]]:
            '''The style options of a header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeaderFooterSectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class HeatMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            rows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a heat map.

            :param columns: The columns field well of a heat map.
            :param rows: The rows field well of a heat map.
            :param values: The values field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_aggregated_field_wells_property = quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                    columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a92cdc553c53e5b50a54b9b199c7389fee8d5a4d679470a79157d2e5fa9c08b3)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The columns field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The rows field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The values field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.HeatMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_scale": "colorScale",
            "column_label_options": "columnLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "row_label_options": "rowLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class HeatMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.HeatMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.HeatMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a heat map.

            :param color_scale: The color options (gradient color, point of divergence) in a heat map.
            :param column_label_options: The label options of the column that is displayed in a heat map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param row_label_options: The label options of the row that is displayed in a ``heat map`` .
            :param sort_configuration: The sort configuration of a heat map.
            :param tooltip: The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_configuration_property = quicksight.CfnTemplate.HeatMapConfigurationProperty(
                    color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                        color_fill_type="colorFillType",
                        colors=[quicksight.CfnTemplate.DataColorProperty(
                            color="color",
                            data_value=123
                        )],
                
                        # the properties below are optional
                        null_value_color=quicksight.CfnTemplate.DataColorProperty(
                            color="color",
                            data_value=123
                        )
                    ),
                    column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                        heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                            columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                        heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7072130ce3e4e6a5bdfe8b1eadd9fa3bf74924c9d38b0c9f29152fbfa8e2524b)
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument column_label_options", value=column_label_options, expected_type=type_hints["column_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument row_label_options", value=row_label_options, expected_type=type_hints["row_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if column_label_options is not None:
                self._values["column_label_options"] = column_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if row_label_options is not None:
                self._values["row_label_options"] = row_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColorScaleProperty"]]:
            '''The color options (gradient color, point of divergence) in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColorScaleProperty"]], result)

        @builtins.property
        def column_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the column that is displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-columnlabeloptions
            '''
            result = self._values.get("column_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeatMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeatMapFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def row_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the row that is displayed in a ``heat map`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-rowlabeloptions
            '''
            result = self._values.get("row_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeatMapSortConfigurationProperty"]]:
            '''The sort configuration of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeatMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.HeatMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_aggregated_field_wells": "heatMapAggregatedFieldWells",
        },
    )
    class HeatMapFieldWellsProperty:
        def __init__(
            self,
            *,
            heat_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.HeatMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a heat map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param heat_map_aggregated_field_wells: The aggregated field wells of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_field_wells_property = quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                    heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                        columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8e3fd252e2c5ea63493fbbb7ad5ad1f50b31619097efda5a316e5e9bd9e29c22)
                check_type(argname="argument heat_map_aggregated_field_wells", value=heat_map_aggregated_field_wells, expected_type=type_hints["heat_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_aggregated_field_wells is not None:
                self._values["heat_map_aggregated_field_wells"] = heat_map_aggregated_field_wells

        @builtins.property
        def heat_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeatMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapfieldwells.html#cfn-quicksight-template-heatmapfieldwells-heatmapaggregatedfieldwells
            '''
            result = self._values.get("heat_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeatMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.HeatMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_column_items_limit_configuration": "heatMapColumnItemsLimitConfiguration",
            "heat_map_column_sort": "heatMapColumnSort",
            "heat_map_row_items_limit_configuration": "heatMapRowItemsLimitConfiguration",
            "heat_map_row_sort": "heatMapRowSort",
        },
    )
    class HeatMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            heat_map_column_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_column_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            heat_map_row_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_row_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a heat map.

            :param heat_map_column_items_limit_configuration: The limit on the number of columns that are displayed in a heat map.
            :param heat_map_column_sort: The column sort configuration for heat map for columns that aren't a part of a field well.
            :param heat_map_row_items_limit_configuration: The limit on the number of rows that are displayed in a heat map.
            :param heat_map_row_sort: The field sort configuration of the rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_sort_configuration_property = quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                    heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04122ae3f20b1e55768a6649066c5b1edc2736da800f8d41188f5584b5b55c44)
                check_type(argname="argument heat_map_column_items_limit_configuration", value=heat_map_column_items_limit_configuration, expected_type=type_hints["heat_map_column_items_limit_configuration"])
                check_type(argname="argument heat_map_column_sort", value=heat_map_column_sort, expected_type=type_hints["heat_map_column_sort"])
                check_type(argname="argument heat_map_row_items_limit_configuration", value=heat_map_row_items_limit_configuration, expected_type=type_hints["heat_map_row_items_limit_configuration"])
                check_type(argname="argument heat_map_row_sort", value=heat_map_row_sort, expected_type=type_hints["heat_map_row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_column_items_limit_configuration is not None:
                self._values["heat_map_column_items_limit_configuration"] = heat_map_column_items_limit_configuration
            if heat_map_column_sort is not None:
                self._values["heat_map_column_sort"] = heat_map_column_sort
            if heat_map_row_items_limit_configuration is not None:
                self._values["heat_map_row_items_limit_configuration"] = heat_map_row_items_limit_configuration
            if heat_map_row_sort is not None:
                self._values["heat_map_row_sort"] = heat_map_row_sort

        @builtins.property
        def heat_map_column_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of columns that are displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
            '''
            result = self._values.get("heat_map_column_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def heat_map_column_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The column sort configuration for heat map for columns that aren't a part of a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmapcolumnsort
            '''
            result = self._values.get("heat_map_column_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def heat_map_row_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of rows that are displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
            '''
            result = self._values.get("heat_map_row_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def heat_map_row_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The field sort configuration of the rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmaprowsort
            '''
            result = self._values.get("heat_map_row_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.HeatMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HeatMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.HeatMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a heat map.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                heat_map_visual_property = quicksight.CfnTemplate.HeatMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.HeatMapConfigurationProperty(
                        color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                            color_fill_type="colorFillType",
                            colors=[quicksight.CfnTemplate.DataColorProperty(
                                color="color",
                                data_value=123
                            )],
                
                            # the properties below are optional
                            null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                color="color",
                                data_value=123
                            )
                        ),
                        column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                            heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                                columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                            heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1adc7e1121576aa0e7248feaea0759c096809b66225b10c8ac83a13348bb903c)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeatMapConfigurationProperty"]]:
            '''The configuration of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeatMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class HistogramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param values: The value field wells of a histogram. Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                histogram_aggregated_field_wells_property = quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6610cc9bf6d861a1fb87e7b83ce8035a6bc62879d31a8582f2d0961f6801e114)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a histogram.

            Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramaggregatedfieldwells.html#cfn-quicksight-template-histogramaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.HistogramBinOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_count": "binCount",
            "bin_width": "binWidth",
            "selected_bin_type": "selectedBinType",
            "start_value": "startValue",
        },
    )
    class HistogramBinOptionsProperty:
        def __init__(
            self,
            *,
            bin_count: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BinCountOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            bin_width: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BinWidthOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_bin_type: typing.Optional[builtins.str] = None,
            start_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the presentation of histogram bins.

            :param bin_count: The options that determine the bin count of a histogram.
            :param bin_width: The options that determine the bin width of a histogram.
            :param selected_bin_type: The options that determine the selected bin type.
            :param start_value: The options that determine the bin start value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                histogram_bin_options_property = quicksight.CfnTemplate.HistogramBinOptionsProperty(
                    bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                        value=123
                    ),
                    bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                        bin_count_limit=123,
                        value=123
                    ),
                    selected_bin_type="selectedBinType",
                    start_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5076d846e9250b18e6ccfd809b8b00d737f4db5161e007b30bbcb1705c5e57a)
                check_type(argname="argument bin_count", value=bin_count, expected_type=type_hints["bin_count"])
                check_type(argname="argument bin_width", value=bin_width, expected_type=type_hints["bin_width"])
                check_type(argname="argument selected_bin_type", value=selected_bin_type, expected_type=type_hints["selected_bin_type"])
                check_type(argname="argument start_value", value=start_value, expected_type=type_hints["start_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count is not None:
                self._values["bin_count"] = bin_count
            if bin_width is not None:
                self._values["bin_width"] = bin_width
            if selected_bin_type is not None:
                self._values["selected_bin_type"] = selected_bin_type
            if start_value is not None:
                self._values["start_value"] = start_value

        @builtins.property
        def bin_count(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BinCountOptionsProperty"]]:
            '''The options that determine the bin count of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-bincount
            '''
            result = self._values.get("bin_count")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BinCountOptionsProperty"]], result)

        @builtins.property
        def bin_width(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BinWidthOptionsProperty"]]:
            '''The options that determine the bin width of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-binwidth
            '''
            result = self._values.get("bin_width")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BinWidthOptionsProperty"]], result)

        @builtins.property
        def selected_bin_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the selected bin type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-selectedbintype
            '''
            result = self._values.get("selected_bin_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin start value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-startvalue
            '''
            result = self._values.get("start_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramBinOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.HistogramConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_options": "binOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
        },
    )
    class HistogramConfigurationProperty:
        def __init__(
            self,
            *,
            bin_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.HistogramBinOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.HistogramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``HistogramVisual`` .

            :param bin_options: The options that determine the presentation of histogram bins.
            :param data_labels: The data label configuration of a histogram.
            :param field_wells: The field well configuration of a histogram.
            :param tooltip: The tooltip configuration of a histogram.
            :param visual_palette: The visual palette configuration of a histogram.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.
            :param y_axis_display_options: The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                histogram_configuration_property = quicksight.CfnTemplate.HistogramConfigurationProperty(
                    bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                        bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                            value=123
                        ),
                        bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                            bin_count_limit=123,
                            value=123
                        ),
                        selected_bin_type="selectedBinType",
                        start_value=123
                    ),
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                        histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ef33952bc9141e873fb82a75bbf27bdac0dc32ab34bb5307b25de48b0ca32028)
                check_type(argname="argument bin_options", value=bin_options, expected_type=type_hints["bin_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_options is not None:
                self._values["bin_options"] = bin_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options

        @builtins.property
        def bin_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HistogramBinOptionsProperty"]]:
            '''The options that determine the presentation of histogram bins.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-binoptions
            '''
            result = self._values.get("bin_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HistogramBinOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The data label configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HistogramFieldWellsProperty"]]:
            '''The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HistogramFieldWellsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]]:
            '''The visual palette configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.HistogramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "histogram_aggregated_field_wells": "histogramAggregatedFieldWells",
        },
    )
    class HistogramFieldWellsProperty:
        def __init__(
            self,
            *,
            histogram_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.HistogramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param histogram_aggregated_field_wells: The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                histogram_field_wells_property = quicksight.CfnTemplate.HistogramFieldWellsProperty(
                    histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e0e1783f5b5886123b9f7f7a979f3ae40ea4d890770d70e00ccb502273481771)
                check_type(argname="argument histogram_aggregated_field_wells", value=histogram_aggregated_field_wells, expected_type=type_hints["histogram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if histogram_aggregated_field_wells is not None:
                self._values["histogram_aggregated_field_wells"] = histogram_aggregated_field_wells

        @builtins.property
        def histogram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HistogramAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramfieldwells.html#cfn-quicksight-template-histogramfieldwells-histogramaggregatedfieldwells
            '''
            result = self._values.get("histogram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HistogramAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.HistogramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HistogramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.HistogramConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a ``HistogramVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                histogram_visual_property = quicksight.CfnTemplate.HistogramVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.HistogramConfigurationProperty(
                        bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                            bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                                value=123
                            ),
                            bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                                bin_count_limit=123,
                                value=123
                            ),
                            selected_bin_type="selectedBinType",
                            start_value=123
                        ),
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                            histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        )
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4372e43613ae307237846434dea564d5c862af5e043655fe3e4f02e5139ee9c6)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HistogramConfigurationProperty"]]:
            '''The configuration for a ``HistogramVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HistogramConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.InsightConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computations": "computations",
            "custom_narrative": "customNarrative",
        },
    )
    class InsightConfigurationProperty:
        def __init__(
            self,
            *,
            computations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ComputationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            custom_narrative: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CustomNarrativeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of an insight visual.

            :param computations: The computations configurations of the insight visual.
            :param custom_narrative: The custom narrative of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                insight_configuration_property = quicksight.CfnTemplate.InsightConfigurationProperty(
                    computations=[quicksight.CfnTemplate.ComputationProperty(
                        forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            custom_seasonality_value=123,
                            lower_boundary=123,
                            name="name",
                            periods_backward=123,
                            periods_forward=123,
                            prediction_interval=123,
                            seasonality="seasonality",
                            upper_boundary=123,
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            period_size=123,
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            type="type",
                
                            # the properties below are optional
                            name="name",
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                            computation_id="computationId",
                            from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                            target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name"
                        ),
                        period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            period_time_granularity="periodTimeGranularity",
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            type="type",
                
                            # the properties below are optional
                            mover_size=123,
                            name="name",
                            sort_order="sortOrder",
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                            type="type",
                
                            # the properties below are optional
                            name="name",
                            result_size=123,
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                            computation_id="computationId",
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                
                            # the properties below are optional
                            name="name"
                        ),
                        unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                
                            # the properties below are optional
                            name="name"
                        )
                    )],
                    custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                        narrative="narrative"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6462f9c9234baa859425aae598e4c68d698c2da3517e01a6c4c29d8ae60129f4)
                check_type(argname="argument computations", value=computations, expected_type=type_hints["computations"])
                check_type(argname="argument custom_narrative", value=custom_narrative, expected_type=type_hints["custom_narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if computations is not None:
                self._values["computations"] = computations
            if custom_narrative is not None:
                self._values["custom_narrative"] = custom_narrative

        @builtins.property
        def computations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComputationProperty"]]]]:
            '''The computations configurations of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html#cfn-quicksight-template-insightconfiguration-computations
            '''
            result = self._values.get("computations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComputationProperty"]]]], result)

        @builtins.property
        def custom_narrative(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomNarrativeOptionsProperty"]]:
            '''The custom narrative of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html#cfn-quicksight-template-insightconfiguration-customnarrative
            '''
            result = self._values.get("custom_narrative")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomNarrativeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.InsightVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "insight_configuration": "insightConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class InsightVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            insight_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.InsightConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used in the insight visual.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param insight_configuration: The configuration of an insight visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                insight_visual_property = quicksight.CfnTemplate.InsightVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    insight_configuration=quicksight.CfnTemplate.InsightConfigurationProperty(
                        computations=[quicksight.CfnTemplate.ComputationProperty(
                            forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                custom_seasonality_value=123,
                                lower_boundary=123,
                                name="name",
                                periods_backward=123,
                                periods_forward=123,
                                prediction_interval=123,
                                seasonality="seasonality",
                                upper_boundary=123,
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                period_size=123,
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                type="type",
                
                                # the properties below are optional
                                name="name",
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                                computation_id="computationId",
                                from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                                target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name"
                            ),
                            period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                period_time_granularity="periodTimeGranularity",
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                                category=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                type="type",
                
                                # the properties below are optional
                                mover_size=123,
                                name="name",
                                sort_order="sortOrder",
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                                category=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                                type="type",
                
                                # the properties below are optional
                                name="name",
                                result_size=123,
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                                computation_id="computationId",
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                
                                # the properties below are optional
                                name="name"
                            ),
                            unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                                category=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                
                                # the properties below are optional
                                name="name"
                            )
                        )],
                        custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                            narrative="narrative"
                        )
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a53135c107293ffefdce6f0a7229aff9a8e330a07af447b6f977c5ea0b625eb2)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument insight_configuration", value=insight_configuration, expected_type=type_hints["insight_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if insight_configuration is not None:
                self._values["insight_configuration"] = insight_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used in the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def insight_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.InsightConfigurationProperty"]]:
            '''The configuration of an insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-insightconfiguration
            '''
            result = self._values.get("insight_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.InsightConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.IntegerDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class IntegerDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``IntegerParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``IntegerDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``IntegerDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                integer_default_values_property = quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                    dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a97c9f90f4d058cd8ced529a29db488cd1777d2834bf263b9729245e4cfae595)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``IntegerDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html#cfn-quicksight-template-integerdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]]:
            '''The static values of the ``IntegerDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html#cfn-quicksight-template-integerdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.IntegerParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class IntegerParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.IntegerDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.IntegerValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnTemplate.IntegerParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                integer_parameter_declaration_property = quicksight.CfnTemplate.IntegerParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                        dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ad2f6d533686102b6bdb88d11fc19337f5d96e6da3070acaad65cd9353a6b6f5)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.IntegerDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.IntegerDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MappedDataSetParameterProperty"]]]]:
            '''``CfnTemplate.IntegerParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.IntegerValueWhenUnsetConfigurationProperty"]]:
            '''A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.IntegerValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class IntegerValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                integer_value_when_unset_configuration_property = quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2754edf7b793b1387ebdaaff5a63ebdf6864d3636f19b731a50e14b4a288fad1)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html#cfn-quicksight-template-integervaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html#cfn-quicksight-template-integervaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ItemsLimitConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "items_limit": "itemsLimit",
            "other_categories": "otherCategories",
        },
    )
    class ItemsLimitConfigurationProperty:
        def __init__(
            self,
            *,
            items_limit: typing.Optional[jsii.Number] = None,
            other_categories: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The limit configuration of the visual display for an axis.

            :param items_limit: The limit on how many items of a field are showed in the chart. For example, the number of slices that are displayed in a pie chart.
            :param other_categories: The ``Show other`` of an axis in the chart. Choose one of the following options:. - ``INCLUDE`` - ``EXCLUDE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                items_limit_configuration_property = quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                    items_limit=123,
                    other_categories="otherCategories"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__acc77cfd0baca29acedfc800fa378c5f8bff05c3c31a77f092ab5e290aa9061f)
                check_type(argname="argument items_limit", value=items_limit, expected_type=type_hints["items_limit"])
                check_type(argname="argument other_categories", value=other_categories, expected_type=type_hints["other_categories"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if items_limit is not None:
                self._values["items_limit"] = items_limit
            if other_categories is not None:
                self._values["other_categories"] = other_categories

        @builtins.property
        def items_limit(self) -> typing.Optional[jsii.Number]:
            '''The limit on how many items of a field are showed in the chart.

            For example, the number of slices that are displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html#cfn-quicksight-template-itemslimitconfiguration-itemslimit
            '''
            result = self._values.get("items_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def other_categories(self) -> typing.Optional[builtins.str]:
            '''The ``Show other`` of an axis in the chart. Choose one of the following options:.

            - ``INCLUDE``
            - ``EXCLUDE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html#cfn-quicksight-template-itemslimitconfiguration-othercategories
            '''
            result = self._values.get("other_categories")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ItemsLimitConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"primary_value": "primaryValue", "progress_bar": "progressBar"},
    )
    class KPIConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            primary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.KPIPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            progress_bar: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.KPIProgressBarConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting options of a KPI visual.

            :param primary_value: The conditional formatting for the primary value of a KPI visual.
            :param progress_bar: The conditional formatting for the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIConditional_formatting_option_property = quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                    primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fca720a4c0ae8857ce3d4e947a54506b1a8a1d4c4b5ec2d1d84ce48266a9118d)
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if primary_value is not None:
                self._values["primary_value"] = primary_value
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIPrimaryValueConditionalFormattingProperty"]]:
            '''The conditional formatting for the primary value of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIPrimaryValueConditionalFormattingProperty"]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIProgressBarConditionalFormattingProperty"]]:
            '''The conditional formatting for the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIProgressBarConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.KPIConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class KPIConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.KPIConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting of a KPI visual.

            :param conditional_formatting_options: The conditional formatting options of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIConditional_formatting_property = quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                        primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f6d9049ce24facb977b9736ac502833ee27635adbf2d083a1818ef68d930e93c)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIConditionalFormattingOptionProperty"]]]]:
            '''The conditional formatting options of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformatting.html#cfn-quicksight-template-kpiconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.KPIConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "kpi_options": "kpiOptions",
            "sort_configuration": "sortConfiguration",
        },
    )
    class KPIConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.KPIFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            kpi_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.KPIOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.KPISortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a KPI visual.

            :param field_wells: The field well configuration of a KPI visual.
            :param kpi_options: The options that determine the presentation of a KPI visual.
            :param sort_configuration: The sort configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIConfiguration_property = quicksight.CfnTemplate.KPIConfigurationProperty(
                    field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                        target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                        comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                            comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            comparison_method="comparisonMethod"
                        ),
                        primary_value_display_type="primaryValueDisplayType",
                        primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                            visibility="visibility"
                        ),
                        secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                            visibility="visibility"
                        ),
                        secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                            visibility="visibility"
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                        trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0095f2ed855f00c031073f5a985cd08a3ddf1e41c51003271f6739577d1b5e92)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument kpi_options", value=kpi_options, expected_type=type_hints["kpi_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if kpi_options is not None:
                self._values["kpi_options"] = kpi_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIFieldWellsProperty"]]:
            '''The field well configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIFieldWellsProperty"]], result)

        @builtins.property
        def kpi_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIOptionsProperty"]]:
            '''The options that determine the presentation of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-kpioptions
            '''
            result = self._values.get("kpi_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPISortConfigurationProperty"]]:
            '''The sort configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPISortConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.KPIFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_values": "targetValues",
            "trend_groups": "trendGroups",
            "values": "values",
        },
    )
    class KPIFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            trend_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a KPI visual.

            :param target_values: The target value field wells of a KPI visual.
            :param trend_groups: The trend group field wells of a KPI visual.
            :param values: The value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIField_wells_property = quicksight.CfnTemplate.KPIFieldWellsProperty(
                    target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c70f30261320a94ad217222b1c85836c858fb1be89eb4e0f7ae5bbe6937833b1)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument trend_groups", value=trend_groups, expected_type=type_hints["trend_groups"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if trend_groups is not None:
                self._values["trend_groups"] = trend_groups
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The target value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def trend_groups(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The trend group field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-trendgroups
            '''
            result = self._values.get("trend_groups")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.KPIOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
            "progress_bar": "progressBar",
            "secondary_value": "secondaryValue",
            "secondary_value_font_configuration": "secondaryValueFontConfiguration",
            "trend_arrows": "trendArrows",
        },
    )
    class KPIOptionsProperty:
        def __init__(
            self,
            *,
            comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            progress_bar: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ProgressBarOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SecondaryValueOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            trend_arrows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TrendArrowOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of a KPI visual.

            :param comparison: The comparison configuration of a KPI visual.
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.
            :param progress_bar: The options that determine the presentation of the progress bar of a KPI visual.
            :param secondary_value: The options that determine the presentation of the secondary value of a KPI visual.
            :param secondary_value_font_configuration: The options that determine the secondary value font configuration.
            :param trend_arrows: The options that determine the presentation of trend arrows in a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIOptions_property = quicksight.CfnTemplate.KPIOptionsProperty(
                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0323eedecc56313e0b9f7a00ddba85eb1fff256405499c3140462b65ef072731)
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
                check_type(argname="argument secondary_value", value=secondary_value, expected_type=type_hints["secondary_value"])
                check_type(argname="argument secondary_value_font_configuration", value=secondary_value_font_configuration, expected_type=type_hints["secondary_value_font_configuration"])
                check_type(argname="argument trend_arrows", value=trend_arrows, expected_type=type_hints["trend_arrows"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar
            if secondary_value is not None:
                self._values["secondary_value"] = secondary_value
            if secondary_value_font_configuration is not None:
                self._values["secondary_value_font_configuration"] = secondary_value_font_configuration
            if trend_arrows is not None:
                self._values["trend_arrows"] = trend_arrows

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComparisonConfigurationProperty"]]:
            '''The comparison configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComparisonConfigurationProperty"]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]]:
            '''The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ProgressBarOptionsProperty"]]:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ProgressBarOptionsProperty"]], result)

        @builtins.property
        def secondary_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SecondaryValueOptionsProperty"]]:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-secondaryvalue
            '''
            result = self._values.get("secondary_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SecondaryValueOptionsProperty"]], result)

        @builtins.property
        def secondary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]]:
            '''The options that determine the secondary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-secondaryvaluefontconfiguration
            '''
            result = self._values.get("secondary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def trend_arrows(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TrendArrowOptionsProperty"]]:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-trendarrows
            '''
            result = self._values.get("trend_arrows")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TrendArrowOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a KPI visual.

            :param icon: The conditional formatting of the primary value's icon.
            :param text_color: The conditional formatting of the primary value's text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIPrimary_value_conditional_formatting_property = quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fb5836e50d3abc34aeb960a6bd9c5bd367487eade59f8c826b0b15a6d7da1300)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting of the primary value's icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-template-kpiprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the primary value's text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-template-kpiprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class KPIProgressBarConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the progress bar of a KPI visual.

            :param foreground_color: The conditional formatting of the progress bar's foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprogressbarconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIProgress_bar_conditional_formatting_property = quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                    foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f2e21288bd12931fe08ca6ce7a3c71751c3df19c811d3ed14c124668595bc0ca)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting of the progress bar's foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprogressbarconditionalformatting.html#cfn-quicksight-template-kpiprogressbarconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIProgressBarConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.KPISortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"trend_group_sort": "trendGroupSort"},
    )
    class KPISortConfigurationProperty:
        def __init__(
            self,
            *,
            trend_group_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a KPI visual.

            :param trend_group_sort: The sort configuration of the trend group fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pISort_configuration_property = quicksight.CfnTemplate.KPISortConfigurationProperty(
                    trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33b253eb7e7045b9964ff7f2bf4545674c95e2d1c85e6f1b6ce76020d0127637)
                check_type(argname="argument trend_group_sort", value=trend_group_sort, expected_type=type_hints["trend_group_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if trend_group_sort is not None:
                self._values["trend_group_sort"] = trend_group_sort

        @builtins.property
        def trend_group_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the trend group fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisortconfiguration.html#cfn-quicksight-template-kpisortconfiguration-trendgroupsort
            '''
            result = self._values.get("trend_group_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPISortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.KPIVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class KPIVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.KPIConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.KPIConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a KPI visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a KPI visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                k_pIVisual_property = quicksight.CfnTemplate.KPIVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.KPIConfigurationProperty(
                        field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                            target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                            comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                comparison_method="comparisonMethod"
                            ),
                            primary_value_display_type="primaryValueDisplayType",
                            primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                                visibility="visibility"
                            ),
                            secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                                visibility="visibility"
                            ),
                            secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                                visibility="visibility"
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                            trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    conditional_formatting=quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                            primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            ),
                            progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                                foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fc97e42c3914fad54bc7f9471e0c125ae623dbf7f3d431f0b7d9756dcf27da4c)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIConfigurationProperty"]]:
            '''The configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIConditionalFormattingProperty"]]:
            '''The conditional formatting of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
            "visibility": "visibility",
        },
    )
    class LabelOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The share label options for the labels.

            :param custom_label: The text for the label.
            :param font_configuration: The font configuration of the label.
            :param visibility: Determines whether or not the label is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                label_options_property = quicksight.CfnTemplate.LabelOptionsProperty(
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a1fb861f9ad7ece5edf93e8aba2af0f9c5c9b0fa3434651e1c9ab80d89d5423)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]]:
            '''The font configuration of the label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the label is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "free_form_layout": "freeFormLayout",
            "grid_layout": "gridLayout",
            "section_based_layout": "sectionBasedLayout",
        },
    )
    class LayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            grid_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            section_based_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration that determines what the type of layout will be used on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param free_form_layout: A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
            :param grid_layout: A type of layout that can be used on a sheet. In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .
            :param section_based_layout: A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                layout_configuration_property = quicksight.CfnTemplate.LayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                        body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                            content=quicksight.CfnTemplate.BodySectionContentProperty(
                                layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                    status="status"
                                )
                            ),
                            style=quicksight.CfnTemplate.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        ),
                        footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnTemplate.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnTemplate.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__48567ce06ab8f4438ea3c57029063c6be2a1acce544a3890f1a95ca30da121a9)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
                check_type(argname="argument section_based_layout", value=section_based_layout, expected_type=type_hints["section_based_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form_layout is not None:
                self._values["free_form_layout"] = free_form_layout
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout
            if section_based_layout is not None:
                self._values["section_based_layout"] = section_based_layout

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutConfigurationProperty"]]:
            '''A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormLayoutConfigurationProperty"]], result)

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GridLayoutConfigurationProperty"]]:
            '''A type of layout that can be used on a sheet.

            In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GridLayoutConfigurationProperty"]], result)

        @builtins.property
        def section_based_layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionBasedLayoutConfigurationProperty"]]:
            '''A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-sectionbasedlayout
            '''
            result = self._values.get("section_based_layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionBasedLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class LayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A ``Layout`` defines the placement of elements within a sheet.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param configuration: The configuration that determines what the type of layout for a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                layout_property = quicksight.CfnTemplate.LayoutProperty(
                    configuration=quicksight.CfnTemplate.LayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                            body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                                content=quicksight.CfnTemplate.BodySectionContentProperty(
                                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                    after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                        status="status"
                                    )
                                ),
                                style=quicksight.CfnTemplate.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            ),
                            footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnTemplate.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnTemplate.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__504be645140d32a6a7fd5a6f055896fb69f4ea60c2856694cc4c2dc535b5f433)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LayoutConfigurationProperty"]:
            '''The configuration that determines what the type of layout for a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layout.html#cfn-quicksight-template-layout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LegendOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "height": "height",
            "position": "position",
            "title": "title",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class LegendOptionsProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for the legend setup of a visual.

            :param height: The height of the legend. If this value is omitted, a default height is used when rendering.
            :param position: The positions for the legend. Choose one of the following options:. - ``AUTO`` - ``RIGHT`` - ``BOTTOM`` - ``LEFT``
            :param title: The custom title for the legend.
            :param visibility: Determines whether or not the legend is visible.
            :param width: The width of the legend. If this value is omitted, a default width is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                legend_options_property = quicksight.CfnTemplate.LegendOptionsProperty(
                    height="height",
                    position="position",
                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c0e4676ff7adb314ff2f71defb32730779226e61104cf1971386c7a8b56f0bee)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if position is not None:
                self._values["position"] = position
            if title is not None:
                self._values["title"] = title
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of the legend.

            If this value is omitted, a default height is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''The positions for the legend. Choose one of the following options:.

            - ``AUTO``
            - ``RIGHT``
            - ``BOTTOM``
            - ``LEFT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]]:
            '''The custom title for the legend.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the legend is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the legend.

            If this value is omitted, a default width is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LegendOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class LineChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param category: The category field wells of a line chart. Values are grouped by category fields.
            :param colors: The color field wells of a line chart. Values are grouped by category fields.
            :param small_multiples: The small multiples field well of a line chart.
            :param values: The value field wells of a line chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_aggregated_field_wells_property = quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6ccf66b798df838b19dc69c3f32211fca45de84f681d3b3ae9c99ba959238801)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The category field wells of a line chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The color field wells of a line chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a line chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LineChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "default_series_settings": "defaultSeriesSettings",
            "field_wells": "fieldWells",
            "forecast_configurations": "forecastConfigurations",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "series": "series",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "type": "type",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
        },
    )
    class LineChartConfigurationProperty:
        def __init__(
            self,
            *,
            contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            default_series_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineChartDefaultSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            forecast_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ForecastConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            series: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a line chart.

            :param contribution_analysis_defaults: The default configuration of a line chart's contribution analysis.
            :param data_labels: The data label configuration of a line chart.
            :param default_series_settings: The options that determine the default presentation of all line series in ``LineChartVisual`` .
            :param field_wells: The field well configuration of a line chart.
            :param forecast_configurations: The forecast configuration of a line chart.
            :param legend: The legend configuration of a line chart.
            :param primary_y_axis_display_options: The series axis configuration of a line chart.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param reference_lines: The reference lines configuration of a line chart.
            :param secondary_y_axis_display_options: The series axis configuration of a line chart.
            :param secondary_y_axis_label_options: The options that determine the presentation of the secondary y-axis label.
            :param series: The series item configuration of a line chart.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a line chart.
            :param tooltip: The tooltip configuration of a line chart.
            :param type: Determines the type of the line chart.
            :param visual_palette: The visual palette configuration of a line chart.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_chart_configuration_property = quicksight.CfnTemplate.LineChartConfigurationProperty(
                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                        axis_binding="axisBinding",
                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    ),
                    field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                        line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                        forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                            lower_boundary=123,
                            periods_backward=123,
                            periods_forward=123,
                            prediction_interval=123,
                            seasonality=123,
                            upper_boundary=123
                        ),
                        scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                            what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                date="date",
                                value=123
                            ),
                            what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                end_date="endDate",
                                start_date="startDate",
                                value=123
                            )
                        )
                    )],
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                        axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                            treatment_option="treatmentOption"
                        )]
                    ),
                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                        axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                            treatment_option="treatmentOption"
                        )]
                    ),
                    secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    series=[quicksight.CfnTemplate.SeriesItemProperty(
                        data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                            axis_binding="axisBinding",
                            field_id="fieldId",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            )
                        ),
                        field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                            axis_binding="axisBinding",
                            field_id="fieldId",
                
                            # the properties below are optional
                            settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            )
                        )
                    )],
                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                        category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    type="type",
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a28a2370876a149246e9baab467b2be66e23cd80014e99a45766b1e754262441)
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument default_series_settings", value=default_series_settings, expected_type=type_hints["default_series_settings"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument forecast_configurations", value=forecast_configurations, expected_type=type_hints["forecast_configurations"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument series", value=series, expected_type=type_hints["series"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if default_series_settings is not None:
                self._values["default_series_settings"] = default_series_settings
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if forecast_configurations is not None:
                self._values["forecast_configurations"] = forecast_configurations
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if series is not None:
                self._values["series"] = series
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if type is not None:
                self._values["type"] = type
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ContributionAnalysisDefaultProperty"]]]]:
            '''The default configuration of a line chart's contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The data label configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def default_series_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartDefaultSeriesSettingsProperty"]]:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-defaultseriessettings
            '''
            result = self._values.get("default_series_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartDefaultSeriesSettingsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartFieldWellsProperty"]]:
            '''The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartFieldWellsProperty"]], result)

        @builtins.property
        def forecast_configurations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ForecastConfigurationProperty"]]]]:
            '''The forecast configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-forecastconfigurations
            '''
            result = self._values.get("forecast_configurations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ForecastConfigurationProperty"]]]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineSeriesAxisDisplayOptionsProperty"]]:
            '''The series axis configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineSeriesAxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineProperty"]]]]:
            '''The reference lines configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineProperty"]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineSeriesAxisDisplayOptionsProperty"]]:
            '''The series axis configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineSeriesAxisDisplayOptionsProperty"]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the secondary y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def series(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SeriesItemProperty"]]]]:
            '''The series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-series
            '''
            result = self._values.get("series")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SeriesItemProperty"]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartSortConfigurationProperty"]]:
            '''The sort configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Determines the type of the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]]:
            '''The visual palette configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartDefaultSeriesSettingsProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            line_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            marker_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :param axis_binding: The axis to which you are binding all line series to.
            :param line_style_settings: Line styles options for all line series in the visual.
            :param marker_style_settings: Marker styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_default_series_settings_property = quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                    axis_binding="axisBinding",
                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__121e7f03f9327779047c46584816c36d7cc3cca1ee8605090357810780c17997)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis to which you are binding all line series to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartLineStyleSettingsProperty"]]:
            '''Line styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartLineStyleSettingsProperty"]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartMarkerStyleSettingsProperty"]]:
            '''Marker styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartMarkerStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartDefaultSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LineChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_chart_aggregated_field_wells": "lineChartAggregatedFieldWells",
        },
    )
    class LineChartFieldWellsProperty:
        def __init__(
            self,
            *,
            line_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param line_chart_aggregated_field_wells: The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_field_wells_property = quicksight.CfnTemplate.LineChartFieldWellsProperty(
                    line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__317d18f262fabf4c4d25c2b562f978a4ce604f55dbedcecf2e2d1f2a9023a857)
                check_type(argname="argument line_chart_aggregated_field_wells", value=line_chart_aggregated_field_wells, expected_type=type_hints["line_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_chart_aggregated_field_wells is not None:
                self._values["line_chart_aggregated_field_wells"] = line_chart_aggregated_field_wells

        @builtins.property
        def line_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartfieldwells.html#cfn-quicksight-template-linechartfieldwells-linechartaggregatedfieldwells
            '''
            result = self._values.get("line_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LineChartLineStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_interpolation": "lineInterpolation",
            "line_style": "lineStyle",
            "line_visibility": "lineVisibility",
            "line_width": "lineWidth",
        },
    )
    class LineChartLineStyleSettingsProperty:
        def __init__(
            self,
            *,
            line_interpolation: typing.Optional[builtins.str] = None,
            line_style: typing.Optional[builtins.str] = None,
            line_visibility: typing.Optional[builtins.str] = None,
            line_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :param line_interpolation: Interpolation style for line series. - ``LINEAR`` : Show as default, linear style. - ``SMOOTH`` : Show as a smooth curve. - ``STEPPED`` : Show steps in line.
            :param line_style: Line style for line series. - ``SOLID`` : Show as a solid line. - ``DOTTED`` : Show as a dotted line. - ``DASHED`` : Show as a dashed line.
            :param line_visibility: Configuration option that determines whether to show the line for the series.
            :param line_width: Width that determines the line thickness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_line_style_settings_property = quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                    line_interpolation="lineInterpolation",
                    line_style="lineStyle",
                    line_visibility="lineVisibility",
                    line_width="lineWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dcf29ed0eed8563f3b9d3a5066a71502b30fd80da85fb2fe1a37c9965233de02)
                check_type(argname="argument line_interpolation", value=line_interpolation, expected_type=type_hints["line_interpolation"])
                check_type(argname="argument line_style", value=line_style, expected_type=type_hints["line_style"])
                check_type(argname="argument line_visibility", value=line_visibility, expected_type=type_hints["line_visibility"])
                check_type(argname="argument line_width", value=line_width, expected_type=type_hints["line_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_interpolation is not None:
                self._values["line_interpolation"] = line_interpolation
            if line_style is not None:
                self._values["line_style"] = line_style
            if line_visibility is not None:
                self._values["line_visibility"] = line_visibility
            if line_width is not None:
                self._values["line_width"] = line_width

        @builtins.property
        def line_interpolation(self) -> typing.Optional[builtins.str]:
            '''Interpolation style for line series.

            - ``LINEAR`` : Show as default, linear style.
            - ``SMOOTH`` : Show as a smooth curve.
            - ``STEPPED`` : Show steps in line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-lineinterpolation
            '''
            result = self._values.get("line_interpolation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style(self) -> typing.Optional[builtins.str]:
            '''Line style for line series.

            - ``SOLID`` : Show as a solid line.
            - ``DOTTED`` : Show as a dotted line.
            - ``DASHED`` : Show as a dashed line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linestyle
            '''
            result = self._values.get("line_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the line for the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linevisibility
            '''
            result = self._values.get("line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_width(self) -> typing.Optional[builtins.str]:
            '''Width that determines the line thickness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linewidth
            '''
            result = self._values.get("line_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartLineStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "marker_color": "markerColor",
            "marker_shape": "markerShape",
            "marker_size": "markerSize",
            "marker_visibility": "markerVisibility",
        },
    )
    class LineChartMarkerStyleSettingsProperty:
        def __init__(
            self,
            *,
            marker_color: typing.Optional[builtins.str] = None,
            marker_shape: typing.Optional[builtins.str] = None,
            marker_size: typing.Optional[builtins.str] = None,
            marker_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :param marker_color: Color of marker in the series.
            :param marker_shape: Shape option for markers in the series. - ``CIRCLE`` : Show marker as a circle. - ``TRIANGLE`` : Show marker as a triangle. - ``SQUARE`` : Show marker as a square. - ``DIAMOND`` : Show marker as a diamond. - ``ROUNDED_SQUARE`` : Show marker as a rounded square.
            :param marker_size: Size of marker in the series.
            :param marker_visibility: Configuration option that determines whether to show the markers in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_marker_style_settings_property = quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                    marker_color="markerColor",
                    marker_shape="markerShape",
                    marker_size="markerSize",
                    marker_visibility="markerVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__89a0f588beb1fc026b2b73e32f2d4cab0b2e966d50d1a75dd56dcb55b5c3e67b)
                check_type(argname="argument marker_color", value=marker_color, expected_type=type_hints["marker_color"])
                check_type(argname="argument marker_shape", value=marker_shape, expected_type=type_hints["marker_shape"])
                check_type(argname="argument marker_size", value=marker_size, expected_type=type_hints["marker_size"])
                check_type(argname="argument marker_visibility", value=marker_visibility, expected_type=type_hints["marker_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if marker_color is not None:
                self._values["marker_color"] = marker_color
            if marker_shape is not None:
                self._values["marker_shape"] = marker_shape
            if marker_size is not None:
                self._values["marker_size"] = marker_size
            if marker_visibility is not None:
                self._values["marker_visibility"] = marker_visibility

        @builtins.property
        def marker_color(self) -> typing.Optional[builtins.str]:
            '''Color of marker in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markercolor
            '''
            result = self._values.get("marker_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_shape(self) -> typing.Optional[builtins.str]:
            '''Shape option for markers in the series.

            - ``CIRCLE`` : Show marker as a circle.
            - ``TRIANGLE`` : Show marker as a triangle.
            - ``SQUARE`` : Show marker as a square.
            - ``DIAMOND`` : Show marker as a diamond.
            - ``ROUNDED_SQUARE`` : Show marker as a rounded square.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markershape
            '''
            result = self._values.get("marker_shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_size(self) -> typing.Optional[builtins.str]:
            '''Size of marker in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markersize
            '''
            result = self._values.get("marker_size")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the markers in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markervisibility
            '''
            result = self._values.get("marker_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartMarkerStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LineChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            line_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            marker_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the presentation of a line series in the visual.

            :param line_style_settings: Line styles options for a line series in ``LineChartVisual`` .
            :param marker_style_settings: Marker styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_series_settings_property = quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ca3e5aba20762e5e684de205be7b571ba029a30082c04622b99428617fe268df)
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartLineStyleSettingsProperty"]]:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html#cfn-quicksight-template-linechartseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartLineStyleSettingsProperty"]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartMarkerStyleSettingsProperty"]]:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html#cfn-quicksight-template-linechartseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartMarkerStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LineChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit_configuration": "categoryItemsLimitConfiguration",
            "category_sort": "categorySort",
            "color_items_limit_configuration": "colorItemsLimitConfiguration",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class LineChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a line chart.

            :param category_items_limit_configuration: The limit on the number of categories that are displayed in a line chart.
            :param category_sort: The sort configuration of the category fields.
            :param color_items_limit_configuration: The limit on the number of lines that are displayed in a line chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                line_chart_sort_configuration_property = quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                    category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b66bbc318f7c3a7ab6bcbd9470383cade2262c582d43e45e9b5bce50c1e59219)
                check_type(argname="argument category_items_limit_configuration", value=category_items_limit_configuration, expected_type=type_hints["category_items_limit_configuration"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit_configuration", value=color_items_limit_configuration, expected_type=type_hints["color_items_limit_configuration"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit_configuration is not None:
                self._values["category_items_limit_configuration"] = category_items_limit_configuration
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit_configuration is not None:
                self._values["color_items_limit_configuration"] = color_items_limit_configuration
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories that are displayed in a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-categoryitemslimitconfiguration
            '''
            result = self._values.get("category_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of lines that are displayed in a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-coloritemslimitconfiguration
            '''
            result = self._values.get("color_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LineChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class LineChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a line chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_chart_visual_property = quicksight.CfnTemplate.LineChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.LineChartConfigurationProperty(
                        contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                            axis_binding="axisBinding",
                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        ),
                        field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                            line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                            forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                                lower_boundary=123,
                                periods_backward=123,
                                periods_forward=123,
                                prediction_interval=123,
                                seasonality=123,
                                upper_boundary=123
                            ),
                            scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                                what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                    date="date",
                                    value=123
                                ),
                                what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                    end_date="endDate",
                                    start_date="startDate",
                                    value=123
                                )
                            )
                        )],
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                            axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                treatment_option="treatmentOption"
                            )]
                        ),
                        primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                            data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                            axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                treatment_option="treatmentOption"
                            )]
                        ),
                        secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        series=[quicksight.CfnTemplate.SeriesItemProperty(
                            data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                                axis_binding="axisBinding",
                                field_id="fieldId",
                
                                # the properties below are optional
                                field_value="fieldValue",
                                settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                )
                            ),
                            field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                                axis_binding="axisBinding",
                                field_id="fieldId",
                
                                # the properties below are optional
                                settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                )
                            )
                        )],
                        small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                            category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        type="type",
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__36484ddac8fa54bbb02c3c090ea6ec08b427bc05d77d268432e021722c24a396)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartConfigurationProperty"]]:
            '''The configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_options": "axisOptions",
            "missing_data_configurations": "missingDataConfigurations",
        },
    )
    class LineSeriesAxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            missing_data_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MissingDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The series axis configuration of a line chart.

            :param axis_options: The options that determine the presentation of the line series axis.
            :param missing_data_configurations: The configuration options that determine how missing data is treated during the rendering of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_series_axis_display_options_property = quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                    axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                        treatment_option="treatmentOption"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fdabfa0c37dcb1c5639059703a6dee0b545440338e261e1d6f3b2b11bf63e629)
                check_type(argname="argument axis_options", value=axis_options, expected_type=type_hints["axis_options"])
                check_type(argname="argument missing_data_configurations", value=missing_data_configurations, expected_type=type_hints["missing_data_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_options is not None:
                self._values["axis_options"] = axis_options
            if missing_data_configurations is not None:
                self._values["missing_data_configurations"] = missing_data_configurations

        @builtins.property
        def axis_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the line series axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html#cfn-quicksight-template-lineseriesaxisdisplayoptions-axisoptions
            '''
            result = self._values.get("axis_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def missing_data_configurations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MissingDataConfigurationProperty"]]]]:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html#cfn-quicksight-template-lineseriesaxisdisplayoptions-missingdataconfigurations
            '''
            result = self._values.get("missing_data_configurations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MissingDataConfigurationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineSeriesAxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ListControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "search_options": "searchOptions",
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class ListControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            search_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ListControlSearchOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param search_options: The configuration of the search options in a list control.
            :param select_all_options: The configuration of the ``Select all`` options in a list control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                list_control_display_options_property = quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                    search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                        visibility="visibility"
                    ),
                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__85307f8b0ffa316b10f6265fda4919aada7e4f84dce18bdfad4e03774aa7d3f3)
                check_type(argname="argument search_options", value=search_options, expected_type=type_hints["search_options"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if search_options is not None:
                self._values["search_options"] = search_options
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def search_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ListControlSearchOptionsProperty"]]:
            '''The configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-searchoptions
            '''
            result = self._values.get("search_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ListControlSearchOptionsProperty"]], result)

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ListControlSelectAllOptionsProperty"]]:
            '''The configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ListControlSelectAllOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ListControlSearchOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSearchOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the search options in a list control.

            :param visibility: The visibility configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolsearchoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                list_control_search_options_property = quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec5b714d61e0dc89447102d54b30b7b888260342ce9f96464ccfc6c3125d75ea)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolsearchoptions.html#cfn-quicksight-template-listcontrolsearchoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSearchOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ListControlSelectAllOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSelectAllOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the ``Select all`` options in a list control.

            :param visibility: The visibility configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolselectalloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                list_control_select_all_options_property = quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a0abeb54c7dd4d269d172c461bf1348eef16fef9a6f135b1921c9431094e1c7d)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolselectalloptions.html#cfn-quicksight-template-listcontrolselectalloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSelectAllOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LoadingAnimationProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class LoadingAnimationProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of loading animation in free-form layout.

            :param visibility: The visibility configuration of ``LoadingAnimation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-loadinganimation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                loading_animation_property = quicksight.CfnTemplate.LoadingAnimationProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__10b8a84c08a0f4fa62e19db1efdb1c82205c4e7575540c19468957360f00994d)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of ``LoadingAnimation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-loadinganimation.html#cfn-quicksight-template-loadinganimation-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LoadingAnimationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LocalNavigationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"target_sheet_id": "targetSheetId"},
    )
    class LocalNavigationConfigurationProperty:
        def __init__(self, *, target_sheet_id: builtins.str) -> None:
            '''The navigation configuration for ``CustomActionNavigationOperation`` .

            :param target_sheet_id: The sheet that is targeted for navigation in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-localnavigationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                local_navigation_configuration_property = quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                    target_sheet_id="targetSheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__313d38638c0e10fc3c75ba94b57a69d64c9edc4eef729cb86a04df056f125ceb)
                check_type(argname="argument target_sheet_id", value=target_sheet_id, expected_type=type_hints["target_sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "target_sheet_id": target_sheet_id,
            }

        @builtins.property
        def target_sheet_id(self) -> builtins.str:
            '''The sheet that is targeted for navigation in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-localnavigationconfiguration.html#cfn-quicksight-template-localnavigationconfiguration-targetsheetid
            '''
            result = self._values.get("target_sheet_id")
            assert result is not None, "Required property 'target_sheet_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LocalNavigationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.LongFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class LongFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for a subtitle.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                long_format_text_property = quicksight.CfnTemplate.LongFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d11adbd6a79fdd9da8536fe5ac63207af0b758d4acab898c47d4fbcc1f7c0395)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html#cfn-quicksight-template-longformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html#cfn-quicksight-template-longformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LongFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.MappedDataSetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "data_set_parameter_name": "dataSetParameterName",
        },
    )
    class MappedDataSetParameterProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            data_set_parameter_name: builtins.str,
        ) -> None:
            '''
            :param data_set_identifier: ``CfnTemplate.MappedDataSetParameterProperty.DataSetIdentifier``.
            :param data_set_parameter_name: ``CfnTemplate.MappedDataSetParameterProperty.DataSetParameterName``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                mapped_data_set_parameter_property = quicksight.CfnTemplate.MappedDataSetParameterProperty(
                    data_set_identifier="dataSetIdentifier",
                    data_set_parameter_name="dataSetParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f158c328ee5ded448e6a5cec1001e528a04907ba9679324484373ce3ac48c922)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument data_set_parameter_name", value=data_set_parameter_name, expected_type=type_hints["data_set_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "data_set_parameter_name": data_set_parameter_name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''``CfnTemplate.MappedDataSetParameterProperty.DataSetIdentifier``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html#cfn-quicksight-template-mappeddatasetparameter-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_parameter_name(self) -> builtins.str:
            '''``CfnTemplate.MappedDataSetParameterProperty.DataSetParameterName``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html#cfn-quicksight-template-mappeddatasetparameter-datasetparametername
            '''
            result = self._values.get("data_set_parameter_name")
            assert result is not None, "Required property 'data_set_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MappedDataSetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.MaximumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MaximumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The maximum label of a data path label.

            :param visibility: The visibility of the maximum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                maximum_label_type_property = quicksight.CfnTemplate.MaximumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c070aecc1c4e14ca10c74181daac36d896d586b0053828ad3d340580c25a6f94)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the maximum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumlabeltype.html#cfn-quicksight-template-maximumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.MaximumMinimumComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "type": "type",
            "name": "name",
            "value": "value",
        },
    )
    class MaximumMinimumComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The maximum and minimum computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param type: The type of computation. Choose one of the following options:. - MAXIMUM: A maximum computation. - MINIMUM: A minimum computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                maximum_minimum_computation_property = quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c5678ff7029f08a14dfb053eafdb8975c70f84f07d40b4e20a973534acaefd0)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"], result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of computation. Choose one of the following options:.

            - MAXIMUM: A maximum computation.
            - MINIMUM: A minimum computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumMinimumComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.MeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculated_measure_field": "calculatedMeasureField",
            "categorical_measure_field": "categoricalMeasureField",
            "date_measure_field": "dateMeasureField",
            "numerical_measure_field": "numericalMeasureField",
        },
    )
    class MeasureFieldProperty:
        def __init__(
            self,
            *,
            calculated_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CalculatedMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            categorical_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CategoricalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            date_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DateMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numerical_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure (metric) type field.

            :param calculated_measure_field: The calculated measure field only used in pivot tables.
            :param categorical_measure_field: The measure type field with categorical type columns.
            :param date_measure_field: The measure type field with date type columns.
            :param numerical_measure_field: The measure type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                measure_field_property = quicksight.CfnTemplate.MeasureFieldProperty(
                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                        expression="expression",
                        field_id="fieldId"
                    ),
                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__60df1a815fc1857fb068fc71edfec6e462093abd7430f2f3967dfb40e6e171e6)
                check_type(argname="argument calculated_measure_field", value=calculated_measure_field, expected_type=type_hints["calculated_measure_field"])
                check_type(argname="argument categorical_measure_field", value=categorical_measure_field, expected_type=type_hints["categorical_measure_field"])
                check_type(argname="argument date_measure_field", value=date_measure_field, expected_type=type_hints["date_measure_field"])
                check_type(argname="argument numerical_measure_field", value=numerical_measure_field, expected_type=type_hints["numerical_measure_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if calculated_measure_field is not None:
                self._values["calculated_measure_field"] = calculated_measure_field
            if categorical_measure_field is not None:
                self._values["categorical_measure_field"] = categorical_measure_field
            if date_measure_field is not None:
                self._values["date_measure_field"] = date_measure_field
            if numerical_measure_field is not None:
                self._values["numerical_measure_field"] = numerical_measure_field

        @builtins.property
        def calculated_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CalculatedMeasureFieldProperty"]]:
            '''The calculated measure field only used in pivot tables.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-calculatedmeasurefield
            '''
            result = self._values.get("calculated_measure_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CalculatedMeasureFieldProperty"]], result)

        @builtins.property
        def categorical_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CategoricalMeasureFieldProperty"]]:
            '''The measure type field with categorical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-categoricalmeasurefield
            '''
            result = self._values.get("categorical_measure_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CategoricalMeasureFieldProperty"]], result)

        @builtins.property
        def date_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateMeasureFieldProperty"]]:
            '''The measure type field with date type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-datemeasurefield
            '''
            result = self._values.get("date_measure_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateMeasureFieldProperty"]], result)

        @builtins.property
        def numerical_measure_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericalMeasureFieldProperty"]]:
            '''The measure type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-numericalmeasurefield
            '''
            result = self._values.get("numerical_measure_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericalMeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.MetricComparisonComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "from_value": "fromValue",
            "target_value": "targetValue",
            "time": "time",
            "name": "name",
        },
    )
    class MetricComparisonComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            from_value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            target_value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The metric comparison computation configuration.

            :param computation_id: The ID for a computation.
            :param from_value: The field that is used in a metric comparison from value setup.
            :param target_value: The field that is used in a metric comparison to value setup.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                metric_comparison_computation_property = quicksight.CfnTemplate.MetricComparisonComputationProperty(
                    computation_id="computationId",
                    from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                    target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9cc0fce1e439b8b098f4ba0e5a329c153940802785d2e2a3182cab55609137df)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument from_value", value=from_value, expected_type=type_hints["from_value"])
                check_type(argname="argument target_value", value=target_value, expected_type=type_hints["target_value"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "from_value": from_value,
                "target_value": target_value,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def from_value(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]:
            '''The field that is used in a metric comparison from value setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-fromvalue
            '''
            result = self._values.get("from_value")
            assert result is not None, "Required property 'from_value' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"], result)

        @builtins.property
        def target_value(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]:
            '''The field that is used in a metric comparison to value setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-targetvalue
            '''
            result = self._values.get("target_value")
            assert result is not None, "Required property 'target_value' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MetricComparisonComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.MinimumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MinimumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The minimum label of a data path label.

            :param visibility: The visibility of the minimum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-minimumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                minimum_label_type_property = quicksight.CfnTemplate.MinimumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce3e4b27390623a5fea91f88938f39a2661b870a476ab82e79f1c722bd4fdb43)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the minimum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-minimumlabeltype.html#cfn-quicksight-template-minimumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MinimumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.MissingDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"treatment_option": "treatmentOption"},
    )
    class MissingDataConfigurationProperty:
        def __init__(
            self,
            *,
            treatment_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :param treatment_option: The treatment option that determines how missing data should be rendered. Choose from the following options:. - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value. - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` . - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-missingdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                missing_data_configuration_property = quicksight.CfnTemplate.MissingDataConfigurationProperty(
                    treatment_option="treatmentOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a29c7b80f03bc691c706579b3fbc4dbd104d89933402b11e99b318b89bead604)
                check_type(argname="argument treatment_option", value=treatment_option, expected_type=type_hints["treatment_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if treatment_option is not None:
                self._values["treatment_option"] = treatment_option

        @builtins.property
        def treatment_option(self) -> typing.Optional[builtins.str]:
            '''The treatment option that determines how missing data should be rendered. Choose from the following options:.

            - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value.
            - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` .
            - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-missingdataconfiguration.html#cfn-quicksight-template-missingdataconfiguration-treatmentoption
            '''
            result = self._values.get("treatment_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MissingDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NegativeValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"display_mode": "displayMode"},
    )
    class NegativeValueConfigurationProperty:
        def __init__(self, *, display_mode: builtins.str) -> None:
            '''The options that determine the negative value configuration.

            :param display_mode: Determines the display mode of the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-negativevalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                negative_value_configuration_property = quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                    display_mode="displayMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c7ea6f072086a7438b043928ce4104949a1591aa69f7d41590b44c3d030a8390)
                check_type(argname="argument display_mode", value=display_mode, expected_type=type_hints["display_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "display_mode": display_mode,
            }

        @builtins.property
        def display_mode(self) -> builtins.str:
            '''Determines the display mode of the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-negativevalueconfiguration.html#cfn-quicksight-template-negativevalueconfiguration-displaymode
            '''
            result = self._values.get("display_mode")
            assert result is not None, "Required property 'display_mode' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NegativeValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NullValueFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"null_string": "nullString"},
    )
    class NullValueFormatConfigurationProperty:
        def __init__(self, *, null_string: builtins.str) -> None:
            '''The options that determine the null value format configuration.

            :param null_string: Determines the null string of null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-nullvalueformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                null_value_format_configuration_property = quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                    null_string="nullString"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__48f0f0fef64bf4339d36ebdf70b44980825c7532476cf686825b791826a892c0)
                check_type(argname="argument null_string", value=null_string, expected_type=type_hints["null_string"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "null_string": null_string,
            }

        @builtins.property
        def null_string(self) -> builtins.str:
            '''Determines the null string of null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-nullvalueformatconfiguration.html#cfn-quicksight-template-nullvalueformatconfiguration-nullstring
            '''
            result = self._values.get("null_string")
            assert result is not None, "Required property 'null_string' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NullValueFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class NumberDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the number display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value of the number format.
            :param prefix: Determines the prefix value of the number format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                number_display_format_configuration_property = quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93d8ea50e69fba3ee87a375505d369d6e5a129e3c3504a31c67bb3652dc683ce)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NumberFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"format_configuration": "formatConfiguration"},
    )
    class NumberFormatConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for number fields.

            :param format_configuration: The options that determine the numeric format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                number_format_configuration_property = quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__defa462056d49f39ed2a441770c6ff30a569efa75bb580c49167dd02b648aabc)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericFormatConfigurationProperty"]]:
            '''The options that determine the numeric format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberformatconfiguration.html#cfn-quicksight-template-numberformatconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NumericAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "scale": "scale"},
    )
    class NumericAxisOptionsProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for an axis with a numeric field.

            :param range: The range setup of a numeric axis.
            :param scale: The scale setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                numeric_axis_options_property = quicksight.CfnTemplate.NumericAxisOptionsProperty(
                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                        data_driven=data_driven,
                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                            maximum=123,
                            minimum=123
                        )
                    ),
                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                            step_count=123,
                            step_size=123
                        ),
                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                            base=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__450c6eeea8db42ceb8da21060479905496ef2731d51271c1dac11fedc0de4944)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if scale is not None:
                self._values["scale"] = scale

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayRangeProperty"]]:
            '''The range setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html#cfn-quicksight-template-numericaxisoptions-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayRangeProperty"]], result)

        @builtins.property
        def scale(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisScaleProperty"]]:
            '''The scale setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html#cfn-quicksight-template-numericaxisoptions-scale
            '''
            result = self._values.get("scale")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisScaleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "value": "value"},
    )
    class NumericEqualityDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            value: jsii.Number,
        ) -> None:
            '''The category drill down filter.

            :param column: The column that the filter is applied to.
            :param value: The value of the double input numeric drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_equality_drill_down_filter_property = quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e91c57d94904cee14d192a73d38dd4453671ca740ea20644f164e28f0538a524)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "value": value,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html#cfn-quicksight-template-numericequalitydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The value of the double input numeric drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html#cfn-quicksight-template-numericequalitydrilldownfilter-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NumericEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
            "value": "value",
        },
    )
    class NumericEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            match_operator: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``NumericEqualityFilter`` filters values that are equal to the specified value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``
            :param value: The input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_equality_filter_property = quicksight.CfnTemplate.NumericEqualityFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d0c7649847cadd8aca5822743593e956166c0c0de9a346345bf1928e7c34c5fc)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationFunctionProperty"]]:
            '''The aggregation function of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationFunctionProperty"]], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NumericFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "currency_display_format_configuration": "currencyDisplayFormatConfiguration",
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class NumericFormatConfigurationProperty:
        def __init__(
            self,
            *,
            currency_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CurrencyDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            number_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the numeric format configuration.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param currency_display_format_configuration: The options that determine the currency display format configuration.
            :param number_display_format_configuration: The options that determine the number display format configuration.
            :param percentage_display_format_configuration: The options that determine the percentage display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_format_configuration_property = quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix",
                        symbol="symbol"
                    ),
                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5dbf7c6911ddca52a95ad9207d4ef33a16a1f6c53b76e92b544b0083d6468d14)
                check_type(argname="argument currency_display_format_configuration", value=currency_display_format_configuration, expected_type=type_hints["currency_display_format_configuration"])
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if currency_display_format_configuration is not None:
                self._values["currency_display_format_configuration"] = currency_display_format_configuration
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def currency_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CurrencyDisplayFormatConfigurationProperty"]]:
            '''The options that determine the currency display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-currencydisplayformatconfiguration
            '''
            result = self._values.get("currency_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CurrencyDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumberDisplayFormatConfigurationProperty"]]:
            '''The options that determine the number display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumberDisplayFormatConfigurationProperty"]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PercentageDisplayFormatConfigurationProperty"]]:
            '''The options that determine the percentage display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PercentageDisplayFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NumericRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "select_all_options": "selectAllOptions",
        },
    )
    class NumericRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            range_maximum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_minimum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``NumericRangeFilter`` filters values that are within the value range.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_range_filter_property = quicksight.CfnTemplate.NumericRangeFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b10405831f4737b6e1f4cefdaab019c2b7924e010958775605196c32c306abaa)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum is not None:
                self._values["range_maximum"] = range_maximum
            if range_minimum is not None:
                self._values["range_minimum"] = range_minimum
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationFunctionProperty"]]:
            '''The aggregation function of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationFunctionProperty"]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def range_maximum(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericRangeFilterValueProperty"]]:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericRangeFilterValueProperty"]], result)

        @builtins.property
        def range_minimum(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericRangeFilterValueProperty"]]:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericRangeFilterValueProperty"]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NumericRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={"parameter": "parameter", "static_value": "staticValue"},
    )
    class NumericRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            static_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The value input pf the numeric range filter.

            :param parameter: The parameter that is used in the numeric range.
            :param static_value: The static value of the numeric range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_range_filter_value_property = quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                    parameter="parameter",
                    static_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8151062daa8c08abd26cdf15519cdabb4ada61425aa8bfc105077f605a6ac4f3)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter that is used in the numeric range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html#cfn-quicksight-template-numericrangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def static_value(self) -> typing.Optional[jsii.Number]:
            '''The static value of the numeric range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html#cfn-quicksight-template-numericrangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NumericSeparatorConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_separator": "decimalSeparator",
            "thousands_separator": "thousandsSeparator",
        },
    )
    class NumericSeparatorConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_separator: typing.Optional[builtins.str] = None,
            thousands_separator: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ThousandSeparatorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that determine the numeric separator configuration.

            :param decimal_separator: Determines the decimal separator.
            :param thousands_separator: The options that determine the thousands separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numeric_separator_configuration_property = quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                    decimal_separator="decimalSeparator",
                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                        symbol="symbol",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ef52e0adcdf7c4affbe622a41d45b3bb36a2f5ce0cd860f836e53df32d87eafd)
                check_type(argname="argument decimal_separator", value=decimal_separator, expected_type=type_hints["decimal_separator"])
                check_type(argname="argument thousands_separator", value=thousands_separator, expected_type=type_hints["thousands_separator"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_separator is not None:
                self._values["decimal_separator"] = decimal_separator
            if thousands_separator is not None:
                self._values["thousands_separator"] = thousands_separator

        @builtins.property
        def decimal_separator(self) -> typing.Optional[builtins.str]:
            '''Determines the decimal separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html#cfn-quicksight-template-numericseparatorconfiguration-decimalseparator
            '''
            result = self._values.get("decimal_separator")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thousands_separator(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ThousandSeparatorOptionsProperty"]]:
            '''The options that determine the thousands separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html#cfn-quicksight-template-numericseparatorconfiguration-thousandsseparator
            '''
            result = self._values.get("thousands_separator")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ThousandSeparatorOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericSeparatorConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NumericalAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "percentile_aggregation": "percentileAggregation",
            "simple_numerical_aggregation": "simpleNumericalAggregation",
        },
    )
    class NumericalAggregationFunctionProperty:
        def __init__(
            self,
            *,
            percentile_aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PercentileAggregationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            simple_numerical_aggregation: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Aggregation for numerical values.

            :param percentile_aggregation: An aggregation based on the percentile of values in a dimension or measure.
            :param simple_numerical_aggregation: Built-in aggregation functions for numerical values. - ``SUM`` : The sum of a dimension or measure. - ``AVERAGE`` : The average of a dimension or measure. - ``MIN`` : The minimum value of a dimension or measure. - ``MAX`` : The maximum value of a dimension or measure. - ``COUNT`` : The count of a dimension or measure. - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure. - ``VAR`` : The variance of a dimension or measure. - ``VARP`` : The partitioned variance of a dimension or measure. - ``STDEV`` : The standard deviation of a dimension or measure. - ``STDEVP`` : The partitioned standard deviation of a dimension or measure. - ``MEDIAN`` : The median value of a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numerical_aggregation_function_property = quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                        percentile_value=123
                    ),
                    simple_numerical_aggregation="simpleNumericalAggregation"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__60865f3ef5e9b1a0a80d2eb52985dc7cda4086f43cc4b81400560fdc1ace8cab)
                check_type(argname="argument percentile_aggregation", value=percentile_aggregation, expected_type=type_hints["percentile_aggregation"])
                check_type(argname="argument simple_numerical_aggregation", value=simple_numerical_aggregation, expected_type=type_hints["simple_numerical_aggregation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_aggregation is not None:
                self._values["percentile_aggregation"] = percentile_aggregation
            if simple_numerical_aggregation is not None:
                self._values["simple_numerical_aggregation"] = simple_numerical_aggregation

        @builtins.property
        def percentile_aggregation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PercentileAggregationProperty"]]:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html#cfn-quicksight-template-numericalaggregationfunction-percentileaggregation
            '''
            result = self._values.get("percentile_aggregation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PercentileAggregationProperty"]], result)

        @builtins.property
        def simple_numerical_aggregation(self) -> typing.Optional[builtins.str]:
            '''Built-in aggregation functions for numerical values.

            - ``SUM`` : The sum of a dimension or measure.
            - ``AVERAGE`` : The average of a dimension or measure.
            - ``MIN`` : The minimum value of a dimension or measure.
            - ``MAX`` : The maximum value of a dimension or measure.
            - ``COUNT`` : The count of a dimension or measure.
            - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure.
            - ``VAR`` : The variance of a dimension or measure.
            - ``VARP`` : The partitioned variance of a dimension or measure.
            - ``STDEV`` : The standard deviation of a dimension or measure.
            - ``STDEVP`` : The partitioned standard deviation of a dimension or measure.
            - ``MEDIAN`` : The median value of a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html#cfn-quicksight-template-numericalaggregationfunction-simplenumericalaggregation
            '''
            result = self._values.get("simple_numerical_aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NumericalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class NumericalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with numerical type columns.

            :param column: The column that is used in the ``NumericalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numerical_dimension_field_property = quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c0231818db68b0694f544295adc11eac3f3802c1ce4705f5ed445d19f5473ee)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``NumericalDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumberFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumberFormatConfigurationProperty"]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.NumericalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class NumericalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The measure type field with numerical type columns.

            :param column: The column that is used in the ``NumericalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                numerical_measure_field_property = quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c84162b566349c6d221f0589e47f33d92ba179f3b8564a97886042013b73065e)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``NumericalMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericalAggregationFunctionProperty"]]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericalAggregationFunctionProperty"]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumberFormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumberFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PaginationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"page_number": "pageNumber", "page_size": "pageSize"},
    )
    class PaginationConfigurationProperty:
        def __init__(self, *, page_number: jsii.Number, page_size: jsii.Number) -> None:
            '''The pagination configuration for a table visual or boxplot.

            :param page_number: Indicates the page number.
            :param page_size: Indicates how many items render in one page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pagination_configuration_property = quicksight.CfnTemplate.PaginationConfigurationProperty(
                    page_number=123,
                    page_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dbdac14920743145395dc439bb93c33959e5ecc4447f120c8fb7fa7d74d9ad96)
                check_type(argname="argument page_number", value=page_number, expected_type=type_hints["page_number"])
                check_type(argname="argument page_size", value=page_size, expected_type=type_hints["page_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "page_number": page_number,
                "page_size": page_size,
            }

        @builtins.property
        def page_number(self) -> jsii.Number:
            '''Indicates the page number.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html#cfn-quicksight-template-paginationconfiguration-pagenumber
            '''
            result = self._values.get("page_number")
            assert result is not None, "Required property 'page_number' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def page_size(self) -> jsii.Number:
            '''Indicates how many items render in one page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html#cfn-quicksight-template-paginationconfiguration-pagesize
            '''
            result = self._values.get("page_size")
            assert result is not None, "Required property 'page_size' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PaginationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PanelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "background_visibility": "backgroundVisibility",
            "border_color": "borderColor",
            "border_style": "borderStyle",
            "border_thickness": "borderThickness",
            "border_visibility": "borderVisibility",
            "gutter_spacing": "gutterSpacing",
            "gutter_visibility": "gutterVisibility",
            "title": "title",
        },
    )
    class PanelConfigurationProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            background_visibility: typing.Optional[builtins.str] = None,
            border_color: typing.Optional[builtins.str] = None,
            border_style: typing.Optional[builtins.str] = None,
            border_thickness: typing.Optional[builtins.str] = None,
            border_visibility: typing.Optional[builtins.str] = None,
            gutter_spacing: typing.Optional[builtins.str] = None,
            gutter_visibility: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PanelTitleOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A collection of options that configure how each panel displays in a small multiples chart.

            :param background_color: Sets the background color for each panel.
            :param background_visibility: Determines whether or not a background for each small multiples panel is rendered.
            :param border_color: Sets the line color of panel borders.
            :param border_style: Sets the line style of panel borders.
            :param border_thickness: Sets the line thickness of panel borders.
            :param border_visibility: Determines whether or not each panel displays a border.
            :param gutter_spacing: Sets the total amount of negative space to display between sibling panels.
            :param gutter_visibility: Determines whether or not negative space between sibling panels is rendered.
            :param title: Configures the title display within each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                panel_configuration_property = quicksight.CfnTemplate.PanelConfigurationProperty(
                    background_color="backgroundColor",
                    background_visibility="backgroundVisibility",
                    border_color="borderColor",
                    border_style="borderStyle",
                    border_thickness="borderThickness",
                    border_visibility="borderVisibility",
                    gutter_spacing="gutterSpacing",
                    gutter_visibility="gutterVisibility",
                    title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_text_alignment="horizontalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc4850c28f964aac51af2f26fc7094a1a386ee77679e927a2f2685e339174ae2)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument background_visibility", value=background_visibility, expected_type=type_hints["background_visibility"])
                check_type(argname="argument border_color", value=border_color, expected_type=type_hints["border_color"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument border_thickness", value=border_thickness, expected_type=type_hints["border_thickness"])
                check_type(argname="argument border_visibility", value=border_visibility, expected_type=type_hints["border_visibility"])
                check_type(argname="argument gutter_spacing", value=gutter_spacing, expected_type=type_hints["gutter_spacing"])
                check_type(argname="argument gutter_visibility", value=gutter_visibility, expected_type=type_hints["gutter_visibility"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if background_visibility is not None:
                self._values["background_visibility"] = background_visibility
            if border_color is not None:
                self._values["border_color"] = border_color
            if border_style is not None:
                self._values["border_style"] = border_style
            if border_thickness is not None:
                self._values["border_thickness"] = border_thickness
            if border_visibility is not None:
                self._values["border_visibility"] = border_visibility
            if gutter_spacing is not None:
                self._values["gutter_spacing"] = gutter_spacing
            if gutter_visibility is not None:
                self._values["gutter_visibility"] = gutter_visibility
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''Sets the background color for each panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def background_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not a background for each small multiples panel is rendered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-backgroundvisibility
            '''
            result = self._values.get("background_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_color(self) -> typing.Optional[builtins.str]:
            '''Sets the line color of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-bordercolor
            '''
            result = self._values.get("border_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_style(self) -> typing.Optional[builtins.str]:
            '''Sets the line style of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_thickness(self) -> typing.Optional[builtins.str]:
            '''Sets the line thickness of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-borderthickness
            '''
            result = self._values.get("border_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not each panel displays a border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-bordervisibility
            '''
            result = self._values.get("border_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_spacing(self) -> typing.Optional[builtins.str]:
            '''Sets the total amount of negative space to display between sibling panels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-gutterspacing
            '''
            result = self._values.get("gutter_spacing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not negative space between sibling panels is rendered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-guttervisibility
            '''
            result = self._values.get("gutter_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PanelTitleOptionsProperty"]]:
            '''Configures the title display within each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PanelTitleOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PanelTitleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_configuration": "fontConfiguration",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "visibility": "visibility",
        },
    )
    class PanelTitleOptionsProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the title styles for each small multiples panel.

            :param font_configuration: ``CfnTemplate.PanelTitleOptionsProperty.FontConfiguration``.
            :param horizontal_text_alignment: Sets the horizontal text alignment of the title within each panel.
            :param visibility: Determines whether or not panel titles are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                panel_title_options_property = quicksight.CfnTemplate.PanelTitleOptionsProperty(
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_text_alignment="horizontalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bf3688869b05d616c7dae229a3cf9249c5707b88580ef11075d7946e00680a74)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]]:
            '''``CfnTemplate.PanelTitleOptionsProperty.FontConfiguration``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''Sets the horizontal text alignment of the title within each panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not panel titles are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelTitleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ParameterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class ParameterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ParameterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            dropdown: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ParameterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ParameterListControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            slider: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ParameterSliderControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_area: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ParameterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ParameterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The control of a parameter that users can interact with in a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date parameter that specifies date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_control_property = quicksight.CfnTemplate.ParameterControlProperty(
                    date_time_picker=quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    dropdown=quicksight.CfnTemplate.ParameterDropDownControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                            select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnTemplate.ParameterListControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                            search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    slider=quicksight.CfnTemplate.ParameterSliderControlProperty(
                        maximum_value=123,
                        minimum_value=123,
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_area=quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a4318b6e65fc6bf3045ef085124f750b76f9010e79f51409f5f80cc7660b7594)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterDateTimePickerControlProperty"]]:
            '''A control from a date parameter that specifies date and time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterDateTimePickerControlProperty"]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterDropDownControlProperty"]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterDropDownControlProperty"]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterListControlProperty"]]:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterListControlProperty"]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterSliderControlProperty"]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterSliderControlProperty"]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterTextAreaControlProperty"]]:
            '''A control to display a text box that is used to enter multiple entries.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterTextAreaControlProperty"]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterTextFieldControlProperty"]]:
            '''A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterTextFieldControlProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ParameterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control from a date parameter that specifies date and time.

            :param parameter_control_id: The ID of the ``ParameterDateTimePickerControl`` .
            :param source_parameter_name: The name of the ``ParameterDateTimePickerControl`` .
            :param title: The title of the ``ParameterDateTimePickerControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_date_time_picker_control_property = quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e433dd5e6b7e2bd85a298bd6e810a89e42f1009ba197714a9320e08caabe9edb)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The name of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimePickerControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimePickerControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameter_declaration": "dateTimeParameterDeclaration",
            "decimal_parameter_declaration": "decimalParameterDeclaration",
            "integer_parameter_declaration": "integerParameterDeclaration",
            "string_parameter_declaration": "stringParameterDeclaration",
        },
    )
    class ParameterDeclarationProperty:
        def __init__(
            self,
            *,
            date_time_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DateTimeParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            decimal_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DecimalParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            integer_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.IntegerParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            string_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.StringParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The declaration definition of a parameter.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_parameter_declaration: A parameter declaration for the ``DateTime`` data type.
            :param decimal_parameter_declaration: A parameter declaration for the ``Decimal`` data type.
            :param integer_parameter_declaration: A parameter declaration for the ``Integer`` data type.
            :param string_parameter_declaration: A parameter declaration for the ``String`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_declaration_property = quicksight.CfnTemplate.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnTemplate.DateTimeParameterDeclarationProperty(
                        name="name",
                
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnTemplate.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnTemplate.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnTemplate.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__368309055ad7c63750fe3dc2b80de2180903ad9aa3f59bc1e7b0bed12a244598)
                check_type(argname="argument date_time_parameter_declaration", value=date_time_parameter_declaration, expected_type=type_hints["date_time_parameter_declaration"])
                check_type(argname="argument decimal_parameter_declaration", value=decimal_parameter_declaration, expected_type=type_hints["decimal_parameter_declaration"])
                check_type(argname="argument integer_parameter_declaration", value=integer_parameter_declaration, expected_type=type_hints["integer_parameter_declaration"])
                check_type(argname="argument string_parameter_declaration", value=string_parameter_declaration, expected_type=type_hints["string_parameter_declaration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameter_declaration is not None:
                self._values["date_time_parameter_declaration"] = date_time_parameter_declaration
            if decimal_parameter_declaration is not None:
                self._values["decimal_parameter_declaration"] = decimal_parameter_declaration
            if integer_parameter_declaration is not None:
                self._values["integer_parameter_declaration"] = integer_parameter_declaration
            if string_parameter_declaration is not None:
                self._values["string_parameter_declaration"] = string_parameter_declaration

        @builtins.property
        def date_time_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``DateTime`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-datetimeparameterdeclaration
            '''
            result = self._values.get("date_time_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DateTimeParameterDeclarationProperty"]], result)

        @builtins.property
        def decimal_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DecimalParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``Decimal`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-decimalparameterdeclaration
            '''
            result = self._values.get("decimal_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DecimalParameterDeclarationProperty"]], result)

        @builtins.property
        def integer_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.IntegerParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-integerparameterdeclaration
            '''
            result = self._values.get("integer_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.IntegerParameterDeclarationProperty"]], result)

        @builtins.property
        def string_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.StringParameterDeclarationProperty"]]:
            '''A parameter declaration for the ``String`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-stringparameterdeclaration
            '''
            result = self._values.get("string_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.StringParameterDeclarationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ParameterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterDropDownControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param parameter_control_id: The ID of the ``ParameterDropDownControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterDropDownControl`` .
            :param title: The title of the ``ParameterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_drop_down_control_property = quicksight.CfnTemplate.ParameterDropDownControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                        select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__67a040bccc553a4b58b2fd721bc869173bf276058bf21ae00d16bcac16981228)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DropDownControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DropDownControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ParameterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterListControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :param parameter_control_id: The ID of the ``ParameterListControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterListControl`` .
            :param title: The title of the ``ParameterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_list_control_property = quicksight.CfnTemplate.ParameterListControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                        search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bf7ded3da390b3fdc06b3f7bdc723b725650e0b0ac55f62248715a8644f72960)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CascadingControlConfigurationProperty"]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CascadingControlConfigurationProperty"]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ListControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ListControlDisplayOptionsProperty"]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterSelectableValuesProperty"]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterSelectableValuesProperty"]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ParameterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "link_to_data_set_column": "linkToDataSetColumn",
            "values": "values",
        },
    )
    class ParameterSelectableValuesProperty:
        def __init__(
            self,
            *,
            link_to_data_set_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param link_to_data_set_column: The column identifier that fetches values from the data set.
            :param values: The values that are used in ``ParameterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_selectable_values_property = quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                    link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0c9a0c23906196bc8b2dd97de574cf7abbc9c3ee041315229d3f58a4a6b29571)
                check_type(argname="argument link_to_data_set_column", value=link_to_data_set_column, expected_type=type_hints["link_to_data_set_column"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if link_to_data_set_column is not None:
                self._values["link_to_data_set_column"] = link_to_data_set_column
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def link_to_data_set_column(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]]:
            '''The column identifier that fetches values from the data set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html#cfn-quicksight-template-parameterselectablevalues-linktodatasetcolumn
            '''
            result = self._values.get("link_to_data_set_column")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]], result)

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in ``ParameterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html#cfn-quicksight-template-parameterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ParameterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterSliderControlProperty:
        def __init__(
            self,
            *,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param maximum_value: The smaller value that is displayed at the left of the slider.
            :param minimum_value: The larger value that is displayed at the right of the slider.
            :param parameter_control_id: The ID of the ``ParameterSliderControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into.
            :param title: The title of the ``ParameterSliderControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_slider_control_property = quicksight.CfnTemplate.ParameterSliderControlProperty(
                    maximum_value=123,
                    minimum_value=123,
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8b285ac78165ed93ca21745aa6139a5ac9adf6d50308879b5ae65eeb9e79bf42)
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SliderControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SliderControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ParameterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextAreaControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param parameter_control_id: The ID of the ``ParameterTextAreaControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextAreaControl`` .
            :param title: The title of the ``ParameterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_text_area_control_property = quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bf3033bc1187c04e787737d664e2524d54d3d2c4e9368dfc1e2d9ff925cac203)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextAreaControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextAreaControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ParameterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextFieldControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param parameter_control_id: The ID of the ``ParameterTextFieldControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextFieldControl`` .
            :param title: The title of the ``ParameterTextFieldControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                parameter_text_field_control_property = quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd6178b7f841026bc7cb485bc578cea52b53aada109d833bc5044919125ee9eb)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextFieldControlDisplayOptionsProperty"]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextFieldControlDisplayOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PercentVisibleRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"from_": "from", "to": "to"},
    )
    class PercentVisibleRangeProperty:
        def __init__(
            self,
            *,
            from_: typing.Optional[jsii.Number] = None,
            to: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The percent range in the visible range.

            :param from_: The lower bound of the range.
            :param to: The top bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                percent_visible_range_property = quicksight.CfnTemplate.PercentVisibleRangeProperty(
                    from=123,
                    to=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__82d71de5b9463d9f445bc2256bae7c4bb0932b64e8b005ecc493cba03f1a709e)
                check_type(argname="argument from_", value=from_, expected_type=type_hints["from_"])
                check_type(argname="argument to", value=to, expected_type=type_hints["to"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if from_ is not None:
                self._values["from_"] = from_
            if to is not None:
                self._values["to"] = to

        @builtins.property
        def from_(self) -> typing.Optional[jsii.Number]:
            '''The lower bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html#cfn-quicksight-template-percentvisiblerange-from
            '''
            result = self._values.get("from_")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def to(self) -> typing.Optional[jsii.Number]:
            '''The top bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html#cfn-quicksight-template-percentvisiblerange-to
            '''
            result = self._values.get("to")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentVisibleRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class PercentageDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the percentage display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param prefix: Determines the prefix value of the percentage format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                percentage_display_format_configuration_property = quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    prefix="prefix",
                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22e1d2b4e47a5d124f8f44833569abed1d81aa1eb3ea7f7bb439726de7b95b40)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DecimalPlacesConfigurationProperty"]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DecimalPlacesConfigurationProperty"]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NegativeValueConfigurationProperty"]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NegativeValueConfigurationProperty"]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericSeparatorConfigurationProperty"]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericSeparatorConfigurationProperty"]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentageDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PercentileAggregationProperty",
        jsii_struct_bases=[],
        name_mapping={"percentile_value": "percentileValue"},
    )
    class PercentileAggregationProperty:
        def __init__(
            self,
            *,
            percentile_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :param percentile_value: The percentile value. This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentileaggregation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                percentile_aggregation_property = quicksight.CfnTemplate.PercentileAggregationProperty(
                    percentile_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9bf6f0badbb862d081f1d1bfda80fe3c1ce55ba99e6712e5b03d2fab9144639b)
                check_type(argname="argument percentile_value", value=percentile_value, expected_type=type_hints["percentile_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_value is not None:
                self._values["percentile_value"] = percentile_value

        @builtins.property
        def percentile_value(self) -> typing.Optional[jsii.Number]:
            '''The percentile value.

            This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentileaggregation.html#cfn-quicksight-template-percentileaggregation-percentilevalue
            '''
            result = self._values.get("percentile_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentileAggregationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PeriodOverPeriodComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "value": "value",
        },
    )
    class PeriodOverPeriodComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The period over period computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                period_over_period_computation_property = quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e6802920f34fddd7614e1d44ef06b4ef95537f0e792dc32d4291c430be3afa89)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodOverPeriodComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PeriodToDateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "period_time_granularity": "periodTimeGranularity",
            "value": "value",
        },
    )
    class PeriodToDateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
            period_time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The period to date computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param period_time_granularity: The time granularity setup of period to date computation. Choose from the following options:. - YEAR: Year to date. - MONTH: Month to date.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                period_to_date_computation_property = quicksight.CfnTemplate.PeriodToDateComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    period_time_granularity="periodTimeGranularity",
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c8c446ba7e83422b30febab3ef109a7f5740c9b5a0705f66c40d481985a8da13)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_time_granularity", value=period_time_granularity, expected_type=type_hints["period_time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if period_time_granularity is not None:
                self._values["period_time_granularity"] = period_time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity setup of period to date computation. Choose from the following options:.

            - YEAR: Year to date.
            - MONTH: Month to date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-periodtimegranularity
            '''
            result = self._values.get("period_time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodToDateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class PieChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            :param category: The category (group/color) field wells of a pie chart.
            :param small_multiples: The small multiples field well of a pie chart.
            :param values: The value field wells of a pie chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_aggregated_field_wells_property = quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__11011ce1e97e61489dbed7a96144a1fb83f7e0ff71fdea9ea3e6697b870d332f)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The category (group/color) field wells of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The small multiples field well of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a pie chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PieChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "donut_options": "donutOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class PieChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            donut_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DonutOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PieChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PieChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a pie chart.

            :param category_label_options: The label options of the group/color that is displayed in a pie chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param donut_options: The options that determine the shape of the chart. This option determines whether the chart is a pie chart or a donut chart.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a pie chart.
            :param tooltip: The tooltip display setup of the visual.
            :param value_label_options: The label options for the value that is displayed in a pie chart.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_configuration_property = quicksight.CfnTemplate.PieChartConfigurationProperty(
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                        arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                            arc_thickness="arcThickness"
                        ),
                        donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                            label_visibility="labelVisibility"
                        )
                    ),
                    field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                        pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9e8439ffb05b795551cb3ae1339175e9ef969ef85a035171dab7b9da5360eaf8)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument donut_options", value=donut_options, expected_type=type_hints["donut_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if donut_options is not None:
                self._values["donut_options"] = donut_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options of the group/color that is displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ContributionAnalysisDefaultProperty"]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ContributionAnalysisDefaultProperty"]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def donut_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DonutOptionsProperty"]]:
            '''The options that determine the shape of the chart.

            This option determines whether the chart is a pie chart or a donut chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-donutoptions
            '''
            result = self._values.get("donut_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DonutOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PieChartFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PieChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SmallMultiplesOptionsProperty"]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SmallMultiplesOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PieChartSortConfigurationProperty"]]:
            '''The sort configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PieChartSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options for the value that is displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PieChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pie_chart_aggregated_field_wells": "pieChartAggregatedFieldWells",
        },
    )
    class PieChartFieldWellsProperty:
        def __init__(
            self,
            *,
            pie_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PieChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pie_chart_aggregated_field_wells: The field well configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_field_wells_property = quicksight.CfnTemplate.PieChartFieldWellsProperty(
                    pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__74f755486f07e76fce4278da9e4219ecded215a2ddbd33a1b85db597d4f4f5ae)
                check_type(argname="argument pie_chart_aggregated_field_wells", value=pie_chart_aggregated_field_wells, expected_type=type_hints["pie_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pie_chart_aggregated_field_wells is not None:
                self._values["pie_chart_aggregated_field_wells"] = pie_chart_aggregated_field_wells

        @builtins.property
        def pie_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PieChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartfieldwells.html#cfn-quicksight-template-piechartfieldwells-piechartaggregatedfieldwells
            '''
            result = self._values.get("pie_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PieChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PieChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class PieChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a pie chart.

            :param category_items_limit: The limit on the number of categories that are displayed in a pie chart.
            :param category_sort: The sort configuration of the category fields.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_sort_configuration_property = quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__81612f9fd1ab90ff031810ba5bad26b4842fa156835b19426b336be4d1d4ec54)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of categories that are displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PieChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PieChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PieChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A pie or donut chart.

            The ``PieChartVisual`` structure describes a visual that is a member of the pie chart family.

            The following charts can be described by using this structure:

            - Pie charts
            - Donut charts

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            For more information, see `Using donut charts <https://docs.aws.amazon.com/quicksight/latest/user/donut-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a pie chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pie_chart_visual_property = quicksight.CfnTemplate.PieChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.PieChartConfigurationProperty(
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                            arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                                arc_thickness="arcThickness"
                            ),
                            donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                                label_visibility="labelVisibility"
                            )
                        ),
                        field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                            pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e40a6ef83bed4089763b489f09c076f28757eac1531a54109d03a91b9e14fb51)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PieChartConfigurationProperty"]]:
            '''The configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PieChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotFieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "sort_by": "sortBy"},
    )
    class PivotFieldSortOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            sort_by: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableSortByProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The field sort options for a pivot table sort configuration.

            :param field_id: The field ID for the field sort options.
            :param sort_by: The sort by field for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_field_sort_options_property = quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                    field_id="fieldId",
                    sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                        column=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        data_path=quicksight.CfnTemplate.DataPathSortProperty(
                            direction="direction",
                            sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            )]
                        ),
                        field=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__08bf2450f02b03e55baf9773d089f470b61d24921b572c70c11e850db0c20af2)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "sort_by": sort_by,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html#cfn-quicksight-template-pivotfieldsortoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableSortByProperty"]:
            '''The sort by field for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html#cfn-quicksight-template-pivotfieldsortoptions-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableSortByProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotFieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class PivotTableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            rows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for the pivot table.

            :param columns: The columns field well for a pivot table. Values are grouped by columns fields.
            :param rows: The rows field well for a pivot table. Values are grouped by rows fields.
            :param values: The values field well for a pivot table. Values are aggregated based on rows and columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_aggregated_field_wells_property = quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                    columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3409ee4a8dd6c9d4722ab1155dc0d0e1b631c9df9003f0b4f675dd9f00e17202)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The columns field well for a pivot table.

            Values are grouped by columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The rows field well for a pivot table.

            Values are grouped by rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on rows and columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "scope": "scope",
            "text_format": "textFormat",
        },
    )
    class PivotTableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            scope: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableConditionalFormattingScopeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cell conditional formatting option for a pivot table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param scope: The scope of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_cell_conditional_formatting_property = quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                        role="role"
                    ),
                    text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__357c43f89872d9a67bf98d306540fdbe5dcb0f0742d31d7100bac9e828787629)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if scope is not None:
                self._values["scope"] = scope
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def scope(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableConditionalFormattingScopeProperty"]]:
            '''The scope of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-scope
            '''
            result = self._values.get("scope")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableConditionalFormattingScopeProperty"]], result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextConditionalFormatProperty"]]:
            '''The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell"},
    )
    class PivotTableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_option_property = quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                            role="role"
                        ),
                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b937871ea87c127d6788b44584abb29e8b1435faaf9ba392f38886f6fc528858)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableCellConditionalFormattingProperty"]]:
            '''The cell conditional formatting option for a pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingoption.html#cfn-quicksight-template-pivottableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableCellConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class PivotTableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_property = quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                role="role"
                            ),
                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__035d0cac94a0acbd4823e600a95aa9da7ae66b81da88295d8ddefd9585e1c7cd)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformatting.html#cfn-quicksight-template-pivottableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty",
        jsii_struct_bases=[],
        name_mapping={"role": "role"},
    )
    class PivotTableConditionalFormattingScopeProperty:
        def __init__(self, *, role: typing.Optional[builtins.str] = None) -> None:
            '''The scope of the cell for conditional formatting.

            :param role: The role (field, field total, grand total) of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingscope.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_scope_property = quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__25a9461603e54716f57702474f0abd9b3505021be84e5850458cb3edba1543ec)
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role (field, field total, grand total) of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingscope.html#cfn-quicksight-template-pivottableconditionalformattingscope-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingScopeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class PivotTableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_report_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``PivotTableVisual`` .

            :param field_options: The field options for a pivot table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a pivot table visual.
            :param sort_configuration: The sort configuration for a ``PivotTableVisual`` .
            :param table_options: The table options for a pivot table visual.
            :param total_options: The total options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_configuration_property = quicksight.CfnTemplate.PivotTableConfigurationProperty(
                    field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                        data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                            data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            )],
                
                            # the properties below are optional
                            width="width"
                        )],
                        selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            custom_label="customLabel",
                            visibility="visibility"
                        )]
                    ),
                    field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                        pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                            columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                        vertical_overflow_visibility="verticalOverflowVisibility"
                    ),
                    sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                        field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                            field_id="fieldId",
                            sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                column=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                    direction="direction",
                                    sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    )]
                                ),
                                field=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )
                        )]
                    ),
                    table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                        cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        column_names_visibility="columnNamesVisibility",
                        metric_placement="metricPlacement",
                        row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                            row_alternate_colors=["rowAlternateColors"],
                            status="status"
                        ),
                        row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        single_metric_visibility="singleMetricVisibility",
                        toggle_buttons_visibility="toggleButtonsVisibility"
                    ),
                    total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                        column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                            custom_label="customLabel",
                            field_level="fieldLevel",
                            field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                field_id="fieldId"
                            )],
                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                            custom_label="customLabel",
                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                            custom_label="customLabel",
                            field_level="fieldLevel",
                            field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                field_id="fieldId"
                            )],
                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                            custom_label="customLabel",
                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5f1cc5c1c6fa51a2410b7d3eb133d223b015b3ef2562aaf44a2c8d2e1c8d1a1a)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableFieldOptionsProperty"]]:
            '''The field options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableFieldOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableFieldWellsProperty"]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTablePaginatedReportOptionsProperty"]]:
            '''The paginated report options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTablePaginatedReportOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableSortConfigurationProperty"]]:
            '''The sort configuration for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableSortConfigurationProperty"]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableOptionsProperty"]]:
            '''The table options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableOptionsProperty"]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableTotalOptionsProperty"]]:
            '''The total options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableTotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableDataPathOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"data_path_list": "dataPathList", "width": "width"},
    )
    class PivotTableDataPathOptionProperty:
        def __init__(
            self,
            *,
            data_path_list: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]]]]],
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data path options for the pivot table field options.

            :param data_path_list: The list of data path values for the data path options.
            :param width: The width of the data path option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_data_path_option_property = quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                    data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    )],
                
                    # the properties below are optional
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__58654b6ff119260e31338943d528cd5ac758c9244e58c5b0cb29d78290a6831f)
                check_type(argname="argument data_path_list", value=data_path_list, expected_type=type_hints["data_path_list"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_path_list": data_path_list,
            }
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def data_path_list(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataPathValueProperty"]]]:
            '''The list of data path values for the data path options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html#cfn-quicksight-template-pivottabledatapathoption-datapathlist
            '''
            result = self._values.get("data_path_list")
            assert result is not None, "Required property 'data_path_list' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataPathValueProperty"]]], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the data path option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html#cfn-quicksight-template-pivottabledatapathoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableDataPathOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "visibility": "visibility",
        },
    )
    class PivotTableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The selected field options for the pivot table field options.

            :param field_id: The field ID of the pivot table field.
            :param custom_label: The custom label of the pivot table field.
            :param visibility: The visibility of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_field_option_property = quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cff7dda3c65652234ff946f8989ac8aed08551d1cd74f446e16e3da03c275f52)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_options": "dataPathOptions",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class PivotTableFieldOptionsProperty:
        def __init__(
            self,
            *,
            data_path_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableDataPathOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            selected_field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field options for a pivot table visual.

            :param data_path_options: The data path options for the pivot table field options.
            :param selected_field_options: The selected field options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_field_options_property = quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                    data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                        data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        )],
                
                        # the properties below are optional
                        width="width"
                    )],
                    selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec91a762a2bb3f5c0f7941952de70e5c55eefe3e31d17dde1a87e14e375b46d6)
                check_type(argname="argument data_path_options", value=data_path_options, expected_type=type_hints["data_path_options"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_options is not None:
                self._values["data_path_options"] = data_path_options
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def data_path_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableDataPathOptionProperty"]]]]:
            '''The data path options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html#cfn-quicksight-template-pivottablefieldoptions-datapathoptions
            '''
            result = self._values.get("data_path_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableDataPathOptionProperty"]]]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableFieldOptionProperty"]]]]:
            '''The selected field options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html#cfn-quicksight-template-pivottablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableFieldOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId"},
    )
    class PivotTableFieldSubtotalOptionsProperty:
        def __init__(self, *, field_id: typing.Optional[builtins.str] = None) -> None:
            '''The optional configuration of subtotals cells.

            :param field_id: The field ID of the subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldsubtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_field_subtotal_options_property = quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e4e5047fede2835330e36fc5e9be361e03046e7d6b611a56ee8ce2479c9ca92c)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldsubtotaloptions.html#cfn-quicksight-template-pivottablefieldsubtotaloptions-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldSubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pivot_table_aggregated_field_wells": "pivotTableAggregatedFieldWells",
        },
    )
    class PivotTableFieldWellsProperty:
        def __init__(
            self,
            *,
            pivot_table_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells for a pivot table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pivot_table_aggregated_field_wells: The aggregated field well for the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_field_wells_property = quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                    pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                        columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__851fcb9d26c3f48a528ffacff0b32bd8241dc4362adea47fdac79bff9dc9c236)
                check_type(argname="argument pivot_table_aggregated_field_wells", value=pivot_table_aggregated_field_wells, expected_type=type_hints["pivot_table_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pivot_table_aggregated_field_wells is not None:
                self._values["pivot_table_aggregated_field_wells"] = pivot_table_aggregated_field_wells

        @builtins.property
        def pivot_table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldwells.html#cfn-quicksight-template-pivottablefieldwells-pivottableaggregatedfieldwells
            '''
            result = self._values.get("pivot_table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "column_header_style": "columnHeaderStyle",
            "column_names_visibility": "columnNamesVisibility",
            "metric_placement": "metricPlacement",
            "row_alternate_color_options": "rowAlternateColorOptions",
            "row_field_names_style": "rowFieldNamesStyle",
            "row_header_style": "rowHeaderStyle",
            "single_metric_visibility": "singleMetricVisibility",
            "toggle_buttons_visibility": "toggleButtonsVisibility",
        },
    )
    class PivotTableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_names_visibility: typing.Optional[builtins.str] = None,
            metric_placement: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_field_names_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            single_metric_visibility: typing.Optional[builtins.str] = None,
            toggle_buttons_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table options for a pivot table visual.

            :param cell_style: The table cell style of cells.
            :param column_header_style: The table cell style of the column header.
            :param column_names_visibility: The visibility of the column names.
            :param metric_placement: The metric placement (row, column) options.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors).
            :param row_field_names_style: The table cell style of row field names.
            :param row_header_style: The table cell style of the row headers.
            :param single_metric_visibility: The visibility of the single metric options.
            :param toggle_buttons_visibility: Determines the visibility of the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_options_property = quicksight.CfnTemplate.PivotTableOptionsProperty(
                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_names_visibility="columnNamesVisibility",
                    metric_placement="metricPlacement",
                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status"
                    ),
                    row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    single_metric_visibility="singleMetricVisibility",
                    toggle_buttons_visibility="toggleButtonsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55807bc671c89984c46690c703e569d2dc2fa225ac0382c96199f3470740b615)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument column_header_style", value=column_header_style, expected_type=type_hints["column_header_style"])
                check_type(argname="argument column_names_visibility", value=column_names_visibility, expected_type=type_hints["column_names_visibility"])
                check_type(argname="argument metric_placement", value=metric_placement, expected_type=type_hints["metric_placement"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
                check_type(argname="argument row_field_names_style", value=row_field_names_style, expected_type=type_hints["row_field_names_style"])
                check_type(argname="argument row_header_style", value=row_header_style, expected_type=type_hints["row_header_style"])
                check_type(argname="argument single_metric_visibility", value=single_metric_visibility, expected_type=type_hints["single_metric_visibility"])
                check_type(argname="argument toggle_buttons_visibility", value=toggle_buttons_visibility, expected_type=type_hints["toggle_buttons_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if column_header_style is not None:
                self._values["column_header_style"] = column_header_style
            if column_names_visibility is not None:
                self._values["column_names_visibility"] = column_names_visibility
            if metric_placement is not None:
                self._values["metric_placement"] = metric_placement
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options
            if row_field_names_style is not None:
                self._values["row_field_names_style"] = row_field_names_style
            if row_header_style is not None:
                self._values["row_header_style"] = row_header_style
            if single_metric_visibility is not None:
                self._values["single_metric_visibility"] = single_metric_visibility
            if toggle_buttons_visibility is not None:
                self._values["toggle_buttons_visibility"] = toggle_buttons_visibility

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]]:
            '''The table cell style of cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def column_header_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]]:
            '''The table cell style of the column header.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-columnheaderstyle
            '''
            result = self._values.get("column_header_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def column_names_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the column names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-columnnamesvisibility
            '''
            result = self._values.get("column_names_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_placement(self) -> typing.Optional[builtins.str]:
            '''The metric placement (row, column) options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-metricplacement
            '''
            result = self._values.get("metric_placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RowAlternateColorOptionsProperty"]]:
            '''The row alternate color options (widget status, row alternate colors).

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RowAlternateColorOptionsProperty"]], result)

        @builtins.property
        def row_field_names_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]]:
            '''The table cell style of row field names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowfieldnamesstyle
            '''
            result = self._values.get("row_field_names_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def row_header_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]]:
            '''The table cell style of the row headers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowheaderstyle
            '''
            result = self._values.get("row_header_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def single_metric_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the single metric options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-singlemetricvisibility
            '''
            result = self._values.get("single_metric_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def toggle_buttons_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-togglebuttonsvisibility
            '''
            result = self._values.get("toggle_buttons_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class PivotTablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a pivot table visual.

            :param overflow_column_header_visibility: The visibility of the repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of the printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_paginated_report_options_property = quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec8b553e0faa555f569c0327c205f520226fa16640532faad76ece9ec04cd91e)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the repeating header rows on each page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html#cfn-quicksight-template-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html#cfn-quicksight-template-pivottablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableSortByProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "data_path": "dataPath", "field": "field"},
    )
    class PivotTableSortByProperty:
        def __init__(
            self,
            *,
            column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_path: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataPathSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The sort by field for the field sort options.

            :param column: The column sort (field id, direction) for the pivot table sort by options.
            :param data_path: The data path sort (data path value, direction) for the pivot table sort by options.
            :param field: The field sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_sort_by_property = quicksight.CfnTemplate.PivotTableSortByProperty(
                    column=quicksight.CfnTemplate.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    data_path=quicksight.CfnTemplate.DataPathSortProperty(
                        direction="direction",
                        sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        )]
                    ),
                    field=quicksight.CfnTemplate.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0fb6a5f79e2cd053d8a1106abc8be4d5c7d07e590bc291a51de0dd18a61716e0)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument data_path", value=data_path, expected_type=type_hints["data_path"])
                check_type(argname="argument field", value=field, expected_type=type_hints["field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column is not None:
                self._values["column"] = column
            if data_path is not None:
                self._values["data_path"] = data_path
            if field is not None:
                self._values["field"] = field

        @builtins.property
        def column(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnSortProperty"]]:
            '''The column sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-column
            '''
            result = self._values.get("column")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnSortProperty"]], result)

        @builtins.property
        def data_path(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataPathSortProperty"]]:
            '''The data path sort (data path value, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-datapath
            '''
            result = self._values.get("data_path")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataPathSortProperty"]], result)

        @builtins.property
        def field(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortProperty"]]:
            '''The field sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-field
            '''
            result = self._values.get("field")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortByProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"field_sort_options": "fieldSortOptions"},
    )
    class PivotTableSortConfigurationProperty:
        def __init__(
            self,
            *,
            field_sort_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotFieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration for a ``PivotTableVisual`` .

            :param field_sort_options: The field sort options for a pivot table sort configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_sort_configuration_property = quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                    field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                        field_id="fieldId",
                        sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                            column=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                direction="direction",
                                sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )]
                            ),
                            field=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__424551c1a70d72cef9ec805a9a9e360d8f9248fc1c69bab2150765e0869a3a71)
                check_type(argname="argument field_sort_options", value=field_sort_options, expected_type=type_hints["field_sort_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_sort_options is not None:
                self._values["field_sort_options"] = field_sort_options

        @builtins.property
        def field_sort_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotFieldSortOptionsProperty"]]]]:
            '''The field sort options for a pivot table sort configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortconfiguration.html#cfn-quicksight-template-pivottablesortconfiguration-fieldsortoptions
            '''
            result = self._values.get("field_sort_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotFieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_subtotal_options": "columnSubtotalOptions",
            "column_total_options": "columnTotalOptions",
            "row_subtotal_options": "rowSubtotalOptions",
            "row_total_options": "rowTotalOptions",
        },
    )
    class PivotTableTotalOptionsProperty:
        def __init__(
            self,
            *,
            column_subtotal_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_subtotal_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The total options for a pivot table visual.

            :param column_subtotal_options: The column subtotal options.
            :param column_total_options: The column total options.
            :param row_subtotal_options: The row subtotal options.
            :param row_total_options: The row total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_total_options_property = quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                    column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                        custom_label="customLabel",
                        field_level="fieldLevel",
                        field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                            field_id="fieldId"
                        )],
                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                        custom_label="customLabel",
                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                        custom_label="customLabel",
                        field_level="fieldLevel",
                        field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                            field_id="fieldId"
                        )],
                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                        custom_label="customLabel",
                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f5d6729c91fe72bf1cbd0bb576ebf0b0de75aef2ff9e57ecddf2d1785bd67e33)
                check_type(argname="argument column_subtotal_options", value=column_subtotal_options, expected_type=type_hints["column_subtotal_options"])
                check_type(argname="argument column_total_options", value=column_total_options, expected_type=type_hints["column_total_options"])
                check_type(argname="argument row_subtotal_options", value=row_subtotal_options, expected_type=type_hints["row_subtotal_options"])
                check_type(argname="argument row_total_options", value=row_total_options, expected_type=type_hints["row_total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_subtotal_options is not None:
                self._values["column_subtotal_options"] = column_subtotal_options
            if column_total_options is not None:
                self._values["column_total_options"] = column_total_options
            if row_subtotal_options is not None:
                self._values["row_subtotal_options"] = row_subtotal_options
            if row_total_options is not None:
                self._values["row_total_options"] = row_total_options

        @builtins.property
        def column_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SubtotalOptionsProperty"]]:
            '''The column subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-columnsubtotaloptions
            '''
            result = self._values.get("column_subtotal_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SubtotalOptionsProperty"]], result)

        @builtins.property
        def column_total_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTotalOptionsProperty"]]:
            '''The column total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-columntotaloptions
            '''
            result = self._values.get("column_total_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTotalOptionsProperty"]], result)

        @builtins.property
        def row_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SubtotalOptionsProperty"]]:
            '''The row subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-rowsubtotaloptions
            '''
            result = self._values.get("row_subtotal_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SubtotalOptionsProperty"]], result)

        @builtins.property
        def row_total_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTotalOptionsProperty"]]:
            '''The row total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-rowtotaloptions
            '''
            result = self._values.get("row_total_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PivotTableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_table_visual_property = quicksight.CfnTemplate.PivotTableVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.PivotTableConfigurationProperty(
                        field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                            data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                                data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )],
                
                                # the properties below are optional
                                width="width"
                            )],
                            selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                custom_label="customLabel",
                                visibility="visibility"
                            )]
                        ),
                        field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                            pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                                columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                            overflow_column_header_visibility="overflowColumnHeaderVisibility",
                            vertical_overflow_visibility="verticalOverflowVisibility"
                        ),
                        sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                            field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                                field_id="fieldId",
                                sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                    column=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                        direction="direction",
                                        sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )]
                                    ),
                                    field=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )
                            )]
                        ),
                        table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                            cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            column_names_visibility="columnNamesVisibility",
                            metric_placement="metricPlacement",
                            row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                row_alternate_colors=["rowAlternateColors"],
                                status="status"
                            ),
                            row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            single_metric_visibility="singleMetricVisibility",
                            toggle_buttons_visibility="toggleButtonsVisibility"
                        ),
                        total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                            column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                custom_label="customLabel",
                                field_level="fieldLevel",
                                field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                    field_id="fieldId"
                                )],
                                metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                custom_label="customLabel",
                                metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                custom_label="customLabel",
                                field_level="fieldLevel",
                                field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                    field_id="fieldId"
                                )],
                                metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                custom_label="customLabel",
                                metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        )
                    ),
                    conditional_formatting=quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                            cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                    role="role"
                                ),
                                text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__146828c2a834df67b29e4968b17f81d6956be56036ccab98eccdd63b1aae632a)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableConditionalFormattingProperty"]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PivotTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class PivotTotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            metric_header_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The optional configuration of totals cells in a ``PivotTableVisual`` .

            :param custom_label: The custom label string for the total cells.
            :param metric_header_cell_style: The cell styling options for the total of header cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_cell_style: The cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.
            :param value_cell_style: The cell styling options for the totals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                pivot_total_options_property = quicksight.CfnTemplate.PivotTotalOptionsProperty(
                    custom_label="customLabel",
                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c8a2015b32c17c40bc2e896b60c957295ef26ac76ab46c67985ab068067e7783)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]]:
            '''The cell styling options for the total of header cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]]:
            '''The cell styling options for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]]:
            '''The cell styling options for the totals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.PredefinedHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class PredefinedHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :param columns: The list of columns that define the predefined hierarchy.
            :param hierarchy_id: The hierarchy ID of the predefined hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                predefined_hierarchy_property = quicksight.CfnTemplate.PredefinedHierarchyProperty(
                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cdc19a96d146feace31864ec2aceb0a0a587458f54185acf5b83cc75c88a0574)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]]]:
            '''The list of columns that define the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DrillDownFilterProperty"]]]]:
            '''The option that determines the drill down filters for the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DrillDownFilterProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PredefinedHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ProgressBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ProgressBarOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :param visibility: The visibility of the progress bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-progressbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                progress_bar_options_property = quicksight.CfnTemplate.ProgressBarOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2fbeff0581bdd92eb128cdd5bd61027d5452cd5207160e3d0d0c85d11411d649)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the progress bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-progressbaroptions.html#cfn-quicksight-template-progressbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ProgressBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "color": "color", "values": "values"},
    )
    class RadarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well configuration of a ``RadarChartVisual`` .

            :param category: The aggregated field well categories of a radar chart.
            :param color: The color that are assigned to the aggregated field wells of a radar chart.
            :param values: The values that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_aggregated_field_wells_property = quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    color=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__095a9eea9257aa9c90b7df132a754f7103ffb64cd51a997998e081eb1d730337)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if color is not None:
                self._values["color"] = color
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The aggregated field well categories of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The color that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The values that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RadarChartAreaStyleSettingsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configured style settings of a radar chart.

            :param visibility: The visibility settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartareastylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_area_style_settings_property = quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7fe678ae2b6d868b07d32dcbe9fe979faeabac00317121d42f08e1d3e4bf380f)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartareastylesettings.html#cfn-quicksight-template-radarchartareastylesettings-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAreaStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.RadarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "alternate_band_colors_visibility": "alternateBandColorsVisibility",
            "alternate_band_even_color": "alternateBandEvenColor",
            "alternate_band_odd_color": "alternateBandOddColor",
            "base_series_settings": "baseSeriesSettings",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_axis": "colorAxis",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "shape": "shape",
            "sort_configuration": "sortConfiguration",
            "start_angle": "startAngle",
            "visual_palette": "visualPalette",
        },
    )
    class RadarChartConfigurationProperty:
        def __init__(
            self,
            *,
            alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
            alternate_band_even_color: typing.Optional[builtins.str] = None,
            alternate_band_odd_color: typing.Optional[builtins.str] = None,
            base_series_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RadarChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RadarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            shape: typing.Optional[builtins.str] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RadarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            start_angle: typing.Optional[jsii.Number] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a ``RadarChartVisual`` .

            :param alternate_band_colors_visibility: Determines the visibility of the colors of alternatign bands in a radar chart.
            :param alternate_band_even_color: The color of the even-numbered alternate bands of a radar chart.
            :param alternate_band_odd_color: The color of the odd-numbered alternate bands of a radar chart.
            :param base_series_settings: The base sreies settings of a radar chart.
            :param category_axis: The category axis of a radar chart.
            :param category_label_options: The category label options of a radar chart.
            :param color_axis: The color axis of a radar chart.
            :param color_label_options: The color label options of a radar chart.
            :param field_wells: The field well configuration of a ``RadarChartVisual`` .
            :param legend: The legend display setup of the visual.
            :param shape: The shape of the radar chart.
            :param sort_configuration: The sort configuration of a ``RadarChartVisual`` .
            :param start_angle: The start angle of a radar chart's axis.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                radar_chart_configuration_property = quicksight.CfnTemplate.RadarChartConfigurationProperty(
                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                    alternate_band_even_color="alternateBandEvenColor",
                    alternate_band_odd_color="alternateBandOddColor",
                    base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                        area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                            visibility="visibility"
                        )
                    ),
                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                        radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    shape="shape",
                    sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    start_angle=123,
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96f7757eb87c230efcce250df70fb551839f1a71d53fd5adcadaa44d3129daec)
                check_type(argname="argument alternate_band_colors_visibility", value=alternate_band_colors_visibility, expected_type=type_hints["alternate_band_colors_visibility"])
                check_type(argname="argument alternate_band_even_color", value=alternate_band_even_color, expected_type=type_hints["alternate_band_even_color"])
                check_type(argname="argument alternate_band_odd_color", value=alternate_band_odd_color, expected_type=type_hints["alternate_band_odd_color"])
                check_type(argname="argument base_series_settings", value=base_series_settings, expected_type=type_hints["base_series_settings"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_axis", value=color_axis, expected_type=type_hints["color_axis"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument start_angle", value=start_angle, expected_type=type_hints["start_angle"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if alternate_band_colors_visibility is not None:
                self._values["alternate_band_colors_visibility"] = alternate_band_colors_visibility
            if alternate_band_even_color is not None:
                self._values["alternate_band_even_color"] = alternate_band_even_color
            if alternate_band_odd_color is not None:
                self._values["alternate_band_odd_color"] = alternate_band_odd_color
            if base_series_settings is not None:
                self._values["base_series_settings"] = base_series_settings
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_axis is not None:
                self._values["color_axis"] = color_axis
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if shape is not None:
                self._values["shape"] = shape
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if start_angle is not None:
                self._values["start_angle"] = start_angle
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def alternate_band_colors_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the colors of alternatign bands in a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandcolorsvisibility
            '''
            result = self._values.get("alternate_band_colors_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_even_color(self) -> typing.Optional[builtins.str]:
            '''The color of the even-numbered alternate bands of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandevencolor
            '''
            result = self._values.get("alternate_band_even_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_odd_color(self) -> typing.Optional[builtins.str]:
            '''The color of the odd-numbered alternate bands of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandoddcolor
            '''
            result = self._values.get("alternate_band_odd_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def base_series_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartSeriesSettingsProperty"]]:
            '''The base sreies settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-baseseriessettings
            '''
            result = self._values.get("base_series_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartSeriesSettingsProperty"]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The category axis of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The category label options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The color axis of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-coloraxis
            '''
            result = self._values.get("color_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The color label options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartFieldWellsProperty"]]:
            '''The field well configuration of a ``RadarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def shape(self) -> typing.Optional[builtins.str]:
            '''The shape of the radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-shape
            '''
            result = self._values.get("shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartSortConfigurationProperty"]]:
            '''The sort configuration of a ``RadarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartSortConfigurationProperty"]], result)

        @builtins.property
        def start_angle(self) -> typing.Optional[jsii.Number]:
            '''The start angle of a radar chart's axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-startangle
            '''
            result = self._values.get("start_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.RadarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "radar_chart_aggregated_field_wells": "radarChartAggregatedFieldWells",
        },
    )
    class RadarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            radar_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RadarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a radar chart visual.

            :param radar_chart_aggregated_field_wells: The aggregated field wells of a radar chart visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_field_wells_property = quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                    radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        color=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5d8bf0e7e9dc42df37a53ddcf58192e5fe86aecfb15833acb48d3fcc7b4eb4c4)
                check_type(argname="argument radar_chart_aggregated_field_wells", value=radar_chart_aggregated_field_wells, expected_type=type_hints["radar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if radar_chart_aggregated_field_wells is not None:
                self._values["radar_chart_aggregated_field_wells"] = radar_chart_aggregated_field_wells

        @builtins.property
        def radar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a radar chart visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartfieldwells.html#cfn-quicksight-template-radarchartfieldwells-radarchartaggregatedfieldwells
            '''
            result = self._values.get("radar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.RadarChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"area_style_settings": "areaStyleSettings"},
    )
    class RadarChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            area_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RadarChartAreaStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The series settings of a radar chart.

            :param area_style_settings: The area style settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_series_settings_property = quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                    area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__097e9c133742d068d61cacad3b4f0432216e37ff94eefbdc1d55772acec58fc5)
                check_type(argname="argument area_style_settings", value=area_style_settings, expected_type=type_hints["area_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if area_style_settings is not None:
                self._values["area_style_settings"] = area_style_settings

        @builtins.property
        def area_style_settings(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartAreaStyleSettingsProperty"]]:
            '''The area style settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartseriessettings.html#cfn-quicksight-template-radarchartseriessettings-areastylesettings
            '''
            result = self._values.get("area_style_settings")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartAreaStyleSettingsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.RadarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class RadarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a ``RadarChartVisual`` .

            :param category_items_limit: The category items limit for a radar chart.
            :param category_sort: The category sort options of a radar chart.
            :param color_items_limit: The color items limit of a radar chart.
            :param color_sort: The color sort configuration of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                radar_chart_sort_configuration_property = quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5e72e8280ca99dece4ab1785fc1d83ad258d0876ee04d2f491e276e0a139da57)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The category items limit for a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The category sort options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The color items limit of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The color sort configuration of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.RadarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class RadarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RadarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A radar chart visual.

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                radar_chart_visual_property = quicksight.CfnTemplate.RadarChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.RadarChartConfigurationProperty(
                        alternate_band_colors_visibility="alternateBandColorsVisibility",
                        alternate_band_even_color="alternateBandEvenColor",
                        alternate_band_odd_color="alternateBandOddColor",
                        base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                            area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                                visibility="visibility"
                            )
                        ),
                        category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                            radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        shape="shape",
                        sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        start_angle=123,
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1d64fd9efcc95ec898ca909a2759e9ce1934fdf3a7effd0190eba7f20d2a7eee)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.RangeEndsLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RangeEndsLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The range ends label type of a data path label.

            :param visibility: The visibility of the range ends label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rangeendslabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                range_ends_label_type_property = quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a5088b07837546460f883aabdea7314c35114296b8869c5c97c6300a31ff7fd4)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the range ends label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rangeendslabeltype.html#cfn-quicksight-template-rangeendslabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RangeEndsLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_label": "customLabel"},
    )
    class ReferenceLineCustomLabelConfigurationProperty:
        def __init__(self, *, custom_label: builtins.str) -> None:
            '''The configuration for a custom label on a ``ReferenceLine`` .

            :param custom_label: The string text of the custom label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinecustomlabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_custom_label_configuration_property = quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                    custom_label="customLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ed4c82403805b57bdb385478e81e2b81849d4bb6f2b22cbdb4263fe4dadfe363)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_label": custom_label,
            }

        @builtins.property
        def custom_label(self) -> builtins.str:
            '''The string text of the custom label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinecustomlabelconfiguration.html#cfn-quicksight-template-referencelinecustomlabelconfiguration-customlabel
            '''
            result = self._values.get("custom_label")
            assert result is not None, "Required property 'custom_label' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineCustomLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "dynamic_configuration": "dynamicConfiguration",
            "static_configuration": "staticConfiguration",
        },
    )
    class ReferenceLineDataConfigurationProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            dynamic_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ReferenceLineDynamicDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ReferenceLineStaticDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The data configuration of the reference line.

            :param axis_binding: The axis binding type of the reference line. Choose one of the following options:. - PrimaryY - SecondaryY
            :param dynamic_configuration: The dynamic configuration of the reference line data configuration.
            :param static_configuration: The static data configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_data_configuration_property = quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                    axis_binding="axisBinding",
                    dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                        calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f951199320edb751350a5c9a70a386180fb3093e41174bb3d2666184ff3efa0b)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument dynamic_configuration", value=dynamic_configuration, expected_type=type_hints["dynamic_configuration"])
                check_type(argname="argument static_configuration", value=static_configuration, expected_type=type_hints["static_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if dynamic_configuration is not None:
                self._values["dynamic_configuration"] = dynamic_configuration
            if static_configuration is not None:
                self._values["static_configuration"] = static_configuration

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis binding type of the reference line. Choose one of the following options:.

            - PrimaryY
            - SecondaryY

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dynamic_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineDynamicDataConfigurationProperty"]]:
            '''The dynamic configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-dynamicconfiguration
            '''
            result = self._values.get("dynamic_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineDynamicDataConfigurationProperty"]], result)

        @builtins.property
        def static_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineStaticDataConfigurationProperty"]]:
            '''The static data configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-staticconfiguration
            '''
            result = self._values.get("static_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineStaticDataConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculation": "calculation",
            "column": "column",
            "measure_aggregation_function": "measureAggregationFunction",
        },
    )
    class ReferenceLineDynamicDataConfigurationProperty:
        def __init__(
            self,
            *,
            calculation: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            measure_aggregation_function: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The dynamic configuration of the reference line data configuration.

            :param calculation: The calculation that is used in the dynamic data.
            :param column: The column that the dynamic data targets.
            :param measure_aggregation_function: The aggregation function that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_dynamic_data_configuration_property = quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                    calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7691d7ab751d6135e0ca0bf93dcb6da2fef97a5ed77bd57edab2e022a3449c5)
                check_type(argname="argument calculation", value=calculation, expected_type=type_hints["calculation"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument measure_aggregation_function", value=measure_aggregation_function, expected_type=type_hints["measure_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "calculation": calculation,
                "column": column,
                "measure_aggregation_function": measure_aggregation_function,
            }

        @builtins.property
        def calculation(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericalAggregationFunctionProperty"]:
            '''The calculation that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-calculation
            '''
            result = self._values.get("calculation")
            assert result is not None, "Required property 'calculation' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericalAggregationFunctionProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the dynamic data targets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def measure_aggregation_function(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationFunctionProperty"]:
            '''The aggregation function that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-measureaggregationfunction
            '''
            result = self._values.get("measure_aggregation_function")
            assert result is not None, "Required property 'measure_aggregation_function' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationFunctionProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDynamicDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label_configuration": "customLabelConfiguration",
            "font_color": "fontColor",
            "font_configuration": "fontConfiguration",
            "horizontal_position": "horizontalPosition",
            "value_label_configuration": "valueLabelConfiguration",
            "vertical_position": "verticalPosition",
        },
    )
    class ReferenceLineLabelConfigurationProperty:
        def __init__(
            self,
            *,
            custom_label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ReferenceLineCustomLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_color: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            horizontal_position: typing.Optional[builtins.str] = None,
            value_label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ReferenceLineValueLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            vertical_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label configuration of a reference line.

            :param custom_label_configuration: The custom label configuration of the label in a reference line.
            :param font_color: The font color configuration of the label in a reference line.
            :param font_configuration: The font configuration of the label in a reference line.
            :param horizontal_position: The horizontal position configuration of the label in a reference line. Choose one of the following options:. - ``LEFT`` - ``CENTER`` - ``RIGHT``
            :param value_label_configuration: The value label configuration of the label in a reference line.
            :param vertical_position: The vertical position configuration of the label in a reference line. Choose one of the following options:. - ``ABOVE`` - ``BELOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_label_configuration_property = quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                    custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                        custom_label="customLabel"
                    ),
                    font_color="fontColor",
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_position="horizontalPosition",
                    value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        relative_position="relativePosition"
                    ),
                    vertical_position="verticalPosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6681fa3f7ecf41b46f494147d4c15e6f4f01510780fe1655653912ba8cfafb4a)
                check_type(argname="argument custom_label_configuration", value=custom_label_configuration, expected_type=type_hints["custom_label_configuration"])
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_position", value=horizontal_position, expected_type=type_hints["horizontal_position"])
                check_type(argname="argument value_label_configuration", value=value_label_configuration, expected_type=type_hints["value_label_configuration"])
                check_type(argname="argument vertical_position", value=vertical_position, expected_type=type_hints["vertical_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label_configuration is not None:
                self._values["custom_label_configuration"] = custom_label_configuration
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_position is not None:
                self._values["horizontal_position"] = horizontal_position
            if value_label_configuration is not None:
                self._values["value_label_configuration"] = value_label_configuration
            if vertical_position is not None:
                self._values["vertical_position"] = vertical_position

        @builtins.property
        def custom_label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineCustomLabelConfigurationProperty"]]:
            '''The custom label configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-customlabelconfiguration
            '''
            result = self._values.get("custom_label_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineCustomLabelConfigurationProperty"]], result)

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''The font color configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]]:
            '''The font configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def horizontal_position(self) -> typing.Optional[builtins.str]:
            '''The horizontal position configuration of the label in a reference line. Choose one of the following options:.

            - ``LEFT``
            - ``CENTER``
            - ``RIGHT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-horizontalposition
            '''
            result = self._values.get("horizontal_position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineValueLabelConfigurationProperty"]]:
            '''The value label configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-valuelabelconfiguration
            '''
            result = self._values.get("value_label_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineValueLabelConfigurationProperty"]], result)

        @builtins.property
        def vertical_position(self) -> typing.Optional[builtins.str]:
            '''The vertical position configuration of the label in a reference line. Choose one of the following options:.

            - ``ABOVE``
            - ``BELOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-verticalposition
            '''
            result = self._values.get("vertical_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ReferenceLineProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_configuration": "dataConfiguration",
            "label_configuration": "labelConfiguration",
            "status": "status",
            "style_configuration": "styleConfiguration",
        },
    )
    class ReferenceLineProperty:
        def __init__(
            self,
            *,
            data_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ReferenceLineDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ReferenceLineLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            status: typing.Optional[builtins.str] = None,
            style_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ReferenceLineStyleConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The reference line visual display options.

            :param data_configuration: The data configuration of the reference line.
            :param label_configuration: The label configuration of the reference line.
            :param status: The status of the reference line. Choose one of the following options:. - ``ENABLE`` - ``DISABLE``
            :param style_configuration: The style configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_property = quicksight.CfnTemplate.ReferenceLineProperty(
                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                        axis_binding="axisBinding",
                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                            value=123
                        )
                    ),
                
                    # the properties below are optional
                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                            custom_label="customLabel"
                        ),
                        font_color="fontColor",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_position="horizontalPosition",
                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            relative_position="relativePosition"
                        ),
                        vertical_position="verticalPosition"
                    ),
                    status="status",
                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                        color="color",
                        pattern="pattern"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bff8e571bf73d0416515ef0837435b6e6faf6e0a5308c9c43fcdd3872f409454)
                check_type(argname="argument data_configuration", value=data_configuration, expected_type=type_hints["data_configuration"])
                check_type(argname="argument label_configuration", value=label_configuration, expected_type=type_hints["label_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument style_configuration", value=style_configuration, expected_type=type_hints["style_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_configuration": data_configuration,
            }
            if label_configuration is not None:
                self._values["label_configuration"] = label_configuration
            if status is not None:
                self._values["status"] = status
            if style_configuration is not None:
                self._values["style_configuration"] = style_configuration

        @builtins.property
        def data_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineDataConfigurationProperty"]:
            '''The data configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-dataconfiguration
            '''
            result = self._values.get("data_configuration")
            assert result is not None, "Required property 'data_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineDataConfigurationProperty"], result)

        @builtins.property
        def label_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineLabelConfigurationProperty"]]:
            '''The label configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-labelconfiguration
            '''
            result = self._values.get("label_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineLabelConfigurationProperty"]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the reference line. Choose one of the following options:.

            - ``ENABLE``
            - ``DISABLE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineStyleConfigurationProperty"]]:
            '''The style configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-styleconfiguration
            '''
            result = self._values.get("style_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ReferenceLineStyleConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class ReferenceLineStaticDataConfigurationProperty:
        def __init__(self, *, value: jsii.Number) -> None:
            '''The static data configuration of the reference line data configuration.

            :param value: The double input of the static data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestaticdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_static_data_configuration_property = quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__895e4cec174e07b469a195a4fa6b7ecd2790e36ecd1e66196fca6e9f1fbad499)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "value": value,
            }

        @builtins.property
        def value(self) -> jsii.Number:
            '''The double input of the static data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestaticdataconfiguration.html#cfn-quicksight-template-referencelinestaticdataconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStaticDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "pattern": "pattern"},
    )
    class ReferenceLineStyleConfigurationProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            pattern: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The style configuration of the reference line.

            :param color: The hex color of the reference line.
            :param pattern: The pattern type of the line style. Choose one of the following options:. - ``SOLID`` - ``DASHED`` - ``DOTTED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_style_configuration_property = quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                    color="color",
                    pattern="pattern"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0420fcff71b3b7d3a6389bd01a087cc94aa02ac89dac45c3e69666ae1f84289b)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if pattern is not None:
                self._values["pattern"] = pattern

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The hex color of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html#cfn-quicksight-template-referencelinestyleconfiguration-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def pattern(self) -> typing.Optional[builtins.str]:
            '''The pattern type of the line style. Choose one of the following options:.

            - ``SOLID``
            - ``DASHED``
            - ``DOTTED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html#cfn-quicksight-template-referencelinestyleconfiguration-pattern
            '''
            result = self._values.get("pattern")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStyleConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "format_configuration": "formatConfiguration",
            "relative_position": "relativePosition",
        },
    )
    class ReferenceLineValueLabelConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            relative_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value label configuration of the label in a reference line.

            :param format_configuration: The format configuration of the value label.
            :param relative_position: The relative position of the value label. Choose one of the following options:. - ``BEFORE_CUSTOM_LABEL`` - ``AFTER_CUSTOM_LABEL``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                reference_line_value_label_configuration_property = quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    relative_position="relativePosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e334758eac1d605c590ffe46ef717e16df6946b9f617bee8e33308704a05f45c)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument relative_position", value=relative_position, expected_type=type_hints["relative_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if relative_position is not None:
                self._values["relative_position"] = relative_position

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericFormatConfigurationProperty"]]:
            '''The format configuration of the value label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html#cfn-quicksight-template-referencelinevaluelabelconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericFormatConfigurationProperty"]], result)

        @builtins.property
        def relative_position(self) -> typing.Optional[builtins.str]:
            '''The relative position of the value label. Choose one of the following options:.

            - ``BEFORE_CUSTOM_LABEL``
            - ``AFTER_CUSTOM_LABEL``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html#cfn-quicksight-template-referencelinevaluelabelconfiguration-relativeposition
            '''
            result = self._values.get("relative_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineValueLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "title_options": "titleOptions",
        },
    )
    class RelativeDateTimeControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                relative_date_time_control_display_options_property = quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f86545a16d0420903a655e122d7d64eee742623db2564c6e735dbdb7e9b9785)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html#cfn-quicksight-template-relativedatetimecontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html#cfn-quicksight-template-relativedatetimecontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDateTimeControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.RelativeDatesFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_date_configuration": "anchorDateConfiguration",
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "relative_date_type": "relativeDateType",
            "time_granularity": "timeGranularity",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "minimum_granularity": "minimumGranularity",
            "parameter_name": "parameterName",
            "relative_date_value": "relativeDateValue",
        },
    )
    class RelativeDatesFilterProperty:
        def __init__(
            self,
            *,
            anchor_date_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AnchorDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            relative_date_type: builtins.str,
            time_granularity: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            minimum_granularity: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            relative_date_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``RelativeDatesFilter`` filters relative dates values.

            :param anchor_date_configuration: The date configuration of the filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param relative_date_type: The range date type of the filter. Choose one of the options below:. - ``PREVIOUS`` - ``THIS`` - ``LAST`` - ``NOW`` - ``NEXT``
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param exclude_period_configuration: The configuration for the exclude period of the filter.
            :param minimum_granularity: The minimum granularity (period granularity) of the relative dates filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param relative_date_value: The date value of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                relative_dates_filter_property = quicksight.CfnTemplate.RelativeDatesFilterProperty(
                    anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                        anchor_option="anchorOption",
                        parameter_name="parameterName"
                    ),
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                    relative_date_type="relativeDateType",
                    time_granularity="timeGranularity",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    minimum_granularity="minimumGranularity",
                    parameter_name="parameterName",
                    relative_date_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ffbb840ad1107d349338ba41684b863ffbda9809024b0529c9f576978cc1472f)
                check_type(argname="argument anchor_date_configuration", value=anchor_date_configuration, expected_type=type_hints["anchor_date_configuration"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument relative_date_type", value=relative_date_type, expected_type=type_hints["relative_date_type"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument minimum_granularity", value=minimum_granularity, expected_type=type_hints["minimum_granularity"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument relative_date_value", value=relative_date_value, expected_type=type_hints["relative_date_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "anchor_date_configuration": anchor_date_configuration,
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
                "relative_date_type": relative_date_type,
                "time_granularity": time_granularity,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if minimum_granularity is not None:
                self._values["minimum_granularity"] = minimum_granularity
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if relative_date_value is not None:
                self._values["relative_date_value"] = relative_date_value

        @builtins.property
        def anchor_date_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AnchorDateConfigurationProperty"]:
            '''The date configuration of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-anchordateconfiguration
            '''
            result = self._values.get("anchor_date_configuration")
            assert result is not None, "Required property 'anchor_date_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AnchorDateConfigurationProperty"], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def relative_date_type(self) -> builtins.str:
            '''The range date type of the filter. Choose one of the options below:.

            - ``PREVIOUS``
            - ``THIS``
            - ``LAST``
            - ``NOW``
            - ``NEXT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-relativedatetype
            '''
            result = self._values.get("relative_date_type")
            assert result is not None, "Required property 'relative_date_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ExcludePeriodConfigurationProperty"]]:
            '''The configuration for the exclude period of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ExcludePeriodConfigurationProperty"]], result)

        @builtins.property
        def minimum_granularity(self) -> typing.Optional[builtins.str]:
            '''The minimum granularity (period granularity) of the relative dates filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-minimumgranularity
            '''
            result = self._values.get("minimum_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def relative_date_value(self) -> typing.Optional[jsii.Number]:
            '''The date value of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-relativedatevalue
            '''
            result = self._values.get("relative_date_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDatesFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "actions": "actions",
            "principal": "principal",
            "resource": "resource",
        },
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
            resource: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
            :param resource: ``CfnTemplate.ResourcePermissionProperty.Resource``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnTemplate.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
                
                    # the properties below are optional
                    resource="resource"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b09dc6ec382166a1a6c8698f327de3b289c8f7a0b69e9220ca28cb85e7971fe)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
                check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }
            if resource is not None:
                self._values["resource"] = resource

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def resource(self) -> typing.Optional[builtins.str]:
            '''``CfnTemplate.ResourcePermissionProperty.Resource``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-resource
            '''
            result = self._values.get("resource")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.RollingDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class RollingDateConfigurationProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            data_set_identifier: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The rolling date configuration of a date time filter.

            :param expression: The expression of the rolling date configuration.
            :param data_set_identifier: The data set that is used in the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                rolling_date_configuration_property = quicksight.CfnTemplate.RollingDateConfigurationProperty(
                    expression="expression",
                
                    # the properties below are optional
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7e77f6441c5544d1c8c5d9f12874f640744c309900b2677ffa601010a931035)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if data_set_identifier is not None:
                self._values["data_set_identifier"] = data_set_identifier

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html#cfn-quicksight-template-rollingdateconfiguration-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> typing.Optional[builtins.str]:
            '''The data set that is used in the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html#cfn-quicksight-template-rollingdateconfiguration-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RollingDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.RowAlternateColorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "row_alternate_colors": "rowAlternateColors",
            "status": "status",
        },
    )
    class RowAlternateColorOptionsProperty:
        def __init__(
            self,
            *,
            row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the row alternate color options.

            :param row_alternate_colors: Determines the list of row alternate colors.
            :param status: Determines the widget status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                row_alternate_color_options_property = quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                    row_alternate_colors=["rowAlternateColors"],
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__38d10353bdfdd52716b5673584f61452563aae5f84d7ebc4f1c5eb66d4ceb50f)
                check_type(argname="argument row_alternate_colors", value=row_alternate_colors, expected_type=type_hints["row_alternate_colors"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if row_alternate_colors is not None:
                self._values["row_alternate_colors"] = row_alternate_colors
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def row_alternate_colors(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Determines the list of row alternate colors.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html#cfn-quicksight-template-rowalternatecoloroptions-rowalternatecolors
            '''
            result = self._values.get("row_alternate_colors")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''Determines the widget status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html#cfn-quicksight-template-rowalternatecoloroptions-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowAlternateColorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_visual_options": "targetVisualOptions",
            "target_visuals": "targetVisuals",
        },
    )
    class SameSheetTargetVisualConfigurationProperty:
        def __init__(
            self,
            *,
            target_visual_options: typing.Optional[builtins.str] = None,
            target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param target_visual_options: The options that choose the target visual in the same sheet. Valid values are defined as follows: - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.
            :param target_visuals: A list of the target visual IDs that are located in the same sheet of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                same_sheet_target_visual_configuration_property = quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                    target_visual_options="targetVisualOptions",
                    target_visuals=["targetVisuals"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__11c541b5cf7f2cd1485b2524dde8d774defdf9b2b48a8154476f2ac511274ec2)
                check_type(argname="argument target_visual_options", value=target_visual_options, expected_type=type_hints["target_visual_options"])
                check_type(argname="argument target_visuals", value=target_visuals, expected_type=type_hints["target_visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_visual_options is not None:
                self._values["target_visual_options"] = target_visual_options
            if target_visuals is not None:
                self._values["target_visuals"] = target_visuals

        @builtins.property
        def target_visual_options(self) -> typing.Optional[builtins.str]:
            '''The options that choose the target visual in the same sheet.

            Valid values are defined as follows:

            - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html#cfn-quicksight-template-samesheettargetvisualconfiguration-targetvisualoptions
            '''
            result = self._values.get("target_visual_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def target_visuals(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of the target visual IDs that are located in the same sheet of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html#cfn-quicksight-template-samesheettargetvisualconfiguration-targetvisuals
            '''
            result = self._values.get("target_visuals")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SameSheetTargetVisualConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination": "destination",
            "source": "source",
            "weight": "weight",
        },
    )
    class SankeyDiagramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            destination: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            source: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            weight: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param destination: The destination field wells of a sankey diagram.
            :param source: The source field wells of a sankey diagram.
            :param weight: The weight field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_aggregated_field_wells_property = quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                    destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    source=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e6dce4ab950f301b2e353e1b4bd56f85d40b706fe9023788d6cdb549c8064ad7)
                check_type(argname="argument destination", value=destination, expected_type=type_hints["destination"])
                check_type(argname="argument source", value=source, expected_type=type_hints["source"])
                check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination is not None:
                self._values["destination"] = destination
            if source is not None:
                self._values["source"] = source
            if weight is not None:
                self._values["weight"] = weight

        @builtins.property
        def destination(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The destination field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-destination
            '''
            result = self._values.get("destination")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def source(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The source field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-source
            '''
            result = self._values.get("source")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def weight(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The weight field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-weight
            '''
            result = self._values.get("weight")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
        },
    )
    class SankeyDiagramChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SankeyDiagramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SankeyDiagramSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a sankey diagram.

            :param data_labels: The data label configuration of a sankey diagram.
            :param field_wells: The field well configuration of a sankey diagram.
            :param sort_configuration: The sort configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_chart_configuration_property = quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                        sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                            destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                        destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb16f663ef34bb6f0fdf5be0267ea4e70629740cfad1aaee67602b96f531ce4b)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The data label configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SankeyDiagramFieldWellsProperty"]]:
            '''The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SankeyDiagramFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SankeyDiagramSortConfigurationProperty"]]:
            '''The sort configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SankeyDiagramSortConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sankey_diagram_aggregated_field_wells": "sankeyDiagramAggregatedFieldWells",
        },
    )
    class SankeyDiagramFieldWellsProperty:
        def __init__(
            self,
            *,
            sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param sankey_diagram_aggregated_field_wells: The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_field_wells_property = quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                    sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                        destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        source=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d7ee6fa6b9e0ac59dfbbc6089b942df5b6eea4db627435d6822b25c09bb09a70)
                check_type(argname="argument sankey_diagram_aggregated_field_wells", value=sankey_diagram_aggregated_field_wells, expected_type=type_hints["sankey_diagram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sankey_diagram_aggregated_field_wells is not None:
                self._values["sankey_diagram_aggregated_field_wells"] = sankey_diagram_aggregated_field_wells

        @builtins.property
        def sankey_diagram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramfieldwells.html#cfn-quicksight-template-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
            '''
            result = self._values.get("sankey_diagram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_items_limit": "destinationItemsLimit",
            "source_items_limit": "sourceItemsLimit",
            "weight_sort": "weightSort",
        },
    )
    class SankeyDiagramSortConfigurationProperty:
        def __init__(
            self,
            *,
            destination_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            weight_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a sankey diagram.

            :param destination_items_limit: The limit on the number of destination nodes that are displayed in a sankey diagram.
            :param source_items_limit: The limit on the number of source nodes that are displayed in a sankey diagram.
            :param weight_sort: The sort configuration of the weight fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_sort_configuration_property = quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                    destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6b3817f41ae7ba394a810a11843e666c6017f6692e6877119dfca6b5cb66fa53)
                check_type(argname="argument destination_items_limit", value=destination_items_limit, expected_type=type_hints["destination_items_limit"])
                check_type(argname="argument source_items_limit", value=source_items_limit, expected_type=type_hints["source_items_limit"])
                check_type(argname="argument weight_sort", value=weight_sort, expected_type=type_hints["weight_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination_items_limit is not None:
                self._values["destination_items_limit"] = destination_items_limit
            if source_items_limit is not None:
                self._values["source_items_limit"] = source_items_limit
            if weight_sort is not None:
                self._values["weight_sort"] = weight_sort

        @builtins.property
        def destination_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of destination nodes that are displayed in a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-destinationitemslimit
            '''
            result = self._values.get("destination_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def source_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of source nodes that are displayed in a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-sourceitemslimit
            '''
            result = self._values.get("source_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def weight_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the weight fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-weightsort
            '''
            result = self._values.get("weight_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SankeyDiagramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class SankeyDiagramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SankeyDiagramChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a sankey diagram.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sankey_diagram_visual_property = quicksight.CfnTemplate.SankeyDiagramVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                            sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                                destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                            destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        )
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3a8fa08a3314084d5cec3f251f6416ecd68485fbaf0c4daa05f6df7373e9caf2)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SankeyDiagramChartConfigurationProperty"]]:
            '''The configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SankeyDiagramChartConfigurationProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "size": "size",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class ScatterPlotCategoricallyAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            x_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            y_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well of a scatter plot.

            :param category: The category field well of a scatter plot.
            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is aggregated by category.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                scatter_plot_categorically_aggregated_field_wells_property = quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c50887dda6fefb9488c05547f6e535268a9a532d818feb4367b8bdc2a2fd3c5)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The category field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The size field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotCategoricallyAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ScatterPlotConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
            "y_axis_label_options": "yAxisLabelOptions",
        },
    )
    class ScatterPlotConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ScatterPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a scatter plot.

            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.
            :param x_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
            :param x_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
            :param y_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
            :param y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                scatter_plot_configuration_property = quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__989de1bd52abd6d91e073dc3d1e256c4a3fd11a99dcd4b53ddec0a10cb6d86ba)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
                check_type(argname="argument y_axis_label_options", value=y_axis_label_options, expected_type=type_hints["y_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options
            if y_axis_label_options is not None:
                self._values["y_axis_label_options"] = y_axis_label_options

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ScatterPlotFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ScatterPlotFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-yaxislabeloptions
            '''
            result = self._values.get("y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ScatterPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scatter_plot_categorically_aggregated_field_wells": "scatterPlotCategoricallyAggregatedFieldWells",
            "scatter_plot_unaggregated_field_wells": "scatterPlotUnaggregatedFieldWells",
        },
    )
    class ScatterPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a scatter plot.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param scatter_plot_categorically_aggregated_field_wells: The aggregated field wells of a scatter plot. Scatter plots that have a field in the category (group/color) field will have aggregated field wells. The x and y-axes of these scatter plots are aggregated by category.
            :param scatter_plot_unaggregated_field_wells: The unaggregated field wells of a scatter plot. Scatter plots without a category field well have unaggregated field wells. The x and y-axes of these scatter plots are unaggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                scatter_plot_field_wells_property = quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__574b4d8c89b9f543bca9431e42f05d3fb3c4650e0a6d8f6665183ccc430b0d8d)
                check_type(argname="argument scatter_plot_categorically_aggregated_field_wells", value=scatter_plot_categorically_aggregated_field_wells, expected_type=type_hints["scatter_plot_categorically_aggregated_field_wells"])
                check_type(argname="argument scatter_plot_unaggregated_field_wells", value=scatter_plot_unaggregated_field_wells, expected_type=type_hints["scatter_plot_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if scatter_plot_categorically_aggregated_field_wells is not None:
                self._values["scatter_plot_categorically_aggregated_field_wells"] = scatter_plot_categorically_aggregated_field_wells
            if scatter_plot_unaggregated_field_wells is not None:
                self._values["scatter_plot_unaggregated_field_wells"] = scatter_plot_unaggregated_field_wells

        @builtins.property
        def scatter_plot_categorically_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a scatter plot.

            Scatter plots that have a field in the category (group/color) field will have aggregated field wells. The x and y-axes of these scatter plots are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html#cfn-quicksight-template-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_categorically_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty"]], result)

        @builtins.property
        def scatter_plot_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty"]]:
            '''The unaggregated field wells of a scatter plot.

            Scatter plots without a category field well have unaggregated field wells. The x and y-axes of these scatter plots are unaggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html#cfn-quicksight-template-scatterplotfieldwells-scatterplotunaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"size": "size", "x_axis": "xAxis", "y_axis": "yAxis"},
    )
    class ScatterPlotUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            x_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            y_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The unaggregated field wells of a scatter plot.

            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is a dimension field and cannot be aggregated.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                scatter_plot_unaggregated_field_wells_property = quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                    size=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d7960b944e5bac5cc6b38549e3794e1da16ad0d4e3b99d941b4ad6c03f8c203a)
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The size field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ScatterPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ScatterPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ScatterPlotConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                scatter_plot_visual_property = quicksight.CfnTemplate.ScatterPlotVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                            scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                                size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4da2f448e052b587e661c3748e378a7920d7a8c729aa4d7258410705196be454)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ScatterPlotConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ScatterPlotConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ScrollBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility", "visible_range": "visibleRange"},
    )
    class ScrollBarOptionsProperty:
        def __init__(
            self,
            *,
            visibility: typing.Optional[builtins.str] = None,
            visible_range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisibleRangeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The visual display options for a data zoom scroll bar.

            :param visibility: The visibility of the data zoom scroll bar.
            :param visible_range: The visibility range for the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                scroll_bar_options_property = quicksight.CfnTemplate.ScrollBarOptionsProperty(
                    visibility="visibility",
                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                            from=123,
                            to=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1861cacdaea4f9ce19ced5ae32e70faedac10e12c81e9cb782ba03dcc13a912b)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument visible_range", value=visible_range, expected_type=type_hints["visible_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility
            if visible_range is not None:
                self._values["visible_range"] = visible_range

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html#cfn-quicksight-template-scrollbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visible_range(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisibleRangeOptionsProperty"]]:
            '''The visibility range for the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html#cfn-quicksight-template-scrollbaroptions-visiblerange
            '''
            result = self._values.get("visible_range")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisibleRangeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScrollBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SecondaryValueOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SecondaryValueOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :param visibility: Determines the visibility of the secondary value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-secondaryvalueoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                secondary_value_options_property = quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75eeeab3ab6156ca5bc9507d047ebc08435a23bedc51bda121b979329d875d2c)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the secondary value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-secondaryvalueoptions.html#cfn-quicksight-template-secondaryvalueoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SecondaryValueOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SectionAfterPageBreakProperty",
        jsii_struct_bases=[],
        name_mapping={"status": "status"},
    )
    class SectionAfterPageBreakProperty:
        def __init__(self, *, status: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of a page break after a section.

            :param status: The option that enables or disables a page break at the end of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionafterpagebreak.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_after_page_break_property = quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5ba43ed7db0782d63dcb671f48fe5b87c90b6e049f7dc86c84bb4ab9f079cd0c)
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The option that enables or disables a page break at the end of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionafterpagebreak.html#cfn-quicksight-template-sectionafterpagebreak-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionAfterPageBreakProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"paper_canvas_size_options": "paperCanvasSizeOptions"},
    )
    class SectionBasedLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options for the canvas of a section-based layout.

            :param paper_canvas_size_options: The options for a paper canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_based_layout_canvas_size_options_property = quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                    paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                        paper_margin=quicksight.CfnTemplate.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        ),
                        paper_orientation="paperOrientation",
                        paper_size="paperSize"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d01dc390894c0ec232c06f911078e3e095b464cdff27ecb4dd7ed6e2e45fd414)
                check_type(argname="argument paper_canvas_size_options", value=paper_canvas_size_options, expected_type=type_hints["paper_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_canvas_size_options is not None:
                self._values["paper_canvas_size_options"] = paper_canvas_size_options

        @builtins.property
        def paper_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty"]]:
            '''The options for a paper canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
            '''
            result = self._values.get("paper_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "body_sections": "bodySections",
            "canvas_size_options": "canvasSizeOptions",
            "footer_sections": "footerSections",
            "header_sections": "headerSections",
        },
    )
    class SectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            body_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BodySectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]]],
            footer_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            header_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The configuration for a section-based layout.

            :param body_sections: A list of body section configurations.
            :param canvas_size_options: The options for the canvas of a section-based layout.
            :param footer_sections: A list of footer section configurations.
            :param header_sections: A list of header section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_based_layout_configuration_property = quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                    body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                        content=quicksight.CfnTemplate.BodySectionContentProperty(
                            layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                            after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                status="status"
                            )
                        ),
                        style=quicksight.CfnTemplate.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    ),
                    footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnTemplate.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnTemplate.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__332983e5bd59cfea1d53e8a4fcfaab6cbb7ae50f853934ec5b7dbb2f6a86a7ef)
                check_type(argname="argument body_sections", value=body_sections, expected_type=type_hints["body_sections"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
                check_type(argname="argument footer_sections", value=footer_sections, expected_type=type_hints["footer_sections"])
                check_type(argname="argument header_sections", value=header_sections, expected_type=type_hints["header_sections"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "body_sections": body_sections,
                "canvas_size_options": canvas_size_options,
                "footer_sections": footer_sections,
                "header_sections": header_sections,
            }

        @builtins.property
        def body_sections(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BodySectionConfigurationProperty"]]]:
            '''A list of body section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-bodysections
            '''
            result = self._values.get("body_sections")
            assert result is not None, "Required property 'body_sections' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BodySectionConfigurationProperty"]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty"]:
            '''The options for the canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty"], result)

        @builtins.property
        def footer_sections(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeaderFooterSectionConfigurationProperty"]]]:
            '''A list of footer section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-footersections
            '''
            result = self._values.get("footer_sections")
            assert result is not None, "Required property 'footer_sections' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeaderFooterSectionConfigurationProperty"]]], result)

        @builtins.property
        def header_sections(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeaderFooterSectionConfigurationProperty"]]]:
            '''A list of header section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-headersections
            '''
            result = self._values.get("header_sections")
            assert result is not None, "Required property 'header_sections' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeaderFooterSectionConfigurationProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "paper_margin": "paperMargin",
            "paper_orientation": "paperOrientation",
            "paper_size": "paperSize",
        },
    )
    class SectionBasedLayoutPaperCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_margin: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SpacingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paper_orientation: typing.Optional[builtins.str] = None,
            paper_size: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a paper canvas of a section-based layout.

            :param paper_margin: Defines the spacing between the canvas content and the top, bottom, left, and right edges.
            :param paper_orientation: The paper orientation that is used to define canvas dimensions. Choose one of the following options:. - PORTRAIT - LANDSCAPE
            :param paper_size: The paper size that is used to define canvas dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_based_layout_paper_canvas_size_options_property = quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                    paper_margin=quicksight.CfnTemplate.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    ),
                    paper_orientation="paperOrientation",
                    paper_size="paperSize"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a18714d8a417e62e64387933abd5bbf8d41dd57a11b35f8c43d82b0509168f79)
                check_type(argname="argument paper_margin", value=paper_margin, expected_type=type_hints["paper_margin"])
                check_type(argname="argument paper_orientation", value=paper_orientation, expected_type=type_hints["paper_orientation"])
                check_type(argname="argument paper_size", value=paper_size, expected_type=type_hints["paper_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_margin is not None:
                self._values["paper_margin"] = paper_margin
            if paper_orientation is not None:
                self._values["paper_orientation"] = paper_orientation
            if paper_size is not None:
                self._values["paper_size"] = paper_size

        @builtins.property
        def paper_margin(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SpacingProperty"]]:
            '''Defines the spacing between the canvas content and the top, bottom, left, and right edges.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-papermargin
            '''
            result = self._values.get("paper_margin")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SpacingProperty"]], result)

        @builtins.property
        def paper_orientation(self) -> typing.Optional[builtins.str]:
            '''The paper orientation that is used to define canvas dimensions. Choose one of the following options:.

            - PORTRAIT
            - LANDSCAPE

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-paperorientation
            '''
            result = self._values.get("paper_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def paper_size(self) -> typing.Optional[builtins.str]:
            '''The paper size that is used to define canvas dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-papersize
            '''
            result = self._values.get("paper_size")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutPaperCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form_layout": "freeFormLayout"},
    )
    class SectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FreeFormSectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The layout configuration of a section.

            :param free_form_layout: The free-form layout configuration of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_layout_configuration_property = quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d4357f7980b3ac7e5a36d219436f994672508105418f941db07f7929bf16defa)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "free_form_layout": free_form_layout,
            }

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormSectionLayoutConfigurationProperty"]:
            '''The free-form layout configuration of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionlayoutconfiguration.html#cfn-quicksight-template-sectionlayoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            assert result is not None, "Required property 'free_form_layout' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FreeFormSectionLayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SectionPageBreakConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"after": "after"},
    )
    class SectionPageBreakConfigurationProperty:
        def __init__(
            self,
            *,
            after: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SectionAfterPageBreakProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a page break for a section.

            :param after: The configuration of a page break after a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionpagebreakconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_page_break_configuration_property = quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                    after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b70b963165cbcd8724d0b022680232a27fa7eb3b6cf8ee98cc87250dcb408369)
                check_type(argname="argument after", value=after, expected_type=type_hints["after"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if after is not None:
                self._values["after"] = after

        @builtins.property
        def after(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionAfterPageBreakProperty"]]:
            '''The configuration of a page break after a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionpagebreakconfiguration.html#cfn-quicksight-template-sectionpagebreakconfiguration-after
            '''
            result = self._values.get("after")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SectionAfterPageBreakProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionPageBreakConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SectionStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"height": "height", "padding": "padding"},
    )
    class SectionStyleProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            padding: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SpacingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The options that style a section.

            :param height: The height of a section. Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.
            :param padding: The spacing between section content and its top, bottom, left, and right edges. There is no padding by default.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                section_style_property = quicksight.CfnTemplate.SectionStyleProperty(
                    height="height",
                    padding=quicksight.CfnTemplate.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e03d7b592feef121508b2403c225dd3d3e505634f182cfb2969241bc2573b42c)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument padding", value=padding, expected_type=type_hints["padding"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if padding is not None:
                self._values["padding"] = padding

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of a section.

            Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html#cfn-quicksight-template-sectionstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def padding(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SpacingProperty"]]:
            '''The spacing between section content and its top, bottom, left, and right edges.

            There is no padding by default.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html#cfn-quicksight-template-sectionstyle-padding
            '''
            result = self._values.get("padding")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SpacingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_visual_scoping_configurations": "sheetVisualScopingConfigurations",
        },
    )
    class SelectedSheetsFilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            sheet_visual_scoping_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SheetVisualScopingConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The configuration for applying a filter to specific sheets or visuals.

            You can apply this filter to multiple visuals that are on one sheet or to all visuals on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param sheet_visual_scoping_configurations: The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-selectedsheetsfilterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                selected_sheets_filter_scope_configuration_property = quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                    sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                        scope="scope",
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        visual_ids=["visualIds"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cbebab0daebeae96874493fe135a970b3bb48532d93e9bc5dd1001d64ffa4ce7)
                check_type(argname="argument sheet_visual_scoping_configurations", value=sheet_visual_scoping_configurations, expected_type=type_hints["sheet_visual_scoping_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sheet_visual_scoping_configurations is not None:
                self._values["sheet_visual_scoping_configurations"] = sheet_visual_scoping_configurations

        @builtins.property
        def sheet_visual_scoping_configurations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetVisualScopingConfigurationProperty"]]]]:
            '''The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-template-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
            '''
            result = self._values.get("sheet_visual_scoping_configurations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetVisualScopingConfigurationProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SelectedSheetsFilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_field_series_item": "dataFieldSeriesItem",
            "field_series_item": "fieldSeriesItem",
        },
    )
    class SeriesItemProperty:
        def __init__(
            self,
            *,
            data_field_series_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataFieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_series_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The series item configuration of a line chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_field_series_item: The data field series item configuration of a line chart.
            :param field_series_item: The field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                series_item_property = quicksight.CfnTemplate.SeriesItemProperty(
                    data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    ),
                    field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5ef94b9975654ae2a8f70919ae08af8698a96af5e3c8504efce56300ed0bddbc)
                check_type(argname="argument data_field_series_item", value=data_field_series_item, expected_type=type_hints["data_field_series_item"])
                check_type(argname="argument field_series_item", value=field_series_item, expected_type=type_hints["field_series_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_field_series_item is not None:
                self._values["data_field_series_item"] = data_field_series_item
            if field_series_item is not None:
                self._values["field_series_item"] = field_series_item

        @builtins.property
        def data_field_series_item(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataFieldSeriesItemProperty"]]:
            '''The data field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html#cfn-quicksight-template-seriesitem-datafieldseriesitem
            '''
            result = self._values.get("data_field_series_item")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataFieldSeriesItemProperty"]], result)

        @builtins.property
        def field_series_item(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSeriesItemProperty"]]:
            '''The field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html#cfn-quicksight-template-seriesitem-fieldseriesitem
            '''
            result = self._values.get("field_series_item")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSeriesItemProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SetParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_parameter_name": "destinationParameterName",
            "value": "value",
        },
    )
    class SetParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            destination_parameter_name: builtins.str,
            value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DestinationParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The configuration of adding parameters in action.

            :param destination_parameter_name: The destination parameter name of the ``SetParameterValueConfiguration`` .
            :param value: ``CfnTemplate.SetParameterValueConfigurationProperty.Value``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                set_parameter_value_configuration_property = quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                    destination_parameter_name="destinationParameterName",
                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                date_time_values=["dateTimeValues"],
                                decimal_values=[123],
                                integer_values=[123],
                                string_values=["stringValues"]
                            ),
                
                            # the properties below are optional
                            include_null_value=False
                        ),
                        select_all_value_options="selectAllValueOptions",
                        source_field="sourceField",
                        source_parameter_name="sourceParameterName"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__58d4e967cd00306ecb039e9e8e03c7f16a7b75013bfc7aee1aa23a67ae0ed659)
                check_type(argname="argument destination_parameter_name", value=destination_parameter_name, expected_type=type_hints["destination_parameter_name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "destination_parameter_name": destination_parameter_name,
                "value": value,
            }

        @builtins.property
        def destination_parameter_name(self) -> builtins.str:
            '''The destination parameter name of the ``SetParameterValueConfiguration`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html#cfn-quicksight-template-setparametervalueconfiguration-destinationparametername
            '''
            result = self._values.get("destination_parameter_name")
            assert result is not None, "Required property 'destination_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DestinationParameterValueConfigurationProperty"]:
            '''``CfnTemplate.SetParameterValueConfigurationProperty.Value``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html#cfn-quicksight-template-setparametervalueconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DestinationParameterValueConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SetParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ShapeConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={"background_color": "backgroundColor"},
    )
    class ShapeConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''The shape conditional formatting of a filled map visual.

            :param background_color: The conditional formatting for the shape background color of a filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shapeconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                shape_conditional_format_property = quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d6a55475f6abba68c2957a70aef92cb7bbd42b1359357187e55e6f197948faf)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "background_color": background_color,
            }

        @builtins.property
        def background_color(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]:
            '''The conditional formatting for the shape background color of a filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shapeconditionalformat.html#cfn-quicksight-template-shapeconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            assert result is not None, "Required property 'background_color' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShapeConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"grid_layout": "gridLayout"},
    )
    class SheetControlLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            grid_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :param grid_layout: The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_control_layout_configuration_property = quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                    grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33a7cc8555d6e123f5d793e59883d050ab8a3ec183e819e20c206f3c5558af26)
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GridLayoutConfigurationProperty"]]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayoutconfiguration.html#cfn-quicksight-template-sheetcontrollayoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GridLayoutConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SheetControlLayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class SheetControlLayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SheetControlLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A grid layout to define the placement of sheet control.

            :param configuration: The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_control_layout_property = quicksight.CfnTemplate.SheetControlLayoutProperty(
                    configuration=quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                        grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9831f60ab74b87f9b2c51fb29e72f0a7483fc63c0f21859f373870853f270dbf)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetControlLayoutConfigurationProperty"]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayout.html#cfn-quicksight-template-sheetcontrollayout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetControlLayoutConfigurationProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SheetDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_id": "sheetId",
            "content_type": "contentType",
            "description": "description",
            "filter_controls": "filterControls",
            "layouts": "layouts",
            "name": "name",
            "parameter_controls": "parameterControls",
            "sheet_control_layouts": "sheetControlLayouts",
            "text_boxes": "textBoxes",
            "title": "title",
            "visuals": "visuals",
        },
    )
    class SheetDefinitionProperty:
        def __init__(
            self,
            *,
            sheet_id: builtins.str,
            content_type: typing.Optional[builtins.str] = None,
            description: typing.Optional[builtins.str] = None,
            filter_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterControlProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            layouts: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LayoutProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            name: typing.Optional[builtins.str] = None,
            parameter_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ParameterControlProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheet_control_layouts: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SheetControlLayoutProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            text_boxes: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SheetTextBoxProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            title: typing.Optional[builtins.str] = None,
            visuals: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''A sheet is an object that contains a set of visuals that are viewed together on one page in a paginated report.

            Every analysis and dashboard must contain at least one sheet.

            :param sheet_id: The unique identifier of a sheet.
            :param content_type: The layout content type of the sheet. Choose one of the following options:. - ``PAGINATED`` : Creates a sheet for a paginated report. - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.
            :param description: A description of the sheet.
            :param filter_controls: The list of filter controls that are on a sheet. For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param layouts: Layouts define how the components of a sheet are arranged. For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .
            :param name: The name of the sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param parameter_controls: The list of parameter controls that are on a sheet. For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheet_control_layouts: The control layouts of the sheet.
            :param text_boxes: The text boxes that are on a sheet.
            :param title: The title of the sheet.
            :param visuals: A list of the visuals that are on a sheet. Visual placement is determined by the layout of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                sheet_definition_property = quicksight.CfnTemplate.SheetDefinitionProperty(
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    content_type="contentType",
                    description="description",
                    filter_controls=[quicksight.CfnTemplate.FilterControlProperty(
                        date_time_picker=quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        dropdown=quicksight.CfnTemplate.FilterDropDownControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnTemplate.FilterListControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        relative_date_time=quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        slider=quicksight.CfnTemplate.FilterSliderControlProperty(
                            filter_control_id="filterControlId",
                            maximum_value=123,
                            minimum_value=123,
                            source_filter_id="sourceFilterId",
                            step_size=123,
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        text_area=quicksight.CfnTemplate.FilterTextAreaControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnTemplate.FilterTextFieldControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    layouts=[quicksight.CfnTemplate.LayoutProperty(
                        configuration=quicksight.CfnTemplate.LayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
                
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                                body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                                    content=quicksight.CfnTemplate.BodySectionContentProperty(
                                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                        after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                            status="status"
                                        )
                                    ),
                                    style=quicksight.CfnTemplate.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                ),
                                footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    style=quicksight.CfnTemplate.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    style=quicksight.CfnTemplate.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )]
                            )
                        )
                    )],
                    name="name",
                    parameter_controls=[quicksight.CfnTemplate.ParameterControlProperty(
                        date_time_picker=quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        dropdown=quicksight.CfnTemplate.ParameterDropDownControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnTemplate.ParameterListControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        slider=quicksight.CfnTemplate.ParameterSliderControlProperty(
                            maximum_value=123,
                            minimum_value=123,
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            step_size=123,
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_area=quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    sheet_control_layouts=[quicksight.CfnTemplate.SheetControlLayoutProperty(
                        configuration=quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                            grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
                
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        )
                    )],
                    text_boxes=[quicksight.CfnTemplate.SheetTextBoxProperty(
                        sheet_text_box_id="sheetTextBoxId",
                
                        # the properties below are optional
                        content="content"
                    )],
                    title="title",
                    visuals=[quicksight.CfnTemplate.VisualProperty(
                        bar_chart_visual=quicksight.CfnTemplate.BarChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.BarChartConfigurationProperty(
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                                    bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                orientation="orientation",
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        box_plot_visual=quicksight.CfnTemplate.BoxPlotVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                                box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                                    all_data_points_visibility="allDataPointsVisibility",
                                    outlier_visibility="outlierVisibility",
                                    style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                                        fill_style="fillStyle"
                                    )
                                ),
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                                    box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    )
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        combo_chart_visual=quicksight.CfnTemplate.ComboChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.ComboChartConfigurationProperty(
                                bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                                    combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                                        bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        custom_content_visual=quicksight.CfnTemplate.CustomContentVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.CustomContentConfigurationProperty(
                                content_type="contentType",
                                content_url="contentUrl",
                                image_scaling="imageScaling"
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        empty_visual=quicksight.CfnTemplate.EmptyVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )]
                        ),
                        filled_map_visual=quicksight.CfnTemplate.FilledMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.FilledMapConfigurationProperty(
                                field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                                    filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                                        geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                                    shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        funnel_chart_visual=quicksight.CfnTemplate.FunnelChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    label_color="labelColor",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_data_label_style="measureDataLabelStyle",
                                    measure_label_visibility="measureLabelVisibility",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                                    funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        gauge_chart_visual=quicksight.CfnTemplate.GaugeChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                                    target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                                    arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                                        arc_angle=123,
                                        arc_thickness="arcThickness"
                                    ),
                                    arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                                        range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                            max=123,
                                            min=123
                                        ),
                                        reserve_range=123
                                    ),
                                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                ),
                                tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            conditional_formatting=quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                                    arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        geospatial_map_visual=quicksight.CfnTemplate.GeospatialMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                                field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                                    geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                                    cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                                        cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                            simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                                color="color"
                                            )
                                        )
                                    ),
                                    selected_point_style="selectedPointStyle"
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        heat_map_visual=quicksight.CfnTemplate.HeatMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.HeatMapConfigurationProperty(
                                color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
                
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                                    heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                                    heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        histogram_visual=quicksight.CfnTemplate.HistogramVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.HistogramConfigurationProperty(
                                bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                                    bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                                        value=123
                                    ),
                                    bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                                        bin_count_limit=123,
                                        value=123
                                    ),
                                    selected_bin_type="selectedBinType",
                                    start_value=123
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                                    histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                )
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        insight_visual=quicksight.CfnTemplate.InsightVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            insight_configuration=quicksight.CfnTemplate.InsightConfigurationProperty(
                                computations=[quicksight.CfnTemplate.ComputationProperty(
                                    forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        custom_seasonality_value=123,
                                        lower_boundary=123,
                                        name="name",
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality="seasonality",
                                        upper_boundary=123,
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        period_size=123,
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
                
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                                        computation_id="computationId",
                                        from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        period_time_granularity="periodTimeGranularity",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
                
                                        # the properties below are optional
                                        mover_size=123,
                                        name="name",
                                        sort_order="sortOrder",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        type="type",
                
                                        # the properties below are optional
                                        name="name",
                                        result_size=123,
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                                        computation_id="computationId",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                
                                        # the properties below are optional
                                        name="name"
                                    )
                                )],
                                custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                                    narrative="narrative"
                                )
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        kpi_visual=quicksight.CfnTemplate.KPIVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.KPIConfigurationProperty(
                                field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                                    target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                                    trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                                    primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        line_chart_visual=quicksight.CfnTemplate.LineChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.LineChartConfigurationProperty(
                                contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                                    axis_binding="axisBinding",
                                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                                    line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                                    forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                                        lower_boundary=123,
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality=123,
                                        upper_boundary=123
                                    ),
                                    scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                                        what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                            date="date",
                                            value=123
                                        ),
                                        what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                            end_date="endDate",
                                            start_date="startDate",
                                            value=123
                                        )
                                    )
                                )],
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                series=[quicksight.CfnTemplate.SeriesItemProperty(
                                    data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        field_value="fieldValue",
                                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    ),
                                    field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    )
                                )],
                                small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                                    category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                type="type",
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pie_chart_visual=quicksight.CfnTemplate.PieChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.PieChartConfigurationProperty(
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                                    arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                                        arc_thickness="arcThickness"
                                    ),
                                    donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                                        label_visibility="labelVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                                    pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pivot_table_visual=quicksight.CfnTemplate.PivotTableVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.PivotTableConfigurationProperty(
                                field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                                    data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                                        data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )],
                
                                        # the properties below are optional
                                        width="width"
                                    )],
                                    selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        visibility="visibility"
                                    )]
                                ),
                                field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                                    pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                                    field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                                        field_id="fieldId",
                                        sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                            column=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                                direction="direction",
                                                sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                                    field_id="fieldId",
                                                    field_value="fieldValue"
                                                )]
                                            ),
                                            field=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )
                                    )]
                                ),
                                table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_names_visibility="columnNamesVisibility",
                                    metric_placement="metricPlacement",
                                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    ),
                                    row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    single_metric_visibility="singleMetricVisibility",
                                    toggle_buttons_visibility="toggleButtonsVisibility"
                                ),
                                total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                                    column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                )
                            ),
                            conditional_formatting=quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                            role="role"
                                        ),
                                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        radar_chart_visual=quicksight.CfnTemplate.RadarChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.RadarChartConfigurationProperty(
                                alternate_band_colors_visibility="alternateBandColorsVisibility",
                                alternate_band_even_color="alternateBandEvenColor",
                                alternate_band_odd_color="alternateBandOddColor",
                                base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                                    area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                                    radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                shape="shape",
                                sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                start_angle=123,
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        sankey_diagram_visual=quicksight.CfnTemplate.SankeyDiagramVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                                    sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                                        destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                                    destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        scatter_plot_visual=quicksight.CfnTemplate.ScatterPlotVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        table_visual=quicksight.CfnTemplate.TableVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.TableConfigurationProperty(
                                field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                                    order=["order"],
                                    selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                            image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                                sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                )
                                            ),
                                            link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                                content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                                    custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                                        icon="icon"
                                                    ),
                                                    custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                            font_color="fontColor",
                                                            font_decoration="fontDecoration",
                                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                                relative="relative"
                                                            ),
                                                            font_style="fontStyle",
                                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                                name="name"
                                                            )
                                                        ),
                
                                                        # the properties below are optional
                                                        value="value"
                                                    )
                                                ),
                                                target="target"
                                            )
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    )]
                                ),
                                field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                                    table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                                        values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                                date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    ),
                                    row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                                    data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        negative_color="negativeColor",
                                        positive_color="positiveColor"
                                    )
                                )],
                                table_options=quicksight.CfnTemplate.TableOptionsProperty(
                                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    orientation="orientation",
                                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    )
                                ),
                                total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                                    custom_label="customLabel",
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility"
                                )
                            ),
                            conditional_formatting=quicksight.CfnTemplate.TableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    ),
                                    row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        tree_map_visual=quicksight.CfnTemplate.TreeMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.TreeMapConfigurationProperty(
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
                
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                                    tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                                    tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        waterfall_visual=quicksight.CfnTemplate.WaterfallVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                                category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                                    waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                                        breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                                    breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                                    total_bar_label="totalBarLabel"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        word_cloud_visual=quicksight.CfnTemplate.WordCloudVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                                    word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                                    cloud_layout="cloudLayout",
                                    maximum_string_length=123,
                                    word_casing="wordCasing",
                                    word_orientation="wordOrientation",
                                    word_padding="wordPadding",
                                    word_scaling="wordScaling"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b5cbe7b2e49d923ec415b843f2fc1da19e40269ce5cdfdf78cbb44cfc6888e4a)
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument filter_controls", value=filter_controls, expected_type=type_hints["filter_controls"])
                check_type(argname="argument layouts", value=layouts, expected_type=type_hints["layouts"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_controls", value=parameter_controls, expected_type=type_hints["parameter_controls"])
                check_type(argname="argument sheet_control_layouts", value=sheet_control_layouts, expected_type=type_hints["sheet_control_layouts"])
                check_type(argname="argument text_boxes", value=text_boxes, expected_type=type_hints["text_boxes"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visuals", value=visuals, expected_type=type_hints["visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_id": sheet_id,
            }
            if content_type is not None:
                self._values["content_type"] = content_type
            if description is not None:
                self._values["description"] = description
            if filter_controls is not None:
                self._values["filter_controls"] = filter_controls
            if layouts is not None:
                self._values["layouts"] = layouts
            if name is not None:
                self._values["name"] = name
            if parameter_controls is not None:
                self._values["parameter_controls"] = parameter_controls
            if sheet_control_layouts is not None:
                self._values["sheet_control_layouts"] = sheet_control_layouts
            if text_boxes is not None:
                self._values["text_boxes"] = text_boxes
            if title is not None:
                self._values["title"] = title
            if visuals is not None:
                self._values["visuals"] = visuals

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The unique identifier of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The layout content type of the sheet. Choose one of the following options:.

            - ``PAGINATED`` : Creates a sheet for a paginated report.
            - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''A description of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def filter_controls(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterControlProperty"]]]]:
            '''The list of filter controls that are on a sheet.

            For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-filtercontrols
            '''
            result = self._values.get("filter_controls")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterControlProperty"]]]], result)

        @builtins.property
        def layouts(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LayoutProperty"]]]]:
            '''Layouts define how the components of a sheet are arranged.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-layouts
            '''
            result = self._values.get("layouts")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LayoutProperty"]]]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_controls(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterControlProperty"]]]]:
            '''The list of parameter controls that are on a sheet.

            For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-parametercontrols
            '''
            result = self._values.get("parameter_controls")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterControlProperty"]]]], result)

        @builtins.property
        def sheet_control_layouts(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetControlLayoutProperty"]]]]:
            '''The control layouts of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-sheetcontrollayouts
            '''
            result = self._values.get("sheet_control_layouts")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetControlLayoutProperty"]]]], result)

        @builtins.property
        def text_boxes(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetTextBoxProperty"]]]]:
            '''The text boxes that are on a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-textboxes
            '''
            result = self._values.get("text_boxes")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetTextBoxProperty"]]]], result)

        @builtins.property
        def title(self) -> typing.Optional[builtins.str]:
            '''The title of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visuals(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualProperty"]]]]:
            '''A list of the visuals that are on a sheet.

            Visual placement is determined by the layout of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-visuals
            '''
            result = self._values.get("visuals")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SheetElementConfigurationOverridesProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The override configuration of the rendering rules of a sheet.

            :param visibility: Determines whether or not the overrides are visible. Choose one of the following options:. - ``VISIBLE`` - ``HIDDEN``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementconfigurationoverrides.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_element_configuration_overrides_property = quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9182daf0924b1ee487eb1f46fa7870581807713db24720374b72d78b6b11f11f)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the overrides are visible. Choose one of the following options:.

            - ``VISIBLE``
            - ``HIDDEN``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementconfigurationoverrides.html#cfn-quicksight-template-sheetelementconfigurationoverrides-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementConfigurationOverridesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SheetElementRenderingRuleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "configuration_overrides": "configurationOverrides",
            "expression": "expression",
        },
    )
    class SheetElementRenderingRuleProperty:
        def __init__(
            self,
            *,
            configuration_overrides: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SheetElementConfigurationOverridesProperty", typing.Dict[builtins.str, typing.Any]]],
            expression: builtins.str,
        ) -> None:
            '''The rendering rules of a sheet that uses a free-form layout.

            :param configuration_overrides: The override configuration of the rendering rules of a sheet.
            :param expression: The expression of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_element_rendering_rule_property = quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                        visibility="visibility"
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b516f185464bcee70a0bdaf1a78a2d71a4c22a57f8c6518dad766d97322a132)
                check_type(argname="argument configuration_overrides", value=configuration_overrides, expected_type=type_hints["configuration_overrides"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration_overrides": configuration_overrides,
                "expression": expression,
            }

        @builtins.property
        def configuration_overrides(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetElementConfigurationOverridesProperty"]:
            '''The override configuration of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html#cfn-quicksight-template-sheetelementrenderingrule-configurationoverrides
            '''
            result = self._values.get("configuration_overrides")
            assert result is not None, "Required property 'configuration_overrides' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetElementConfigurationOverridesProperty"], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html#cfn-quicksight-template-sheetelementrenderingrule-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementRenderingRuleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SheetProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "sheet_id": "sheetId"},
    )
    class SheetProperty:
        def __init__(
            self,
            *,
            name: typing.Optional[builtins.str] = None,
            sheet_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight.

            Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.

            :param name: The name of a sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param sheet_id: The unique identifier associated with a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_property = quicksight.CfnTemplate.SheetProperty(
                    name="name",
                    sheet_id="sheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__21f7115f0aced40a4d9034224651b3271649c96bddc733a72edfef865bd911dd)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name
            if sheet_id is not None:
                self._values["sheet_id"] = sheet_id

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html#cfn-quicksight-template-sheet-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sheet_id(self) -> typing.Optional[builtins.str]:
            '''The unique identifier associated with a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html#cfn-quicksight-template-sheet-sheetid
            '''
            result = self._values.get("sheet_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SheetTextBoxProperty",
        jsii_struct_bases=[],
        name_mapping={"sheet_text_box_id": "sheetTextBoxId", "content": "content"},
    )
    class SheetTextBoxProperty:
        def __init__(
            self,
            *,
            sheet_text_box_id: builtins.str,
            content: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A text box.

            :param sheet_text_box_id: The unique identifier for a text box. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
            :param content: The content that is displayed in the text box.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_text_box_property = quicksight.CfnTemplate.SheetTextBoxProperty(
                    sheet_text_box_id="sheetTextBoxId",
                
                    # the properties below are optional
                    content="content"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__543333098e297089353569c26abb78effe002d1c93675ccffdcbe6048994335c)
                check_type(argname="argument sheet_text_box_id", value=sheet_text_box_id, expected_type=type_hints["sheet_text_box_id"])
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_text_box_id": sheet_text_box_id,
            }
            if content is not None:
                self._values["content"] = content

        @builtins.property
        def sheet_text_box_id(self) -> builtins.str:
            '''The unique identifier for a text box.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html#cfn-quicksight-template-sheettextbox-sheettextboxid
            '''
            result = self._values.get("sheet_text_box_id")
            assert result is not None, "Required property 'sheet_text_box_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content(self) -> typing.Optional[builtins.str]:
            '''The content that is displayed in the text box.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html#cfn-quicksight-template-sheettextbox-content
            '''
            result = self._values.get("content")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetTextBoxProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scope": "scope",
            "sheet_id": "sheetId",
            "visual_ids": "visualIds",
        },
    )
    class SheetVisualScopingConfigurationProperty:
        def __init__(
            self,
            *,
            scope: builtins.str,
            sheet_id: builtins.str,
            visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The filter that is applied to the options.

            :param scope: The scope of the applied entities. Choose one of the following options:. - ``ALL_VISUALS`` - ``SELECTED_VISUALS``
            :param sheet_id: The selected sheet that the filter is applied to.
            :param visual_ids: The selected visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_visual_scoping_configuration_property = quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                    scope="scope",
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    visual_ids=["visualIds"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7d59337d6fc58ccfb926e1fdef6ac2c99f7544715b325382c4e778b0cdf2b3b1)
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument visual_ids", value=visual_ids, expected_type=type_hints["visual_ids"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "scope": scope,
                "sheet_id": sheet_id,
            }
            if visual_ids is not None:
                self._values["visual_ids"] = visual_ids

        @builtins.property
        def scope(self) -> builtins.str:
            '''The scope of the applied entities. Choose one of the following options:.

            - ``ALL_VISUALS``
            - ``SELECTED_VISUALS``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-scope
            '''
            result = self._values.get("scope")
            assert result is not None, "Required property 'scope' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The selected sheet that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_ids(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The selected visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-visualids
            '''
            result = self._values.get("visual_ids")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetVisualScopingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ShortFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class ShortFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for the title.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                short_format_text_property = quicksight.CfnTemplate.ShortFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b62b50a2f8d157300d1e0e5fa5d9703e0bacf64fb17a557783e5d07e07abc41f)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html#cfn-quicksight-template-shortformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html#cfn-quicksight-template-shortformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShortFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SimpleClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color"},
    )
    class SimpleClusterMarkerProperty:
        def __init__(self, *, color: typing.Optional[builtins.str] = None) -> None:
            '''The simple cluster marker of the cluster marker.

            :param color: The color of the simple cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-simpleclustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                simple_cluster_marker_property = quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac6a683c36447f6cc1a60f8ed5e6ebd52eb0b6e540a654eb5e64c62c496d0bb7)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of the simple cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-simpleclustermarker.html#cfn-quicksight-template-simpleclustermarker-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SimpleClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SliderControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"title_options": "titleOptions"},
    )
    class SliderControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-slidercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                slider_control_display_options_property = quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__13e00de9440e5e65d1325bdb54bdffb6c281d402d0c109d942e64360d0be202c)
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-slidercontroldisplayoptions.html#cfn-quicksight-template-slidercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SliderControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SmallMultiplesOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "max_visible_columns": "maxVisibleColumns",
            "max_visible_rows": "maxVisibleRows",
            "panel_configuration": "panelConfiguration",
        },
    )
    class SmallMultiplesOptionsProperty:
        def __init__(
            self,
            *,
            max_visible_columns: typing.Optional[jsii.Number] = None,
            max_visible_rows: typing.Optional[jsii.Number] = None,
            panel_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PanelConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Options that determine the layout and display options of a chart's small multiples.

            :param max_visible_columns: Sets the maximum number of visible columns to display in the grid of small multiples panels. The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
            :param max_visible_rows: Sets the maximum number of visible rows to display in the grid of small multiples panels. The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
            :param panel_configuration: Configures the display options for each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                small_multiples_options_property = quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                    max_visible_columns=123,
                    max_visible_rows=123,
                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                        background_color="backgroundColor",
                        background_visibility="backgroundVisibility",
                        border_color="borderColor",
                        border_style="borderStyle",
                        border_thickness="borderThickness",
                        border_visibility="borderVisibility",
                        gutter_spacing="gutterSpacing",
                        gutter_visibility="gutterVisibility",
                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_text_alignment="horizontalTextAlignment",
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__21c7f6b5ebf3a4cc33c865adc4e1b6d978259efe55ae5538a6b7d8bda686006d)
                check_type(argname="argument max_visible_columns", value=max_visible_columns, expected_type=type_hints["max_visible_columns"])
                check_type(argname="argument max_visible_rows", value=max_visible_rows, expected_type=type_hints["max_visible_rows"])
                check_type(argname="argument panel_configuration", value=panel_configuration, expected_type=type_hints["panel_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max_visible_columns is not None:
                self._values["max_visible_columns"] = max_visible_columns
            if max_visible_rows is not None:
                self._values["max_visible_rows"] = max_visible_rows
            if panel_configuration is not None:
                self._values["panel_configuration"] = panel_configuration

        @builtins.property
        def max_visible_columns(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible columns to display in the grid of small multiples panels.

            The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-maxvisiblecolumns
            '''
            result = self._values.get("max_visible_columns")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def max_visible_rows(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible rows to display in the grid of small multiples panels.

            The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-maxvisiblerows
            '''
            result = self._values.get("max_visible_rows")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def panel_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PanelConfigurationProperty"]]:
            '''Configures the display options for each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-panelconfiguration
            '''
            result = self._values.get("panel_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PanelConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SmallMultiplesOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SpacingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class SpacingProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[builtins.str] = None,
            left: typing.Optional[builtins.str] = None,
            right: typing.Optional[builtins.str] = None,
            top: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of spacing (often a margin or padding).

            :param bottom: Define the bottom spacing.
            :param left: Define the left spacing.
            :param right: Define the right spacing.
            :param top: Define the top spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                spacing_property = quicksight.CfnTemplate.SpacingProperty(
                    bottom="bottom",
                    left="left",
                    right="right",
                    top="top"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e20034a0c57a2cd823e62adc76a3be4950ac258bdb0ab7f63047ab063ef4c5f8)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(self) -> typing.Optional[builtins.str]:
            '''Define the bottom spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def left(self) -> typing.Optional[builtins.str]:
            '''Define the left spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def right(self) -> typing.Optional[builtins.str]:
            '''Define the right spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def top(self) -> typing.Optional[builtins.str]:
            '''Define the top spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SpacingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.StringDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class StringDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``StringParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``StringDefaultValues`` . Different defaults displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_default_values_property = quicksight.CfnTemplate.StringDefaultValuesProperty(
                    dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bdb82b2f5f87cd8248c76d68629866eea5e572817604a317a7adaa674df402f7)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DynamicDefaultValueProperty"]]:
            '''The dynamic value of the ``StringDefaultValues`` .

            Different defaults displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html#cfn-quicksight-template-stringdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DynamicDefaultValueProperty"]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html#cfn-quicksight-template-stringdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.StringFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class StringFormatConfigurationProperty:
        def __init__(
            self,
            *,
            null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Formatting configuration for string fields.

            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric strings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_format_configuration_property = quicksight.CfnTemplate.StringFormatConfigurationProperty(
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__40e7ac5fffd8efbe5888f760223c0c2935df76675627b0ad43a50560b4f9bb01)
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NullValueFormatConfigurationProperty"]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html#cfn-quicksight-template-stringformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NullValueFormatConfigurationProperty"]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericFormatConfigurationProperty"]]:
            '''The formatting configuration for numeric strings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html#cfn-quicksight-template-stringformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.NumericFormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.StringParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class StringParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.StringDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.StringValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A parameter declaration for the ``String`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnTemplate.StringParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_parameter_declaration_property = quicksight.CfnTemplate.StringParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnTemplate.StringDefaultValuesProperty(
                        dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__da717b40d4a97a18632c272f1c7e294a9fe141c9ec726f7da27828fc32279969)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.StringDefaultValuesProperty"]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.StringDefaultValuesProperty"]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MappedDataSetParameterProperty"]]]]:
            '''``CfnTemplate.StringParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MappedDataSetParameterProperty"]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.StringValueWhenUnsetConfigurationProperty"]]:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.StringValueWhenUnsetConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class StringValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                string_value_when_unset_configuration_property = quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b7e7823e45ca3c359bf27bc35e04105106ed9fb2667cc720232838ea57e93b49)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html#cfn-quicksight-template-stringvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html#cfn-quicksight-template-stringvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.SubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "field_level": "fieldLevel",
            "field_level_options": "fieldLevelOptions",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class SubtotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            field_level: typing.Optional[builtins.str] = None,
            field_level_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableFieldSubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            metric_header_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The subtotal options.

            :param custom_label: The custom label string for the subtotal cells.
            :param field_level: The field level (all, custom, last) for the subtotal cells.
            :param field_level_options: The optional configuration of subtotal cells.
            :param metric_header_cell_style: The cell styling options for the subtotals of header cells.
            :param total_cell_style: The cell styling options for the subtotal cells.
            :param totals_visibility: The visibility configuration for the subtotal cells.
            :param value_cell_style: The cell styling options for the subtotals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                subtotal_options_property = quicksight.CfnTemplate.SubtotalOptionsProperty(
                    custom_label="customLabel",
                    field_level="fieldLevel",
                    field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                        field_id="fieldId"
                    )],
                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dd162de8714c9bfbd3ca8d73eb00058046e6fd2772b4877effa9721ad32b7433)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument field_level", value=field_level, expected_type=type_hints["field_level"])
                check_type(argname="argument field_level_options", value=field_level_options, expected_type=type_hints["field_level_options"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if field_level is not None:
                self._values["field_level"] = field_level
            if field_level_options is not None:
                self._values["field_level_options"] = field_level_options
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level(self) -> typing.Optional[builtins.str]:
            '''The field level (all, custom, last) for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-fieldlevel
            '''
            result = self._values.get("field_level")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableFieldSubtotalOptionsProperty"]]]]:
            '''The optional configuration of subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-fieldleveloptions
            '''
            result = self._values.get("field_level_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableFieldSubtotalOptionsProperty"]]]], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotals of header cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]]:
            '''The cell styling options for the subtotals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class TableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field well for the table.

            :param group_by: The group by field well for a pivot table. Values are grouped by group by fields.
            :param values: The values field well for a pivot table. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_aggregated_field_wells_property = quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dfc08ee6fc7d3dc678431485ec4293e696ceee84ca8da8478bd0f6aec63ba6ee)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The group by field well for a pivot table.

            Values are grouped by group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html#cfn-quicksight-template-tableaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html#cfn-quicksight-template-tableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "style": "style", "thickness": "thickness"},
    )
    class TableBorderOptionsProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            style: typing.Optional[builtins.str] = None,
            thickness: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The border options for a table border.

            :param color: The color of a table border.
            :param style: The style (none, solid) of a table border.
            :param thickness: The thickness of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_border_options_property = quicksight.CfnTemplate.TableBorderOptionsProperty(
                    color="color",
                    style="style",
                    thickness=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a78c9fb72eb06f1a7bfc8123ef9fc027380f27ee4563bc683d70950c21fdce36)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
                check_type(argname="argument thickness", value=thickness, expected_type=type_hints["thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if style is not None:
                self._values["style"] = style
            if thickness is not None:
                self._values["thickness"] = thickness

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style(self) -> typing.Optional[builtins.str]:
            '''The style (none, solid) of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thickness(self) -> typing.Optional[jsii.Number]:
            '''The thickness of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-thickness
            '''
            result = self._values.get("thickness")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "text_format": "textFormat"},
    )
    class TableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            text_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The cell conditional formatting option for a table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_cell_conditional_formatting_property = quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6f7b19da59b0b0ce369aa6af3a7f2a8429384948f628227a0eaa12a8d8f0cc32)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html#cfn-quicksight-template-tablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextConditionalFormatProperty"]]:
            '''The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html#cfn-quicksight-template-tablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextConditionalFormatProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_cell_image_scaling_configuration": "tableCellImageScalingConfiguration",
        },
    )
    class TableCellImageSizingConfigurationProperty:
        def __init__(
            self,
            *,
            table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The sizing options for the table image configuration.

            :param table_cell_image_scaling_configuration: The cell scaling configuration of the sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellimagesizingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_cell_image_sizing_configuration_property = quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fac214beeb3c59ad5a438008eebe38504d998a55c118355e2c3edfff4259e375)
                check_type(argname="argument table_cell_image_scaling_configuration", value=table_cell_image_scaling_configuration, expected_type=type_hints["table_cell_image_scaling_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_cell_image_scaling_configuration is not None:
                self._values["table_cell_image_scaling_configuration"] = table_cell_image_scaling_configuration

        @builtins.property
        def table_cell_image_scaling_configuration(
            self,
        ) -> typing.Optional[builtins.str]:
            '''The cell scaling configuration of the sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellimagesizingconfiguration.html#cfn-quicksight-template-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
            '''
            result = self._values.get("table_cell_image_scaling_configuration")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellImageSizingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableCellStyleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "border": "border",
            "font_configuration": "fontConfiguration",
            "height": "height",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "text_wrap": "textWrap",
            "vertical_text_alignment": "verticalTextAlignment",
            "visibility": "visibility",
        },
    )
    class TableCellStyleProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GlobalTableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            height: typing.Optional[jsii.Number] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            text_wrap: typing.Optional[builtins.str] = None,
            vertical_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table cell style for a cell in pivot table or table visual.

            :param background_color: The background color for the table cells.
            :param border: The borders for the table cells.
            :param font_configuration: The font configuration of the table cells.
            :param height: The height color for the table cells.
            :param horizontal_text_alignment: The horizontal text alignment (left, center, right, auto) for the table cells.
            :param text_wrap: The text wrap (none, wrap) for the table cells.
            :param vertical_text_alignment: The vertical text alignment (top, middle, bottom) for the table cells.
            :param visibility: The visibility of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_cell_style_property = quicksight.CfnTemplate.TableCellStyleProperty(
                    background_color="backgroundColor",
                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    height=123,
                    horizontal_text_alignment="horizontalTextAlignment",
                    text_wrap="textWrap",
                    vertical_text_alignment="verticalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e353b0906ffc42d0e046297d9a7ec55687049c364505829f4f93a9b3feefd2fc)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument border", value=border, expected_type=type_hints["border"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument text_wrap", value=text_wrap, expected_type=type_hints["text_wrap"])
                check_type(argname="argument vertical_text_alignment", value=vertical_text_alignment, expected_type=type_hints["vertical_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if border is not None:
                self._values["border"] = border
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if height is not None:
                self._values["height"] = height
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if text_wrap is not None:
                self._values["text_wrap"] = text_wrap
            if vertical_text_alignment is not None:
                self._values["vertical_text_alignment"] = vertical_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''The background color for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GlobalTableBorderOptionsProperty"]]:
            '''The borders for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-border
            '''
            result = self._values.get("border")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GlobalTableBorderOptionsProperty"]], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]]:
            '''The font configuration of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]], result)

        @builtins.property
        def height(self) -> typing.Optional[jsii.Number]:
            '''The height color for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The horizontal text alignment (left, center, right, auto) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def text_wrap(self) -> typing.Optional[builtins.str]:
            '''The text wrap (none, wrap) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-textwrap
            '''
            result = self._values.get("text_wrap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The vertical text alignment (top, middle, bottom) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-verticaltextalignment
            '''
            result = self._values.get("vertical_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell", "row": "row"},
    )
    class TableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableRowConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a table.
            :param row: The row conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_conditional_formatting_option_property = quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    ),
                    row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__752956e3167affcac6f43e69db63679b855c6dfe13aae3193489127e3c96139e)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
                check_type(argname="argument row", value=row, expected_type=type_hints["row"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell
            if row is not None:
                self._values["row"] = row

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellConditionalFormattingProperty"]]:
            '''The cell conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html#cfn-quicksight-template-tableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellConditionalFormattingProperty"]], result)

        @builtins.property
        def row(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableRowConditionalFormattingProperty"]]:
            '''The row conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html#cfn-quicksight-template-tableconditionalformattingoption-row
            '''
            result = self._values.get("row")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableRowConditionalFormattingProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class TableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_conditional_formatting_property = quicksight.CfnTemplate.TableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        ),
                        row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9ba82da3036cab59a3a4df98757ba822839a9ade1db327ffe6dcf895d855ffcc)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableConditionalFormattingOptionProperty"]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformatting.html#cfn-quicksight-template-tableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableConditionalFormattingOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_inline_visualizations": "tableInlineVisualizations",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class TableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            paginated_report_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_inline_visualizations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableInlineVisualizationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            table_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TotalOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a ``TableVisual`` .

            :param field_options: The field options for a table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a table visual.
            :param sort_configuration: The sort configuration for a ``TableVisual`` .
            :param table_inline_visualizations: A collection of inline visualizations to display within a chart.
            :param table_options: The table options for a table visual.
            :param total_options: The total options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_configuration_property = quicksight.CfnTemplate.TableConfigurationProperty(
                    field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                        order=["order"],
                        selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            custom_label="customLabel",
                            url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                    sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                    )
                                ),
                                link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                    content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                        custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                            icon="icon"
                                        ),
                                        custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            value="value"
                                        )
                                    ),
                                    target="target"
                                )
                            ),
                            visibility="visibility",
                            width="width"
                        )]
                    ),
                    field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                        table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                            values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                    date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                        vertical_overflow_visibility="verticalOverflowVisibility"
                    ),
                    sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                        pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                            page_number=123,
                            page_size=123
                        ),
                        row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                        data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            negative_color="negativeColor",
                            positive_color="positiveColor"
                        )
                    )],
                    table_options=quicksight.CfnTemplate.TableOptionsProperty(
                        cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        orientation="orientation",
                        row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                            row_alternate_colors=["rowAlternateColors"],
                            status="status"
                        )
                    ),
                    total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                        custom_label="customLabel",
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3690ac3d20c6a56f25234e21f03e753e64da4171793e35022060f27f8c3213c9)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_inline_visualizations", value=table_inline_visualizations, expected_type=type_hints["table_inline_visualizations"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_inline_visualizations is not None:
                self._values["table_inline_visualizations"] = table_inline_visualizations
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldOptionsProperty"]]:
            '''The field options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldWellsProperty"]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TablePaginatedReportOptionsProperty"]]:
            '''The paginated report options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TablePaginatedReportOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableSortConfigurationProperty"]]:
            '''The sort configuration for a ``TableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableSortConfigurationProperty"]], result)

        @builtins.property
        def table_inline_visualizations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableInlineVisualizationProperty"]]]]:
            '''A collection of inline visualizations to display within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-tableinlinevisualizations
            '''
            result = self._values.get("table_inline_visualizations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableInlineVisualizationProperty"]]]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableOptionsProperty"]]:
            '''The table options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableOptionsProperty"]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TotalOptionsProperty"]]:
            '''The total options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TotalOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableFieldCustomIconContentProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon"},
    )
    class TableFieldCustomIconContentProperty:
        def __init__(self, *, icon: typing.Optional[builtins.str] = None) -> None:
            '''The custom icon content for the table link content configuration.

            :param icon: The icon set type (link) of the custom icon content for table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomiconcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_custom_icon_content_property = quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                    icon="icon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__46ae24aecee747f525712a3eacf17a785fe369b02aa34105a1d02a4181366f1e)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''The icon set type (link) of the custom icon content for table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomiconcontent.html#cfn-quicksight-template-tablefieldcustomiconcontent-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomIconContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableFieldCustomTextContentProperty",
        jsii_struct_bases=[],
        name_mapping={"font_configuration": "fontConfiguration", "value": "value"},
    )
    class TableFieldCustomTextContentProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :param font_configuration: The font configuration of the custom text content for the table URL link content.
            :param value: The string value of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_custom_text_content_property = quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                
                    # the properties below are optional
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ed2c979bb1ab67ef5004ba9030e62dc46cc138163435ec58212b53e6c1e228cd)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "font_configuration": font_configuration,
            }
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"]:
            '''The font configuration of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html#cfn-quicksight-template-tablefieldcustomtextcontent-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            assert result is not None, "Required property 'font_configuration' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FontConfigurationProperty"], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The string value of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html#cfn-quicksight-template-tablefieldcustomtextcontent-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomTextContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableFieldImageConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"sizing_options": "sizingOptions"},
    )
    class TableFieldImageConfigurationProperty:
        def __init__(
            self,
            *,
            sizing_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellImageSizingConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The image configuration of a table field URL.

            :param sizing_options: The sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldimageconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_image_configuration_property = quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                    sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f0066e703797ff66476dacc898065fc9f9d1bf23e8991fd5f947868a2c2b4d7)
                check_type(argname="argument sizing_options", value=sizing_options, expected_type=type_hints["sizing_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sizing_options is not None:
                self._values["sizing_options"] = sizing_options

        @builtins.property
        def sizing_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellImageSizingConfigurationProperty"]]:
            '''The sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldimageconfiguration.html#cfn-quicksight-template-tablefieldimageconfiguration-sizingoptions
            '''
            result = self._values.get("sizing_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellImageSizingConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldImageConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableFieldLinkConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"content": "content", "target": "target"},
    )
    class TableFieldLinkConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableFieldLinkContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]]],
            target: builtins.str,
        ) -> None:
            '''The link configuration of a table field URL.

            :param content: The URL content (text, icon) for the table link configuration.
            :param target: The URL target (new tab, new window, same tab) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_link_configuration_property = quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                    content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                        custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                            icon="icon"
                        ),
                        custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                
                            # the properties below are optional
                            value="value"
                        )
                    ),
                    target="target"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0df78a18009d1148af9d972ff114b12b7128d03dd8ebebea80b1ceda8050f058)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument target", value=target, expected_type=type_hints["target"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "target": target,
            }

        @builtins.property
        def content(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldLinkContentConfigurationProperty"]:
            '''The URL content (text, icon) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html#cfn-quicksight-template-tablefieldlinkconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldLinkContentConfigurationProperty"], result)

        @builtins.property
        def target(self) -> builtins.str:
            '''The URL target (new tab, new window, same tab) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html#cfn-quicksight-template-tablefieldlinkconfiguration-target
            '''
            result = self._values.get("target")
            assert result is not None, "Required property 'target' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_icon_content": "customIconContent",
            "custom_text_content": "customTextContent",
        },
    )
    class TableFieldLinkContentConfigurationProperty:
        def __init__(
            self,
            *,
            custom_icon_content: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableFieldCustomIconContentProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_text_content: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableFieldCustomTextContentProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The URL content (text, icon) for the table link configuration.

            :param custom_icon_content: The custom icon content for the table link content configuration.
            :param custom_text_content: The custom text content (value, font configuration) for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_link_content_configuration_property = quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                    custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                        icon="icon"
                    ),
                    custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                
                        # the properties below are optional
                        value="value"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__98fb493ae0affa22d8837ab4e43dbc713820eb728462c38b8584c6f251589864)
                check_type(argname="argument custom_icon_content", value=custom_icon_content, expected_type=type_hints["custom_icon_content"])
                check_type(argname="argument custom_text_content", value=custom_text_content, expected_type=type_hints["custom_text_content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_icon_content is not None:
                self._values["custom_icon_content"] = custom_icon_content
            if custom_text_content is not None:
                self._values["custom_text_content"] = custom_text_content

        @builtins.property
        def custom_icon_content(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldCustomIconContentProperty"]]:
            '''The custom icon content for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html#cfn-quicksight-template-tablefieldlinkcontentconfiguration-customiconcontent
            '''
            result = self._values.get("custom_icon_content")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldCustomIconContentProperty"]], result)

        @builtins.property
        def custom_text_content(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldCustomTextContentProperty"]]:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html#cfn-quicksight-template-tablefieldlinkcontentconfiguration-customtextcontent
            '''
            result = self._values.get("custom_text_content")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldCustomTextContentProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "url_styling": "urlStyling",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class TableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            url_styling: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableFieldURLConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a table field.

            :param field_id: The field ID for a table field.
            :param custom_label: The custom label for a table field.
            :param url_styling: The URL configuration for a table field.
            :param visibility: The visibility of a table field.
            :param width: The width for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_option_property = quicksight.CfnTemplate.TableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                        image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                            sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                            )
                        ),
                        link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                            content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                    icon="icon"
                                ),
                                custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    value="value"
                                )
                            ),
                            target="target"
                        )
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fb22c78fb95b867e24c21290926f33f2901013392e9a8d3bd201564ffbca0071)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument url_styling", value=url_styling, expected_type=type_hints["url_styling"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if url_styling is not None:
                self._values["url_styling"] = url_styling
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def url_styling(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldURLConfigurationProperty"]]:
            '''The URL configuration for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-urlstyling
            '''
            result = self._values.get("url_styling")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldURLConfigurationProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "order": "order",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class TableFieldOptionsProperty:
        def __init__(
            self,
            *,
            order: typing.Optional[typing.Sequence[builtins.str]] = None,
            selected_field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field options for a table visual.

            :param order: The order of field IDs of the field options for a table visual.
            :param selected_field_options: The selected field options for the table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_options_property = quicksight.CfnTemplate.TableFieldOptionsProperty(
                    order=["order"],
                    selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                            image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                )
                            ),
                            link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                    custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                        icon="icon"
                                    ),
                                    custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        value="value"
                                    )
                                ),
                                target="target"
                            )
                        ),
                        visibility="visibility",
                        width="width"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8094b48247b8fd26a9d16c7c2422354a003341b3c824a77610a2d6a66b10c37d)
                check_type(argname="argument order", value=order, expected_type=type_hints["order"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if order is not None:
                self._values["order"] = order
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def order(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The order of field IDs of the field options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html#cfn-quicksight-template-tablefieldoptions-order
            '''
            result = self._values.get("order")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldOptionProperty"]]]]:
            '''The selected field options for the table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html#cfn-quicksight-template-tablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldOptionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableFieldURLConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "image_configuration": "imageConfiguration",
            "link_configuration": "linkConfiguration",
        },
    )
    class TableFieldURLConfigurationProperty:
        def __init__(
            self,
            *,
            image_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableFieldImageConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            link_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableFieldLinkConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The URL configuration for a table field.

            :param image_configuration: The image configuration of a table field URL.
            :param link_configuration: The link configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_uRLConfiguration_property = quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                    image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                        sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                        )
                    ),
                    link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                        content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                            custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                icon="icon"
                            ),
                            custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                
                                # the properties below are optional
                                value="value"
                            )
                        ),
                        target="target"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__17906605ce701441ec5974d576e14f116fd0c7495f18214d4714163e6ab3c097)
                check_type(argname="argument image_configuration", value=image_configuration, expected_type=type_hints["image_configuration"])
                check_type(argname="argument link_configuration", value=link_configuration, expected_type=type_hints["link_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if image_configuration is not None:
                self._values["image_configuration"] = image_configuration
            if link_configuration is not None:
                self._values["link_configuration"] = link_configuration

        @builtins.property
        def image_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldImageConfigurationProperty"]]:
            '''The image configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html#cfn-quicksight-template-tablefieldurlconfiguration-imageconfiguration
            '''
            result = self._values.get("image_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldImageConfigurationProperty"]], result)

        @builtins.property
        def link_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldLinkConfigurationProperty"]]:
            '''The link configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html#cfn-quicksight-template-tablefieldurlconfiguration-linkconfiguration
            '''
            result = self._values.get("link_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableFieldLinkConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldURLConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_aggregated_field_wells": "tableAggregatedFieldWells",
            "table_unaggregated_field_wells": "tableUnaggregatedFieldWells",
        },
    )
    class TableFieldWellsProperty:
        def __init__(
            self,
            *,
            table_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_unaggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells for a table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param table_aggregated_field_wells: The aggregated field well for the table.
            :param table_unaggregated_field_wells: The unaggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_field_wells_property = quicksight.CfnTemplate.TableFieldWellsProperty(
                    table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                        values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d748a1d97a591403c464cdf9b9eebcb5dd8951f3ec87e56159747e39443f2444)
                check_type(argname="argument table_aggregated_field_wells", value=table_aggregated_field_wells, expected_type=type_hints["table_aggregated_field_wells"])
                check_type(argname="argument table_unaggregated_field_wells", value=table_unaggregated_field_wells, expected_type=type_hints["table_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_aggregated_field_wells is not None:
                self._values["table_aggregated_field_wells"] = table_aggregated_field_wells
            if table_unaggregated_field_wells is not None:
                self._values["table_unaggregated_field_wells"] = table_unaggregated_field_wells

        @builtins.property
        def table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableAggregatedFieldWellsProperty"]]:
            '''The aggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html#cfn-quicksight-template-tablefieldwells-tableaggregatedfieldwells
            '''
            result = self._values.get("table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableAggregatedFieldWellsProperty"]], result)

        @builtins.property
        def table_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableUnaggregatedFieldWellsProperty"]]:
            '''The unaggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html#cfn-quicksight-template-tablefieldwells-tableunaggregatedfieldwells
            '''
            result = self._values.get("table_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableUnaggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableInlineVisualizationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_bars": "dataBars"},
    )
    class TableInlineVisualizationProperty:
        def __init__(
            self,
            *,
            data_bars: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataBarsOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The inline visualization of a specific type to display within a chart.

            :param data_bars: The configuration of the inline visualization of the data bars within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableinlinevisualization.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_inline_visualization_property = quicksight.CfnTemplate.TableInlineVisualizationProperty(
                    data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        negative_color="negativeColor",
                        positive_color="positiveColor"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__596441c6f755f9b531be56569889b0b5d27480ea078a49d151a424c9c9cedb85)
                check_type(argname="argument data_bars", value=data_bars, expected_type=type_hints["data_bars"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_bars is not None:
                self._values["data_bars"] = data_bars

        @builtins.property
        def data_bars(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataBarsOptionsProperty"]]:
            '''The configuration of the inline visualization of the data bars within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableinlinevisualization.html#cfn-quicksight-template-tableinlinevisualization-databars
            '''
            result = self._values.get("data_bars")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataBarsOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableInlineVisualizationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "header_style": "headerStyle",
            "orientation": "orientation",
            "row_alternate_color_options": "rowAlternateColorOptions",
        },
    )
    class TableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            orientation: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The table options for a table visual.

            :param cell_style: The table cell style of table cells.
            :param header_style: The table cell style of a table header.
            :param orientation: The orientation (vertical, horizontal) for a table.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_options_property = quicksight.CfnTemplate.TableOptionsProperty(
                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    orientation="orientation",
                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4644728c2f0e48039960fe1ae046384e1c8e4d2f25a8e85f10af19210b32a8bf)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument header_style", value=header_style, expected_type=type_hints["header_style"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if header_style is not None:
                self._values["header_style"] = header_style
            if orientation is not None:
                self._values["orientation"] = orientation
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]]:
            '''The table cell style of table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def header_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]]:
            '''The table cell style of a table header.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-headerstyle
            '''
            result = self._values.get("header_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation (vertical, horizontal) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RowAlternateColorOptionsProperty"]]:
            '''The row alternate color options (widget status, row alternate colors) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RowAlternateColorOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class TablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a table visual.

            :param overflow_column_header_visibility: The visibility of repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_paginated_report_options_property = quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1866401a03347cf54e3c443e4abfd8855dfbb464b92d5c54beb138bb99104a3c)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of repeating header rows on each page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html#cfn-quicksight-template-tablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html#cfn-quicksight-template-tablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableRowConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "text_color": "textColor",
        },
    )
    class TableRowConditionalFormattingProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting of a table row.

            :param background_color: The conditional formatting color (solid, gradient) of the background for a table row.
            :param text_color: The conditional formatting color (solid, gradient) of the text for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_row_conditional_formatting_property = quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e042f546df8c09b712295455ebeb342c2d72dbef7814e9281ada6c4e15629a0)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting color (solid, gradient) of the background for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html#cfn-quicksight-template-tablerowconditionalformatting-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting color (solid, gradient) of the text for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html#cfn-quicksight-template-tablerowconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableRowConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableSideBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "inner_horizontal": "innerHorizontal",
            "inner_vertical": "innerVertical",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class TableSideBorderOptionsProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inner_horizontal: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            inner_vertical: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            left: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            right: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            top: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The side border options for a table.

            :param bottom: The table border options of the bottom border.
            :param inner_horizontal: The table border options of the inner horizontal border.
            :param inner_vertical: The table border options of the inner vertical border.
            :param left: The table border options of the left border.
            :param right: The table border options of the right border.
            :param top: The table border options of the top border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_side_border_options_property = quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__923b6737c5e4d6ee25bc46262ffe461329f836ab963a340e58f2db883e52a6b0)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument inner_horizontal", value=inner_horizontal, expected_type=type_hints["inner_horizontal"])
                check_type(argname="argument inner_vertical", value=inner_vertical, expected_type=type_hints["inner_vertical"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if inner_horizontal is not None:
                self._values["inner_horizontal"] = inner_horizontal
            if inner_vertical is not None:
                self._values["inner_vertical"] = inner_vertical
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''The table border options of the bottom border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]], result)

        @builtins.property
        def inner_horizontal(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''The table border options of the inner horizontal border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-innerhorizontal
            '''
            result = self._values.get("inner_horizontal")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]], result)

        @builtins.property
        def inner_vertical(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''The table border options of the inner vertical border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-innervertical
            '''
            result = self._values.get("inner_vertical")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]], result)

        @builtins.property
        def left(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''The table border options of the left border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]], result)

        @builtins.property
        def right(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''The table border options of the right border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]], result)

        @builtins.property
        def top(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]]:
            '''The table border options of the top border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableBorderOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSideBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pagination_configuration": "paginationConfiguration",
            "row_sort": "rowSort",
        },
    )
    class TableSortConfigurationProperty:
        def __init__(
            self,
            *,
            pagination_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            row_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration for a ``TableVisual`` .

            :param pagination_configuration: The pagination configuration (page size, page number) for the table.
            :param row_sort: The field sort options for rows in the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_sort_configuration_property = quicksight.CfnTemplate.TableSortConfigurationProperty(
                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    ),
                    row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d8bfdb0d14396bf09b63e5ad62fcc98948eb2ed4b6a76e6f306e3f882eceff79)
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
                check_type(argname="argument row_sort", value=row_sort, expected_type=type_hints["row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration
            if row_sort is not None:
                self._values["row_sort"] = row_sort

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PaginationConfigurationProperty"]]:
            '''The pagination configuration (page size, page number) for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html#cfn-quicksight-template-tablesortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PaginationConfigurationProperty"]], result)

        @builtins.property
        def row_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The field sort options for rows in the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html#cfn-quicksight-template-tablesortconfiguration-rowsort
            '''
            result = self._values.get("row_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class TableUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.UnaggregatedFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The unaggregated field well for the table.

            :param values: The values field well for a pivot table. Values are unaggregated for an unaggregated table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_unaggregated_field_wells_property = quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                    values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2f4825d84ad9afafd8238ebc0f26f127847df2d9ff4c7ee1a3c311178529e24a)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.UnaggregatedFieldProperty"]]]]:
            '''The values field well for a pivot table.

            Values are unaggregated for an unaggregated table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableunaggregatedfieldwells.html#cfn-quicksight-template-tableunaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.UnaggregatedFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                table_visual_property = quicksight.CfnTemplate.TableVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.TableConfigurationProperty(
                        field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                            order=["order"],
                            selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                custom_label="customLabel",
                                url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                    image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                        sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                        )
                                    ),
                                    link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                        content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                            custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                                icon="icon"
                                            ),
                                            custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                
                                                # the properties below are optional
                                                value="value"
                                            )
                                        ),
                                        target="target"
                                    )
                                ),
                                visibility="visibility",
                                width="width"
                            )]
                        ),
                        field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                            table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                                values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                        date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                            overflow_column_header_visibility="overflowColumnHeaderVisibility",
                            vertical_overflow_visibility="verticalOverflowVisibility"
                        ),
                        sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                            pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                page_number=123,
                                page_size=123
                            ),
                            row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                            data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                negative_color="negativeColor",
                                positive_color="positiveColor"
                            )
                        )],
                        table_options=quicksight.CfnTemplate.TableOptionsProperty(
                            cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            orientation="orientation",
                            row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                row_alternate_colors=["rowAlternateColors"],
                                status="status"
                            )
                        ),
                        total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                            custom_label="customLabel",
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility"
                        )
                    ),
                    conditional_formatting=quicksight.CfnTemplate.TableConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                            cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            ),
                            row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c862a95a3f2de46e8b96594fa14813e90bb47d8245233ea0dc8b79c55c625042)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableConfigurationProperty"]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableConditionalFormattingProperty"]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableConditionalFormattingProperty"]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TemplateErrorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "message": "message",
            "type": "type",
            "violated_entities": "violatedEntities",
        },
    )
    class TemplateErrorProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
            violated_entities: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.EntityProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''List of errors that occurred when the template version creation failed.

            :param message: Description of the error type.
            :param type: Type of error.
            :param violated_entities: An error path that shows which entities caused the template error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                template_error_property = quicksight.CfnTemplate.TemplateErrorProperty(
                    message="message",
                    type="type",
                    violated_entities=[quicksight.CfnTemplate.EntityProperty(
                        path="path"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f34ef286783509032bd241f42e5c8e0588e8446c9de42e83ed47cf958a772f2f)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument violated_entities", value=violated_entities, expected_type=type_hints["violated_entities"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type
            if violated_entities is not None:
                self._values["violated_entities"] = violated_entities

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''Description of the error type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Type of error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def violated_entities(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.EntityProperty"]]]]:
            '''An error path that shows which entities caused the template error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-violatedentities
            '''
            result = self._values.get("violated_entities")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.EntityProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateErrorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TemplateSourceAnalysisProperty",
        jsii_struct_bases=[],
        name_mapping={"arn": "arn", "data_set_references": "dataSetReferences"},
    )
    class TemplateSourceAnalysisProperty:
        def __init__(
            self,
            *,
            arn: builtins.str,
            data_set_references: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataSetReferenceProperty", typing.Dict[builtins.str, typing.Any]]]]],
        ) -> None:
            '''The source analysis of the template.

            :param arn: The Amazon Resource Name (ARN) of the resource.
            :param data_set_references: A structure containing information about the dataset references used as placeholders in the template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                template_source_analysis_property = quicksight.CfnTemplate.TemplateSourceAnalysisProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnTemplate.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f3023bc8928d71a604add70dea7460abac66c102c04b10e32d363a78667058d8)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument data_set_references", value=data_set_references, expected_type=type_hints["data_set_references"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
                "data_set_references": data_set_references,
            }

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the resource.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html#cfn-quicksight-template-templatesourceanalysis-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_references(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataSetReferenceProperty"]]]:
            '''A structure containing information about the dataset references used as placeholders in the template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html#cfn-quicksight-template-templatesourceanalysis-datasetreferences
            '''
            result = self._values.get("data_set_references")
            assert result is not None, "Required property 'data_set_references' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataSetReferenceProperty"]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateSourceAnalysisProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TemplateSourceEntityProperty",
        jsii_struct_bases=[],
        name_mapping={
            "source_analysis": "sourceAnalysis",
            "source_template": "sourceTemplate",
        },
    )
    class TemplateSourceEntityProperty:
        def __init__(
            self,
            *,
            source_analysis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TemplateSourceAnalysisProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            source_template: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TemplateSourceTemplateProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The source entity of the template.

            :param source_analysis: The source analysis, if it is based on an analysis.
            :param source_template: The source template, if it is based on an template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                template_source_entity_property = quicksight.CfnTemplate.TemplateSourceEntityProperty(
                    source_analysis=quicksight.CfnTemplate.TemplateSourceAnalysisProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnTemplate.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    ),
                    source_template=quicksight.CfnTemplate.TemplateSourceTemplateProperty(
                        arn="arn"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5662926ff0bf7e1b6f8620b610ab49b47d25bcd56ee6994c22c1ce8c7a1a4da9)
                check_type(argname="argument source_analysis", value=source_analysis, expected_type=type_hints["source_analysis"])
                check_type(argname="argument source_template", value=source_template, expected_type=type_hints["source_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_analysis is not None:
                self._values["source_analysis"] = source_analysis
            if source_template is not None:
                self._values["source_template"] = source_template

        @builtins.property
        def source_analysis(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TemplateSourceAnalysisProperty"]]:
            '''The source analysis, if it is based on an analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html#cfn-quicksight-template-templatesourceentity-sourceanalysis
            '''
            result = self._values.get("source_analysis")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TemplateSourceAnalysisProperty"]], result)

        @builtins.property
        def source_template(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TemplateSourceTemplateProperty"]]:
            '''The source template, if it is based on an template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html#cfn-quicksight-template-templatesourceentity-sourcetemplate
            '''
            result = self._values.get("source_template")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TemplateSourceTemplateProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateSourceEntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TemplateSourceTemplateProperty",
        jsii_struct_bases=[],
        name_mapping={"arn": "arn"},
    )
    class TemplateSourceTemplateProperty:
        def __init__(self, *, arn: builtins.str) -> None:
            '''The source template of the template.

            :param arn: The Amazon Resource Name (ARN) of the resource.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourcetemplate.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                template_source_template_property = quicksight.CfnTemplate.TemplateSourceTemplateProperty(
                    arn="arn"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5e70b381a5ecc510942be4843c252ac74c8d58c2608ef88d906dd1b56336413c)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
            }

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the resource.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourcetemplate.html#cfn-quicksight-template-templatesourcetemplate-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateSourceTemplateProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TemplateVersionDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_configurations": "dataSetConfigurations",
            "analysis_defaults": "analysisDefaults",
            "calculated_fields": "calculatedFields",
            "column_configurations": "columnConfigurations",
            "filter_groups": "filterGroups",
            "parameter_declarations": "parameterDeclarations",
            "sheets": "sheets",
        },
    )
    class TemplateVersionDefinitionProperty:
        def __init__(
            self,
            *,
            data_set_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataSetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AnalysisDefaultsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            calculated_fields: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CalculatedFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            column_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            filter_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilterGroupProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            parameter_declarations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SheetDefinitionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The detailed definition of a template.

            :param data_set_configurations: An array of dataset configurations. These configurations define the required columns for each dataset used within a template.
            :param analysis_defaults: ``CfnTemplate.TemplateVersionDefinitionProperty.AnalysisDefaults``.
            :param calculated_fields: An array of calculated field definitions for the template.
            :param column_configurations: An array of template-level column configurations. Column configurations are used to set default formatting for a column that's used throughout a template.
            :param filter_groups: Filter definitions for a template. For more information, see `Filtering Data <https://docs.aws.amazon.com/quicksight/latest/user/filtering-visual-data.html>`_ in the *Amazon QuickSight User Guide* .
            :param parameter_declarations: An array of parameter declarations for a template. *Parameters* are named variables that can transfer a value for use by an action or an object. For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheets: An array of sheet definitions for a template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                template_version_definition_property = quicksight.CfnTemplate.TemplateVersionDefinitionProperty(
                    data_set_configurations=[quicksight.CfnTemplate.DataSetConfigurationProperty(
                        column_group_schema_list=[quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                            column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                                name="name"
                            )],
                            name="name"
                        )],
                        data_set_schema=quicksight.CfnTemplate.DataSetSchemaProperty(
                            column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                                data_type="dataType",
                                geographic_role="geographicRole",
                                name="name"
                            )]
                        ),
                        placeholder="placeholder"
                    )],
                
                    # the properties below are optional
                    analysis_defaults=quicksight.CfnTemplate.AnalysisDefaultsProperty(
                        default_new_sheet_configuration=quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty(
                            interactive_layout_configuration=quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                                free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            ),
                            paginated_layout_configuration=quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                                section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    )
                                )
                            ),
                            sheet_content_type="sheetContentType"
                        )
                    ),
                    calculated_fields=[quicksight.CfnTemplate.CalculatedFieldProperty(
                        data_set_identifier="dataSetIdentifier",
                        expression="expression",
                        name="name"
                    )],
                    column_configurations=[quicksight.CfnTemplate.ColumnConfigurationProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        colors_configuration=quicksight.CfnTemplate.ColorsConfigurationProperty(
                            custom_colors=[quicksight.CfnTemplate.CustomColorProperty(
                                color="color",
                
                                # the properties below are optional
                                field_value="fieldValue",
                                special_value="specialValue"
                            )]
                        ),
                        format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        role="role"
                    )],
                    filter_groups=[quicksight.CfnTemplate.FilterGroupProperty(
                        cross_dataset="crossDataset",
                        filter_group_id="filterGroupId",
                        filters=[quicksight.CfnTemplate.FilterProperty(
                            category_filter=quicksight.CfnTemplate.CategoryFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                                    custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
                
                                        # the properties below are optional
                                        category_value="categoryValue",
                                        parameter_name="parameterName",
                                        select_all_options="selectAllOptions"
                                    ),
                                    custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
                
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    ),
                                    filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                                        match_operator="matchOperator",
                
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    )
                                ),
                                filter_id="filterId"
                            ),
                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions",
                                value=123
                            ),
                            numeric_range_filter=quicksight.CfnTemplate.NumericRangeFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                select_all_options="selectAllOptions"
                            ),
                            relative_dates_filter=quicksight.CfnTemplate.RelativeDatesFilterProperty(
                                anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                                    anchor_option="anchorOption",
                                    parameter_name="parameterName"
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                                relative_date_type="relativeDateType",
                                time_granularity="timeGranularity",
                
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
                
                                    # the properties below are optional
                                    status="status"
                                ),
                                minimum_granularity="minimumGranularity",
                                parameter_name="parameterName",
                                relative_date_value=123
                            ),
                            time_equality_filter=quicksight.CfnTemplate.TimeEqualityFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                
                                # the properties below are optional
                                parameter_name="parameterName",
                                time_granularity="timeGranularity",
                                value="value"
                            ),
                            time_range_filter=quicksight.CfnTemplate.TimeRangeFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
                
                                    # the properties below are optional
                                    status="status"
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                time_granularity="timeGranularity"
                            ),
                            top_bottom_filter=quicksight.CfnTemplate.TopBottomFilterProperty(
                                aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    sort_direction="sortDirection"
                                )],
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                
                                # the properties below are optional
                                limit=123,
                                parameter_name="parameterName",
                                time_granularity="timeGranularity"
                            )
                        )],
                        scope_configuration=quicksight.CfnTemplate.FilterScopeConfigurationProperty(
                            selected_sheets=quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                                sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                                    scope="scope",
                                    sheet_id="sheetId",
                
                                    # the properties below are optional
                                    visual_ids=["visualIds"]
                                )]
                            )
                        ),
                
                        # the properties below are optional
                        status="status"
                    )],
                    parameter_declarations=[quicksight.CfnTemplate.ParameterDeclarationProperty(
                        date_time_parameter_declaration=quicksight.CfnTemplate.DateTimeParameterDeclarationProperty(
                            name="name",
                
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            time_granularity="timeGranularity",
                            value_when_unset=quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        decimal_parameter_declaration=quicksight.CfnTemplate.DecimalParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        integer_parameter_declaration=quicksight.CfnTemplate.IntegerParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        string_parameter_declaration=quicksight.CfnTemplate.StringParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.StringDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        )
                    )],
                    sheets=[quicksight.CfnTemplate.SheetDefinitionProperty(
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        content_type="contentType",
                        description="description",
                        filter_controls=[quicksight.CfnTemplate.FilterControlProperty(
                            date_time_picker=quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            dropdown=quicksight.CfnTemplate.FilterDropDownControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnTemplate.FilterListControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            relative_date_time=quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            slider=quicksight.CfnTemplate.FilterSliderControlProperty(
                                filter_control_id="filterControlId",
                                maximum_value=123,
                                minimum_value=123,
                                source_filter_id="sourceFilterId",
                                step_size=123,
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            text_area=quicksight.CfnTemplate.FilterTextAreaControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnTemplate.FilterTextFieldControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        layouts=[quicksight.CfnTemplate.LayoutProperty(
                            configuration=quicksight.CfnTemplate.LayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
                
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                                    body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                                        content=quicksight.CfnTemplate.BodySectionContentProperty(
                                            layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                                free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                        element_id="elementId",
                                                        element_type="elementType",
                                                        height="height",
                                                        width="width",
                                                        x_axis_location="xAxisLocation",
                                                        y_axis_location="yAxisLocation",
                
                                                        # the properties below are optional
                                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                            visibility="visibility"
                                                        ),
                                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                                visibility="visibility"
                                                            ),
                                                            expression="expression"
                                                        )],
                                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        visibility="visibility"
                                                    )]
                                                )
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                            after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                                status="status"
                                            )
                                        ),
                                        style=quicksight.CfnTemplate.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    ),
                                    footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        style=quicksight.CfnTemplate.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        style=quicksight.CfnTemplate.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )]
                                )
                            )
                        )],
                        name="name",
                        parameter_controls=[quicksight.CfnTemplate.ParameterControlProperty(
                            date_time_picker=quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            dropdown=quicksight.CfnTemplate.ParameterDropDownControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnTemplate.ParameterListControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            slider=quicksight.CfnTemplate.ParameterSliderControlProperty(
                                maximum_value=123,
                                minimum_value=123,
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                step_size=123,
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_area=quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        sheet_control_layouts=[quicksight.CfnTemplate.SheetControlLayoutProperty(
                            configuration=quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                                grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
                
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            )
                        )],
                        text_boxes=[quicksight.CfnTemplate.SheetTextBoxProperty(
                            sheet_text_box_id="sheetTextBoxId",
                
                            # the properties below are optional
                            content="content"
                        )],
                        title="title",
                        visuals=[quicksight.CfnTemplate.VisualProperty(
                            bar_chart_visual=quicksight.CfnTemplate.BarChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.BarChartConfigurationProperty(
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                                        bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    orientation="orientation",
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            box_plot_visual=quicksight.CfnTemplate.BoxPlotVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                                    box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                                        all_data_points_visibility="allDataPointsVisibility",
                                        outlier_visibility="outlierVisibility",
                                        style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                                            fill_style="fillStyle"
                                        )
                                    ),
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                                        box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        )
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            combo_chart_visual=quicksight.CfnTemplate.ComboChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.ComboChartConfigurationProperty(
                                    bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                                        combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                                            bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            custom_content_visual=quicksight.CfnTemplate.CustomContentVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.CustomContentConfigurationProperty(
                                    content_type="contentType",
                                    content_url="contentUrl",
                                    image_scaling="imageScaling"
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            empty_visual=quicksight.CfnTemplate.EmptyVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )]
                            ),
                            filled_map_visual=quicksight.CfnTemplate.FilledMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.FilledMapConfigurationProperty(
                                    field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                                        filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                                            geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                                        shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            funnel_chart_visual=quicksight.CfnTemplate.FunnelChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        label_color="labelColor",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_data_label_style="measureDataLabelStyle",
                                        measure_label_visibility="measureLabelVisibility",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                                        funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            gauge_chart_visual=quicksight.CfnTemplate.GaugeChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                                        target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                                        arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                                            arc_angle=123,
                                            arc_thickness="arcThickness"
                                        ),
                                        arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                                            range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                                max=123,
                                                min=123
                                            ),
                                            reserve_range=123
                                        ),
                                        comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    ),
                                    tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                conditional_formatting=quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                                        arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            geospatial_map_visual=quicksight.CfnTemplate.GeospatialMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                                    field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                                        geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                                        cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                                            cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                                simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                                    color="color"
                                                )
                                            )
                                        ),
                                        selected_point_style="selectedPointStyle"
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            heat_map_visual=quicksight.CfnTemplate.HeatMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.HeatMapConfigurationProperty(
                                    color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
                
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                                        heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                                        heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            histogram_visual=quicksight.CfnTemplate.HistogramVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.HistogramConfigurationProperty(
                                    bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                                        bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                                            value=123
                                        ),
                                        bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                                            bin_count_limit=123,
                                            value=123
                                        ),
                                        selected_bin_type="selectedBinType",
                                        start_value=123
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                                        histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    )
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            insight_visual=quicksight.CfnTemplate.InsightVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                insight_configuration=quicksight.CfnTemplate.InsightConfigurationProperty(
                                    computations=[quicksight.CfnTemplate.ComputationProperty(
                                        forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            custom_seasonality_value=123,
                                            lower_boundary=123,
                                            name="name",
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality="seasonality",
                                            upper_boundary=123,
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            period_size=123,
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
                
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                                            computation_id="computationId",
                                            from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            period_time_granularity="periodTimeGranularity",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
                
                                            # the properties below are optional
                                            mover_size=123,
                                            name="name",
                                            sort_order="sortOrder",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            type="type",
                
                                            # the properties below are optional
                                            name="name",
                                            result_size=123,
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                                            computation_id="computationId",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                
                                            # the properties below are optional
                                            name="name"
                                        )
                                    )],
                                    custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                                        narrative="narrative"
                                    )
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            kpi_visual=quicksight.CfnTemplate.KPIVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.KPIConfigurationProperty(
                                    field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                                        target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                                        comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                                        trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                                        primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            line_chart_visual=quicksight.CfnTemplate.LineChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.LineChartConfigurationProperty(
                                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                                        axis_binding="axisBinding",
                                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                                        line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                                        forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                                            lower_boundary=123,
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality=123,
                                            upper_boundary=123
                                        ),
                                        scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                                            what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                                date="date",
                                                value=123
                                            ),
                                            what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                                end_date="endDate",
                                                start_date="startDate",
                                                value=123
                                            )
                                        )
                                    )],
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    series=[quicksight.CfnTemplate.SeriesItemProperty(
                                        data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            field_value="fieldValue",
                                            settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        ),
                                        field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                                        category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    type="type",
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pie_chart_visual=quicksight.CfnTemplate.PieChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.PieChartConfigurationProperty(
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                                        arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                                            arc_thickness="arcThickness"
                                        ),
                                        donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                                            label_visibility="labelVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                                        pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pivot_table_visual=quicksight.CfnTemplate.PivotTableVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.PivotTableConfigurationProperty(
                                    field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                                        data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                                            data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )],
                
                                            # the properties below are optional
                                            width="width"
                                        )],
                                        selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            visibility="visibility"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                                        pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                                        field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                                            field_id="fieldId",
                                            sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                                column=quicksight.CfnTemplate.ColumnSortProperty(
                                                    direction="direction",
                                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    )
                                                ),
                                                data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                                    direction="direction",
                                                    sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                                        field_id="fieldId",
                                                        field_value="fieldValue"
                                                    )]
                                                ),
                                                field=quicksight.CfnTemplate.FieldSortProperty(
                                                    direction="direction",
                                                    field_id="fieldId"
                                                )
                                            )
                                        )]
                                    ),
                                    table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                                        cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_names_visibility="columnNamesVisibility",
                                        metric_placement="metricPlacement",
                                        row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        ),
                                        row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        single_metric_visibility="singleMetricVisibility",
                                        toggle_buttons_visibility="toggleButtonsVisibility"
                                    ),
                                    total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                                        column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    )
                                ),
                                conditional_formatting=quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                                role="role"
                                            ),
                                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
                
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            radar_chart_visual=quicksight.CfnTemplate.RadarChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.RadarChartConfigurationProperty(
                                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                                    alternate_band_even_color="alternateBandEvenColor",
                                    alternate_band_odd_color="alternateBandOddColor",
                                    base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                                        area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                                        radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    shape="shape",
                                    sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    start_angle=123,
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            sankey_diagram_visual=quicksight.CfnTemplate.SankeyDiagramVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                                        sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                                            destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                                        destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            scatter_plot_visual=quicksight.CfnTemplate.ScatterPlotVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            table_visual=quicksight.CfnTemplate.TableVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.TableConfigurationProperty(
                                    field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                                        order=["order"],
                                        selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                                image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                                    sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                    )
                                                ),
                                                link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                                    content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                                        custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                                            icon="icon"
                                                        ),
                                                        custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                                font_color="fontColor",
                                                                font_decoration="fontDecoration",
                                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                                    relative="relative"
                                                                ),
                                                                font_style="fontStyle",
                                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                                    name="name"
                                                                )
                                                            ),
                
                                                            # the properties below are optional
                                                            value="value"
                                                        )
                                                    ),
                                                    target="target"
                                                )
                                            ),
                                            visibility="visibility",
                                            width="width"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                                        table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                                            values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                                    date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                                        pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        ),
                                        row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                                        data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            negative_color="negativeColor",
                                            positive_color="positiveColor"
                                        )
                                    )],
                                    table_options=quicksight.CfnTemplate.TableOptionsProperty(
                                        cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        orientation="orientation",
                                        row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        )
                                    ),
                                    total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                                        custom_label="customLabel",
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility"
                                    )
                                ),
                                conditional_formatting=quicksight.CfnTemplate.TableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
                
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        ),
                                        row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            tree_map_visual=quicksight.CfnTemplate.TreeMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.TreeMapConfigurationProperty(
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
                
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                                        tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                                        tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            waterfall_visual=quicksight.CfnTemplate.WaterfallVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                                    category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                                        waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                                            breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                                        breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                                        total_bar_label="totalBarLabel"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            word_cloud_visual=quicksight.CfnTemplate.WordCloudVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                                        word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                                        cloud_layout="cloudLayout",
                                        maximum_string_length=123,
                                        word_casing="wordCasing",
                                        word_orientation="wordOrientation",
                                        word_padding="wordPadding",
                                        word_scaling="wordScaling"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0df77e44def83f43d195e623b70ecf79dea128ea53b02d8f1434f9e850f2716f)
                check_type(argname="argument data_set_configurations", value=data_set_configurations, expected_type=type_hints["data_set_configurations"])
                check_type(argname="argument analysis_defaults", value=analysis_defaults, expected_type=type_hints["analysis_defaults"])
                check_type(argname="argument calculated_fields", value=calculated_fields, expected_type=type_hints["calculated_fields"])
                check_type(argname="argument column_configurations", value=column_configurations, expected_type=type_hints["column_configurations"])
                check_type(argname="argument filter_groups", value=filter_groups, expected_type=type_hints["filter_groups"])
                check_type(argname="argument parameter_declarations", value=parameter_declarations, expected_type=type_hints["parameter_declarations"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_configurations": data_set_configurations,
            }
            if analysis_defaults is not None:
                self._values["analysis_defaults"] = analysis_defaults
            if calculated_fields is not None:
                self._values["calculated_fields"] = calculated_fields
            if column_configurations is not None:
                self._values["column_configurations"] = column_configurations
            if filter_groups is not None:
                self._values["filter_groups"] = filter_groups
            if parameter_declarations is not None:
                self._values["parameter_declarations"] = parameter_declarations
            if sheets is not None:
                self._values["sheets"] = sheets

        @builtins.property
        def data_set_configurations(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataSetConfigurationProperty"]]]:
            '''An array of dataset configurations.

            These configurations define the required columns for each dataset used within a template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-datasetconfigurations
            '''
            result = self._values.get("data_set_configurations")
            assert result is not None, "Required property 'data_set_configurations' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataSetConfigurationProperty"]]], result)

        @builtins.property
        def analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AnalysisDefaultsProperty"]]:
            '''``CfnTemplate.TemplateVersionDefinitionProperty.AnalysisDefaults``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-analysisdefaults
            '''
            result = self._values.get("analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AnalysisDefaultsProperty"]], result)

        @builtins.property
        def calculated_fields(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CalculatedFieldProperty"]]]]:
            '''An array of calculated field definitions for the template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-calculatedfields
            '''
            result = self._values.get("calculated_fields")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CalculatedFieldProperty"]]]], result)

        @builtins.property
        def column_configurations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnConfigurationProperty"]]]]:
            '''An array of template-level column configurations.

            Column configurations are used to set default formatting for a column that's used throughout a template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-columnconfigurations
            '''
            result = self._values.get("column_configurations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnConfigurationProperty"]]]], result)

        @builtins.property
        def filter_groups(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterGroupProperty"]]]]:
            '''Filter definitions for a template.

            For more information, see `Filtering Data <https://docs.aws.amazon.com/quicksight/latest/user/filtering-visual-data.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-filtergroups
            '''
            result = self._values.get("filter_groups")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilterGroupProperty"]]]], result)

        @builtins.property
        def parameter_declarations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterDeclarationProperty"]]]]:
            '''An array of parameter declarations for a template.

            *Parameters* are named variables that can transfer a value for use by an action or an object.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-parameterdeclarations
            '''
            result = self._values.get("parameter_declarations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ParameterDeclarationProperty"]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetDefinitionProperty"]]]]:
            '''An array of sheet definitions for a template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetDefinitionProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateVersionDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TemplateVersionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "created_time": "createdTime",
            "data_set_configurations": "dataSetConfigurations",
            "description": "description",
            "errors": "errors",
            "sheets": "sheets",
            "source_entity_arn": "sourceEntityArn",
            "status": "status",
            "theme_arn": "themeArn",
            "version_number": "versionNumber",
        },
    )
    class TemplateVersionProperty:
        def __init__(
            self,
            *,
            created_time: typing.Optional[builtins.str] = None,
            data_set_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataSetConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            description: typing.Optional[builtins.str] = None,
            errors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TemplateErrorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SheetProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            source_entity_arn: typing.Optional[builtins.str] = None,
            status: typing.Optional[builtins.str] = None,
            theme_arn: typing.Optional[builtins.str] = None,
            version_number: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A version of a template.

            :param created_time: The time that this template version was created.
            :param data_set_configurations: Schema of the dataset identified by the placeholder. Any dashboard created from this template should be bound to new datasets matching the same schema described through this API operation.
            :param description: The description of the template.
            :param errors: Errors associated with this template version.
            :param sheets: A list of the associated sheets with the unique identifier and name of each sheet.
            :param source_entity_arn: The Amazon Resource Name (ARN) of an analysis or template that was used to create this template.
            :param status: The status that is associated with the template. - ``CREATION_IN_PROGRESS`` - ``CREATION_SUCCESSFUL`` - ``CREATION_FAILED`` - ``UPDATE_IN_PROGRESS`` - ``UPDATE_SUCCESSFUL`` - ``UPDATE_FAILED`` - ``DELETED``
            :param theme_arn: The ARN of the theme associated with this version of the template.
            :param version_number: The version number of the template version.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                template_version_property = quicksight.CfnTemplate.TemplateVersionProperty(
                    created_time="createdTime",
                    data_set_configurations=[quicksight.CfnTemplate.DataSetConfigurationProperty(
                        column_group_schema_list=[quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                            column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                                name="name"
                            )],
                            name="name"
                        )],
                        data_set_schema=quicksight.CfnTemplate.DataSetSchemaProperty(
                            column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                                data_type="dataType",
                                geographic_role="geographicRole",
                                name="name"
                            )]
                        ),
                        placeholder="placeholder"
                    )],
                    description="description",
                    errors=[quicksight.CfnTemplate.TemplateErrorProperty(
                        message="message",
                        type="type",
                        violated_entities=[quicksight.CfnTemplate.EntityProperty(
                            path="path"
                        )]
                    )],
                    sheets=[quicksight.CfnTemplate.SheetProperty(
                        name="name",
                        sheet_id="sheetId"
                    )],
                    source_entity_arn="sourceEntityArn",
                    status="status",
                    theme_arn="themeArn",
                    version_number=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f02a1cb0b1d3bc271bc81c1c5de6e57182f108cbf816f3777c6308098d61d5ff)
                check_type(argname="argument created_time", value=created_time, expected_type=type_hints["created_time"])
                check_type(argname="argument data_set_configurations", value=data_set_configurations, expected_type=type_hints["data_set_configurations"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument errors", value=errors, expected_type=type_hints["errors"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
                check_type(argname="argument source_entity_arn", value=source_entity_arn, expected_type=type_hints["source_entity_arn"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument theme_arn", value=theme_arn, expected_type=type_hints["theme_arn"])
                check_type(argname="argument version_number", value=version_number, expected_type=type_hints["version_number"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if created_time is not None:
                self._values["created_time"] = created_time
            if data_set_configurations is not None:
                self._values["data_set_configurations"] = data_set_configurations
            if description is not None:
                self._values["description"] = description
            if errors is not None:
                self._values["errors"] = errors
            if sheets is not None:
                self._values["sheets"] = sheets
            if source_entity_arn is not None:
                self._values["source_entity_arn"] = source_entity_arn
            if status is not None:
                self._values["status"] = status
            if theme_arn is not None:
                self._values["theme_arn"] = theme_arn
            if version_number is not None:
                self._values["version_number"] = version_number

        @builtins.property
        def created_time(self) -> typing.Optional[builtins.str]:
            '''The time that this template version was created.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-createdtime
            '''
            result = self._values.get("created_time")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_set_configurations(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataSetConfigurationProperty"]]]]:
            '''Schema of the dataset identified by the placeholder.

            Any dashboard created from this template should be bound to new datasets matching the same schema described through this API operation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-datasetconfigurations
            '''
            result = self._values.get("data_set_configurations")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataSetConfigurationProperty"]]]], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''The description of the template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def errors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TemplateErrorProperty"]]]]:
            '''Errors associated with this template version.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-errors
            '''
            result = self._values.get("errors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TemplateErrorProperty"]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetProperty"]]]]:
            '''A list of the associated sheets with the unique identifier and name of each sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SheetProperty"]]]], result)

        @builtins.property
        def source_entity_arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of an analysis or template that was used to create this template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-sourceentityarn
            '''
            result = self._values.get("source_entity_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status that is associated with the template.

            - ``CREATION_IN_PROGRESS``
            - ``CREATION_SUCCESSFUL``
            - ``CREATION_FAILED``
            - ``UPDATE_IN_PROGRESS``
            - ``UPDATE_SUCCESSFUL``
            - ``UPDATE_FAILED``
            - ``DELETED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def theme_arn(self) -> typing.Optional[builtins.str]:
            '''The ARN of the theme associated with this version of the template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-themearn
            '''
            result = self._values.get("theme_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def version_number(self) -> typing.Optional[jsii.Number]:
            '''The version number of the template version.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-versionnumber
            '''
            result = self._values.get("version_number")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateVersionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextAreaControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            placeholder_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param placeholder_options: The configuration of the placeholder options in a text area control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                text_area_control_display_options_property = quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e0b5602e0bc05ac7707ecc57c97065daa81224895daaa3849dc99049c5e4879a)
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextControlPlaceholderOptionsProperty"]]:
            '''The configuration of the placeholder options in a text area control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html#cfn-quicksight-template-textareacontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextControlPlaceholderOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html#cfn-quicksight-template-textareacontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextAreaControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TextConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "icon": "icon",
            "text_color": "textColor",
        },
    )
    class TextConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The conditional formatting for the text.

            :param background_color: The conditional formatting for the text background color.
            :param icon: The conditional formatting for the icon.
            :param text_color: The conditional formatting for the text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                text_conditional_format_property = quicksight.CfnTemplate.TextConditionalFormatProperty(
                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__25c55600e7a726facbee06cbc15f52c7886bf0e4123873d75917f1d795113bc5)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting for the text background color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingIconProperty"]]:
            '''The conditional formatting for the icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingIconProperty"]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]]:
            '''The conditional formatting for the text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ConditionalFormattingColorProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TextControlPlaceholderOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the placeholder options in a text control.

            :param visibility: The visibility configuration of the placeholder options in a text control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textcontrolplaceholderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                text_control_placeholder_options_property = quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__31b28b66b0e8cb070fb76eda0675c147ee6dc9af416347b3b48195010067bced)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the placeholder options in a text control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textcontrolplaceholderoptions.html#cfn-quicksight-template-textcontrolplaceholderoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextControlPlaceholderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextFieldControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            placeholder_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options of a control.

            :param placeholder_options: The configuration of the placeholder options in a text field control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                text_field_control_display_options_property = quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cbab6b4dab2a153e0e3e0e4281ef3f41a77341a7372de21ed7e72ef03765aab2)
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextControlPlaceholderOptionsProperty"]]:
            '''The configuration of the placeholder options in a text field control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html#cfn-quicksight-template-textfieldcontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TextControlPlaceholderOptionsProperty"]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html#cfn-quicksight-template-textfieldcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextFieldControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.ThousandSeparatorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"symbol": "symbol", "visibility": "visibility"},
    )
    class ThousandSeparatorOptionsProperty:
        def __init__(
            self,
            *,
            symbol: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the thousands separator configuration.

            :param symbol: Determines the thousands separator symbol.
            :param visibility: Determines the visibility of the thousands separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                thousand_separator_options_property = quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                    symbol="symbol",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__caee7777108fbd9f61fb6d591d68411fdc47241bd8397559b7029d5c1eef9dce)
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if symbol is not None:
                self._values["symbol"] = symbol
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the thousands separator symbol.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html#cfn-quicksight-template-thousandseparatoroptions-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the thousands separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html#cfn-quicksight-template-thousandseparatoroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThousandSeparatorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "lower_boundary": "lowerBoundary",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
        },
    )
    class TimeBasedForecastPropertiesProperty:
        def __init__(
            self,
            *,
            lower_boundary: typing.Optional[jsii.Number] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[jsii.Number] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The forecast properties setup of a forecast in the line chart.

            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``NULL`` : The input is set to ``NULL`` . - ``NON_NULL`` : The input is set to a custom value.
            :param upper_boundary: The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_based_forecast_properties_property = quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                    lower_boundary=123,
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality=123,
                    upper_boundary=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45aa0f9578b2ad37353c36d2efab39de7d13d3f7860c784784df659cb45bccbc)
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[jsii.Number]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``NULL`` : The input is set to ``NULL`` .
            - ``NON_NULL`` : The input is set to a custom value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeBasedForecastPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TimeEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
            "value": "value",
        },
    )
    class TimeEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeEqualityFilter`` filters values that are equal to a given value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``Value`` .
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value: The value of a ``TimeEquality`` filter. This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_equality_filter_property = quicksight.CfnTemplate.TimeEqualityFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    parameter_name="parameterName",
                    time_granularity="timeGranularity",
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__68fb13fa54532373c849bebe069c7f1494f2263761e9c812018c1bcc1b922641)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
            }
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``Value`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The value of a ``TimeEquality`` filter.

            This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            range_maximum: builtins.str,
            range_minimum: builtins.str,
            time_granularity: builtins.str,
        ) -> None:
            '''The time range drill down filter.

            :param column: The column that the filter is applied to.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_range_drill_down_filter_property = quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    range_maximum="rangeMaximum",
                    range_minimum="rangeMinimum",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4abc91996aefc14ce46b194f1ddf9e244e5e38dca94a9c79e1b7ab8329ca39f2)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "range_maximum": range_maximum,
                "range_minimum": range_minimum,
                "time_granularity": time_granularity,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def range_maximum(self) -> builtins.str:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            assert result is not None, "Required property 'range_maximum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def range_minimum(self) -> builtins.str:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            assert result is not None, "Required property 'range_minimum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TimeRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum_value": "rangeMaximumValue",
            "range_minimum_value": "rangeMinimumValue",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            null_option: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
            range_maximum_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            range_minimum_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeRangeFilter`` filters values that are between two specified values.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param exclude_period_configuration: The exclude period of the time range filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum_value: The maximum value for the filter value range.
            :param range_minimum_value: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_range_filter_property = quicksight.CfnTemplate.TimeRangeFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__80d2e359add74055b1301f3cdf06ed7046f74cf48a6b1b317f47c41d4136b780)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum_value", value=range_maximum_value, expected_type=type_hints["range_maximum_value"])
                check_type(argname="argument range_minimum_value", value=range_minimum_value, expected_type=type_hints["range_minimum_value"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum_value is not None:
                self._values["range_maximum_value"] = range_maximum_value
            if range_minimum_value is not None:
                self._values["range_minimum_value"] = range_minimum_value
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ExcludePeriodConfigurationProperty"]]:
            '''The exclude period of the time range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ExcludePeriodConfigurationProperty"]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        @builtins.property
        def range_maximum_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TimeRangeFilterValueProperty"]]:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-rangemaximumvalue
            '''
            result = self._values.get("range_maximum_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TimeRangeFilterValueProperty"]], result)

        @builtins.property
        def range_minimum_value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TimeRangeFilterValueProperty"]]:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-rangeminimumvalue
            '''
            result = self._values.get("range_minimum_value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TimeRangeFilterValueProperty"]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TimeRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter": "parameter",
            "rolling_date": "rollingDate",
            "static_value": "staticValue",
        },
    )
    class TimeRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            rolling_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            static_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value of a time range filter.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param parameter: The parameter type input value.
            :param rolling_date: The rolling date input value.
            :param static_value: The static input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                time_range_filter_value_property = quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                    parameter="parameter",
                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_value="staticValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e4978b81eeb0495f6e43674661bb3534c3b28c9d41a19596829fc9c7cb3ea2ef)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter type input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RollingDateConfigurationProperty"]]:
            '''The rolling date input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RollingDateConfigurationProperty"]], result)

        @builtins.property
        def static_value(self) -> typing.Optional[builtins.str]:
            '''The static input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_tooltip_item": "columnTooltipItem",
            "field_tooltip_item": "fieldTooltipItem",
        },
    )
    class TooltipItemProperty:
        def __init__(
            self,
            *,
            column_tooltip_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnTooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_tooltip_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldTooltipItemProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The tooltip.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param column_tooltip_item: The tooltip item for the columns that are not part of a field well.
            :param field_tooltip_item: The tooltip item for the fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tooltip_item_property = quicksight.CfnTemplate.TooltipItemProperty(
                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        label="label",
                        visibility="visibility"
                    ),
                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        label="label",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6f1c67569cde922ce4ecadfdc62fa36c88adaeb23b4ecd724fbe00028b9d62a5)
                check_type(argname="argument column_tooltip_item", value=column_tooltip_item, expected_type=type_hints["column_tooltip_item"])
                check_type(argname="argument field_tooltip_item", value=field_tooltip_item, expected_type=type_hints["field_tooltip_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_tooltip_item is not None:
                self._values["column_tooltip_item"] = column_tooltip_item
            if field_tooltip_item is not None:
                self._values["field_tooltip_item"] = field_tooltip_item

        @builtins.property
        def column_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnTooltipItemProperty"]]:
            '''The tooltip item for the columns that are not part of a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html#cfn-quicksight-template-tooltipitem-columntooltipitem
            '''
            result = self._values.get("column_tooltip_item")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnTooltipItemProperty"]], result)

        @builtins.property
        def field_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldTooltipItemProperty"]]:
            '''The tooltip item for the fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html#cfn-quicksight-template-tooltipitem-fieldtooltipitem
            '''
            result = self._values.get("field_tooltip_item")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldTooltipItemProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TooltipOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_based_tooltip": "fieldBasedTooltip",
            "selected_tooltip_type": "selectedTooltipType",
            "tooltip_visibility": "tooltipVisibility",
        },
    )
    class TooltipOptionsProperty:
        def __init__(
            self,
            *,
            field_based_tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldBasedTooltipProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            selected_tooltip_type: typing.Optional[builtins.str] = None,
            tooltip_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The display options for the visual tooltip.

            :param field_based_tooltip: The setup for the detailed tooltip. The tooltip setup is always saved. The display type is decided based on the tooltip type.
            :param selected_tooltip_type: The selected type for the tooltip. Choose one of the following options:. - ``BASIC`` : A basic tooltip. - ``DETAILED`` : A detailed tooltip.
            :param tooltip_visibility: Determines whether or not the tooltip is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tooltip_options_property = quicksight.CfnTemplate.TooltipOptionsProperty(
                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                        aggregation_visibility="aggregationVisibility",
                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                label="label",
                                visibility="visibility"
                            ),
                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                label="label",
                                visibility="visibility"
                            )
                        )],
                        tooltip_title_type="tooltipTitleType"
                    ),
                    selected_tooltip_type="selectedTooltipType",
                    tooltip_visibility="tooltipVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d5f6afe2ebc1023d254ba6c2fb9f34fb1aec031e3f0ce9e4349a13947b0a4001)
                check_type(argname="argument field_based_tooltip", value=field_based_tooltip, expected_type=type_hints["field_based_tooltip"])
                check_type(argname="argument selected_tooltip_type", value=selected_tooltip_type, expected_type=type_hints["selected_tooltip_type"])
                check_type(argname="argument tooltip_visibility", value=tooltip_visibility, expected_type=type_hints["tooltip_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_based_tooltip is not None:
                self._values["field_based_tooltip"] = field_based_tooltip
            if selected_tooltip_type is not None:
                self._values["selected_tooltip_type"] = selected_tooltip_type
            if tooltip_visibility is not None:
                self._values["tooltip_visibility"] = tooltip_visibility

        @builtins.property
        def field_based_tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldBasedTooltipProperty"]]:
            '''The setup for the detailed tooltip.

            The tooltip setup is always saved. The display type is decided based on the tooltip type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-fieldbasedtooltip
            '''
            result = self._values.get("field_based_tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldBasedTooltipProperty"]], result)

        @builtins.property
        def selected_tooltip_type(self) -> typing.Optional[builtins.str]:
            '''The selected type for the tooltip. Choose one of the following options:.

            - ``BASIC`` : A basic tooltip.
            - ``DETAILED`` : A detailed tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-selectedtooltiptype
            '''
            result = self._values.get("selected_tooltip_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the tooltip is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-tooltipvisibility
            '''
            result = self._values.get("tooltip_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TopBottomFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_sort_configurations": "aggregationSortConfigurations",
            "column": "column",
            "filter_id": "filterId",
            "limit": "limit",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
        },
    )
    class TopBottomFilterProperty:
        def __init__(
            self,
            *,
            aggregation_sort_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AggregationSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            filter_id: builtins.str,
            limit: typing.Optional[jsii.Number] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TopBottomFilter`` filters values that are at the top or the bottom.

            :param aggregation_sort_configurations: The aggregation and sort configuration of the top bottom filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param limit: The number of items to include in the top bottom filter results.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                top_bottom_filter_property = quicksight.CfnTemplate.TopBottomFilterProperty(
                    aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        sort_direction="sortDirection"
                    )],
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    limit=123,
                    parameter_name="parameterName",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75b21c57d26c1429928271e3d18ee6ecd8bc5eeda4aca5b97b29455adc282749)
                check_type(argname="argument aggregation_sort_configurations", value=aggregation_sort_configurations, expected_type=type_hints["aggregation_sort_configurations"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_sort_configurations": aggregation_sort_configurations,
                "column": column,
                "filter_id": filter_id,
            }
            if limit is not None:
                self._values["limit"] = limit
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def aggregation_sort_configurations(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationSortConfigurationProperty"]]]:
            '''The aggregation and sort configuration of the top bottom filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-aggregationsortconfigurations
            '''
            result = self._values.get("aggregation_sort_configurations")
            assert result is not None, "Required property 'aggregation_sort_configurations' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AggregationSortConfigurationProperty"]]], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def limit(self) -> typing.Optional[jsii.Number]:
            '''The number of items to include in the top bottom filter results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-limit
            '''
            result = self._values.get("limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TopBottomMoversComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "time": "time",
            "type": "type",
            "mover_size": "moverSize",
            "name": "name",
            "sort_order": "sortOrder",
            "value": "value",
        },
    )
    class TopBottomMoversComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            computation_id: builtins.str,
            time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            type: builtins.str,
            mover_size: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            sort_order: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The top movers and bottom movers computation setup.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param type: The computation type. Choose from the following options:. - TOP: Top movers computation. - BOTTOM: Bottom movers computation.
            :param mover_size: The mover size setup of the top and bottom movers computation.
            :param name: The name of a computation.
            :param sort_order: The sort order setup of the top and bottom movers computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                top_bottom_movers_computation_property = quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                    category=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    type="type",
                
                    # the properties below are optional
                    mover_size=123,
                    name="name",
                    sort_order="sortOrder",
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e523e81a8a822ac835cbf241e7d6d2d578f885930096fe78d96619210c19bf6c)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument mover_size", value=mover_size, expected_type=type_hints["mover_size"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sort_order", value=sort_order, expected_type=type_hints["sort_order"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
                "time": time,
                "type": type,
            }
            if mover_size is not None:
                self._values["mover_size"] = mover_size
            if name is not None:
                self._values["name"] = name
            if sort_order is not None:
                self._values["sort_order"] = sort_order
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def category(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"], result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose from the following options:.

            - TOP: Top movers computation.
            - BOTTOM: Bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def mover_size(self) -> typing.Optional[jsii.Number]:
            '''The mover size setup of the top and bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-moversize
            '''
            result = self._values.get("mover_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_order(self) -> typing.Optional[builtins.str]:
            '''The sort order setup of the top and bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-sortorder
            '''
            result = self._values.get("sort_order")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomMoversComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TopBottomRankedComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "type": "type",
            "name": "name",
            "result_size": "resultSize",
            "value": "value",
        },
    )
    class TopBottomRankedComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            computation_id: builtins.str,
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            result_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The top ranked and bottom ranked computation configuration.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param type: The computation type. Choose one of the following options:. - TOP: A top ranked computation. - BOTTOM: A bottom ranked computation.
            :param name: The name of a computation.
            :param result_size: The result size of a top and bottom ranked computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                top_bottom_ranked_computation_property = quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                    category=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    result_size=123,
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5c526e822a5c0b2a3d13ee52792f8a74f08c7da4c9385f8c612d531bf0c6d93)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument result_size", value=result_size, expected_type=type_hints["result_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if result_size is not None:
                self._values["result_size"] = result_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def category(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose one of the following options:.

            - TOP: A top ranked computation.
            - BOTTOM: A bottom ranked computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def result_size(self) -> typing.Optional[jsii.Number]:
            '''The result size of a top and bottom ranked computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-resultsize
            '''
            result = self._values.get("result_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomRankedComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TotalAggregationComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "value": "value",
            "name": "name",
        },
    )
    class TotalAggregationComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total aggregation computation configuration.

            :param computation_id: The ID for a computation.
            :param value: The value field that is used in a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                total_aggregation_computation_property = quicksight.CfnTemplate.TotalAggregationComputationProperty(
                    computation_id="computationId",
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2b07d21e860b48c4ec3238938af6ace3dcb1fef6a5c372b9213cb58265046f20)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "value": value,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
        },
    )
    class TotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total options for a table visual.

            :param custom_label: The custom label string for the total cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_cell_style: Cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                total_options_property = quicksight.CfnTemplate.TotalOptionsProperty(
                    custom_label="customLabel",
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9843aa0f958c8b4e757ba83e8b1122fa661853b0b4483d9d269635122a99e24)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]]:
            '''Cell styling options for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableCellStyleProperty"]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"colors": "colors", "groups": "groups", "sizes": "sizes"},
    )
    class TreeMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            sizes: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''Aggregated field wells of a tree map.

            :param colors: The color field well of a tree map. Values are grouped by aggregations based on group by fields.
            :param groups: The group by field well of a tree map. Values are grouped based on group by fields.
            :param sizes: The size field well of a tree map. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_aggregated_field_wells_property = quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                    colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cf3a489de43ffa01157133eb8e5808a957a7e78950664c4aebeec4552455cdf5)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument groups", value=groups, expected_type=type_hints["groups"])
                check_type(argname="argument sizes", value=sizes, expected_type=type_hints["sizes"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if groups is not None:
                self._values["groups"] = groups
            if sizes is not None:
                self._values["sizes"] = sizes

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The color field well of a tree map.

            Values are grouped by aggregations based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        @builtins.property
        def groups(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The group by field well of a tree map.

            Values are grouped based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-groups
            '''
            result = self._values.get("groups")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def sizes(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The size field well of a tree map.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-sizes
            '''
            result = self._values.get("sizes")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TreeMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_label_options": "colorLabelOptions",
            "color_scale": "colorScale",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "group_label_options": "groupLabelOptions",
            "legend": "legend",
            "size_label_options": "sizeLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class TreeMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            color_scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TreeMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            group_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            size_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TreeMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a tree map.

            :param color_label_options: The label options (label text, label visibility) for the colors displayed in a tree map.
            :param color_scale: The color options (gradient color, point of divergence) of a tree map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param group_label_options: The label options (label text, label visibility) of the groups that are displayed in a tree map.
            :param legend: The legend display setup of the visual.
            :param size_label_options: The label options (label text, label visibility) of the sizes that are displayed in a tree map.
            :param sort_configuration: The sort configuration of a tree map.
            :param tooltip: The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_configuration_property = quicksight.CfnTemplate.TreeMapConfigurationProperty(
                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                        color_fill_type="colorFillType",
                        colors=[quicksight.CfnTemplate.DataColorProperty(
                            color="color",
                            data_value=123
                        )],
                
                        # the properties below are optional
                        null_value_color=quicksight.CfnTemplate.DataColorProperty(
                            color="color",
                            data_value=123
                        )
                    ),
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                        tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                            colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                        tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__529103c650fe1879629205714288e1749761b854c2d26a1e31c334c22fee49a0)
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument group_label_options", value=group_label_options, expected_type=type_hints["group_label_options"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument size_label_options", value=size_label_options, expected_type=type_hints["size_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if group_label_options is not None:
                self._values["group_label_options"] = group_label_options
            if legend is not None:
                self._values["legend"] = legend
            if size_label_options is not None:
                self._values["size_label_options"] = size_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) for the colors displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColorScaleProperty"]]:
            '''The color options (gradient color, point of divergence) of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColorScaleProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TreeMapFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TreeMapFieldWellsProperty"]], result)

        @builtins.property
        def group_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) of the groups that are displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-grouplabeloptions
            '''
            result = self._values.get("group_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def size_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility) of the sizes that are displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-sizelabeloptions
            '''
            result = self._values.get("size_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TreeMapSortConfigurationProperty"]]:
            '''The sort configuration of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TreeMapSortConfigurationProperty"]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TooltipOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TreeMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_aggregated_field_wells": "treeMapAggregatedFieldWells",
        },
    )
    class TreeMapFieldWellsProperty:
        def __init__(
            self,
            *,
            tree_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TreeMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a tree map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param tree_map_aggregated_field_wells: The aggregated field wells of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_field_wells_property = quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                    tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                        colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4e70c1ccd2e00794a1a1939cfdba81cdbb013279650d8d016d922f43b2d7a4fd)
                check_type(argname="argument tree_map_aggregated_field_wells", value=tree_map_aggregated_field_wells, expected_type=type_hints["tree_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_aggregated_field_wells is not None:
                self._values["tree_map_aggregated_field_wells"] = tree_map_aggregated_field_wells

        @builtins.property
        def tree_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TreeMapAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapfieldwells.html#cfn-quicksight-template-treemapfieldwells-treemapaggregatedfieldwells
            '''
            result = self._values.get("tree_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TreeMapAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TreeMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_group_items_limit_configuration": "treeMapGroupItemsLimitConfiguration",
            "tree_map_sort": "treeMapSort",
        },
    )
    class TreeMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            tree_map_group_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tree_map_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a tree map.

            :param tree_map_group_items_limit_configuration: The limit on the number of groups that are displayed.
            :param tree_map_sort: The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_sort_configuration_property = quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                    tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fe4db29e596f9be2693a5f97c7db2891c307687b9d06eb4fd63a450ba2d2d9f8)
                check_type(argname="argument tree_map_group_items_limit_configuration", value=tree_map_group_items_limit_configuration, expected_type=type_hints["tree_map_group_items_limit_configuration"])
                check_type(argname="argument tree_map_sort", value=tree_map_sort, expected_type=type_hints["tree_map_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_group_items_limit_configuration is not None:
                self._values["tree_map_group_items_limit_configuration"] = tree_map_group_items_limit_configuration
            if tree_map_sort is not None:
                self._values["tree_map_sort"] = tree_map_sort

        @builtins.property
        def tree_map_group_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of groups that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html#cfn-quicksight-template-treemapsortconfiguration-treemapgroupitemslimitconfiguration
            '''
            result = self._values.get("tree_map_group_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def tree_map_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html#cfn-quicksight-template-treemapsortconfiguration-treemapsort
            '''
            result = self._values.get("tree_map_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TreeMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TreeMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TreeMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tree_map_visual_property = quicksight.CfnTemplate.TreeMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.TreeMapConfigurationProperty(
                        color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                            color_fill_type="colorFillType",
                            colors=[quicksight.CfnTemplate.DataColorProperty(
                                color="color",
                                data_value=123
                            )],
                
                            # the properties below are optional
                            null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                color="color",
                                data_value=123
                            )
                        ),
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                            tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                                colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                            tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__06742e795e567fb5efd0261dde48c0a3873f3950809950f55d25cba439ac40b3)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TreeMapConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TreeMapConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.TrendArrowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TrendArrowOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :param visibility: The visibility of the trend arrows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-trendarrowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                trend_arrow_options_property = quicksight.CfnTemplate.TrendArrowOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dbb4b2a7e25495d4e8f218946007d1c13ec72dd09c97bc2aa713409a31f469d2)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the trend arrows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-trendarrowoptions.html#cfn-quicksight-template-trendarrowoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TrendArrowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.UnaggregatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
        },
    )
    class UnaggregatedFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]]],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The unaggregated field for a table.

            :param column: The column that is used in the ``UnaggregatedField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                unaggregated_field_property = quicksight.CfnTemplate.UnaggregatedFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5f48952ac3a775ac4c7280e2794aa266a3eac2764100e4a9c96d27c667abaa85)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"]:
            '''The column that is used in the ``UnaggregatedField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnIdentifierProperty"], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FormatConfigurationProperty"]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FormatConfigurationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UnaggregatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.UniqueValuesComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "name": "name",
        },
    )
    class UniqueValuesComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]],
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The unique values computation configuration.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                unique_values_computation_property = quicksight.CfnTemplate.UniqueValuesComputationProperty(
                    category=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__438383d5e80165a5807146d73a1c3386440df8b631cbf18c4f39b5283be81e54)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def category(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UniqueValuesComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.VisibleRangeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"percent_range": "percentRange"},
    )
    class VisibleRangeOptionsProperty:
        def __init__(
            self,
            *,
            percent_range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PercentVisibleRangeProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The range options for the data zoom scroll bar.

            :param percent_range: The percent range in the visible range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visiblerangeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visible_range_options_property = quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                        from=123,
                        to=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__83ffca8c86947f5c3288c0273eb8c866eaf2ca20e72ee520518263b4ccdde408)
                check_type(argname="argument percent_range", value=percent_range, expected_type=type_hints["percent_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percent_range is not None:
                self._values["percent_range"] = percent_range

        @builtins.property
        def percent_range(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PercentVisibleRangeProperty"]]:
            '''The percent range in the visible range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visiblerangeoptions.html#cfn-quicksight-template-visiblerangeoptions-percentrange
            '''
            result = self._values.get("percent_range")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PercentVisibleRangeProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisibleRangeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.VisualCustomActionOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_operation": "filterOperation",
            "navigation_operation": "navigationOperation",
            "set_parameters_operation": "setParametersOperation",
            "url_operation": "urlOperation",
        },
    )
    class VisualCustomActionOperationProperty:
        def __init__(
            self,
            *,
            filter_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CustomActionFilterOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            navigation_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CustomActionNavigationOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            set_parameters_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CustomActionSetParametersOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            url_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CustomActionURLOperationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The operation that is defined by the custom action.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filter_operation: The filter operation that filters data included in a visual or in an entire sheet.
            :param navigation_operation: The navigation operation that navigates between different sheets in the same analysis.
            :param set_parameters_operation: The set parameter operation that sets parameters in custom action.
            :param url_operation: The URL operation that opens a link to another webpage.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_custom_action_operation_property = quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                            selected_field_options="selectedFieldOptions",
                            selected_fields=["selectedFields"]
                        ),
                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                target_visual_options="targetVisualOptions",
                                target_visuals=["targetVisuals"]
                            )
                        )
                    ),
                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                            target_sheet_id="targetSheetId"
                        )
                    ),
                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                            destination_parameter_name="destinationParameterName",
                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                        date_time_values=["dateTimeValues"],
                                        decimal_values=[123],
                                        integer_values=[123],
                                        string_values=["stringValues"]
                                    ),
                
                                    # the properties below are optional
                                    include_null_value=False
                                ),
                                select_all_value_options="selectAllValueOptions",
                                source_field="sourceField",
                                source_parameter_name="sourceParameterName"
                            )
                        )]
                    ),
                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                        url_target="urlTarget",
                        url_template="urlTemplate"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__721dcf015696e45dc7d09593bb8afff317b821d4b0355fd9eb2dd35ae2cbcd3c)
                check_type(argname="argument filter_operation", value=filter_operation, expected_type=type_hints["filter_operation"])
                check_type(argname="argument navigation_operation", value=navigation_operation, expected_type=type_hints["navigation_operation"])
                check_type(argname="argument set_parameters_operation", value=set_parameters_operation, expected_type=type_hints["set_parameters_operation"])
                check_type(argname="argument url_operation", value=url_operation, expected_type=type_hints["url_operation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filter_operation is not None:
                self._values["filter_operation"] = filter_operation
            if navigation_operation is not None:
                self._values["navigation_operation"] = navigation_operation
            if set_parameters_operation is not None:
                self._values["set_parameters_operation"] = set_parameters_operation
            if url_operation is not None:
                self._values["url_operation"] = url_operation

        @builtins.property
        def filter_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomActionFilterOperationProperty"]]:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-filteroperation
            '''
            result = self._values.get("filter_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomActionFilterOperationProperty"]], result)

        @builtins.property
        def navigation_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomActionNavigationOperationProperty"]]:
            '''The navigation operation that navigates between different sheets in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-navigationoperation
            '''
            result = self._values.get("navigation_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomActionNavigationOperationProperty"]], result)

        @builtins.property
        def set_parameters_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomActionSetParametersOperationProperty"]]:
            '''The set parameter operation that sets parameters in custom action.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-setparametersoperation
            '''
            result = self._values.get("set_parameters_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomActionSetParametersOperationProperty"]], result)

        @builtins.property
        def url_operation(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomActionURLOperationProperty"]]:
            '''The URL operation that opens a link to another webpage.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-urloperation
            '''
            result = self._values.get("url_operation")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomActionURLOperationProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.VisualCustomActionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "action_operations": "actionOperations",
            "custom_action_id": "customActionId",
            "name": "name",
            "trigger": "trigger",
            "status": "status",
        },
    )
    class VisualCustomActionProperty:
        def __init__(
            self,
            *,
            action_operations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionOperationProperty", typing.Dict[builtins.str, typing.Any]]]]],
            custom_action_id: builtins.str,
            name: builtins.str,
            trigger: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom action defined on a visual.

            :param action_operations: A list of ``VisualCustomActionOperations`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param custom_action_id: The ID of the ``VisualCustomAction`` .
            :param name: The name of the ``VisualCustomAction`` .
            :param trigger: The trigger of the ``VisualCustomAction`` . Valid values are defined as follows: - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point. - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.
            :param status: The status of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_custom_action_property = quicksight.CfnTemplate.VisualCustomActionProperty(
                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                selected_field_options="selectedFieldOptions",
                                selected_fields=["selectedFields"]
                            ),
                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                    target_visual_options="targetVisualOptions",
                                    target_visuals=["targetVisuals"]
                                )
                            )
                        ),
                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                target_sheet_id="targetSheetId"
                            )
                        ),
                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                destination_parameter_name="destinationParameterName",
                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                            date_time_values=["dateTimeValues"],
                                            decimal_values=[123],
                                            integer_values=[123],
                                            string_values=["stringValues"]
                                        ),
                
                                        # the properties below are optional
                                        include_null_value=False
                                    ),
                                    select_all_value_options="selectAllValueOptions",
                                    source_field="sourceField",
                                    source_parameter_name="sourceParameterName"
                                )
                            )]
                        ),
                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                            url_target="urlTarget",
                            url_template="urlTemplate"
                        )
                    )],
                    custom_action_id="customActionId",
                    name="name",
                    trigger="trigger",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5e341cc4d788437d4da39ccbd43c09c5a09195d5ff3ef61b1a95f537f98c529f)
                check_type(argname="argument action_operations", value=action_operations, expected_type=type_hints["action_operations"])
                check_type(argname="argument custom_action_id", value=custom_action_id, expected_type=type_hints["custom_action_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument trigger", value=trigger, expected_type=type_hints["trigger"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "action_operations": action_operations,
                "custom_action_id": custom_action_id,
                "name": name,
                "trigger": trigger,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def action_operations(
            self,
        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionOperationProperty"]]]:
            '''A list of ``VisualCustomActionOperations`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-actionoperations
            '''
            result = self._values.get("action_operations")
            assert result is not None, "Required property 'action_operations' is missing"
            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionOperationProperty"]]], result)

        @builtins.property
        def custom_action_id(self) -> builtins.str:
            '''The ID of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-customactionid
            '''
            result = self._values.get("custom_action_id")
            assert result is not None, "Required property 'custom_action_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def trigger(self) -> builtins.str:
            '''The trigger of the ``VisualCustomAction`` .

            Valid values are defined as follows:

            - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point.
            - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-trigger
            '''
            result = self._values.get("trigger")
            assert result is not None, "Required property 'trigger' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.VisualPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={"chart_color": "chartColor", "color_map": "colorMap"},
    )
    class VisualPaletteProperty:
        def __init__(
            self,
            *,
            chart_color: typing.Optional[builtins.str] = None,
            color_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataPathColorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The visual display options for the visual palette.

            :param chart_color: The chart color options for the visual palette.
            :param color_map: The color map options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_palette_property = quicksight.CfnTemplate.VisualPaletteProperty(
                    chart_color="chartColor",
                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                        color="color",
                        element=quicksight.CfnTemplate.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        ),
                
                        # the properties below are optional
                        time_granularity="timeGranularity"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__83c636bccc6ecd52cee36ffb92a521268b248394dc32fe179ba8f955493011c0)
                check_type(argname="argument chart_color", value=chart_color, expected_type=type_hints["chart_color"])
                check_type(argname="argument color_map", value=color_map, expected_type=type_hints["color_map"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if chart_color is not None:
                self._values["chart_color"] = chart_color
            if color_map is not None:
                self._values["color_map"] = color_map

        @builtins.property
        def chart_color(self) -> typing.Optional[builtins.str]:
            '''The chart color options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html#cfn-quicksight-template-visualpalette-chartcolor
            '''
            result = self._values.get("chart_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def color_map(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataPathColorProperty"]]]]:
            '''The color map options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html#cfn-quicksight-template-visualpalette-colormap
            '''
            result = self._values.get("color_map")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataPathColorProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.VisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_visual": "barChartVisual",
            "box_plot_visual": "boxPlotVisual",
            "combo_chart_visual": "comboChartVisual",
            "custom_content_visual": "customContentVisual",
            "empty_visual": "emptyVisual",
            "filled_map_visual": "filledMapVisual",
            "funnel_chart_visual": "funnelChartVisual",
            "gauge_chart_visual": "gaugeChartVisual",
            "geospatial_map_visual": "geospatialMapVisual",
            "heat_map_visual": "heatMapVisual",
            "histogram_visual": "histogramVisual",
            "insight_visual": "insightVisual",
            "kpi_visual": "kpiVisual",
            "line_chart_visual": "lineChartVisual",
            "pie_chart_visual": "pieChartVisual",
            "pivot_table_visual": "pivotTableVisual",
            "radar_chart_visual": "radarChartVisual",
            "sankey_diagram_visual": "sankeyDiagramVisual",
            "scatter_plot_visual": "scatterPlotVisual",
            "table_visual": "tableVisual",
            "tree_map_visual": "treeMapVisual",
            "waterfall_visual": "waterfallVisual",
            "word_cloud_visual": "wordCloudVisual",
        },
    )
    class VisualProperty:
        def __init__(
            self,
            *,
            bar_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BarChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            box_plot_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.BoxPlotVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            combo_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ComboChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            custom_content_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.CustomContentVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            empty_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.EmptyVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            filled_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FilledMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            funnel_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FunnelChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            gauge_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GaugeChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            geospatial_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.GeospatialMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            heat_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.HeatMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            histogram_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.HistogramVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            insight_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.InsightVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            kpi_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.KPIVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            line_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LineChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            pie_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PieChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            pivot_table_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.PivotTableVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            radar_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.RadarChartVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sankey_diagram_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.SankeyDiagramVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            scatter_plot_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ScatterPlotVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            table_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TableVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tree_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.TreeMapVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            waterfall_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WaterfallVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            word_cloud_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WordCloudVisualProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A visual displayed on a sheet in an analysis, dashboard, or template.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_visual: A bar chart. For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param box_plot_visual: A box plot. For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .
            :param combo_chart_visual: A combo chart. For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param custom_content_visual: A visual that contains custom content. For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param empty_visual: An empty visual.
            :param filled_map_visual: A filled map. For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param funnel_chart_visual: A funnel chart. For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param gauge_chart_visual: A gauge chart. For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param geospatial_map_visual: A geospatial map or a points on map visual. For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param heat_map_visual: A heat map. For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param histogram_visual: A histogram. For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param insight_visual: An insight visual. For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .
            :param kpi_visual: A key performance indicator (KPI). For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .
            :param line_chart_visual: A line chart. For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param pie_chart_visual: A pie or donut chart. For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param pivot_table_visual: A pivot table. For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .
            :param radar_chart_visual: A radar chart visual. For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param sankey_diagram_visual: A sankey diagram. For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .
            :param scatter_plot_visual: A scatter plot. For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .
            :param table_visual: A table visual. For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .
            :param tree_map_visual: A tree map. For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param waterfall_visual: A waterfall chart. For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param word_cloud_visual: A word cloud. For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                visual_property = quicksight.CfnTemplate.VisualProperty(
                    bar_chart_visual=quicksight.CfnTemplate.BarChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.BarChartConfigurationProperty(
                            bars_arrangement="barsArrangement",
                            category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                                bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            orientation="orientation",
                            reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    box_plot_visual=quicksight.CfnTemplate.BoxPlotVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                            box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                                all_data_points_visibility="allDataPointsVisibility",
                                outlier_visibility="outlierVisibility",
                                style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                                    fill_style="fillStyle"
                                )
                            ),
                            category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                                box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                    page_number=123,
                                    page_size=123
                                )
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    combo_chart_visual=quicksight.CfnTemplate.ComboChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.ComboChartConfigurationProperty(
                            bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            bars_arrangement="barsArrangement",
                            category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                                combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                                    bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    custom_content_visual=quicksight.CfnTemplate.CustomContentVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.CustomContentConfigurationProperty(
                            content_type="contentType",
                            content_url="contentUrl",
                            image_scaling="imageScaling"
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    empty_visual=quicksight.CfnTemplate.EmptyVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )]
                    ),
                    filled_map_visual=quicksight.CfnTemplate.FilledMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.FilledMapConfigurationProperty(
                            field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                                filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                                    geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                base_map_style="baseMapStyle"
                            ),
                            sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                    east=123,
                                    north=123,
                                    south=123,
                                    west=123
                                ),
                                map_zoom_mode="mapZoomMode"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        conditional_formatting=quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                                shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    funnel_chart_visual=quicksight.CfnTemplate.FunnelChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                label_color="labelColor",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_data_label_style="measureDataLabelStyle",
                                measure_label_visibility="measureLabelVisibility",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                                funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    gauge_chart_visual=quicksight.CfnTemplate.GaugeChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                                target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                                arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                                    arc_angle=123,
                                    arc_thickness="arcThickness"
                                ),
                                arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                                    range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                        max=123,
                                        min=123
                                    ),
                                    reserve_range=123
                                ),
                                comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                    comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    comparison_method="comparisonMethod"
                                ),
                                primary_value_display_type="primaryValueDisplayType",
                                primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            ),
                            tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        conditional_formatting=quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                                arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                                    foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                ),
                                primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    geospatial_map_visual=quicksight.CfnTemplate.GeospatialMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                            field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                                geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                base_map_style="baseMapStyle"
                            ),
                            point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                                cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                                    cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                        simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                            color="color"
                                        )
                                    )
                                ),
                                selected_point_style="selectedPointStyle"
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                    east=123,
                                    north=123,
                                    south=123,
                                    west=123
                                ),
                                map_zoom_mode="mapZoomMode"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    heat_map_visual=quicksight.CfnTemplate.HeatMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.HeatMapConfigurationProperty(
                            color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                color_fill_type="colorFillType",
                                colors=[quicksight.CfnTemplate.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )],
                
                                # the properties below are optional
                                null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )
                            ),
                            column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                                heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                                    columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                                heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    histogram_visual=quicksight.CfnTemplate.HistogramVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.HistogramConfigurationProperty(
                            bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                                bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                                    value=123
                                ),
                                bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                                    bin_count_limit=123,
                                    value=123
                                ),
                                selected_bin_type="selectedBinType",
                                start_value=123
                            ),
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                                histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            )
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    insight_visual=quicksight.CfnTemplate.InsightVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        insight_configuration=quicksight.CfnTemplate.InsightConfigurationProperty(
                            computations=[quicksight.CfnTemplate.ComputationProperty(
                                forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    custom_seasonality_value=123,
                                    lower_boundary=123,
                                    name="name",
                                    periods_backward=123,
                                    periods_forward=123,
                                    prediction_interval=123,
                                    seasonality="seasonality",
                                    upper_boundary=123,
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    period_size=123,
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    type="type",
                
                                    # the properties below are optional
                                    name="name",
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                                    computation_id="computationId",
                                    from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name"
                                ),
                                period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    period_time_granularity="periodTimeGranularity",
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                                    category=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    type="type",
                
                                    # the properties below are optional
                                    mover_size=123,
                                    name="name",
                                    sort_order="sortOrder",
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                                    category=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                                    type="type",
                
                                    # the properties below are optional
                                    name="name",
                                    result_size=123,
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                                    computation_id="computationId",
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name"
                                ),
                                unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                                    category=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                
                                    # the properties below are optional
                                    name="name"
                                )
                            )],
                            custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                                narrative="narrative"
                            )
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    kpi_visual=quicksight.CfnTemplate.KPIVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.KPIConfigurationProperty(
                            field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                                target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                                comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                    comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    comparison_method="comparisonMethod"
                                ),
                                primary_value_display_type="primaryValueDisplayType",
                                primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                                    visibility="visibility"
                                ),
                                secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                                    visibility="visibility"
                                ),
                                secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                                    visibility="visibility"
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                                trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        conditional_formatting=quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                                primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                ),
                                progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                                    foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    line_chart_visual=quicksight.CfnTemplate.LineChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.LineChartConfigurationProperty(
                            contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                                axis_binding="axisBinding",
                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            ),
                            field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                                line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                                forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                                    lower_boundary=123,
                                    periods_backward=123,
                                    periods_forward=123,
                                    prediction_interval=123,
                                    seasonality=123,
                                    upper_boundary=123
                                ),
                                scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                                    what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                        date="date",
                                        value=123
                                    ),
                                    what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                        end_date="endDate",
                                        start_date="startDate",
                                        value=123
                                    )
                                )
                            )],
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                    treatment_option="treatmentOption"
                                )]
                            ),
                            primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                    treatment_option="treatmentOption"
                                )]
                            ),
                            secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            series=[quicksight.CfnTemplate.SeriesItemProperty(
                                data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                                    axis_binding="axisBinding",
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    field_value="fieldValue",
                                    settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    )
                                ),
                                field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                                    axis_binding="axisBinding",
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    )
                                )
                            )],
                            small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                                category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            type="type",
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    pie_chart_visual=quicksight.CfnTemplate.PieChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.PieChartConfigurationProperty(
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                                arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                                    arc_thickness="arcThickness"
                                ),
                                donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                                    label_visibility="labelVisibility"
                                )
                            ),
                            field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                                pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    pivot_table_visual=quicksight.CfnTemplate.PivotTableVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.PivotTableConfigurationProperty(
                            field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                                data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                                    data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    )],
                
                                    # the properties below are optional
                                    width="width"
                                )],
                                selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    custom_label="customLabel",
                                    visibility="visibility"
                                )]
                            ),
                            field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                                pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                                    columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                                overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                vertical_overflow_visibility="verticalOverflowVisibility"
                            ),
                            sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                                field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                                    field_id="fieldId",
                                    sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                        column=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                            direction="direction",
                                            sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )]
                                        ),
                                        field=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )
                                )]
                            ),
                            table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                                cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                column_names_visibility="columnNamesVisibility",
                                metric_placement="metricPlacement",
                                row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                    row_alternate_colors=["rowAlternateColors"],
                                    status="status"
                                ),
                                row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                single_metric_visibility="singleMetricVisibility",
                                toggle_buttons_visibility="toggleButtonsVisibility"
                            ),
                            total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                                column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                    custom_label="customLabel",
                                    field_level="fieldLevel",
                                    field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                        field_id="fieldId"
                                    )],
                                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                    custom_label="customLabel",
                                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                    custom_label="customLabel",
                                    field_level="fieldLevel",
                                    field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                        field_id="fieldId"
                                    )],
                                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                    custom_label="customLabel",
                                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            )
                        ),
                        conditional_formatting=quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                                cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                        role="role"
                                    ),
                                    text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    radar_chart_visual=quicksight.CfnTemplate.RadarChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.RadarChartConfigurationProperty(
                            alternate_band_colors_visibility="alternateBandColorsVisibility",
                            alternate_band_even_color="alternateBandEvenColor",
                            alternate_band_odd_color="alternateBandOddColor",
                            base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                                area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                                    visibility="visibility"
                                )
                            ),
                            category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                                radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            shape="shape",
                            sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            start_angle=123,
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    sankey_diagram_visual=quicksight.CfnTemplate.SankeyDiagramVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                                sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                                    destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                                destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            )
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    scatter_plot_visual=quicksight.CfnTemplate.ScatterPlotVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                                scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                                    size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    table_visual=quicksight.CfnTemplate.TableVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.TableConfigurationProperty(
                            field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                                order=["order"],
                                selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    custom_label="customLabel",
                                    url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                        image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                            sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                            )
                                        ),
                                        link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                            content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                                custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                                    icon="icon"
                                                ),
                                                custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                
                                                    # the properties below are optional
                                                    value="value"
                                                )
                                            ),
                                            target="target"
                                        )
                                    ),
                                    visibility="visibility",
                                    width="width"
                                )]
                            ),
                            field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                                table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                                    values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                            date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                                overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                vertical_overflow_visibility="verticalOverflowVisibility"
                            ),
                            sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                                pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                    page_number=123,
                                    page_size=123
                                ),
                                row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                                data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    negative_color="negativeColor",
                                    positive_color="positiveColor"
                                )
                            )],
                            table_options=quicksight.CfnTemplate.TableOptionsProperty(
                                cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                orientation="orientation",
                                row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                    row_alternate_colors=["rowAlternateColors"],
                                    status="status"
                                )
                            ),
                            total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                                custom_label="customLabel",
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility"
                            )
                        ),
                        conditional_formatting=quicksight.CfnTemplate.TableConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                                cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                ),
                                row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    tree_map_visual=quicksight.CfnTemplate.TreeMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.TreeMapConfigurationProperty(
                            color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                color_fill_type="colorFillType",
                                colors=[quicksight.CfnTemplate.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )],
                
                                # the properties below are optional
                                null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )
                            ),
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                                tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                                    colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                                tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    waterfall_visual=quicksight.CfnTemplate.WaterfallVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                            category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                                waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                                    breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                                breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                                total_bar_label="totalBarLabel"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    word_cloud_visual=quicksight.CfnTemplate.WordCloudVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                                word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                                category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                                cloud_layout="cloudLayout",
                                maximum_string_length=123,
                                word_casing="wordCasing",
                                word_orientation="wordOrientation",
                                word_padding="wordPadding",
                                word_scaling="wordScaling"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__923a0cb2672aaacb0a393194555664e6ec18ec302e409be9652375393a3c0336)
                check_type(argname="argument bar_chart_visual", value=bar_chart_visual, expected_type=type_hints["bar_chart_visual"])
                check_type(argname="argument box_plot_visual", value=box_plot_visual, expected_type=type_hints["box_plot_visual"])
                check_type(argname="argument combo_chart_visual", value=combo_chart_visual, expected_type=type_hints["combo_chart_visual"])
                check_type(argname="argument custom_content_visual", value=custom_content_visual, expected_type=type_hints["custom_content_visual"])
                check_type(argname="argument empty_visual", value=empty_visual, expected_type=type_hints["empty_visual"])
                check_type(argname="argument filled_map_visual", value=filled_map_visual, expected_type=type_hints["filled_map_visual"])
                check_type(argname="argument funnel_chart_visual", value=funnel_chart_visual, expected_type=type_hints["funnel_chart_visual"])
                check_type(argname="argument gauge_chart_visual", value=gauge_chart_visual, expected_type=type_hints["gauge_chart_visual"])
                check_type(argname="argument geospatial_map_visual", value=geospatial_map_visual, expected_type=type_hints["geospatial_map_visual"])
                check_type(argname="argument heat_map_visual", value=heat_map_visual, expected_type=type_hints["heat_map_visual"])
                check_type(argname="argument histogram_visual", value=histogram_visual, expected_type=type_hints["histogram_visual"])
                check_type(argname="argument insight_visual", value=insight_visual, expected_type=type_hints["insight_visual"])
                check_type(argname="argument kpi_visual", value=kpi_visual, expected_type=type_hints["kpi_visual"])
                check_type(argname="argument line_chart_visual", value=line_chart_visual, expected_type=type_hints["line_chart_visual"])
                check_type(argname="argument pie_chart_visual", value=pie_chart_visual, expected_type=type_hints["pie_chart_visual"])
                check_type(argname="argument pivot_table_visual", value=pivot_table_visual, expected_type=type_hints["pivot_table_visual"])
                check_type(argname="argument radar_chart_visual", value=radar_chart_visual, expected_type=type_hints["radar_chart_visual"])
                check_type(argname="argument sankey_diagram_visual", value=sankey_diagram_visual, expected_type=type_hints["sankey_diagram_visual"])
                check_type(argname="argument scatter_plot_visual", value=scatter_plot_visual, expected_type=type_hints["scatter_plot_visual"])
                check_type(argname="argument table_visual", value=table_visual, expected_type=type_hints["table_visual"])
                check_type(argname="argument tree_map_visual", value=tree_map_visual, expected_type=type_hints["tree_map_visual"])
                check_type(argname="argument waterfall_visual", value=waterfall_visual, expected_type=type_hints["waterfall_visual"])
                check_type(argname="argument word_cloud_visual", value=word_cloud_visual, expected_type=type_hints["word_cloud_visual"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_visual is not None:
                self._values["bar_chart_visual"] = bar_chart_visual
            if box_plot_visual is not None:
                self._values["box_plot_visual"] = box_plot_visual
            if combo_chart_visual is not None:
                self._values["combo_chart_visual"] = combo_chart_visual
            if custom_content_visual is not None:
                self._values["custom_content_visual"] = custom_content_visual
            if empty_visual is not None:
                self._values["empty_visual"] = empty_visual
            if filled_map_visual is not None:
                self._values["filled_map_visual"] = filled_map_visual
            if funnel_chart_visual is not None:
                self._values["funnel_chart_visual"] = funnel_chart_visual
            if gauge_chart_visual is not None:
                self._values["gauge_chart_visual"] = gauge_chart_visual
            if geospatial_map_visual is not None:
                self._values["geospatial_map_visual"] = geospatial_map_visual
            if heat_map_visual is not None:
                self._values["heat_map_visual"] = heat_map_visual
            if histogram_visual is not None:
                self._values["histogram_visual"] = histogram_visual
            if insight_visual is not None:
                self._values["insight_visual"] = insight_visual
            if kpi_visual is not None:
                self._values["kpi_visual"] = kpi_visual
            if line_chart_visual is not None:
                self._values["line_chart_visual"] = line_chart_visual
            if pie_chart_visual is not None:
                self._values["pie_chart_visual"] = pie_chart_visual
            if pivot_table_visual is not None:
                self._values["pivot_table_visual"] = pivot_table_visual
            if radar_chart_visual is not None:
                self._values["radar_chart_visual"] = radar_chart_visual
            if sankey_diagram_visual is not None:
                self._values["sankey_diagram_visual"] = sankey_diagram_visual
            if scatter_plot_visual is not None:
                self._values["scatter_plot_visual"] = scatter_plot_visual
            if table_visual is not None:
                self._values["table_visual"] = table_visual
            if tree_map_visual is not None:
                self._values["tree_map_visual"] = tree_map_visual
            if waterfall_visual is not None:
                self._values["waterfall_visual"] = waterfall_visual
            if word_cloud_visual is not None:
                self._values["word_cloud_visual"] = word_cloud_visual

        @builtins.property
        def bar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BarChartVisualProperty"]]:
            '''A bar chart.

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-barchartvisual
            '''
            result = self._values.get("bar_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BarChartVisualProperty"]], result)

        @builtins.property
        def box_plot_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotVisualProperty"]]:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-boxplotvisual
            '''
            result = self._values.get("box_plot_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.BoxPlotVisualProperty"]], result)

        @builtins.property
        def combo_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComboChartVisualProperty"]]:
            '''A combo chart.

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-combochartvisual
            '''
            result = self._values.get("combo_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ComboChartVisualProperty"]], result)

        @builtins.property
        def custom_content_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomContentVisualProperty"]]:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-customcontentvisual
            '''
            result = self._values.get("custom_content_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.CustomContentVisualProperty"]], result)

        @builtins.property
        def empty_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.EmptyVisualProperty"]]:
            '''An empty visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-emptyvisual
            '''
            result = self._values.get("empty_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.EmptyVisualProperty"]], result)

        @builtins.property
        def filled_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapVisualProperty"]]:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-filledmapvisual
            '''
            result = self._values.get("filled_map_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FilledMapVisualProperty"]], result)

        @builtins.property
        def funnel_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FunnelChartVisualProperty"]]:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-funnelchartvisual
            '''
            result = self._values.get("funnel_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FunnelChartVisualProperty"]], result)

        @builtins.property
        def gauge_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartVisualProperty"]]:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-gaugechartvisual
            '''
            result = self._values.get("gauge_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GaugeChartVisualProperty"]], result)

        @builtins.property
        def geospatial_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialMapVisualProperty"]]:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-geospatialmapvisual
            '''
            result = self._values.get("geospatial_map_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.GeospatialMapVisualProperty"]], result)

        @builtins.property
        def heat_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeatMapVisualProperty"]]:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-heatmapvisual
            '''
            result = self._values.get("heat_map_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HeatMapVisualProperty"]], result)

        @builtins.property
        def histogram_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HistogramVisualProperty"]]:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-histogramvisual
            '''
            result = self._values.get("histogram_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.HistogramVisualProperty"]], result)

        @builtins.property
        def insight_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.InsightVisualProperty"]]:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-insightvisual
            '''
            result = self._values.get("insight_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.InsightVisualProperty"]], result)

        @builtins.property
        def kpi_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIVisualProperty"]]:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-kpivisual
            '''
            result = self._values.get("kpi_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.KPIVisualProperty"]], result)

        @builtins.property
        def line_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartVisualProperty"]]:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-linechartvisual
            '''
            result = self._values.get("line_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LineChartVisualProperty"]], result)

        @builtins.property
        def pie_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PieChartVisualProperty"]]:
            '''A pie or donut chart.

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-piechartvisual
            '''
            result = self._values.get("pie_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PieChartVisualProperty"]], result)

        @builtins.property
        def pivot_table_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableVisualProperty"]]:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-pivottablevisual
            '''
            result = self._values.get("pivot_table_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.PivotTableVisualProperty"]], result)

        @builtins.property
        def radar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartVisualProperty"]]:
            '''A radar chart visual.

            For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-radarchartvisual
            '''
            result = self._values.get("radar_chart_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.RadarChartVisualProperty"]], result)

        @builtins.property
        def sankey_diagram_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SankeyDiagramVisualProperty"]]:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-sankeydiagramvisual
            '''
            result = self._values.get("sankey_diagram_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.SankeyDiagramVisualProperty"]], result)

        @builtins.property
        def scatter_plot_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ScatterPlotVisualProperty"]]:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-scatterplotvisual
            '''
            result = self._values.get("scatter_plot_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ScatterPlotVisualProperty"]], result)

        @builtins.property
        def table_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableVisualProperty"]]:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-tablevisual
            '''
            result = self._values.get("table_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TableVisualProperty"]], result)

        @builtins.property
        def tree_map_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TreeMapVisualProperty"]]:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-treemapvisual
            '''
            result = self._values.get("tree_map_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.TreeMapVisualProperty"]], result)

        @builtins.property
        def waterfall_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WaterfallVisualProperty"]]:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-waterfallvisual
            '''
            result = self._values.get("waterfall_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WaterfallVisualProperty"]], result)

        @builtins.property
        def word_cloud_visual(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WordCloudVisualProperty"]]:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-wordcloudvisual
            '''
            result = self._values.get("word_cloud_visual")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WordCloudVisualProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualSubtitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LongFormatTextProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The subtitle label options for a visual.

            :param format_text: The long text format of the subtitle label, such as plain text or rich text.
            :param visibility: The visibility of the subtitle label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_subtitle_label_options_property = quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62fc9d0a5aaf9b73b4ab4ec8953073a61db943549b6fc08a6a8422a6120285a6)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LongFormatTextProperty"]]:
            '''The long text format of the subtitle label, such as plain text or rich text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html#cfn-quicksight-template-visualsubtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LongFormatTextProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the subtitle label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html#cfn-quicksight-template-visualsubtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualSubtitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.VisualTitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualTitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ShortFormatTextProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The title label options for a visual.

            :param format_text: The short text format of the title label, such as plain text or rich text.
            :param visibility: The visibility of the title label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                visual_title_label_options_property = quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e753584f968bf87b7fc2deca1ea47670c40e02e7b84f70b36c21364ba13ae989)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ShortFormatTextProperty"]]:
            '''The short text format of the title label, such as plain text or rich text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html#cfn-quicksight-template-visualtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ShortFormatTextProperty"]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the title label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html#cfn-quicksight-template-visualtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualTitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdowns": "breakdowns",
            "categories": "categories",
            "values": "values",
        },
    )
    class WaterfallChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            breakdowns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            categories: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param breakdowns: The breakdown field wells of a waterfall visual.
            :param categories: The category field wells of a waterfall visual.
            :param values: The value field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                waterfall_chart_aggregated_field_wells_property = quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                    breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5f2d41a9250a39eb4f2db0b0768f29bc32fe0167b368ab60a0d0db64df89c523)
                check_type(argname="argument breakdowns", value=breakdowns, expected_type=type_hints["breakdowns"])
                check_type(argname="argument categories", value=categories, expected_type=type_hints["categories"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdowns is not None:
                self._values["breakdowns"] = breakdowns
            if categories is not None:
                self._values["categories"] = categories
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def breakdowns(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The breakdown field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-breakdowns
            '''
            result = self._values.get("breakdowns")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def categories(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The category field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-categories
            '''
            result = self._values.get("categories")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The value field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WaterfallChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_axis_display_options": "categoryAxisDisplayOptions",
            "category_axis_label_options": "categoryAxisLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "visual_palette": "visualPalette",
            "waterfall_chart_options": "waterfallChartOptions",
        },
    )
    class WaterfallChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WaterfallChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WaterfallChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            waterfall_chart_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WaterfallChartOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration for a waterfall visual.

            :param category_axis_display_options: The options that determine the presentation of the category axis.
            :param category_axis_label_options: The options that determine the presentation of the category axis label.
            :param data_labels: The data label configuration of a waterfall visual.
            :param field_wells: The field well configuration of a waterfall visual.
            :param legend: The legend configuration of a waterfall visual.
            :param primary_y_axis_display_options: The options that determine the presentation of the y-axis.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param sort_configuration: The sort configuration of a waterfall visual.
            :param visual_palette: The visual palette configuration of a waterfall visual.
            :param waterfall_chart_options: The options that determine the presentation of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                waterfall_chart_configuration_property = quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                    category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                        waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                            breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                        breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                        total_bar_label="totalBarLabel"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c262143fe18a1d2385a0f8329fc92f26eaf7aec22ea1fea95a32d6392c52e769)
                check_type(argname="argument category_axis_display_options", value=category_axis_display_options, expected_type=type_hints["category_axis_display_options"])
                check_type(argname="argument category_axis_label_options", value=category_axis_label_options, expected_type=type_hints["category_axis_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument waterfall_chart_options", value=waterfall_chart_options, expected_type=type_hints["waterfall_chart_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_axis_display_options is not None:
                self._values["category_axis_display_options"] = category_axis_display_options
            if category_axis_label_options is not None:
                self._values["category_axis_label_options"] = category_axis_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if waterfall_chart_options is not None:
                self._values["waterfall_chart_options"] = waterfall_chart_options

        @builtins.property
        def category_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the category axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-categoryaxisdisplayoptions
            '''
            result = self._values.get("category_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def category_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the category axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-categoryaxislabeloptions
            '''
            result = self._values.get("category_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]]:
            '''The data label configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DataLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WaterfallChartFieldWellsProperty"]]:
            '''The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WaterfallChartFieldWellsProperty"]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]]:
            '''The legend configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.LegendOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.AxisDisplayOptionsProperty"]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The options that determine the presentation of the y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WaterfallChartSortConfigurationProperty"]]:
            '''The sort configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WaterfallChartSortConfigurationProperty"]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]]:
            '''The visual palette configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualPaletteProperty"]], result)

        @builtins.property
        def waterfall_chart_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WaterfallChartOptionsProperty"]]:
            '''The options that determine the presentation of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-waterfallchartoptions
            '''
            result = self._values.get("waterfall_chart_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WaterfallChartOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WaterfallChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "waterfall_chart_aggregated_field_wells": "waterfallChartAggregatedFieldWells",
        },
    )
    class WaterfallChartFieldWellsProperty:
        def __init__(
            self,
            *,
            waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WaterfallChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param waterfall_chart_aggregated_field_wells: The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                waterfall_chart_field_wells_property = quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                    waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                        breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__419d921a031125f8a5cbc9397d538b44a166b5a86ad16ef517bd23d9c32d207c)
                check_type(argname="argument waterfall_chart_aggregated_field_wells", value=waterfall_chart_aggregated_field_wells, expected_type=type_hints["waterfall_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if waterfall_chart_aggregated_field_wells is not None:
                self._values["waterfall_chart_aggregated_field_wells"] = waterfall_chart_aggregated_field_wells

        @builtins.property
        def waterfall_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WaterfallChartAggregatedFieldWellsProperty"]]:
            '''The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartfieldwells.html#cfn-quicksight-template-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
            '''
            result = self._values.get("waterfall_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WaterfallChartAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WaterfallChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"total_bar_label": "totalBarLabel"},
    )
    class WaterfallChartOptionsProperty:
        def __init__(
            self,
            *,
            total_bar_label: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of a waterfall visual.

            :param total_bar_label: This option determines the total bar label of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                waterfall_chart_options_property = quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                    total_bar_label="totalBarLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3502b6423d8b8b916d6ae7d88cf10140b3c4351cd01644c4580494e306a871f1)
                check_type(argname="argument total_bar_label", value=total_bar_label, expected_type=type_hints["total_bar_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if total_bar_label is not None:
                self._values["total_bar_label"] = total_bar_label

        @builtins.property
        def total_bar_label(self) -> typing.Optional[builtins.str]:
            '''This option determines the total bar label of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartoptions.html#cfn-quicksight-template-waterfallchartoptions-totalbarlabel
            '''
            result = self._values.get("total_bar_label")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdown_items_limit": "breakdownItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WaterfallChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            breakdown_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a waterfall visual.

            :param breakdown_items_limit: The limit on the number of bar groups that are displayed.
            :param category_sort: The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                waterfall_chart_sort_configuration_property = quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                    breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6bb06da3783264c73b7109c1dd8984bb17ee1045c8efdf2f97d04694500a932a)
                check_type(argname="argument breakdown_items_limit", value=breakdown_items_limit, expected_type=type_hints["breakdown_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdown_items_limit is not None:
                self._values["breakdown_items_limit"] = breakdown_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def breakdown_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of bar groups that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html#cfn-quicksight-template-waterfallchartsortconfiguration-breakdownitemslimit
            '''
            result = self._values.get("breakdown_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html#cfn-quicksight-template-waterfallchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WaterfallVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WaterfallVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WaterfallChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a waterfall visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                # data_driven: Any
                
                waterfall_visual_property = quicksight.CfnTemplate.WaterfallVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                        category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                            waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                                breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                            breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                            total_bar_label="totalBarLabel"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7bdbd11276f3f7f72104beec60b5ee768d0938e52d644ace00f99958298be8d8)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WaterfallChartConfigurationProperty"]]:
            '''The configuration for a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WaterfallChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WhatIfPointScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={"date": "date", "value": "value"},
    )
    class WhatIfPointScenarioProperty:
        def __init__(self, *, date: builtins.str, value: jsii.Number) -> None:
            '''Provides the forecast to meet the target for a particular date.

            :param date: The date that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                what_if_point_scenario_property = quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                    date="date",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ae1b84eaed34d7a24ba20dd80b298b6650902ff3d5ddf079c09751afa5cc50d2)
                check_type(argname="argument date", value=date, expected_type=type_hints["date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "date": date,
                "value": value,
            }

        @builtins.property
        def date(self) -> builtins.str:
            '''The date that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html#cfn-quicksight-template-whatifpointscenario-date
            '''
            result = self._values.get("date")
            assert result is not None, "Required property 'date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html#cfn-quicksight-template-whatifpointscenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfPointScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WhatIfRangeScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "end_date": "endDate",
            "start_date": "startDate",
            "value": "value",
        },
    )
    class WhatIfRangeScenarioProperty:
        def __init__(
            self,
            *,
            end_date: builtins.str,
            start_date: builtins.str,
            value: jsii.Number,
        ) -> None:
            '''Provides the forecast to meet the target for a particular date range.

            :param end_date: The end date in the date range that you need the forecast results for.
            :param start_date: The start date in the date range that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                what_if_range_scenario_property = quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                    end_date="endDate",
                    start_date="startDate",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__85b2c5ba7ea1aa73214826545ff6c486b9ed4553d658c0f89d86c2328b385a16)
                check_type(argname="argument end_date", value=end_date, expected_type=type_hints["end_date"])
                check_type(argname="argument start_date", value=start_date, expected_type=type_hints["start_date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "end_date": end_date,
                "start_date": start_date,
                "value": value,
            }

        @builtins.property
        def end_date(self) -> builtins.str:
            '''The end date in the date range that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-enddate
            '''
            result = self._values.get("end_date")
            assert result is not None, "Required property 'end_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def start_date(self) -> builtins.str:
            '''The start date in the date range that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-startdate
            '''
            result = self._values.get("start_date")
            assert result is not None, "Required property 'start_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfRangeScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "size": "size"},
    )
    class WordCloudAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The aggregated field wells of a word cloud.

            :param group_by: The group by field well of a word cloud. Values are grouped by group by fields.
            :param size: The size field well of a word cloud. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_aggregated_field_wells_property = quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b9b49495ea318089a289d9a1bd2521b9e843819d58c219917b5a27fc3779a986)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if size is not None:
                self._values["size"] = size

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]]:
            '''The group by field well of a word cloud.

            Values are grouped by group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html#cfn-quicksight-template-wordcloudaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.DimensionFieldProperty"]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]]:
            '''The size field well of a word cloud.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html#cfn-quicksight-template-wordcloudaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.MeasureFieldProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WordCloudChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "word_cloud_options": "wordCloudOptions",
        },
    )
    class WordCloudChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WordCloudFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WordCloudSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            word_cloud_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WordCloudOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The configuration of a word cloud visual.

            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
            :param field_wells: The field wells of the visual.
            :param sort_configuration: The sort configuration of a word cloud visual.
            :param word_cloud_options: The options for a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_chart_configuration_property = quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                        word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                        cloud_layout="cloudLayout",
                        maximum_string_length=123,
                        word_casing="wordCasing",
                        word_orientation="wordOrientation",
                        word_padding="wordPadding",
                        word_scaling="wordScaling"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7f79af8d57f9ee39da663706547784f114fa8193dc3865331992be1b6f9ff9e7)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument word_cloud_options", value=word_cloud_options, expected_type=type_hints["word_cloud_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if word_cloud_options is not None:
                self._values["word_cloud_options"] = word_cloud_options

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]]:
            '''The label options (label text, label visibility, and sort icon visibility) for the word cloud category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ChartAxisLabelOptionsProperty"]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WordCloudFieldWellsProperty"]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WordCloudFieldWellsProperty"]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WordCloudSortConfigurationProperty"]]:
            '''The sort configuration of a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WordCloudSortConfigurationProperty"]], result)

        @builtins.property
        def word_cloud_options(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WordCloudOptionsProperty"]]:
            '''The options for a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-wordcloudoptions
            '''
            result = self._values.get("word_cloud_options")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WordCloudOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WordCloudFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "word_cloud_aggregated_field_wells": "wordCloudAggregatedFieldWells",
        },
    )
    class WordCloudFieldWellsProperty:
        def __init__(
            self,
            *,
            word_cloud_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WordCloudAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The field wells of a word cloud visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param word_cloud_aggregated_field_wells: The aggregated field wells of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_field_wells_property = quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                    word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4da3ca444204cbc42e8cd4cf6d6bf294b802283c048cad1611677b3c66582290)
                check_type(argname="argument word_cloud_aggregated_field_wells", value=word_cloud_aggregated_field_wells, expected_type=type_hints["word_cloud_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if word_cloud_aggregated_field_wells is not None:
                self._values["word_cloud_aggregated_field_wells"] = word_cloud_aggregated_field_wells

        @builtins.property
        def word_cloud_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WordCloudAggregatedFieldWellsProperty"]]:
            '''The aggregated field wells of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudfieldwells.html#cfn-quicksight-template-wordcloudfieldwells-wordcloudaggregatedfieldwells
            '''
            result = self._values.get("word_cloud_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WordCloudAggregatedFieldWellsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WordCloudOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cloud_layout": "cloudLayout",
            "maximum_string_length": "maximumStringLength",
            "word_casing": "wordCasing",
            "word_orientation": "wordOrientation",
            "word_padding": "wordPadding",
            "word_scaling": "wordScaling",
        },
    )
    class WordCloudOptionsProperty:
        def __init__(
            self,
            *,
            cloud_layout: typing.Optional[builtins.str] = None,
            maximum_string_length: typing.Optional[jsii.Number] = None,
            word_casing: typing.Optional[builtins.str] = None,
            word_orientation: typing.Optional[builtins.str] = None,
            word_padding: typing.Optional[builtins.str] = None,
            word_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The word cloud options for a word cloud visual.

            :param cloud_layout: The cloud layout options (fluid, normal) of a word cloud.
            :param maximum_string_length: The length limit of each word from 1-100.
            :param word_casing: The word casing options (lower_case, existing_case) for the words in a word cloud.
            :param word_orientation: The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
            :param word_padding: The word padding options (none, small, medium, large) for the words in a word cloud.
            :param word_scaling: The word scaling options (emphasize, normal) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_options_property = quicksight.CfnTemplate.WordCloudOptionsProperty(
                    cloud_layout="cloudLayout",
                    maximum_string_length=123,
                    word_casing="wordCasing",
                    word_orientation="wordOrientation",
                    word_padding="wordPadding",
                    word_scaling="wordScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd1ce26606c639e3a3c42d27cc07ab8232eb7b103c1ecbfcb9bfb90cb48503ec)
                check_type(argname="argument cloud_layout", value=cloud_layout, expected_type=type_hints["cloud_layout"])
                check_type(argname="argument maximum_string_length", value=maximum_string_length, expected_type=type_hints["maximum_string_length"])
                check_type(argname="argument word_casing", value=word_casing, expected_type=type_hints["word_casing"])
                check_type(argname="argument word_orientation", value=word_orientation, expected_type=type_hints["word_orientation"])
                check_type(argname="argument word_padding", value=word_padding, expected_type=type_hints["word_padding"])
                check_type(argname="argument word_scaling", value=word_scaling, expected_type=type_hints["word_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cloud_layout is not None:
                self._values["cloud_layout"] = cloud_layout
            if maximum_string_length is not None:
                self._values["maximum_string_length"] = maximum_string_length
            if word_casing is not None:
                self._values["word_casing"] = word_casing
            if word_orientation is not None:
                self._values["word_orientation"] = word_orientation
            if word_padding is not None:
                self._values["word_padding"] = word_padding
            if word_scaling is not None:
                self._values["word_scaling"] = word_scaling

        @builtins.property
        def cloud_layout(self) -> typing.Optional[builtins.str]:
            '''The cloud layout options (fluid, normal) of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-cloudlayout
            '''
            result = self._values.get("cloud_layout")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def maximum_string_length(self) -> typing.Optional[jsii.Number]:
            '''The length limit of each word from 1-100.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-maximumstringlength
            '''
            result = self._values.get("maximum_string_length")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def word_casing(self) -> typing.Optional[builtins.str]:
            '''The word casing options (lower_case, existing_case) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordcasing
            '''
            result = self._values.get("word_casing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_orientation(self) -> typing.Optional[builtins.str]:
            '''The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordorientation
            '''
            result = self._values.get("word_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_padding(self) -> typing.Optional[builtins.str]:
            '''The word padding options (none, small, medium, large) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordpadding
            '''
            result = self._values.get("word_padding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_scaling(self) -> typing.Optional[builtins.str]:
            '''The word scaling options (emphasize, normal) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordscaling
            '''
            result = self._values.get("word_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WordCloudSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WordCloudSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''The sort configuration of a word cloud visual.

            :param category_items_limit: The limit on the number of groups that are displayed in a word cloud.
            :param category_sort: The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_sort_configuration_property = quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04069ff21989ec3b74f74ab26c2da06c9883c11532f7eca2b45657f0584342cf)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]]:
            '''The limit on the number of groups that are displayed in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html#cfn-quicksight-template-wordcloudsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ItemsLimitConfigurationProperty"]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]]:
            '''The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html#cfn-quicksight-template-wordcloudsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.FieldSortOptionsProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTemplate.WordCloudVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WordCloudVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.WordCloudChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                word_cloud_visual_property = quicksight.CfnTemplate.WordCloudVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                            word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                            category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                            cloud_layout="cloudLayout",
                            maximum_string_length=123,
                            word_casing="wordCasing",
                            word_orientation="wordOrientation",
                            word_padding="wordPadding",
                            word_scaling="wordScaling"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1bf0f20f1d7f4cfb7a2b93de3398fc1f42214b8325cb769c64134112652e6e39)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualCustomActionProperty"]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WordCloudChartConfigurationProperty"]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.WordCloudChartConfigurationProperty"]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.ColumnHierarchyProperty"]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualSubtitleLabelOptionsProperty"]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTemplate.VisualTitleLabelOptionsProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="@aws-cdk/aws-quicksight.CfnTemplateProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "template_id": "templateId",
        "definition": "definition",
        "name": "name",
        "permissions": "permissions",
        "source_entity": "sourceEntity",
        "tags": "tags",
        "version_description": "versionDescription",
    },
)
class CfnTemplateProps:
    def __init__(
        self,
        *,
        aws_account_id: builtins.str,
        template_id: builtins.str,
        definition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TemplateVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        source_entity: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TemplateSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnTemplate``.

        :param aws_account_id: The ID for the AWS account that the group is in. You use the ID for the AWS account that contains your Amazon QuickSight account.
        :param template_id: An ID for the template that you want to create. This template is unique per AWS Region ; in each AWS account.
        :param definition: ``AWS::QuickSight::Template.Definition``.
        :param name: A display name for the template.
        :param permissions: A list of resource permissions to be set on the template.
        :param source_entity: The entity that you are using as a source when you create the template. In ``SourceEntity`` , you specify the type of object you're using as source: ``SourceTemplate`` for a template or ``SourceAnalysis`` for an analysis. Both of these require an Amazon Resource Name (ARN). For ``SourceTemplate`` , specify the ARN of the source template. For ``SourceAnalysis`` , specify the ARN of the source analysis. The ``SourceTemplate`` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region . Use the ``DataSetReferences`` entity within ``SourceTemplate`` or ``SourceAnalysis`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder. Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.
        :param version_description: A description of the current template version being created. This API operation creates the first version of the template. Every time ``UpdateTemplate`` is called, a new version is created. Each version of the template maintains a description of the version in the ``VersionDescription`` field.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            import aws_cdk.aws_quicksight as quicksight
            
            # data_driven: Any
            
            cfn_template_props = quicksight.CfnTemplateProps(
                aws_account_id="awsAccountId",
                template_id="templateId",
            
                # the properties below are optional
                definition=quicksight.CfnTemplate.TemplateVersionDefinitionProperty(
                    data_set_configurations=[quicksight.CfnTemplate.DataSetConfigurationProperty(
                        column_group_schema_list=[quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                            column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                                name="name"
                            )],
                            name="name"
                        )],
                        data_set_schema=quicksight.CfnTemplate.DataSetSchemaProperty(
                            column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                                data_type="dataType",
                                geographic_role="geographicRole",
                                name="name"
                            )]
                        ),
                        placeholder="placeholder"
                    )],
            
                    # the properties below are optional
                    analysis_defaults=quicksight.CfnTemplate.AnalysisDefaultsProperty(
                        default_new_sheet_configuration=quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty(
                            interactive_layout_configuration=quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                                free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            ),
                            paginated_layout_configuration=quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                                section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    )
                                )
                            ),
                            sheet_content_type="sheetContentType"
                        )
                    ),
                    calculated_fields=[quicksight.CfnTemplate.CalculatedFieldProperty(
                        data_set_identifier="dataSetIdentifier",
                        expression="expression",
                        name="name"
                    )],
                    column_configurations=[quicksight.CfnTemplate.ColumnConfigurationProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
            
                        # the properties below are optional
                        colors_configuration=quicksight.CfnTemplate.ColorsConfigurationProperty(
                            custom_colors=[quicksight.CfnTemplate.CustomColorProperty(
                                color="color",
            
                                # the properties below are optional
                                field_value="fieldValue",
                                special_value="specialValue"
                            )]
                        ),
                        format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        role="role"
                    )],
                    filter_groups=[quicksight.CfnTemplate.FilterGroupProperty(
                        cross_dataset="crossDataset",
                        filter_group_id="filterGroupId",
                        filters=[quicksight.CfnTemplate.FilterProperty(
                            category_filter=quicksight.CfnTemplate.CategoryFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                                    custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
            
                                        # the properties below are optional
                                        category_value="categoryValue",
                                        parameter_name="parameterName",
                                        select_all_options="selectAllOptions"
                                    ),
                                    custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
            
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    ),
                                    filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                                        match_operator="matchOperator",
            
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    )
                                ),
                                filter_id="filterId"
                            ),
                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                match_operator="matchOperator",
                                null_option="nullOption",
            
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions",
                                value=123
                            ),
                            numeric_range_filter=quicksight.CfnTemplate.NumericRangeFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
            
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                select_all_options="selectAllOptions"
                            ),
                            relative_dates_filter=quicksight.CfnTemplate.RelativeDatesFilterProperty(
                                anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                                    anchor_option="anchorOption",
                                    parameter_name="parameterName"
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                                relative_date_type="relativeDateType",
                                time_granularity="timeGranularity",
            
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
            
                                    # the properties below are optional
                                    status="status"
                                ),
                                minimum_granularity="minimumGranularity",
                                parameter_name="parameterName",
                                relative_date_value=123
                            ),
                            time_equality_filter=quicksight.CfnTemplate.TimeEqualityFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
            
                                # the properties below are optional
                                parameter_name="parameterName",
                                time_granularity="timeGranularity",
                                value="value"
                            ),
                            time_range_filter=quicksight.CfnTemplate.TimeRangeFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
            
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
            
                                    # the properties below are optional
                                    status="status"
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                        expression="expression",
            
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                        expression="expression",
            
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                time_granularity="timeGranularity"
                            ),
                            top_bottom_filter=quicksight.CfnTemplate.TopBottomFilterProperty(
                                aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    sort_direction="sortDirection"
                                )],
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
            
                                # the properties below are optional
                                limit=123,
                                parameter_name="parameterName",
                                time_granularity="timeGranularity"
                            )
                        )],
                        scope_configuration=quicksight.CfnTemplate.FilterScopeConfigurationProperty(
                            selected_sheets=quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                                sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                                    scope="scope",
                                    sheet_id="sheetId",
            
                                    # the properties below are optional
                                    visual_ids=["visualIds"]
                                )]
                            )
                        ),
            
                        # the properties below are optional
                        status="status"
                    )],
                    parameter_declarations=[quicksight.CfnTemplate.ParameterDeclarationProperty(
                        date_time_parameter_declaration=quicksight.CfnTemplate.DateTimeParameterDeclarationProperty(
                            name="name",
            
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
            
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            time_granularity="timeGranularity",
                            value_when_unset=quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        decimal_parameter_declaration=quicksight.CfnTemplate.DecimalParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        integer_parameter_declaration=quicksight.CfnTemplate.IntegerParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        string_parameter_declaration=quicksight.CfnTemplate.StringParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.StringDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        )
                    )],
                    sheets=[quicksight.CfnTemplate.SheetDefinitionProperty(
                        sheet_id="sheetId",
            
                        # the properties below are optional
                        content_type="contentType",
                        description="description",
                        filter_controls=[quicksight.CfnTemplate.FilterControlProperty(
                            date_time_picker=quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            dropdown=quicksight.CfnTemplate.FilterDropDownControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnTemplate.FilterListControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            relative_date_time=quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            slider=quicksight.CfnTemplate.FilterSliderControlProperty(
                                filter_control_id="filterControlId",
                                maximum_value=123,
                                minimum_value=123,
                                source_filter_id="sourceFilterId",
                                step_size=123,
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            text_area=quicksight.CfnTemplate.FilterTextAreaControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnTemplate.FilterTextFieldControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        layouts=[quicksight.CfnTemplate.LayoutProperty(
                            configuration=quicksight.CfnTemplate.LayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
            
                                        # the properties below are optional
                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
            
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                                    body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                                        content=quicksight.CfnTemplate.BodySectionContentProperty(
                                            layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                                free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                        element_id="elementId",
                                                        element_type="elementType",
                                                        height="height",
                                                        width="width",
                                                        x_axis_location="xAxisLocation",
                                                        y_axis_location="yAxisLocation",
            
                                                        # the properties below are optional
                                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                            visibility="visibility"
                                                        ),
                                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                                visibility="visibility"
                                                            ),
                                                            expression="expression"
                                                        )],
                                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        visibility="visibility"
                                                    )]
                                                )
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                            after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                                status="status"
                                            )
                                        ),
                                        style=quicksight.CfnTemplate.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    ),
                                    footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
            
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        style=quicksight.CfnTemplate.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
            
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        style=quicksight.CfnTemplate.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )]
                                )
                            )
                        )],
                        name="name",
                        parameter_controls=[quicksight.CfnTemplate.ParameterControlProperty(
                            date_time_picker=quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            dropdown=quicksight.CfnTemplate.ParameterDropDownControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnTemplate.ParameterListControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            slider=quicksight.CfnTemplate.ParameterSliderControlProperty(
                                maximum_value=123,
                                minimum_value=123,
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                step_size=123,
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_area=quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        sheet_control_layouts=[quicksight.CfnTemplate.SheetControlLayoutProperty(
                            configuration=quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                                grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
            
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            )
                        )],
                        text_boxes=[quicksight.CfnTemplate.SheetTextBoxProperty(
                            sheet_text_box_id="sheetTextBoxId",
            
                            # the properties below are optional
                            content="content"
                        )],
                        title="title",
                        visuals=[quicksight.CfnTemplate.VisualProperty(
                            bar_chart_visual=quicksight.CfnTemplate.BarChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.BarChartConfigurationProperty(
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                                        bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    orientation="orientation",
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            box_plot_visual=quicksight.CfnTemplate.BoxPlotVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                                    box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                                        all_data_points_visibility="allDataPointsVisibility",
                                        outlier_visibility="outlierVisibility",
                                        style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                                            fill_style="fillStyle"
                                        )
                                    ),
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                                        box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        )
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            combo_chart_visual=quicksight.CfnTemplate.ComboChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.ComboChartConfigurationProperty(
                                    bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                                        combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                                            bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            custom_content_visual=quicksight.CfnTemplate.CustomContentVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.CustomContentConfigurationProperty(
                                    content_type="contentType",
                                    content_url="contentUrl",
                                    image_scaling="imageScaling"
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            empty_visual=quicksight.CfnTemplate.EmptyVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )]
                            ),
                            filled_map_visual=quicksight.CfnTemplate.FilledMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.FilledMapConfigurationProperty(
                                    field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                                        filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                                            geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                                        shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            funnel_chart_visual=quicksight.CfnTemplate.FunnelChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        label_color="labelColor",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_data_label_style="measureDataLabelStyle",
                                        measure_label_visibility="measureLabelVisibility",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                                        funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            gauge_chart_visual=quicksight.CfnTemplate.GaugeChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                                        target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                                        arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                                            arc_angle=123,
                                            arc_thickness="arcThickness"
                                        ),
                                        arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                                            range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                                max=123,
                                                min=123
                                            ),
                                            reserve_range=123
                                        ),
                                        comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    ),
                                    tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                conditional_formatting=quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                                        arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
            
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            geospatial_map_visual=quicksight.CfnTemplate.GeospatialMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                                    field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                                        geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                                        cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                                            cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                                simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                                    color="color"
                                                )
                                            )
                                        ),
                                        selected_point_style="selectedPointStyle"
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            heat_map_visual=quicksight.CfnTemplate.HeatMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.HeatMapConfigurationProperty(
                                    color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
            
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                                        heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                                        heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            histogram_visual=quicksight.CfnTemplate.HistogramVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.HistogramConfigurationProperty(
                                    bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                                        bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                                            value=123
                                        ),
                                        bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                                            bin_count_limit=123,
                                            value=123
                                        ),
                                        selected_bin_type="selectedBinType",
                                        start_value=123
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                                        histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    )
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            insight_visual=quicksight.CfnTemplate.InsightVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                insight_configuration=quicksight.CfnTemplate.InsightConfigurationProperty(
                                    computations=[quicksight.CfnTemplate.ComputationProperty(
                                        forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            custom_seasonality_value=123,
                                            lower_boundary=123,
                                            name="name",
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality="seasonality",
                                            upper_boundary=123,
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            period_size=123,
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
            
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                                            computation_id="computationId",
                                            from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            period_time_granularity="periodTimeGranularity",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
            
                                            # the properties below are optional
                                            mover_size=123,
                                            name="name",
                                            sort_order="sortOrder",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            type="type",
            
                                            # the properties below are optional
                                            name="name",
                                            result_size=123,
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                                            computation_id="computationId",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
            
                                            # the properties below are optional
                                            name="name"
                                        )
                                    )],
                                    custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                                        narrative="narrative"
                                    )
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            kpi_visual=quicksight.CfnTemplate.KPIVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.KPIConfigurationProperty(
                                    field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                                        target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                                        comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                                        trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                                        primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
            
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            line_chart_visual=quicksight.CfnTemplate.LineChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.LineChartConfigurationProperty(
                                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                                        axis_binding="axisBinding",
                                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                                        line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                                        forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                                            lower_boundary=123,
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality=123,
                                            upper_boundary=123
                                        ),
                                        scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                                            what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                                date="date",
                                                value=123
                                            ),
                                            what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                                end_date="endDate",
                                                start_date="startDate",
                                                value=123
                                            )
                                        )
                                    )],
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    series=[quicksight.CfnTemplate.SeriesItemProperty(
                                        data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            field_value="fieldValue",
                                            settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        ),
                                        field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                                        category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    type="type",
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pie_chart_visual=quicksight.CfnTemplate.PieChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.PieChartConfigurationProperty(
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                                        arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                                            arc_thickness="arcThickness"
                                        ),
                                        donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                                            label_visibility="labelVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                                        pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pivot_table_visual=quicksight.CfnTemplate.PivotTableVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.PivotTableConfigurationProperty(
                                    field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                                        data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                                            data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )],
            
                                            # the properties below are optional
                                            width="width"
                                        )],
                                        selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            visibility="visibility"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                                        pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                                        field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                                            field_id="fieldId",
                                            sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                                column=quicksight.CfnTemplate.ColumnSortProperty(
                                                    direction="direction",
                                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    )
                                                ),
                                                data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                                    direction="direction",
                                                    sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                                        field_id="fieldId",
                                                        field_value="fieldValue"
                                                    )]
                                                ),
                                                field=quicksight.CfnTemplate.FieldSortProperty(
                                                    direction="direction",
                                                    field_id="fieldId"
                                                )
                                            )
                                        )]
                                    ),
                                    table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                                        cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_names_visibility="columnNamesVisibility",
                                        metric_placement="metricPlacement",
                                        row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        ),
                                        row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        single_metric_visibility="singleMetricVisibility",
                                        toggle_buttons_visibility="toggleButtonsVisibility"
                                    ),
                                    total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                                        column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    )
                                ),
                                conditional_formatting=quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                                role="role"
                                            ),
                                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
            
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            radar_chart_visual=quicksight.CfnTemplate.RadarChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.RadarChartConfigurationProperty(
                                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                                    alternate_band_even_color="alternateBandEvenColor",
                                    alternate_band_odd_color="alternateBandOddColor",
                                    base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                                        area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                                        radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    shape="shape",
                                    sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    start_angle=123,
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            sankey_diagram_visual=quicksight.CfnTemplate.SankeyDiagramVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                                        sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                                            destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                                        destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            scatter_plot_visual=quicksight.CfnTemplate.ScatterPlotVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            table_visual=quicksight.CfnTemplate.TableVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.TableConfigurationProperty(
                                    field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                                        order=["order"],
                                        selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                                image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                                    sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                    )
                                                ),
                                                link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                                    content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                                        custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                                            icon="icon"
                                                        ),
                                                        custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                                font_color="fontColor",
                                                                font_decoration="fontDecoration",
                                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                                    relative="relative"
                                                                ),
                                                                font_style="fontStyle",
                                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                                    name="name"
                                                                )
                                                            ),
            
                                                            # the properties below are optional
                                                            value="value"
                                                        )
                                                    ),
                                                    target="target"
                                                )
                                            ),
                                            visibility="visibility",
                                            width="width"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                                        table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                                            values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                                    date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                                        pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        ),
                                        row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                                        data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            negative_color="negativeColor",
                                            positive_color="positiveColor"
                                        )
                                    )],
                                    table_options=quicksight.CfnTemplate.TableOptionsProperty(
                                        cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        orientation="orientation",
                                        row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        )
                                    ),
                                    total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                                        custom_label="customLabel",
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility"
                                    )
                                ),
                                conditional_formatting=quicksight.CfnTemplate.TableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
            
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        ),
                                        row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            tree_map_visual=quicksight.CfnTemplate.TreeMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.TreeMapConfigurationProperty(
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
            
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                                        tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                                        tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            waterfall_visual=quicksight.CfnTemplate.WaterfallVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                                    category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                                        waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                                            breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                                        breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                                        total_bar_label="totalBarLabel"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            word_cloud_visual=quicksight.CfnTemplate.WordCloudVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                                        word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                                        cloud_layout="cloudLayout",
                                        maximum_string_length=123,
                                        word_casing="wordCasing",
                                        word_orientation="wordOrientation",
                                        word_padding="wordPadding",
                                        word_scaling="wordScaling"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )]
                    )]
                ),
                name="name",
                permissions=[quicksight.CfnTemplate.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
            
                    # the properties below are optional
                    resource="resource"
                )],
                source_entity=quicksight.CfnTemplate.TemplateSourceEntityProperty(
                    source_analysis=quicksight.CfnTemplate.TemplateSourceAnalysisProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnTemplate.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    ),
                    source_template=quicksight.CfnTemplate.TemplateSourceTemplateProperty(
                        arn="arn"
                    )
                ),
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                version_description="versionDescription"
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__da0ede0a029c9a18c5efd81310d5eb827b7628e83eab5b86d1ab1e34c44eec6d)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument template_id", value=template_id, expected_type=type_hints["template_id"])
            check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument source_entity", value=source_entity, expected_type=type_hints["source_entity"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument version_description", value=version_description, expected_type=type_hints["version_description"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aws_account_id": aws_account_id,
            "template_id": template_id,
        }
        if definition is not None:
            self._values["definition"] = definition
        if name is not None:
            self._values["name"] = name
        if permissions is not None:
            self._values["permissions"] = permissions
        if source_entity is not None:
            self._values["source_entity"] = source_entity
        if tags is not None:
            self._values["tags"] = tags
        if version_description is not None:
            self._values["version_description"] = version_description

    @builtins.property
    def aws_account_id(self) -> builtins.str:
        '''The ID for the AWS account that the group is in.

        You use the ID for the AWS account that contains your Amazon QuickSight account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        assert result is not None, "Required property 'aws_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def template_id(self) -> builtins.str:
        '''An ID for the template that you want to create.

        This template is unique per AWS Region ; in each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-templateid
        '''
        result = self._values.get("template_id")
        assert result is not None, "Required property 'template_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def definition(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTemplate.TemplateVersionDefinitionProperty]]:
        '''``AWS::QuickSight::Template.Definition``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-definition
        '''
        result = self._values.get("definition")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTemplate.TemplateVersionDefinitionProperty]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the template.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTemplate.ResourcePermissionProperty]]]]:
        '''A list of resource permissions to be set on the template.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTemplate.ResourcePermissionProperty]]]], result)

    @builtins.property
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTemplate.TemplateSourceEntityProperty]]:
        '''The entity that you are using as a source when you create the template.

        In ``SourceEntity`` , you specify the type of object you're using as source: ``SourceTemplate`` for a template or ``SourceAnalysis`` for an analysis. Both of these require an Amazon Resource Name (ARN). For ``SourceTemplate`` , specify the ARN of the source template. For ``SourceAnalysis`` , specify the ARN of the source analysis. The ``SourceTemplate`` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region .

        Use the ``DataSetReferences`` entity within ``SourceTemplate`` or ``SourceAnalysis`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.

        Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-sourceentity
        '''
        result = self._values.get("source_entity")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTemplate.TemplateSourceEntityProperty]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]], result)

    @builtins.property
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description of the current template version being created.

        This API operation creates the first version of the template. Every time ``UpdateTemplate`` is called, a new version is created. Each version of the template maintains a description of the version in the ``VersionDescription`` field.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-versiondescription
        '''
        result = self._values.get("version_description")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnTemplateProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_aws_cdk_core_f4b25747.IInspectable)
class CfnTheme(
    _aws_cdk_core_f4b25747.CfnResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@aws-cdk/aws-quicksight.CfnTheme",
):
    '''A CloudFormation ``AWS::QuickSight::Theme``.

    Creates a theme.

    A *theme* is set of configuration options for color and layout. Themes apply to analyses and dashboards. For more information, see `Using Themes in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/themes-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

    :cloudformationResource: AWS::QuickSight::Theme
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        import aws_cdk.aws_quicksight as quicksight
        
        cfn_theme = quicksight.CfnTheme(self, "MyCfnTheme",
            aws_account_id="awsAccountId",
            theme_id="themeId",
        
            # the properties below are optional
            base_theme_id="baseThemeId",
            configuration=quicksight.CfnTheme.ThemeConfigurationProperty(
                data_color_palette=quicksight.CfnTheme.DataColorPaletteProperty(
                    colors=["colors"],
                    empty_fill_color="emptyFillColor",
                    min_max_gradient=["minMaxGradient"]
                ),
                sheet=quicksight.CfnTheme.SheetStyleProperty(
                    tile=quicksight.CfnTheme.TileStyleProperty(
                        border=quicksight.CfnTheme.BorderStyleProperty(
                            show=False
                        )
                    ),
                    tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                        gutter=quicksight.CfnTheme.GutterStyleProperty(
                            show=False
                        ),
                        margin=quicksight.CfnTheme.MarginStyleProperty(
                            show=False
                        )
                    )
                ),
                typography=quicksight.CfnTheme.TypographyProperty(
                    font_families=[quicksight.CfnTheme.FontProperty(
                        font_family="fontFamily"
                    )]
                ),
                ui_color_palette=quicksight.CfnTheme.UIColorPaletteProperty(
                    accent="accent",
                    accent_foreground="accentForeground",
                    danger="danger",
                    danger_foreground="dangerForeground",
                    dimension="dimension",
                    dimension_foreground="dimensionForeground",
                    measure="measure",
                    measure_foreground="measureForeground",
                    primary_background="primaryBackground",
                    primary_foreground="primaryForeground",
                    secondary_background="secondaryBackground",
                    secondary_foreground="secondaryForeground",
                    success="success",
                    success_foreground="successForeground",
                    warning="warning",
                    warning_foreground="warningForeground"
                )
            ),
            name="name",
            permissions=[quicksight.CfnTheme.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal"
            )],
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            version_description="versionDescription"
        )
    '''

    def __init__(
        self,
        scope: _aws_cdk_core_f4b25747.Construct,
        id: builtins.str,
        *,
        aws_account_id: builtins.str,
        theme_id: builtins.str,
        base_theme_id: typing.Optional[builtins.str] = None,
        configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.ThemeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::Theme``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param aws_account_id: The ID of the AWS account where you want to store the new theme.
        :param theme_id: An ID for the theme that you want to create. The theme ID is unique per AWS Region in each AWS account.
        :param base_theme_id: The ID of the theme that a custom theme will inherit from. All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use ``ListThemes`` or choose *Themes* from within an analysis.
        :param configuration: The theme configuration, which contains the theme display properties.
        :param name: A display name for the theme.
        :param permissions: A valid grouping of resource permissions to apply to the new theme.
        :param tags: A map of the key-value pairs for the resource tag or tags that you want to add to the resource.
        :param version_description: A description of the first version of the theme that you're creating. Every time ``UpdateTheme`` is called, a new version is created. Each version of the theme has a description of the version in the ``VersionDescription`` field.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0d97a2c65ae01ccf3d3b3226a5b98f0f7f565cbd27de714e800586e3987daee9)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnThemeProps(
            aws_account_id=aws_account_id,
            theme_id=theme_id,
            base_theme_id=base_theme_id,
            configuration=configuration,
            name=name,
            permissions=permissions,
            tags=tags,
            version_description=version_description,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _aws_cdk_core_f4b25747.TreeInspector) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c5d31b7e255a7b05ca5a1496c05085a78a898e35c5f197cc2365e78dabb5caf0)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1df7c989fc0afd3dd38b6c47d8f5c86c3515abcce558c01f87cdc5ac6a11113d)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the theme.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time the theme was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time the theme was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrType")
    def attr_type(self) -> builtins.str:
        '''Theme type.

        :cloudformationAttribute: Type
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrType"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionArn")
    def attr_version_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionBaseThemeId")
    def attr_version_base_theme_id(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.BaseThemeId
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionBaseThemeId"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionCreatedTime")
    def attr_version_created_time(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDescription")
    def attr_version_description(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Description
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionDescription"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionErrors")
    def attr_version_errors(self) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: Version.Errors
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrVersionErrors"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionStatus")
    def attr_version_status(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionStatus"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionVersionNumber")
    def attr_version_version_number(self) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: Version.VersionNumber
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrVersionVersionNumber"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _aws_cdk_core_f4b25747.TagManager:
        '''A map of the key-value pairs for the resource tag or tags that you want to add to the resource.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-tags
        '''
        return typing.cast(_aws_cdk_core_f4b25747.TagManager, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you want to store the new theme.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-awsaccountid
        '''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8d3ee86e9952db24447ec18879c76c44056075efb6920e9002b7d33dde3f93bd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="themeId")
    def theme_id(self) -> builtins.str:
        '''An ID for the theme that you want to create.

        The theme ID is unique per AWS Region in each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-themeid
        '''
        return typing.cast(builtins.str, jsii.get(self, "themeId"))

    @theme_id.setter
    def theme_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__39a6bb0be980507d80e6e81076d1abd10638efc69ecb18d73fce6b319f3a01ff)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "themeId", value)

    @builtins.property
    @jsii.member(jsii_name="baseThemeId")
    def base_theme_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the theme that a custom theme will inherit from.

        All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use ``ListThemes`` or choose *Themes* from within an analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-basethemeid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "baseThemeId"))

    @base_theme_id.setter
    def base_theme_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a6c2318a4831aa5433ea87f62920e560a286ca012b581830a91a36e41e0abb8e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "baseThemeId", value)

    @builtins.property
    @jsii.member(jsii_name="configuration")
    def configuration(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.ThemeConfigurationProperty"]]:
        '''The theme configuration, which contains the theme display properties.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-configuration
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.ThemeConfigurationProperty"]], jsii.get(self, "configuration"))

    @configuration.setter
    def configuration(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.ThemeConfigurationProperty"]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4ec269ee627a8c5d80e3a3005e7ba13140b45bf5213eeda4cbfa4503c6967ccd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "configuration", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the theme.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-name
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__72e82ae0b5892c79676dc350f2edbff8b64848ab7f4862a7f80f193aa100af33)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.ResourcePermissionProperty"]]]]:
        '''A valid grouping of resource permissions to apply to the new theme.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-permissions
        '''
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.ResourcePermissionProperty"]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.ResourcePermissionProperty"]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__409212622d84e420d87b39a6b168407dddcca251f4b9c92af1195f8b84e8573a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="versionDescription")
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description of the first version of the theme that you're creating.

        Every time ``UpdateTheme`` is called, a new version is created. Each version of the theme has a description of the version in the ``VersionDescription`` field.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-versiondescription
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionDescription"))

    @version_description.setter
    def version_description(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__23c3e2dd891065878d4e73d25428ed2511f9a3b3acb5426683428914de618d6e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "versionDescription", value)

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.BorderStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"show": "show"},
    )
    class BorderStyleProperty:
        def __init__(
            self,
            *,
            show: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
        ) -> None:
            '''The display options for tile borders for visuals.

            :param show: The option to enable display of borders for visuals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-borderstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                border_style_property = quicksight.CfnTheme.BorderStyleProperty(
                    show=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a13afdb34f7384c58342de00287aba691901bdc53eec64918eda62d353f9ebad)
                check_type(argname="argument show", value=show, expected_type=type_hints["show"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if show is not None:
                self._values["show"] = show

        @builtins.property
        def show(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''The option to enable display of borders for visuals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-borderstyle.html#cfn-quicksight-theme-borderstyle-show
            '''
            result = self._values.get("show")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BorderStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.DataColorPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={
            "colors": "colors",
            "empty_fill_color": "emptyFillColor",
            "min_max_gradient": "minMaxGradient",
        },
    )
    class DataColorPaletteProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Sequence[builtins.str]] = None,
            empty_fill_color: typing.Optional[builtins.str] = None,
            min_max_gradient: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The theme colors that are used for data colors in charts.

            The colors description is a hexadecimal color code that consists of six alphanumerical characters, prefixed with ``#`` , for example #37BFF5.

            :param colors: The hexadecimal codes for the colors.
            :param empty_fill_color: The hexadecimal code of a color that applies to charts where a lack of data is highlighted.
            :param min_max_gradient: The minimum and maximum hexadecimal codes that describe a color gradient.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                data_color_palette_property = quicksight.CfnTheme.DataColorPaletteProperty(
                    colors=["colors"],
                    empty_fill_color="emptyFillColor",
                    min_max_gradient=["minMaxGradient"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__898cca280e845aa5606f1c03dd507419feadf4ec4852f879c1b41557c7d61780)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument empty_fill_color", value=empty_fill_color, expected_type=type_hints["empty_fill_color"])
                check_type(argname="argument min_max_gradient", value=min_max_gradient, expected_type=type_hints["min_max_gradient"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if empty_fill_color is not None:
                self._values["empty_fill_color"] = empty_fill_color
            if min_max_gradient is not None:
                self._values["min_max_gradient"] = min_max_gradient

        @builtins.property
        def colors(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The hexadecimal codes for the colors.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def empty_fill_color(self) -> typing.Optional[builtins.str]:
            '''The hexadecimal code of a color that applies to charts where a lack of data is highlighted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-emptyfillcolor
            '''
            result = self._values.get("empty_fill_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def min_max_gradient(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The minimum and maximum hexadecimal codes that describe a color gradient.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-minmaxgradient
            '''
            result = self._values.get("min_max_gradient")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataColorPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.FontProperty",
        jsii_struct_bases=[],
        name_mapping={"font_family": "fontFamily"},
    )
    class FontProperty:
        def __init__(
            self,
            *,
            font_family: typing.Optional[builtins.str] = None,
        ) -> None:
            '''
            :param font_family: ``CfnTheme.FontProperty.FontFamily``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-font.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                font_property = quicksight.CfnTheme.FontProperty(
                    font_family="fontFamily"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9d68d6fb2efed6c0a00eb6974e574f5b01ea6dbb5c107b2a15a71c8352f934c2)
                check_type(argname="argument font_family", value=font_family, expected_type=type_hints["font_family"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_family is not None:
                self._values["font_family"] = font_family

        @builtins.property
        def font_family(self) -> typing.Optional[builtins.str]:
            '''``CfnTheme.FontProperty.FontFamily``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-font.html#cfn-quicksight-theme-font-fontfamily
            '''
            result = self._values.get("font_family")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.GutterStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"show": "show"},
    )
    class GutterStyleProperty:
        def __init__(
            self,
            *,
            show: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
        ) -> None:
            '''The display options for gutter spacing between tiles on a sheet.

            :param show: This Boolean value controls whether to display a gutter space between sheet tiles.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-gutterstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                gutter_style_property = quicksight.CfnTheme.GutterStyleProperty(
                    show=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7e8a6ba1bbe327f848e775d5d339603f487fa18ce125690eb51053635f103c3a)
                check_type(argname="argument show", value=show, expected_type=type_hints["show"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if show is not None:
                self._values["show"] = show

        @builtins.property
        def show(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''This Boolean value controls whether to display a gutter space between sheet tiles.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-gutterstyle.html#cfn-quicksight-theme-gutterstyle-show
            '''
            result = self._values.get("show")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GutterStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.MarginStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"show": "show"},
    )
    class MarginStyleProperty:
        def __init__(
            self,
            *,
            show: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
        ) -> None:
            '''The display options for margins around the outside edge of sheets.

            :param show: This Boolean value controls whether to display sheet margins.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-marginstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                margin_style_property = quicksight.CfnTheme.MarginStyleProperty(
                    show=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c56c66aaf5ef70ebbb94a27700268f46ad23aa1cb66ad1e88e3832595df1a735)
                check_type(argname="argument show", value=show, expected_type=type_hints["show"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if show is not None:
                self._values["show"] = show

        @builtins.property
        def show(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
            '''This Boolean value controls whether to display sheet margins.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-marginstyle.html#cfn-quicksight-theme-marginstyle-show
            '''
            result = self._values.get("show")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MarginStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={"actions": "actions", "principal": "principal"},
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnTheme.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f1aa3ff38c9c3662f2c93cec3c13f9cc49bdf27513b58194e3001974cf0bc9cc)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html#cfn-quicksight-theme-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html#cfn-quicksight-theme-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.SheetStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"tile": "tile", "tile_layout": "tileLayout"},
    )
    class SheetStyleProperty:
        def __init__(
            self,
            *,
            tile: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.TileStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            tile_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.TileLayoutStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The theme display options for sheets.

            :param tile: The display options for tiles.
            :param tile_layout: The layout options for tiles.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                sheet_style_property = quicksight.CfnTheme.SheetStyleProperty(
                    tile=quicksight.CfnTheme.TileStyleProperty(
                        border=quicksight.CfnTheme.BorderStyleProperty(
                            show=False
                        )
                    ),
                    tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                        gutter=quicksight.CfnTheme.GutterStyleProperty(
                            show=False
                        ),
                        margin=quicksight.CfnTheme.MarginStyleProperty(
                            show=False
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a75e77eb907668958a7e13163e7e7684ada34f0b85239695bd2953991a8c5520)
                check_type(argname="argument tile", value=tile, expected_type=type_hints["tile"])
                check_type(argname="argument tile_layout", value=tile_layout, expected_type=type_hints["tile_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tile is not None:
                self._values["tile"] = tile
            if tile_layout is not None:
                self._values["tile_layout"] = tile_layout

        @builtins.property
        def tile(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.TileStyleProperty"]]:
            '''The display options for tiles.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html#cfn-quicksight-theme-sheetstyle-tile
            '''
            result = self._values.get("tile")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.TileStyleProperty"]], result)

        @builtins.property
        def tile_layout(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.TileLayoutStyleProperty"]]:
            '''The layout options for tiles.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html#cfn-quicksight-theme-sheetstyle-tilelayout
            '''
            result = self._values.get("tile_layout")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.TileLayoutStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.ThemeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_color_palette": "dataColorPalette",
            "sheet": "sheet",
            "typography": "typography",
            "ui_color_palette": "uiColorPalette",
        },
    )
    class ThemeConfigurationProperty:
        def __init__(
            self,
            *,
            data_color_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.DataColorPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            sheet: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.SheetStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            typography: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.TypographyProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            ui_color_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.UIColorPaletteProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The theme configuration.

            This configuration contains all of the display properties for a theme.

            :param data_color_palette: Color properties that apply to chart data colors.
            :param sheet: Display options related to sheets.
            :param typography: ``CfnTheme.ThemeConfigurationProperty.Typography``.
            :param ui_color_palette: Color properties that apply to the UI and to charts, excluding the colors that apply to data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                theme_configuration_property = quicksight.CfnTheme.ThemeConfigurationProperty(
                    data_color_palette=quicksight.CfnTheme.DataColorPaletteProperty(
                        colors=["colors"],
                        empty_fill_color="emptyFillColor",
                        min_max_gradient=["minMaxGradient"]
                    ),
                    sheet=quicksight.CfnTheme.SheetStyleProperty(
                        tile=quicksight.CfnTheme.TileStyleProperty(
                            border=quicksight.CfnTheme.BorderStyleProperty(
                                show=False
                            )
                        ),
                        tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                            gutter=quicksight.CfnTheme.GutterStyleProperty(
                                show=False
                            ),
                            margin=quicksight.CfnTheme.MarginStyleProperty(
                                show=False
                            )
                        )
                    ),
                    typography=quicksight.CfnTheme.TypographyProperty(
                        font_families=[quicksight.CfnTheme.FontProperty(
                            font_family="fontFamily"
                        )]
                    ),
                    ui_color_palette=quicksight.CfnTheme.UIColorPaletteProperty(
                        accent="accent",
                        accent_foreground="accentForeground",
                        danger="danger",
                        danger_foreground="dangerForeground",
                        dimension="dimension",
                        dimension_foreground="dimensionForeground",
                        measure="measure",
                        measure_foreground="measureForeground",
                        primary_background="primaryBackground",
                        primary_foreground="primaryForeground",
                        secondary_background="secondaryBackground",
                        secondary_foreground="secondaryForeground",
                        success="success",
                        success_foreground="successForeground",
                        warning="warning",
                        warning_foreground="warningForeground"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f460d11d699592a86fbe5608e9fdb598fe65cce6ee119f3c1aa89a62b2f3ae5d)
                check_type(argname="argument data_color_palette", value=data_color_palette, expected_type=type_hints["data_color_palette"])
                check_type(argname="argument sheet", value=sheet, expected_type=type_hints["sheet"])
                check_type(argname="argument typography", value=typography, expected_type=type_hints["typography"])
                check_type(argname="argument ui_color_palette", value=ui_color_palette, expected_type=type_hints["ui_color_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_color_palette is not None:
                self._values["data_color_palette"] = data_color_palette
            if sheet is not None:
                self._values["sheet"] = sheet
            if typography is not None:
                self._values["typography"] = typography
            if ui_color_palette is not None:
                self._values["ui_color_palette"] = ui_color_palette

        @builtins.property
        def data_color_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.DataColorPaletteProperty"]]:
            '''Color properties that apply to chart data colors.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-datacolorpalette
            '''
            result = self._values.get("data_color_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.DataColorPaletteProperty"]], result)

        @builtins.property
        def sheet(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.SheetStyleProperty"]]:
            '''Display options related to sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-sheet
            '''
            result = self._values.get("sheet")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.SheetStyleProperty"]], result)

        @builtins.property
        def typography(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.TypographyProperty"]]:
            '''``CfnTheme.ThemeConfigurationProperty.Typography``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-typography
            '''
            result = self._values.get("typography")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.TypographyProperty"]], result)

        @builtins.property
        def ui_color_palette(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.UIColorPaletteProperty"]]:
            '''Color properties that apply to the UI and to charts, excluding the colors that apply to data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-uicolorpalette
            '''
            result = self._values.get("ui_color_palette")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.UIColorPaletteProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThemeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.ThemeErrorProperty",
        jsii_struct_bases=[],
        name_mapping={"message": "message", "type": "type"},
    )
    class ThemeErrorProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Theme error.

            :param message: The error message.
            :param type: The type of error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                theme_error_property = quicksight.CfnTheme.ThemeErrorProperty(
                    message="message",
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__40389bf90e3dbaac39f81c1ed5783fd088358f206b44cfa6dcebf45a4dbd1a61)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''The error message.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html#cfn-quicksight-theme-themeerror-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html#cfn-quicksight-theme-themeerror-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThemeErrorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.ThemeVersionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arn": "arn",
            "base_theme_id": "baseThemeId",
            "configuration": "configuration",
            "created_time": "createdTime",
            "description": "description",
            "errors": "errors",
            "status": "status",
            "version_number": "versionNumber",
        },
    )
    class ThemeVersionProperty:
        def __init__(
            self,
            *,
            arn: typing.Optional[builtins.str] = None,
            base_theme_id: typing.Optional[builtins.str] = None,
            configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.ThemeConfigurationProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            created_time: typing.Optional[builtins.str] = None,
            description: typing.Optional[builtins.str] = None,
            errors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.ThemeErrorProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
            status: typing.Optional[builtins.str] = None,
            version_number: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A version of a theme.

            :param arn: The Amazon Resource Name (ARN) of the resource.
            :param base_theme_id: The Amazon QuickSight-defined ID of the theme that a custom theme inherits from. All themes initially inherit from a default Amazon QuickSight theme.
            :param configuration: The theme configuration, which contains all the theme display properties.
            :param created_time: The date and time that this theme version was created.
            :param description: The description of the theme.
            :param errors: Errors associated with the theme.
            :param status: The status of the theme version.
            :param version_number: The version number of the theme.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                theme_version_property = quicksight.CfnTheme.ThemeVersionProperty(
                    arn="arn",
                    base_theme_id="baseThemeId",
                    configuration=quicksight.CfnTheme.ThemeConfigurationProperty(
                        data_color_palette=quicksight.CfnTheme.DataColorPaletteProperty(
                            colors=["colors"],
                            empty_fill_color="emptyFillColor",
                            min_max_gradient=["minMaxGradient"]
                        ),
                        sheet=quicksight.CfnTheme.SheetStyleProperty(
                            tile=quicksight.CfnTheme.TileStyleProperty(
                                border=quicksight.CfnTheme.BorderStyleProperty(
                                    show=False
                                )
                            ),
                            tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                                gutter=quicksight.CfnTheme.GutterStyleProperty(
                                    show=False
                                ),
                                margin=quicksight.CfnTheme.MarginStyleProperty(
                                    show=False
                                )
                            )
                        ),
                        typography=quicksight.CfnTheme.TypographyProperty(
                            font_families=[quicksight.CfnTheme.FontProperty(
                                font_family="fontFamily"
                            )]
                        ),
                        ui_color_palette=quicksight.CfnTheme.UIColorPaletteProperty(
                            accent="accent",
                            accent_foreground="accentForeground",
                            danger="danger",
                            danger_foreground="dangerForeground",
                            dimension="dimension",
                            dimension_foreground="dimensionForeground",
                            measure="measure",
                            measure_foreground="measureForeground",
                            primary_background="primaryBackground",
                            primary_foreground="primaryForeground",
                            secondary_background="secondaryBackground",
                            secondary_foreground="secondaryForeground",
                            success="success",
                            success_foreground="successForeground",
                            warning="warning",
                            warning_foreground="warningForeground"
                        )
                    ),
                    created_time="createdTime",
                    description="description",
                    errors=[quicksight.CfnTheme.ThemeErrorProperty(
                        message="message",
                        type="type"
                    )],
                    status="status",
                    version_number=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ef4d9a8672060f10978f0b81e2d71bb3037e6c1560d90d506194b949a68d8523)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument base_theme_id", value=base_theme_id, expected_type=type_hints["base_theme_id"])
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
                check_type(argname="argument created_time", value=created_time, expected_type=type_hints["created_time"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument errors", value=errors, expected_type=type_hints["errors"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument version_number", value=version_number, expected_type=type_hints["version_number"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arn is not None:
                self._values["arn"] = arn
            if base_theme_id is not None:
                self._values["base_theme_id"] = base_theme_id
            if configuration is not None:
                self._values["configuration"] = configuration
            if created_time is not None:
                self._values["created_time"] = created_time
            if description is not None:
                self._values["description"] = description
            if errors is not None:
                self._values["errors"] = errors
            if status is not None:
                self._values["status"] = status
            if version_number is not None:
                self._values["version_number"] = version_number

        @builtins.property
        def arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of the resource.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-arn
            '''
            result = self._values.get("arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def base_theme_id(self) -> typing.Optional[builtins.str]:
            '''The Amazon QuickSight-defined ID of the theme that a custom theme inherits from.

            All themes initially inherit from a default Amazon QuickSight theme.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-basethemeid
            '''
            result = self._values.get("base_theme_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def configuration(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.ThemeConfigurationProperty"]]:
            '''The theme configuration, which contains all the theme display properties.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-configuration
            '''
            result = self._values.get("configuration")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.ThemeConfigurationProperty"]], result)

        @builtins.property
        def created_time(self) -> typing.Optional[builtins.str]:
            '''The date and time that this theme version was created.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-createdtime
            '''
            result = self._values.get("created_time")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''The description of the theme.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def errors(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.ThemeErrorProperty"]]]]:
            '''Errors associated with the theme.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-errors
            '''
            result = self._values.get("errors")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.ThemeErrorProperty"]]]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the theme version.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def version_number(self) -> typing.Optional[jsii.Number]:
            '''The version number of the theme.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-versionnumber
            '''
            result = self._values.get("version_number")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThemeVersionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.TileLayoutStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"gutter": "gutter", "margin": "margin"},
    )
    class TileLayoutStyleProperty:
        def __init__(
            self,
            *,
            gutter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.GutterStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
            margin: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.MarginStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''The display options for the layout of tiles on a sheet.

            :param gutter: The gutter settings that apply between tiles.
            :param margin: The margin settings that apply around the outside edge of sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tile_layout_style_property = quicksight.CfnTheme.TileLayoutStyleProperty(
                    gutter=quicksight.CfnTheme.GutterStyleProperty(
                        show=False
                    ),
                    margin=quicksight.CfnTheme.MarginStyleProperty(
                        show=False
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4672b8b341aeb421f770e3908e8a197ef7bf17a582fd68535ebcdf24faff8199)
                check_type(argname="argument gutter", value=gutter, expected_type=type_hints["gutter"])
                check_type(argname="argument margin", value=margin, expected_type=type_hints["margin"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if gutter is not None:
                self._values["gutter"] = gutter
            if margin is not None:
                self._values["margin"] = margin

        @builtins.property
        def gutter(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.GutterStyleProperty"]]:
            '''The gutter settings that apply between tiles.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html#cfn-quicksight-theme-tilelayoutstyle-gutter
            '''
            result = self._values.get("gutter")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.GutterStyleProperty"]], result)

        @builtins.property
        def margin(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.MarginStyleProperty"]]:
            '''The margin settings that apply around the outside edge of sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html#cfn-quicksight-theme-tilelayoutstyle-margin
            '''
            result = self._values.get("margin")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.MarginStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TileLayoutStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.TileStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"border": "border"},
    )
    class TileStyleProperty:
        def __init__(
            self,
            *,
            border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.BorderStyleProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
        ) -> None:
            '''Display options related to tiles on a sheet.

            :param border: The border around a tile.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilestyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                tile_style_property = quicksight.CfnTheme.TileStyleProperty(
                    border=quicksight.CfnTheme.BorderStyleProperty(
                        show=False
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb2825e22f00040b7d88e0e46dad98276e68de257ba97aa9fbd06e624444611b)
                check_type(argname="argument border", value=border, expected_type=type_hints["border"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if border is not None:
                self._values["border"] = border

        @builtins.property
        def border(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.BorderStyleProperty"]]:
            '''The border around a tile.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilestyle.html#cfn-quicksight-theme-tilestyle-border
            '''
            result = self._values.get("border")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.BorderStyleProperty"]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TileStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.TypographyProperty",
        jsii_struct_bases=[],
        name_mapping={"font_families": "fontFamilies"},
    )
    class TypographyProperty:
        def __init__(
            self,
            *,
            font_families: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnTheme.FontProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
        ) -> None:
            '''
            :param font_families: ``CfnTheme.TypographyProperty.FontFamilies``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-typography.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                typography_property = quicksight.CfnTheme.TypographyProperty(
                    font_families=[quicksight.CfnTheme.FontProperty(
                        font_family="fontFamily"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__86bb85bfa58dc441a72d3f9fa98766a3b553cc423a9b0aa3981b2f594fa5a872)
                check_type(argname="argument font_families", value=font_families, expected_type=type_hints["font_families"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_families is not None:
                self._values["font_families"] = font_families

        @builtins.property
        def font_families(
            self,
        ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.FontProperty"]]]]:
            '''``CfnTheme.TypographyProperty.FontFamilies``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-typography.html#cfn-quicksight-theme-typography-fontfamilies
            '''
            result = self._values.get("font_families")
            return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnTheme.FontProperty"]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TypographyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnTheme.UIColorPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={
            "accent": "accent",
            "accent_foreground": "accentForeground",
            "danger": "danger",
            "danger_foreground": "dangerForeground",
            "dimension": "dimension",
            "dimension_foreground": "dimensionForeground",
            "measure": "measure",
            "measure_foreground": "measureForeground",
            "primary_background": "primaryBackground",
            "primary_foreground": "primaryForeground",
            "secondary_background": "secondaryBackground",
            "secondary_foreground": "secondaryForeground",
            "success": "success",
            "success_foreground": "successForeground",
            "warning": "warning",
            "warning_foreground": "warningForeground",
        },
    )
    class UIColorPaletteProperty:
        def __init__(
            self,
            *,
            accent: typing.Optional[builtins.str] = None,
            accent_foreground: typing.Optional[builtins.str] = None,
            danger: typing.Optional[builtins.str] = None,
            danger_foreground: typing.Optional[builtins.str] = None,
            dimension: typing.Optional[builtins.str] = None,
            dimension_foreground: typing.Optional[builtins.str] = None,
            measure: typing.Optional[builtins.str] = None,
            measure_foreground: typing.Optional[builtins.str] = None,
            primary_background: typing.Optional[builtins.str] = None,
            primary_foreground: typing.Optional[builtins.str] = None,
            secondary_background: typing.Optional[builtins.str] = None,
            secondary_foreground: typing.Optional[builtins.str] = None,
            success: typing.Optional[builtins.str] = None,
            success_foreground: typing.Optional[builtins.str] = None,
            warning: typing.Optional[builtins.str] = None,
            warning_foreground: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The theme colors that apply to UI and to charts, excluding data colors.

            The colors description is a hexadecimal color code that consists of six alphanumerical characters, prefixed with ``#`` , for example #37BFF5. For more information, see `Using Themes in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/themes-in-quicksight.html>`_ in the *Amazon QuickSight User Guide.*

            :param accent: This color is that applies to selected states and buttons.
            :param accent_foreground: The foreground color that applies to any text or other elements that appear over the accent color.
            :param danger: The color that applies to error messages.
            :param danger_foreground: The foreground color that applies to any text or other elements that appear over the error color.
            :param dimension: The color that applies to the names of fields that are identified as dimensions.
            :param dimension_foreground: The foreground color that applies to any text or other elements that appear over the dimension color.
            :param measure: The color that applies to the names of fields that are identified as measures.
            :param measure_foreground: The foreground color that applies to any text or other elements that appear over the measure color.
            :param primary_background: The background color that applies to visuals and other high emphasis UI.
            :param primary_foreground: The color of text and other foreground elements that appear over the primary background regions, such as grid lines, borders, table banding, icons, and so on.
            :param secondary_background: The background color that applies to the sheet background and sheet controls.
            :param secondary_foreground: The foreground color that applies to any sheet title, sheet control text, or UI that appears over the secondary background.
            :param success: The color that applies to success messages, for example the check mark for a successful download.
            :param success_foreground: The foreground color that applies to any text or other elements that appear over the success color.
            :param warning: This color that applies to warning and informational messages.
            :param warning_foreground: The foreground color that applies to any text or other elements that appear over the warning color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                u_iColor_palette_property = quicksight.CfnTheme.UIColorPaletteProperty(
                    accent="accent",
                    accent_foreground="accentForeground",
                    danger="danger",
                    danger_foreground="dangerForeground",
                    dimension="dimension",
                    dimension_foreground="dimensionForeground",
                    measure="measure",
                    measure_foreground="measureForeground",
                    primary_background="primaryBackground",
                    primary_foreground="primaryForeground",
                    secondary_background="secondaryBackground",
                    secondary_foreground="secondaryForeground",
                    success="success",
                    success_foreground="successForeground",
                    warning="warning",
                    warning_foreground="warningForeground"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c1ea3a241509fa1fd36b2d63a314b3d8a616d8f5176dc04e867c156c4812d8e3)
                check_type(argname="argument accent", value=accent, expected_type=type_hints["accent"])
                check_type(argname="argument accent_foreground", value=accent_foreground, expected_type=type_hints["accent_foreground"])
                check_type(argname="argument danger", value=danger, expected_type=type_hints["danger"])
                check_type(argname="argument danger_foreground", value=danger_foreground, expected_type=type_hints["danger_foreground"])
                check_type(argname="argument dimension", value=dimension, expected_type=type_hints["dimension"])
                check_type(argname="argument dimension_foreground", value=dimension_foreground, expected_type=type_hints["dimension_foreground"])
                check_type(argname="argument measure", value=measure, expected_type=type_hints["measure"])
                check_type(argname="argument measure_foreground", value=measure_foreground, expected_type=type_hints["measure_foreground"])
                check_type(argname="argument primary_background", value=primary_background, expected_type=type_hints["primary_background"])
                check_type(argname="argument primary_foreground", value=primary_foreground, expected_type=type_hints["primary_foreground"])
                check_type(argname="argument secondary_background", value=secondary_background, expected_type=type_hints["secondary_background"])
                check_type(argname="argument secondary_foreground", value=secondary_foreground, expected_type=type_hints["secondary_foreground"])
                check_type(argname="argument success", value=success, expected_type=type_hints["success"])
                check_type(argname="argument success_foreground", value=success_foreground, expected_type=type_hints["success_foreground"])
                check_type(argname="argument warning", value=warning, expected_type=type_hints["warning"])
                check_type(argname="argument warning_foreground", value=warning_foreground, expected_type=type_hints["warning_foreground"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if accent is not None:
                self._values["accent"] = accent
            if accent_foreground is not None:
                self._values["accent_foreground"] = accent_foreground
            if danger is not None:
                self._values["danger"] = danger
            if danger_foreground is not None:
                self._values["danger_foreground"] = danger_foreground
            if dimension is not None:
                self._values["dimension"] = dimension
            if dimension_foreground is not None:
                self._values["dimension_foreground"] = dimension_foreground
            if measure is not None:
                self._values["measure"] = measure
            if measure_foreground is not None:
                self._values["measure_foreground"] = measure_foreground
            if primary_background is not None:
                self._values["primary_background"] = primary_background
            if primary_foreground is not None:
                self._values["primary_foreground"] = primary_foreground
            if secondary_background is not None:
                self._values["secondary_background"] = secondary_background
            if secondary_foreground is not None:
                self._values["secondary_foreground"] = secondary_foreground
            if success is not None:
                self._values["success"] = success
            if success_foreground is not None:
                self._values["success_foreground"] = success_foreground
            if warning is not None:
                self._values["warning"] = warning
            if warning_foreground is not None:
                self._values["warning_foreground"] = warning_foreground

        @builtins.property
        def accent(self) -> typing.Optional[builtins.str]:
            '''This color is that applies to selected states and buttons.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-accent
            '''
            result = self._values.get("accent")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def accent_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the accent color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-accentforeground
            '''
            result = self._values.get("accent_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def danger(self) -> typing.Optional[builtins.str]:
            '''The color that applies to error messages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-danger
            '''
            result = self._values.get("danger")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def danger_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the error color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dangerforeground
            '''
            result = self._values.get("danger_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dimension(self) -> typing.Optional[builtins.str]:
            '''The color that applies to the names of fields that are identified as dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dimension
            '''
            result = self._values.get("dimension")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dimension_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the dimension color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dimensionforeground
            '''
            result = self._values.get("dimension_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure(self) -> typing.Optional[builtins.str]:
            '''The color that applies to the names of fields that are identified as measures.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-measure
            '''
            result = self._values.get("measure")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the measure color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-measureforeground
            '''
            result = self._values.get("measure_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_background(self) -> typing.Optional[builtins.str]:
            '''The background color that applies to visuals and other high emphasis UI.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-primarybackground
            '''
            result = self._values.get("primary_background")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_foreground(self) -> typing.Optional[builtins.str]:
            '''The color of text and other foreground elements that appear over the primary background regions, such as grid lines, borders, table banding, icons, and so on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-primaryforeground
            '''
            result = self._values.get("primary_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def secondary_background(self) -> typing.Optional[builtins.str]:
            '''The background color that applies to the sheet background and sheet controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-secondarybackground
            '''
            result = self._values.get("secondary_background")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def secondary_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any sheet title, sheet control text, or UI that appears over the secondary background.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-secondaryforeground
            '''
            result = self._values.get("secondary_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def success(self) -> typing.Optional[builtins.str]:
            '''The color that applies to success messages, for example the check mark for a successful download.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-success
            '''
            result = self._values.get("success")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def success_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the success color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-successforeground
            '''
            result = self._values.get("success_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def warning(self) -> typing.Optional[builtins.str]:
            '''This color that applies to warning and informational messages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-warning
            '''
            result = self._values.get("warning")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def warning_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the warning color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-warningforeground
            '''
            result = self._values.get("warning_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UIColorPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="@aws-cdk/aws-quicksight.CfnThemeProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "theme_id": "themeId",
        "base_theme_id": "baseThemeId",
        "configuration": "configuration",
        "name": "name",
        "permissions": "permissions",
        "tags": "tags",
        "version_description": "versionDescription",
    },
)
class CfnThemeProps:
    def __init__(
        self,
        *,
        aws_account_id: builtins.str,
        theme_id: builtins.str,
        base_theme_id: typing.Optional[builtins.str] = None,
        configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.ThemeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnTheme``.

        :param aws_account_id: The ID of the AWS account where you want to store the new theme.
        :param theme_id: An ID for the theme that you want to create. The theme ID is unique per AWS Region in each AWS account.
        :param base_theme_id: The ID of the theme that a custom theme will inherit from. All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use ``ListThemes`` or choose *Themes* from within an analysis.
        :param configuration: The theme configuration, which contains the theme display properties.
        :param name: A display name for the theme.
        :param permissions: A valid grouping of resource permissions to apply to the new theme.
        :param tags: A map of the key-value pairs for the resource tag or tags that you want to add to the resource.
        :param version_description: A description of the first version of the theme that you're creating. Every time ``UpdateTheme`` is called, a new version is created. Each version of the theme has a description of the version in the ``VersionDescription`` field.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            import aws_cdk.aws_quicksight as quicksight
            
            cfn_theme_props = quicksight.CfnThemeProps(
                aws_account_id="awsAccountId",
                theme_id="themeId",
            
                # the properties below are optional
                base_theme_id="baseThemeId",
                configuration=quicksight.CfnTheme.ThemeConfigurationProperty(
                    data_color_palette=quicksight.CfnTheme.DataColorPaletteProperty(
                        colors=["colors"],
                        empty_fill_color="emptyFillColor",
                        min_max_gradient=["minMaxGradient"]
                    ),
                    sheet=quicksight.CfnTheme.SheetStyleProperty(
                        tile=quicksight.CfnTheme.TileStyleProperty(
                            border=quicksight.CfnTheme.BorderStyleProperty(
                                show=False
                            )
                        ),
                        tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                            gutter=quicksight.CfnTheme.GutterStyleProperty(
                                show=False
                            ),
                            margin=quicksight.CfnTheme.MarginStyleProperty(
                                show=False
                            )
                        )
                    ),
                    typography=quicksight.CfnTheme.TypographyProperty(
                        font_families=[quicksight.CfnTheme.FontProperty(
                            font_family="fontFamily"
                        )]
                    ),
                    ui_color_palette=quicksight.CfnTheme.UIColorPaletteProperty(
                        accent="accent",
                        accent_foreground="accentForeground",
                        danger="danger",
                        danger_foreground="dangerForeground",
                        dimension="dimension",
                        dimension_foreground="dimensionForeground",
                        measure="measure",
                        measure_foreground="measureForeground",
                        primary_background="primaryBackground",
                        primary_foreground="primaryForeground",
                        secondary_background="secondaryBackground",
                        secondary_foreground="secondaryForeground",
                        success="success",
                        success_foreground="successForeground",
                        warning="warning",
                        warning_foreground="warningForeground"
                    )
                ),
                name="name",
                permissions=[quicksight.CfnTheme.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )],
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                version_description="versionDescription"
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f20cc5143bf1b8e687a71b6d9fa8043da08667d0c19f92778e5356a1fc547c59)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument theme_id", value=theme_id, expected_type=type_hints["theme_id"])
            check_type(argname="argument base_theme_id", value=base_theme_id, expected_type=type_hints["base_theme_id"])
            check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument version_description", value=version_description, expected_type=type_hints["version_description"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aws_account_id": aws_account_id,
            "theme_id": theme_id,
        }
        if base_theme_id is not None:
            self._values["base_theme_id"] = base_theme_id
        if configuration is not None:
            self._values["configuration"] = configuration
        if name is not None:
            self._values["name"] = name
        if permissions is not None:
            self._values["permissions"] = permissions
        if tags is not None:
            self._values["tags"] = tags
        if version_description is not None:
            self._values["version_description"] = version_description

    @builtins.property
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you want to store the new theme.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        assert result is not None, "Required property 'aws_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def theme_id(self) -> builtins.str:
        '''An ID for the theme that you want to create.

        The theme ID is unique per AWS Region in each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-themeid
        '''
        result = self._values.get("theme_id")
        assert result is not None, "Required property 'theme_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def base_theme_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the theme that a custom theme will inherit from.

        All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use ``ListThemes`` or choose *Themes* from within an analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-basethemeid
        '''
        result = self._values.get("base_theme_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def configuration(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTheme.ThemeConfigurationProperty]]:
        '''The theme configuration, which contains the theme display properties.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-configuration
        '''
        result = self._values.get("configuration")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTheme.ThemeConfigurationProperty]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the theme.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTheme.ResourcePermissionProperty]]]]:
        '''A valid grouping of resource permissions to apply to the new theme.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTheme.ResourcePermissionProperty]]]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]]:
        '''A map of the key-value pairs for the resource tag or tags that you want to add to the resource.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]], result)

    @builtins.property
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description of the first version of the theme that you're creating.

        Every time ``UpdateTheme`` is called, a new version is created. Each version of the theme has a description of the version in the ``VersionDescription`` field.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-versiondescription
        '''
        result = self._values.get("version_description")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnThemeProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_aws_cdk_core_f4b25747.IInspectable)
class CfnVPCConnection(
    _aws_cdk_core_f4b25747.CfnResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@aws-cdk/aws-quicksight.CfnVPCConnection",
):
    '''A CloudFormation ``AWS::QuickSight::VPCConnection``.

    :cloudformationResource: AWS::QuickSight::VPCConnection
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        import aws_cdk.aws_quicksight as quicksight
        
        cfn_vPCConnection = quicksight.CfnVPCConnection(self, "MyCfnVPCConnection",
            availability_status="availabilityStatus",
            aws_account_id="awsAccountId",
            dns_resolvers=["dnsResolvers"],
            name="name",
            role_arn="roleArn",
            security_group_ids=["securityGroupIds"],
            subnet_ids=["subnetIds"],
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            vpc_connection_id="vpcConnectionId"
        )
    '''

    def __init__(
        self,
        scope: _aws_cdk_core_f4b25747.Construct,
        id: builtins.str,
        *,
        availability_status: typing.Optional[builtins.str] = None,
        aws_account_id: typing.Optional[builtins.str] = None,
        dns_resolvers: typing.Optional[typing.Sequence[builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        role_arn: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
        vpc_connection_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::VPCConnection``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param availability_status: ``AWS::QuickSight::VPCConnection.AvailabilityStatus``.
        :param aws_account_id: ``AWS::QuickSight::VPCConnection.AwsAccountId``.
        :param dns_resolvers: ``AWS::QuickSight::VPCConnection.DnsResolvers``.
        :param name: ``AWS::QuickSight::VPCConnection.Name``.
        :param role_arn: ``AWS::QuickSight::VPCConnection.RoleArn``.
        :param security_group_ids: ``AWS::QuickSight::VPCConnection.SecurityGroupIds``.
        :param subnet_ids: ``AWS::QuickSight::VPCConnection.SubnetIds``.
        :param tags: ``AWS::QuickSight::VPCConnection.Tags``.
        :param vpc_connection_id: ``AWS::QuickSight::VPCConnection.VPCConnectionId``.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4680edc6f6b2057974aff33c9b1063112db6614eb0a8bdd7a535ebc3b74918d3)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnVPCConnectionProps(
            availability_status=availability_status,
            aws_account_id=aws_account_id,
            dns_resolvers=dns_resolvers,
            name=name,
            role_arn=role_arn,
            security_group_ids=security_group_ids,
            subnet_ids=subnet_ids,
            tags=tags,
            vpc_connection_id=vpc_connection_id,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _aws_cdk_core_f4b25747.TreeInspector) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5491d9d4666ceb63d67d17a157e7d874620e63fe0fe43f0563e1503d673fa0b4)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__9d49e60683256456b6ad85831d4f05c5d106c5363b475fb28a0862a0533a1189)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''
        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''
        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrNetworkInterfaces")
    def attr_network_interfaces(self) -> _aws_cdk_core_f4b25747.IResolvable:
        '''
        :cloudformationAttribute: NetworkInterfaces
        '''
        return typing.cast(_aws_cdk_core_f4b25747.IResolvable, jsii.get(self, "attrNetworkInterfaces"))

    @builtins.property
    @jsii.member(jsii_name="attrStatus")
    def attr_status(self) -> builtins.str:
        '''
        :cloudformationAttribute: Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrStatus"))

    @builtins.property
    @jsii.member(jsii_name="attrVpcId")
    def attr_vpc_id(self) -> builtins.str:
        '''
        :cloudformationAttribute: VPCId
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVpcId"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _aws_cdk_core_f4b25747.TagManager:
        '''``AWS::QuickSight::VPCConnection.Tags``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-tags
        '''
        return typing.cast(_aws_cdk_core_f4b25747.TagManager, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="availabilityStatus")
    def availability_status(self) -> typing.Optional[builtins.str]:
        '''``AWS::QuickSight::VPCConnection.AvailabilityStatus``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-availabilitystatus
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "availabilityStatus"))

    @availability_status.setter
    def availability_status(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13582bd74cd7e94246e413250f4427ad4517ff55211e2f6304e7f410beda7b82)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "availabilityStatus", value)

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''``AWS::QuickSight::VPCConnection.AwsAccountId``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-awsaccountid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2d0f579038be90670f13351cc4fc38c021b446f20c77fba5f17a5f7885330fa6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="dnsResolvers")
    def dns_resolvers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''``AWS::QuickSight::VPCConnection.DnsResolvers``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-dnsresolvers
        '''
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "dnsResolvers"))

    @dns_resolvers.setter
    def dns_resolvers(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__802cdf5aa12ba0e2fe964f603e4df307be17fa1ae0af2d5bfd0f94bf7309d5e4)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dnsResolvers", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''``AWS::QuickSight::VPCConnection.Name``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-name
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b40a735d5d57bfa63044434042d2af339daca63634ca28998ee1cb3ef9159bd0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> typing.Optional[builtins.str]:
        '''``AWS::QuickSight::VPCConnection.RoleArn``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-rolearn
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleArn"))

    @role_arn.setter
    def role_arn(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7350d69cdef3677d8796a65059f3e485ca830f96a4d9381224f4f326889bd8d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''``AWS::QuickSight::VPCConnection.SecurityGroupIds``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-securitygroupids
        '''
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ecd927b3730a2850a7ac182ae4a642ced034abd86826012a1793cc415eb1a716)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "securityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''``AWS::QuickSight::VPCConnection.SubnetIds``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-subnetids
        '''
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "subnetIds"))

    @subnet_ids.setter
    def subnet_ids(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3a853350a1db3b5789ae0ec54a9fead1ee7db62eaa814d118e7a26925f7b34cc)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="vpcConnectionId")
    def vpc_connection_id(self) -> typing.Optional[builtins.str]:
        '''``AWS::QuickSight::VPCConnection.VPCConnectionId``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-vpcconnectionid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "vpcConnectionId"))

    @vpc_connection_id.setter
    def vpc_connection_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b06476e97e1ff2870dae4fe81aeb18aea72a1a57f6bef58ac4feca51a4cb4083)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "vpcConnectionId", value)

    @jsii.data_type(
        jsii_type="@aws-cdk/aws-quicksight.CfnVPCConnection.NetworkInterfaceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "availability_zone": "availabilityZone",
            "error_message": "errorMessage",
            "network_interface_id": "networkInterfaceId",
            "status": "status",
            "subnet_id": "subnetId",
        },
    )
    class NetworkInterfaceProperty:
        def __init__(
            self,
            *,
            availability_zone: typing.Optional[builtins.str] = None,
            error_message: typing.Optional[builtins.str] = None,
            network_interface_id: typing.Optional[builtins.str] = None,
            status: typing.Optional[builtins.str] = None,
            subnet_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''
            :param availability_zone: ``CfnVPCConnection.NetworkInterfaceProperty.AvailabilityZone``.
            :param error_message: ``CfnVPCConnection.NetworkInterfaceProperty.ErrorMessage``.
            :param network_interface_id: ``CfnVPCConnection.NetworkInterfaceProperty.NetworkInterfaceId``.
            :param status: ``CfnVPCConnection.NetworkInterfaceProperty.Status``.
            :param subnet_id: ``CfnVPCConnection.NetworkInterfaceProperty.SubnetId``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                import aws_cdk.aws_quicksight as quicksight
                
                network_interface_property = quicksight.CfnVPCConnection.NetworkInterfaceProperty(
                    availability_zone="availabilityZone",
                    error_message="errorMessage",
                    network_interface_id="networkInterfaceId",
                    status="status",
                    subnet_id="subnetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2a72db4469aeefbfd88b4c7db01b70031b9af40f619e2ec47f00b35a850aedec)
                check_type(argname="argument availability_zone", value=availability_zone, expected_type=type_hints["availability_zone"])
                check_type(argname="argument error_message", value=error_message, expected_type=type_hints["error_message"])
                check_type(argname="argument network_interface_id", value=network_interface_id, expected_type=type_hints["network_interface_id"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument subnet_id", value=subnet_id, expected_type=type_hints["subnet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_zone is not None:
                self._values["availability_zone"] = availability_zone
            if error_message is not None:
                self._values["error_message"] = error_message
            if network_interface_id is not None:
                self._values["network_interface_id"] = network_interface_id
            if status is not None:
                self._values["status"] = status
            if subnet_id is not None:
                self._values["subnet_id"] = subnet_id

        @builtins.property
        def availability_zone(self) -> typing.Optional[builtins.str]:
            '''``CfnVPCConnection.NetworkInterfaceProperty.AvailabilityZone``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-availabilityzone
            '''
            result = self._values.get("availability_zone")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def error_message(self) -> typing.Optional[builtins.str]:
            '''``CfnVPCConnection.NetworkInterfaceProperty.ErrorMessage``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-errormessage
            '''
            result = self._values.get("error_message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def network_interface_id(self) -> typing.Optional[builtins.str]:
            '''``CfnVPCConnection.NetworkInterfaceProperty.NetworkInterfaceId``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-networkinterfaceid
            '''
            result = self._values.get("network_interface_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''``CfnVPCConnection.NetworkInterfaceProperty.Status``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def subnet_id(self) -> typing.Optional[builtins.str]:
            '''``CfnVPCConnection.NetworkInterfaceProperty.SubnetId``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-subnetid
            '''
            result = self._values.get("subnet_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NetworkInterfaceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="@aws-cdk/aws-quicksight.CfnVPCConnectionProps",
    jsii_struct_bases=[],
    name_mapping={
        "availability_status": "availabilityStatus",
        "aws_account_id": "awsAccountId",
        "dns_resolvers": "dnsResolvers",
        "name": "name",
        "role_arn": "roleArn",
        "security_group_ids": "securityGroupIds",
        "subnet_ids": "subnetIds",
        "tags": "tags",
        "vpc_connection_id": "vpcConnectionId",
    },
)
class CfnVPCConnectionProps:
    def __init__(
        self,
        *,
        availability_status: typing.Optional[builtins.str] = None,
        aws_account_id: typing.Optional[builtins.str] = None,
        dns_resolvers: typing.Optional[typing.Sequence[builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        role_arn: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
        vpc_connection_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnVPCConnection``.

        :param availability_status: ``AWS::QuickSight::VPCConnection.AvailabilityStatus``.
        :param aws_account_id: ``AWS::QuickSight::VPCConnection.AwsAccountId``.
        :param dns_resolvers: ``AWS::QuickSight::VPCConnection.DnsResolvers``.
        :param name: ``AWS::QuickSight::VPCConnection.Name``.
        :param role_arn: ``AWS::QuickSight::VPCConnection.RoleArn``.
        :param security_group_ids: ``AWS::QuickSight::VPCConnection.SecurityGroupIds``.
        :param subnet_ids: ``AWS::QuickSight::VPCConnection.SubnetIds``.
        :param tags: ``AWS::QuickSight::VPCConnection.Tags``.
        :param vpc_connection_id: ``AWS::QuickSight::VPCConnection.VPCConnectionId``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            import aws_cdk.aws_quicksight as quicksight
            
            cfn_vPCConnection_props = quicksight.CfnVPCConnectionProps(
                availability_status="availabilityStatus",
                aws_account_id="awsAccountId",
                dns_resolvers=["dnsResolvers"],
                name="name",
                role_arn="roleArn",
                security_group_ids=["securityGroupIds"],
                subnet_ids=["subnetIds"],
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                vpc_connection_id="vpcConnectionId"
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c07040a69bddbfbf2504c9858341608cb5b0fd8a41c8f94dca1472236429a573)
            check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument dns_resolvers", value=dns_resolvers, expected_type=type_hints["dns_resolvers"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument role_arn", value=role_arn, expected_type=type_hints["role_arn"])
            check_type(argname="argument security_group_ids", value=security_group_ids, expected_type=type_hints["security_group_ids"])
            check_type(argname="argument subnet_ids", value=subnet_ids, expected_type=type_hints["subnet_ids"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument vpc_connection_id", value=vpc_connection_id, expected_type=type_hints["vpc_connection_id"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if availability_status is not None:
            self._values["availability_status"] = availability_status
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if dns_resolvers is not None:
            self._values["dns_resolvers"] = dns_resolvers
        if name is not None:
            self._values["name"] = name
        if role_arn is not None:
            self._values["role_arn"] = role_arn
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if subnet_ids is not None:
            self._values["subnet_ids"] = subnet_ids
        if tags is not None:
            self._values["tags"] = tags
        if vpc_connection_id is not None:
            self._values["vpc_connection_id"] = vpc_connection_id

    @builtins.property
    def availability_status(self) -> typing.Optional[builtins.str]:
        '''``AWS::QuickSight::VPCConnection.AvailabilityStatus``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-availabilitystatus
        '''
        result = self._values.get("availability_status")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''``AWS::QuickSight::VPCConnection.AwsAccountId``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def dns_resolvers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''``AWS::QuickSight::VPCConnection.DnsResolvers``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-dnsresolvers
        '''
        result = self._values.get("dns_resolvers")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''``AWS::QuickSight::VPCConnection.Name``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def role_arn(self) -> typing.Optional[builtins.str]:
        '''``AWS::QuickSight::VPCConnection.RoleArn``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-rolearn
        '''
        result = self._values.get("role_arn")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''``AWS::QuickSight::VPCConnection.SecurityGroupIds``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-securitygroupids
        '''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''``AWS::QuickSight::VPCConnection.SubnetIds``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-subnetids
        '''
        result = self._values.get("subnet_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]]:
        '''``AWS::QuickSight::VPCConnection.Tags``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_aws_cdk_core_f4b25747.CfnTag]], result)

    @builtins.property
    def vpc_connection_id(self) -> typing.Optional[builtins.str]:
        '''``AWS::QuickSight::VPCConnection.VPCConnectionId``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-vpcconnectionid
        '''
        result = self._values.get("vpc_connection_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnVPCConnectionProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "CfnAnalysis",
    "CfnAnalysisProps",
    "CfnDashboard",
    "CfnDashboardProps",
    "CfnDataSet",
    "CfnDataSetProps",
    "CfnDataSource",
    "CfnDataSourceProps",
    "CfnRefreshSchedule",
    "CfnRefreshScheduleProps",
    "CfnTemplate",
    "CfnTemplateProps",
    "CfnTheme",
    "CfnThemeProps",
    "CfnVPCConnection",
    "CfnVPCConnectionProps",
]

publication.publish()

def _typecheckingstub__7b1fce8c313f55f5670c2715a689cf3d56b4e20121c9f12b1bd332ee4aea8f5e(
    scope: _aws_cdk_core_f4b25747.Construct,
    id: builtins.str,
    *,
    analysis_id: builtins.str,
    aws_account_id: builtins.str,
    name: builtins.str,
    definition: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AnalysisDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]] = None,
    parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AnalysisSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    status: typing.Optional[builtins.str] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    theme_arn: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83d99561c4cd89e458e1a0bfb21832f2fccc6838e45fc75a8f33afeaaa2b0bd5(
    inspector: _aws_cdk_core_f4b25747.TreeInspector,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__890025bfa01a2d86ffd84169b263a1f637ec5d823a4b8359add0f664658555c5(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a20c5ce03f5536d14402a8b8e303e2203d7dec28e01ce32cd34a033d09805540(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d144a6f13ba657b212b82523a2a45dc878ce0ae01704e0918df144ecfbf2c94e(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7ab38764caa040b6d2810d4a2c284ca670275f7a51ffda19c4835df0f08a64a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef709cf36c65f9d40291088bc1fdba68a9d3ed3ae43306e248f14fda5bbd5e23(
    value: typing.Optional[typing.Union[CfnAnalysis.AnalysisDefinitionProperty, _aws_cdk_core_f4b25747.IResolvable]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd862feedb35fd65f19d36c7a3897fe7cf163a638449bc26f49a7256fcc43b2c(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnAnalysis.ParametersProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__713b5d9027f8d95c33ea9d444992362270d3ac7b31ed744cda089707d37f7d25(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnAnalysis.ResourcePermissionProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6aa3ba5841c43dfade18f5cd08832d0f8362b2867556f5b64b98846f6795a64(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnAnalysis.AnalysisSourceEntityProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da0cb51d15c3d2812e92e618336846041391444e4ffa036ad4e1c2d39c872165(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3dd7327da1bdc4d2b5187e44f09b10eff8f5ab17ec3ce7d001fdfae267d3fc18(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b06fa2f4f355e67f88cc715b75405b4132a6853aaaaffa8343ae24c3f37c58b8(
    *,
    categorical_aggregation_function: typing.Optional[builtins.str] = None,
    date_aggregation_function: typing.Optional[builtins.str] = None,
    numerical_aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__707d4d779e53637a39a6c7cdb86826b6866b8a467b2c3721450caac819bc0280(
    *,
    aggregation_function: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    sort_direction: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54dcf5bf066087e5e9752805222d38e30cffa8b5765a6b794f6f32357b975d0e(
    *,
    default_new_sheet_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DefaultNewSheetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__772b2658fa007306fadbcfba0ec00db97c08a5c24e25fe7846091d13e0dc3855(
    *,
    data_set_identifier_declarations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataSetIdentifierDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AnalysisDefaultsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    calculated_fields: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CalculatedFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    column_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    filter_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterGroupProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    parameter_declarations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SheetDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e22cc5d762db992524875b94a2c36c96b814808b5a8934fb508f135ed25c194b(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
    violated_entities: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.EntityProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b306bfc3f9cbb6620ce938988f1731f678cf18004219081e7ff5fc7dfb7d183d(
    *,
    source_template: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AnalysisSourceTemplateProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d50c5ea15b2ce8c8bf4b90dcff5f82ce746389f3c5196809915cb845081ae884(
    *,
    arn: builtins.str,
    data_set_references: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataSetReferenceProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5d5ba82b15bcff5ac1b7a4ea3aeb46d41e4d2ab9f8b394c74b828b4a9877f87(
    *,
    anchor_option: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02deb962f62e7fb7fda4811d0934eb790b43c2d89156a421ec472c08e8b179d9(
    *,
    range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ArcAxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reserve_range: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0307d0862519a847530b788bc8ba6b28802542557f4b4e14523122ec04cc9165(
    *,
    max: typing.Optional[jsii.Number] = None,
    min: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ed4d40dc2c1217ef0ec7b62fac904c3670875361931f3b52e2a3b8f25b7dff9(
    *,
    arc_angle: typing.Optional[jsii.Number] = None,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4241d86441a9e2f4d2710a85e4a9d2a3633688f84d262273ae6f06569a7d679e(
    *,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe05f10384174634d4321a63159411f22eb1dd513acc8ffca1ca51feccb94f1a(
    *,
    date_axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DateAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54b6dc0f91a398a608054875282adf2b742ea8ee8d3eb75ad48251325f8f459b(
    *,
    maximum: typing.Optional[jsii.Number] = None,
    minimum: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__514f83eddd8d4a660c3e70562beb31b6c9dde97cce0401986da5d9ef4af4bc16(
    *,
    axis_line_visibility: typing.Optional[builtins.str] = None,
    axis_offset: typing.Optional[builtins.str] = None,
    data_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDataOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid_line_visibility: typing.Optional[builtins.str] = None,
    scrollbar_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ScrollBarOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tick_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisTickLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0eaf66dd8211856479578f80ff46b8aea84c54b3081431beb5ecf69e5abf89e(
    *,
    data_driven: typing.Any = None,
    min_max: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayMinMaxRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a83364119dacd8f2542e77a3cc73fd0217f886aa51a7b2c50e2d27a89375ae3(
    *,
    apply_to: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisLabelReferenceOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5a88fcdb887f9fa32143430469d3048389fb45b4cbc1aef1177c7ee95d2327d(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8fb4f5326bdf4d3d8c8e65aab44d5435e88e5186e6a99c7258a31c35143ff0ac(
    *,
    step_count: typing.Optional[jsii.Number] = None,
    step_size: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35d856e3f1482af7c8269c1fd39946da39bb80039c2613d658f68e8e446c2e4e(
    *,
    base: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2fd7aefb784a330743fd375b51f50d2dd67c0db2148ee40dacc2a5a5fc445fc(
    *,
    linear: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisLinearScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    logarithmic: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisLogarithmicScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e637716aac5cf3edcd0b101378f84759379452db8697a26658bcaf69f5c8155(
    *,
    label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rotation_angle: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ea121fd8cc534afba373e75c8ac7e707d79e09b98955352826e4e708fcdf84e(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f2ef81188e298b4724cbc00d2c53af09f2038fb6399691be2c9845784b36837(
    *,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    orientation: typing.Optional[builtins.str] = None,
    reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f931e83286baf43cf4eb5a9bc2596e238a5990c855fb35a00b16635cf24a727(
    *,
    bar_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0100036eea832de868e033add2cd77efbe8fd07b1a95f06655f02bdc3d586d37(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20ceb98ab41c62303b26229aa11497d255f9a91b73a8b60a5f73c42ea68353ec(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c00cb3acee002938487d6aff7bc0126338748e42fc81bdf769ac499aa444ac6f(
    *,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__634fa92577e183d961a1b93636fcb4154d4800d48517ecfc0ea30a05a9219a2e(
    *,
    bin_count_limit: typing.Optional[jsii.Number] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11328aad986b594e3415154bf163ad896cdff1ae5cb6a725f17646bcfa2a0894(
    *,
    content: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BodySectionContentProperty, typing.Dict[builtins.str, typing.Any]]],
    section_id: builtins.str,
    page_break_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SectionPageBreakConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9af14e1f3fc497175eefb7db911deefca552668f2af8b4bce8e843eb3b686ebc(
    *,
    layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8bfc95b29ceb7bcaed3039f20b9aefeb0330e5ff626df4e925f492548e195e6(
    *,
    group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef069cdd6a273594b22206949eebc6d4df91900e511790168bab7a222a02f0fa(
    *,
    box_plot_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BoxPlotOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BoxPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BoxPlotSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c11cd5b5ece7457375b17c273d12c5f2bba3299b43f29002ad34e92160e77afa(
    *,
    box_plot_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BoxPlotAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dae6b024acf60c845f50cf9dddd02dee617160e3b2417127098b02acba3faf50(
    *,
    all_data_points_visibility: typing.Optional[builtins.str] = None,
    outlier_visibility: typing.Optional[builtins.str] = None,
    style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BoxPlotStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ad430defba4c2af9e7a83d85f49e7b2e330dc8a9a7e50d50fec6139ab6c5ed2(
    *,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    pagination_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2905f8c4747225aeecd1c5407d446447db471241ef57def1daad9c636d3cc129(
    *,
    fill_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3158acfd922aba17cbe00864c000adc18c3dbb57008a7a6086651a224e66afeb(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BoxPlotChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28f4c6754779f6f09af0c019c83305f5b4c905ebe5d42e7305b64769ef19ff1d(
    *,
    data_set_identifier: builtins.str,
    expression: builtins.str,
    name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bef9289e943e57c69d50518c0260c2e24d2d479f02e93a38104bd9d06532142(
    *,
    expression: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d13692ded38fc61c29abf79f5d3af18037b1b587645740a1018c77aa6eee2ca2(
    *,
    source_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CascadingControlSourceProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b493ef763227987098e3b917d774c1863a4bf6827234c34b0470ceb81235b206(
    *,
    column_to_match: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_sheet_control_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fb41de23ca98ff54a98d2268a7d885d77cee132508b36061965cf9049b46b58(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40fe259f9bac113e0eda4d2bdfa4ba2d54bb645331499381a1b3f7cb9bcc1f47(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f689302b3aeb1291bc7f6b373ed8d203940f0f8984ed9dd012883745b3bfce7(
    *,
    category_values: typing.Sequence[builtins.str],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2cade7920ca3e9834580a0d02641f931b4cbf3c527c3ab0b5f008fc6172db61a(
    *,
    custom_filter_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CustomFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_filter_list_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CustomFilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filter_list_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90b611566d7fce79c31cda545f3500cfb1322c0dc73a8dd1c5755b4be244b215(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CategoryFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0d0df224c04d87ef597866230cfb71f15e736200769b42d6672358705af1c0d(
    *,
    axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sort_icon_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31698b7a88dad357d9121f1aeb16901e12ce237bc5a9a4fcabde2040ad1be1ab(
    *,
    cluster_marker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e687d2a694b716e5fb6aa67e1ddb677d335b80a4984558c83cce12aa2807d3a9(
    *,
    simple_cluster_marker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SimpleClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1522b51450a61f13c04a38a92939942e2bd38ff4222df53bc0a64936857adbf(
    *,
    color_fill_type: builtins.str,
    colors: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataColorProperty, typing.Dict[builtins.str, typing.Any]]]]],
    null_value_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8651146206e67afab6d8a5e3178254f71ad1612280457128b2a543d4ce078ce6(
    *,
    custom_colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CustomColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b310530156df84e63740b04235cfff0f92b4789a413c28815b6074bf319f0eb(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    colors_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColorsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3e11f3916474b266f6149cd61e2cdc0504a3fe90748e962b72c72eb09974d64(
    *,
    date_time_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DateTimeHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    explicit_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ExplicitHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    predefined_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PredefinedHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38f28f01525e947b3cdbee21b6f92245f728be65e3f5e851394c28496e60e3e6(
    *,
    column_name: builtins.str,
    data_set_identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2938531646915e6078f4a8f67dde8c87089acbfbe4f33823ca1d4ba571424845(
    *,
    direction: builtins.str,
    sort_by: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e27334dc20879b6e02b5013b981a18b12fa7088050ba09f40030f21cc1b0653(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4da7dae4c6bc56b7b127626b59e892e7351be6b1f2569ab0ec727679f947940c(
    *,
    bar_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    line_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bd443b9224046f8a05cfdd54143cf7e1d397fb702f55cb331c8a4451580be9f(
    *,
    bar_data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ComboChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    line_data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ComboChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__211ca5c38b33660b71c4e86baab41b970eaca71627037345e47ddb0f9188eb46(
    *,
    combo_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ComboChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20df5eedc96b8f0b4f86da61b0ef109e9af7f30ca2c9df4ab3a3f632deb8cc34(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__febab50d375f26f94cc5f444bd2ab80b2061c2bed58aa7ea63fc1c02c10646a6(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ComboChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__013300f268c29642e995379f482650e5637358a939f1a1234848f1f563245219(
    *,
    comparison_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ComparisonFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison_method: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c1815fcba9aab19158e9eb01045776128715504e23060c05a3b710ff26e05cb(
    *,
    number_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a611a66166c5b194070e1a4d7e0b7728d5b5e2cdc85cf014322c9d3b7b41d5d3(
    *,
    forecast: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ForecastComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    growth_rate: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GrowthRateComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maximum_minimum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MaximumMinimumComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    metric_comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MetricComparisonComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    period_over_period: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PeriodOverPeriodComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    period_to_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PeriodToDateComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_movers: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TopBottomMoversComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_ranked: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TopBottomRankedComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TotalAggregationComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    unique_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.UniqueValuesComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44c6cb1ede49de42e2d5d0acf17eac74bb9640f46cfd9a659b0bd9f43c9b6c99(
    *,
    gradient: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingGradientColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    solid: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingSolidColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6181670db4f74c2a0c2930e33c51dbe9060d5127decf627d50ab67c6df0b662a(
    *,
    expression: builtins.str,
    icon_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
    color: typing.Optional[builtins.str] = None,
    display_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d37444466424961531c73c56aff15a5db955f06aa85c82047b1e22c855724f55(
    *,
    icon: typing.Optional[builtins.str] = None,
    unicode_icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20c45f519e167a0ecc7d079eb4c1b795f3f910859ecaf24c123c64a5207bcf94(
    *,
    color: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GradientColorProperty, typing.Dict[builtins.str, typing.Any]]],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d95566b1ee23d4937fbc265917b35fa24a7626b3146fe7c3d69c1779535333a(
    *,
    icon_display_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f4b430928ff3492fce2bf021a9059438738fde5409f19850e67c3f3e3d3ab4b(
    *,
    custom_condition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingCustomIconConditionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    icon_set: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingIconSetProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8fa67e4dde2f0e4e9da3d676a22261fc798708624584fad23499c14f1fb8cd69(
    *,
    expression: builtins.str,
    icon_set_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0aad88146879c47fa33dd2c0d29714201b46e227d02d819c9c5e720eca16edf2(
    *,
    expression: builtins.str,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66a771228ca4cf9774e514dc37c6e38bcdb3b3d4a2654555cd6e6a620c815a4e(
    *,
    contributor_dimensions: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    measure_field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc3d01f31007aa3225b0db607b8d19cf05e2e242a77765271a87fd3de1287783(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
    symbol: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__775d6cb725f278dc4b3065acab14f251adf747bee5d0a713f39e5fa5f2b7963e(
    *,
    selected_fields_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    target_visuals_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b77b116aeb1efb20b9916cea780d057605e27e32563c2c0660a5a40b69bb95a3(
    *,
    local_navigation_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LocalNavigationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee373cb01707f3cb449bb37361a9c3f6c2ee6d75139a887ac86cce7500a6a171(
    *,
    parameter_value_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SetParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fda0c22f204d0195ce095fdea679dde6f73317c0c55584b093015aff25e19db(
    *,
    url_target: builtins.str,
    url_template: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bb45df2554c39d45144c386c6875edfa16540c57cd686a19d6a15c261365c52(
    *,
    color: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    special_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7537d20a06b00fa43f9d82ba07dedbc9bd1112f90d616963e73492b97fcad2e4(
    *,
    content_type: typing.Optional[builtins.str] = None,
    content_url: typing.Optional[builtins.str] = None,
    image_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba251fe521bb6ef5c544604f9854d65bb0c02d0d44626dc7c138c750546bdbdf(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CustomContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__808dbf9c453e99b84e61f1c46bcb368ef5a95df893b74bed8ff01f20b1230dcf(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_value: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__145c79c61d99c9dcbb9ade3edcff76f5c4f031d3365ecec2d8d8f4db2fe73792(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3ead21422cced0b1a03a0eaa3bb2b9569cb1015843ca3a685ff12a07ce41ea4(
    *,
    narrative: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96664ad0959f3886c915dd4831f18d0ee49b9c560975962202084734f09d3e51(
    *,
    date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    decimal_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
    integer_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
    string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c29742ab23d9d662a54c4ebbf9fd50e2a0a3808296e4ea0ecf2b79d2b8e6183(
    *,
    custom_values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CustomParameterValuesProperty, typing.Dict[builtins.str, typing.Any]]],
    include_null_value: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a634a2b7fdf8c250265c56efe23fa5a44f87e57436b9f0138962742460464d10(
    *,
    field_id: builtins.str,
    negative_color: typing.Optional[builtins.str] = None,
    positive_color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa9d7aa155725c69b84b58dcaee043c97d0c1fd57aa0185b2ca98772398cc705(
    *,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55e555b80af260a17978917a49d90afc102a3aa84a78aecd4ed75f172a196d3b(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30846b324fab7c7007ab706b72cc63e3b9f627f0dfda422f92fb9359e0a61d48(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    data_label_types: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_content: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    overlap: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__285c7ed12c69bb42c3d8086ee39dfd12bab8ad21679a5c44de3498eabaac8ab3(
    *,
    data_path_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataPathLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maximum_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MaximumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    minimum_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MinimumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_ends_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RangeEndsLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64605ef50ff11a438be355c78f064240a72f9930186e16615c9ca2337b413842(
    *,
    color: builtins.str,
    element: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]],
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b984bf6be29aee3b30d4c6c8881e7b4e315ce92304ab12648fefb74b7b10cda5(
    *,
    field_id: typing.Optional[builtins.str] = None,
    field_value: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__265ffd5292373519b930408f500c2482a77c27a8984456bd4380edcdbdef9ec6(
    *,
    direction: builtins.str,
    sort_paths: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93daddfe245ffc26fd833e1e61598b37bb41119644b0c352fe5019bb3e71da43(
    *,
    field_id: builtins.str,
    field_value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f2c95d256b8519b80bd0fc84d8e221f3562ef2a2cca517e1667bb949e903c0b(
    *,
    data_set_arn: builtins.str,
    identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97a1e22446bf7e842cf7c445e4ee5196ee64f4aabe24431bdbf9d3cfdf71e925(
    *,
    data_set_arn: builtins.str,
    data_set_placeholder: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73cc97b99e55442c1f754227cead311d0556c742eaca61e1c9916f5859d6257e(
    *,
    missing_date_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__368673b331cfc0a41eecb2753b9540c5811dc31b061f92ab6ab281539f3d451c(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    date_granularity: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9faa30e6df5398b455b5878b2730cb5fc3eeb097f878cd1a6a471ccab38597cf(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0414717de43368a6a15960678d0a887f0396f4d14f2c72d1c3c1ed0cae6006a(
    *,
    dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rolling_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24b520cb5315f4bdce10f3c8bdc8240990b875d40e2a62d8a6f4c48bafb7659c(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb7578bab90885b258b37c73f38fcc4cc77e5aa1b189aa224d293d1c25930cd8(
    *,
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ae8017dec7b15901dee198ac9a6ce58af8e78d966525f68ed91becf48d35877(
    *,
    name: builtins.str,
    default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DateTimeDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec2020e76f9a9a61304ff0bd088086e8608b84f4983dc17f7d27905d04a72b98(
    *,
    name: builtins.str,
    values: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62065e00bf524d21667869a7420f8f554fa5f53412ac1471245d0d2c9a322b42(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb62e964d10797b2dc1d06b1c37f990c54f9e8fc5e6890112f1ace51c954d1a2(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98074d18c17769e85607b77d873b7efe2af1607ad7b1fefc2d679daee7b9642e(
    *,
    dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad20dd62db1f0042d9126362c1679cd8bb34d489392941fafb04e74ff48a7096(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DecimalDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51d1023ee96861d6d11966d42e6b472cb3862086f93771e9fbc2304a4bd61802(
    *,
    name: builtins.str,
    values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4edfb6e5285422f53f03985556e201a0872e1e95b156db016ca14623d2a505bf(
    *,
    decimal_places: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8262ee575ea5807ed1c2462f179d833b2b0a8977c84db55abb681edac9c726f(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e01d702867bc9b2f7222a9eceafb62455079c69d90af647b4b97820a98bc2003(
    *,
    canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a5138d0a4e8f3ac6c8a3008d50fe8aa4cf997d1232f3bca4a98a804ddcb1d93(
    *,
    canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e6855c164d33b8ef8b0ef91501ba1046011d9210f39ecef658d137e17f215cb(
    *,
    free_form: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DefaultGridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2b2ea58a80c10603566646da501dac3f0a7e3f5dc367fb49a0a594578bd26ca(
    *,
    interactive_layout_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_layout_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sheet_content_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f1947a24af61814d6c4beca40199a6f7935844fe88b2254cc18ab07de42b2ca(
    *,
    section_based: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4288a6186ceac72c67614b248b364d5a62e547ab78c2e5ed74b830961d52df0(
    *,
    canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5df858c5b6db2b527a4212369479236b1d170464c817a447f9393bf8237a8a44(
    *,
    custom_values_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CustomValuesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_value_options: typing.Optional[builtins.str] = None,
    source_field: typing.Optional[builtins.str] = None,
    source_parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98bcfd07e1cb2003129c43e21934d53b78fc5a3c156410f0ec48dd1a478907b9(
    *,
    categorical_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CategoricalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    date_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DateDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numerical_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75c3848586b04f225f99735404b088e093e76b75630a8c69cf6f923db9fa951a(
    *,
    label_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1eb716ff3ece23bab9e2fb8df996ff7bcc1ec244a1636a67ba80b0cda14ecc3(
    *,
    arc_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ArcOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    donut_center_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DonutCenterOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b639bfd8b9b57cb0d216556557c58599e957084741c42a421498bb4109e0619(
    *,
    category_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CategoryDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericEqualityDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TimeRangeDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee1df67367854f2b715534d7caefd1aa8aa78d135164147b1fb8e6489f5c5f90(
    *,
    select_all_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f5605de45adb38224161831639d47ee50e6c6f79801f8e9b906263a78273609(
    *,
    default_value_column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    group_name_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    user_name_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__698f9e46bbc2415ac2162ea79e3668640d0fa8910595468c2d06184bdebe7835(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d995a51c799426dc474f7c849d042aed921a34440873d1a2e669f9e32beacc32(
    *,
    path: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__114a0cb3e4c23a7c145d2fa26b4433ade594d4960c89f6c5251a91093cc5aa15(
    *,
    amount: jsii.Number,
    granularity: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__587fe3812ef51ed8b5f6c323d5997dd56553bbbe7edebcc9c837d21b89c57c16(
    *,
    columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48b0b2e74afd936e1d9b8859ae38ad59d6b366cb7087b94422ada68e32dd81a3(
    *,
    aggregation_visibility: typing.Optional[builtins.str] = None,
    tooltip_fields: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    tooltip_title_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d3a82390280b1a887fc0e8e8db34ae22b712f05dcae2850827c8911c9fc79ed(
    *,
    field_id: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__076f6a76377debe6af1703c95f9245dde25a45091c7d49c14b0aec5255dd2bb6(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__673f684b8e027caca313ca74061d31a2831ede70c8f4a93b24b81c1889db8cda(
    *,
    column_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fdb955818c91fd914646f08f145a1a047ead96005cebce79bce3ff97496f165(
    *,
    direction: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccec3a4c7920019c1961572a212685070d153da04a08388cfa7a59b7b33259b3(
    *,
    field_id: builtins.str,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c00d3dee7c6f5f11389ad5a8ba6f993e0418b9d49537ec2e9704eb34ae4a431(
    *,
    geospatial: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__560a02368e15f242f23e251e66070b6151756a6246570f6f49cc44d654821173(
    *,
    shape: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilledMapShapeConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a006c84813344f46ea831c454e7a27466aa316ed2895d7e2f8f72450a426c71b(
    *,
    conditional_formatting_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilledMapConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a34bc05a8ebbeafa76f6f1976fa9c6c4dc18c69c684ea72da7420bd79f56bf53(
    *,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilledMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilledMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    window_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__673197faa4eb12b64ba870528053501791129c84297aa9603db12a60bc1ecadd(
    *,
    filled_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilledMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7df3629402bf9812659649b12aa48699497c908f60b723fb8f1f38f2a54bc171(
    *,
    field_id: builtins.str,
    format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ShapeConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13c1b55f379a96e3f7a7b0573bc2be5f5f3fdc0b941dcb1f1e7baf5655545487(
    *,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2940e4c7076a403888593e877f50191e6206fa294d2e7d5d664fe94165ef16f(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilledMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilledMapConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c3cb232d24478e529b1aa9686a7c03ba6878982de21acf61b80372f32096f42(
    *,
    date_time_picker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    dropdown: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterListControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_date_time: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterRelativeDateTimeControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    slider: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterSliderControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_area: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a768003dd7461f8e6c87239cee01d530f48d535af623615d4cb349073cbaf151(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67c7003271fe6e4f386ed5c2d4eaddee92eb91778f7903d26fe4323c9f1ba288(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1013761feb5d36c4bbdbaebdac32aa77153fbece03a2db25453e0fe2e7ee6e02(
    *,
    cross_dataset: builtins.str,
    filter_group_id: builtins.str,
    filters: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterProperty, typing.Dict[builtins.str, typing.Any]]]]],
    scope_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__972ab0882c9219fc5173a68a22ff040c9e5a5528557675015edc78c235aedf1a(
    *,
    match_operator: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1a527c0bcc66567021b2a208b50ff883a8c6951a7229e7b849f3ff67ce95c22(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__caa129f04fc5d531b76e0b33dd594ea54720adfff44a723c483877e96298b33a(
    *,
    selected_field_options: typing.Optional[builtins.str] = None,
    selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b729ca4f3b90a9cd369347f0f6be0c621174493d13ecc544a235dce81ea561b(
    *,
    same_sheet_target_visual_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SameSheetTargetVisualConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59c5ea895762382a2c6066a58d8fe59e210f46c3f423e058706ce9309167e265(
    *,
    category_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CategoryFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_dates_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RelativeDatesFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TimeEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TimeRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TopBottomFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3d3c00aca1ced0c42c779d64205335ecd63c001c37e7ed55c39995179428443(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15a4d07c882611479f6dc77f59df63d1b9565cebfe918c6ac0bfd0d1c6da9738(
    *,
    selected_sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5645326b212216a40604f5df4b00d1ab022267df9114375d3e64a2c45c311a87(
    *,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44dd41f0c24cc4dafa4990db41f8e214b6707201bbd6c0b6e8dc724ffd02180e(
    *,
    filter_control_id: builtins.str,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    source_filter_id: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0737648eb751a23589646bee2cc24d67dd2bfa8996fe13e6022e400c15b22166(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__161b073d73e90502973780845bb9cd211f77a6e3ace7fc09a1eada5d9c664c8c(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eca0537099b1f6da5447f52742252f25f5ed7839c045973575d88ce9e7f55134(
    *,
    font_color: typing.Optional[builtins.str] = None,
    font_decoration: typing.Optional[builtins.str] = None,
    font_size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FontSizeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_style: typing.Optional[builtins.str] = None,
    font_weight: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FontWeightProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0970831d8ef4f7f4cbd43a9c305e917fa21d40aa3831e3c36f020d5ddbb4235a(
    *,
    relative: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21060d642c9ff1fa67e4e935741dfef4ccf59927b6527e0c51065b1bd3722fab(
    *,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3fbc6fee55f7858148a11713f5af8fc48d974f8d9b2481386a82f9c51a44430(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    custom_seasonality_value: typing.Optional[jsii.Number] = None,
    lower_boundary: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[builtins.str] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e2f9fafe39d2a4d10b7fc7fb52d3bc976349cc1d859d2cc8e3d7d35be12ab4e(
    *,
    forecast_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TimeBasedForecastPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ForecastScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__326187016a2f3707ec229cbe9b61b7400c935cd851e54347be58ad4bda2449ee(
    *,
    what_if_point_scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WhatIfPointScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    what_if_range_scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WhatIfRangeScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec245ad43450ee63f8e0cb2df971854f14eb5c180b253df2f0cbb03f743ccd49(
    *,
    date_time_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    string_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f39e28bd8b351299a6f873cb62804157ed1cd4e353fbae6211d912edbbfe6784(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0820d819c37605ff214519777bf51c00a41824121315b9ad5901d8ab2fe6b117(
    *,
    elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14247388c2e38abd374d6cd6ba7357b3316c8c1f769110415a3052006580fc9e(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32722560d57b817821a628637559ec1961494aed9cad7106e19506430140cf93(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75f2de2fedaf2faed6b09ab588962c611cc5333909395bdb6e59ed58fba7cb8b(
    *,
    element_id: builtins.str,
    element_type: builtins.str,
    height: builtins.str,
    width: builtins.str,
    x_axis_location: builtins.str,
    y_axis_location: builtins.str,
    background_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    border_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    loading_animation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LoadingAnimationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rendering_rules: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SheetElementRenderingRuleProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_border_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64329f3129161ae065a9e56b66f5070fb3ba6e6635b21cb2d3d1ae3ce4d4a7b5(
    *,
    optimized_view_port_width: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c415f365825039e9a786921c64e912006ae7c59f0a229ec10215ab563607ebc(
    *,
    elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d3badd12a5e54bc129074eb33e6bcd605f6c49e871a3b36c54d393381db8202(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0586bd91f4fc22e17d331e79dab71d3ee8daebc8bb9d49ec9da27dd196626af1(
    *,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FunnelChartDataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FunnelChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FunnelChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e376186a38e2ee7f52d43bdd38de16d9604a099e845a2dfd0a66d0860f5768fc(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    measure_data_label_style: typing.Optional[builtins.str] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__883e5cfe3c4de46ec83e6073bc7512fc214b9cf8c7a175db885fdfd07ce4c1c0(
    *,
    funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FunnelChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ddb48523ec08b07a9d42bbd7c00cd21ca4233d19a76b2ad2cc2209bd46235119(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__314f45fa1deac54c231e26c2220b95807d52217fc36eea8407228458c0bd6f23(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FunnelChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a6b905d0cf4d9ffd025d354470b906536e4720a00955efd28e0d199e3511175(
    *,
    foreground_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2681bbcfe145fb50345dd461958c68ff8bfa32b20618d0a64772d09e3c8920e0(
    *,
    arc: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GaugeChartArcConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93630b36e8e6739721b8874d939377bb2ed1c85ac6a2677c372f0bc413587e60(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GaugeChartConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c59390b9cdcc21e75744c281692f4a777da13eefe12ec5da69fa80ea7c3649c(
    *,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GaugeChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    gauge_chart_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GaugeChartOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__002086b355f5af5981f2ae5bf929891b1460936b0b21975a3972b5bb392a1b32(
    *,
    target_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0ca8583765488a67b3a55c263069d4f8f20355710c960edb620781b20ed2e75(
    *,
    arc: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ArcConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    arc_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ArcAxisConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5d61d11872c7eed0dda0dc1fe74d5cac23cd0217db8fb222fb6df251d3c3265(
    *,
    icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb38428db864170ab45f2443933efc8de15f36e633302edfd75afd8e62a1bab9(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GaugeChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GaugeChartConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27ffc0c98eac9d7f20dcc7ea41f37a3a168ebf734685d6d902c061ca9e53fc7f(
    *,
    east: jsii.Number,
    north: jsii.Number,
    south: jsii.Number,
    west: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c78704a4ed2ca7f3a6dad28ee6964648f14cbe5af079d5cd2004aca50beb09d(
    *,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    geospatial: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69f4dabd531c5f794ed173dffbbfa2587d458c6726c05e1cf451684f3ffd11b8(
    *,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GeospatialMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    point_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GeospatialPointStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    window_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c5af8487c0d8ceec96aef31a5af621f585f12bf318af1d68a5c1792f2e069ed(
    *,
    geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__306691ad91eb9a55909ccee2a2ac9424dd1ee504b93fe4443dc4a1084c6f7dd9(
    *,
    base_map_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0d69358867e18cdb2416ec54480efa24a61d2bd20ec4d0a48e15d58deed5e5e(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GeospatialMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8152a8ab4db7145f5c03d68e727c3cbc8f5673272e3e36bcf82d430e2bfca08(
    *,
    cluster_marker_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ClusterMarkerConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_point_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4de86cf39a37dd88d52632aa1c5305cd60e0933a432ebbd769de16e935e7e5f7(
    *,
    bounds: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GeospatialCoordinateBoundsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_zoom_mode: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c151864ab238f9d21c50d92971d5989faa254580d56ab1ed6db05754789f28b0(
    *,
    side_specific_border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableSideBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    uniform_border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54688eb7726636f8a3496d5055f62071dee64879fd621b2e1f1033263e7dc46f(
    *,
    stops: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GradientStopProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__730f317073242438eedef9a1faeec28c5cec6b9a17a031704d6eacd3a637e8a7(
    *,
    gradient_offset: jsii.Number,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cc300f8d0d723f1340709c4d7993d81970c7cf1f683cd26192975c578250350(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33b188af7622727512e0e9188423378c37b59993eb4f4036078b32ea2641cb70(
    *,
    elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GridLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb14f471c1d9a14dfd55d168301a6d1eb164f86bf179ec43547dc4cfa7e94afc(
    *,
    column_span: jsii.Number,
    element_id: builtins.str,
    element_type: builtins.str,
    row_span: jsii.Number,
    column_index: typing.Optional[jsii.Number] = None,
    row_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d41beec12bbf93191adfc6eaf36b32c0fa3b59f3487492c999b2906e086b6d0(
    *,
    resize_option: builtins.str,
    optimized_view_port_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54fcf216f414f0f8b8c989053aff5845f1954bcffc1456347582749b1c16fdde(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
    period_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3eded328741f753c3eb9218eb9760066736c6e724e96313d02d90d7db504e120(
    *,
    layout: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    section_id: builtins.str,
    style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__214ac7b660406f84c19804acca2fcdf584b95781e46646ed6cdcc03cf1523fa5(
    *,
    columns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    rows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4aa98212828e5fe93271307814ccae743cd3b57c393e8e93c35b42a0648f6abe(
    *,
    color_scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.HeatMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.HeatMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__183e3f6fc016060954b0f5610689e4b1ad3c1c63a6f5cfe7d020119510f17811(
    *,
    heat_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.HeatMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24b97c1cba5bb97f333c75e5d0a823c079c5b70851f4de6136f5f8830da6547e(
    *,
    heat_map_column_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_column_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    heat_map_row_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_row_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4684ba09a7cb65bff1fcbdce69e44e3c2d2b846d97f21f1a453b88c0e185ad1f(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.HeatMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22442f0144435e00120f9cfb6ab2662364e816d6bf115a85d69cf4d66584613c(
    *,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3aef72c83f3be75e2b3a37d74c1a50d03b0cbf5a4609da7cbf8b4e0afa8dfa3e(
    *,
    bin_count: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BinCountOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    bin_width: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BinWidthOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_bin_type: typing.Optional[builtins.str] = None,
    start_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6982125c80102028b29d52d919137a054b3db65308d26d6a2314e8c9a693b9f(
    *,
    bin_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.HistogramBinOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.HistogramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52315d3d7447f31788d736a570a57a233f08e5011691d864628fe43731862650(
    *,
    histogram_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.HistogramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75648e239edb4a60374d591c8c1718907c546ad755907f8a95b3a28f447eb78f(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.HistogramConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__439763f99773df32868c3697ede2a75a0ee59f27819ec220e22cdaaa9edc6446(
    *,
    computations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ComputationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    custom_narrative: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CustomNarrativeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e73025ad4780a9eda72ac3f5d98ab788721dd40195e40a06c6c993e945d2608(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    insight_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.InsightConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9acb5f2f95d1a97cd587e5bfc698de1343921670c22cf781d81df9ced9554e4(
    *,
    dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c0e4f74ddaad567ae53a74954434aefa0cca0759a3226f518dfb3ff6f1efae6(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.IntegerDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44992c5a6ba079cce6c8b604db9e9530e5686fe70839ad2e00347e761e20de8a(
    *,
    name: builtins.str,
    values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__879b4634cb2b8c14f51cc6404f82e152c86faf9eb98f6e000039e39588108a5d(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e3b7021caad18bdfd19e7370979ae3fb199c86dcc328f2228faec8c39a4d87f(
    *,
    items_limit: typing.Optional[jsii.Number] = None,
    other_categories: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f00849897ed59a8520e884a8bd35f87d82bd5fa4e5090f32d59c59bb17a7731(
    *,
    primary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    progress_bar: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.KPIProgressBarConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abebb1dc633c2e758a6b46ad00787854ad6e97283794058f063efa67856933cf(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.KPIConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f41e9054cfb2e23f2d771425fa6f107eb6a8fb2a204e2c90b56a8db62624121(
    *,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.KPIFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    kpi_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.KPIOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.KPISortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__363f918b3e4b7a3f89ba268a01c1906c5b3d70fd4b673cb94879e545fbe0ae80(
    *,
    target_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    trend_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__365f59cd3f79093fc29ed88d5ee960ff604bd96cf3c550170165a03c879e8b00(
    *,
    comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    progress_bar: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ProgressBarOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SecondaryValueOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    trend_arrows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TrendArrowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7aae78bc4c11a1f09436745a9a7b03bb98ce5c1b2523a9a0b10870965b29c42b(
    *,
    icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4588470a5d3553d9e6978e5a0b774a81fb8944d96098ad284b9ffe3e11c0b73(
    *,
    foreground_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0353982f894d4c9532f4f327e8540522be9adfa28818ecb1a9f6c36f1da7d441(
    *,
    trend_group_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee47410f1b05e1f6f62441e6060f5263f9e1061c66ddfad21be56f33ad3fbca0(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.KPIConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.KPIConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8a63305b387dc9e3e5222c5cdd1aecb7fb534a5618b37603f82aacb325b69ea(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6e3829019b028b8203125c77b7d9dc209e438b260c4e227c2706bac74e892f5(
    *,
    free_form_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    section_based_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1617046f061dcc7641e84455035f8426eaa1a7b3c0ea98a34f81688cee694f2d(
    *,
    configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39a540a0a94a346c833d7916f311441254474464b2c6fd7cabdaea13edb4f3a1(
    *,
    height: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12052e7450234480b9d49028f99b1c0591e1bc9fc7c0a3104a91188988231ba9(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8783ad51034c90ab63639beb8d9f674a44fc140a1f365ab4f90ed8634bccc604(
    *,
    contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    default_series_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineChartDefaultSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    forecast_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ForecastConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    series: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__712a9cec0180817cc2e5fd5018c9b7463dfb8825394f0abbff651ac76c37e63f(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    line_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    marker_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9961d37a6696334c9f4c5e36bfc61631d3b8b30ed42f71a18bdcec19e46a746(
    *,
    line_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d48987524f10706d67bcea9c455673a6e9595c9bdddca32eb41238a594c60009(
    *,
    line_interpolation: typing.Optional[builtins.str] = None,
    line_style: typing.Optional[builtins.str] = None,
    line_visibility: typing.Optional[builtins.str] = None,
    line_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40644dd10170cfd872b3cdf3ad2171913338fffe97b2ed6f6668308f0883a389(
    *,
    marker_color: typing.Optional[builtins.str] = None,
    marker_shape: typing.Optional[builtins.str] = None,
    marker_size: typing.Optional[builtins.str] = None,
    marker_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffc7133f3f4106f26713ea7e63592136a91f7c6edf1a0c6041221b5f5091873c(
    *,
    line_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    marker_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7dbd6ce87bc54c6447b1a2b1ed0268afd76988d72455e9e3df22380e0ae5066f(
    *,
    category_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5284f9b25fc45cd57b681aaf71fe392497852dbd890bfdb18384e426b9414db(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__148c1a4ce871ab113950a9a5b24c4b59eefdbab388f4ae40ddf6334475395d43(
    *,
    axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    missing_data_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MissingDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e15b3daa8a4eb17bbf585641affb51d65a81c4382f500d0f01869311df1c752d(
    *,
    search_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ListControlSearchOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2a2b999c175fd2f9fc4668e116879dadb6929a09f8d1f4b90b34bb82addd270(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__745d8b3603dca6bb47bafd4b6a572500ea846f3b8c92f3a78d41181d03473853(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__117cbdb7cd88c7d99a0fc27406b855af7f3291663cf0e5a9664fa47919f2dc7d(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8edd40e5c665390e851ec533fade8e1de0b7a881891695931eae142a128e034b(
    *,
    target_sheet_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ad7d8a04e1fea3fdf86b7d3de91e884f5864d8e3975fdee554e8f3c1fff48f2(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9722426542715bb43b3c698c9d611350dd0f863e952977f0943c5c0559707160(
    *,
    data_set_identifier: builtins.str,
    data_set_parameter_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__132fda3fc2952925abdac70d31244274ec63918ac462e9bf5e4e769050394039(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__189a36ce054f57c902106eaa08ffe5dfbff5bcbcdfc89e8d7789e88b94dd6145(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2dd402a512e779923f0cba4b24087e39e2767a91bbd44697e671950c130af66(
    *,
    calculated_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CalculatedMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    categorical_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CategoricalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    date_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DateMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numerical_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a91fa342e53ed6f91bead5f9636c2211b37caf97a6e55463c5c9853db8eae27b(
    *,
    computation_id: builtins.str,
    from_value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    target_value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b24e44009415a6c6718a11bbbb682734dcf9321b444f906e26a340d9a0af4af9(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__938fb9dbf52790acc7ec1e50594d516345571c5c5ea382de808cbaebe61da3fd(
    *,
    treatment_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f43be72a6bdd1b6d36b53f1edcd1c145ecf9833e0be86b18c483e2c655e84836(
    *,
    display_mode: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35f31368b328ad250a5f6529200843a8c2eed2f5011aba82464dd02fd785a61a(
    *,
    null_string: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__980fea01022173c154c7296e9fcc1ca025eca5a3c05156180a7b6cf30b459802(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__652da5db56ba367f63dcc3e09d5016acdc536de052bcc8bab2c345c4381f16ed(
    *,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d8c460bf6f32b91c04167889ed22b358eeb73516b712762ef78a82474a9e835(
    *,
    range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__acf738e889bc0618003fa78595f3cb7eee8d6851e6bad68a9265ccfefeceef1b(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c75e5bbe1238a201f85a94c16b095a983a84cb43fc8af4cd6ced86059f5a47d(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    match_operator: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__566edeedca4ed20e48a4eda6f9af40c82aab81756e987c45265aa5fda0682404(
    *,
    currency_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CurrencyDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88bd9d150ae96de667a1e3b25b5cc65409cf063cb33f0d0e5fba674800209944(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    range_maximum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_minimum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2403c508bca5ca082eeee8dbd225a008db08c3a639d0117b47d89267ad9bb404(
    *,
    parameter: typing.Optional[builtins.str] = None,
    static_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45872501ea91ccc71a58d845f546dcba4d6912689c3be5feb9b13359e1f085de(
    *,
    decimal_separator: typing.Optional[builtins.str] = None,
    thousands_separator: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ThousandSeparatorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__836d306506e53962d3152fea384f453641eda78620b24ba606c883f3b88d217a(
    *,
    percentile_aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PercentileAggregationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    simple_numerical_aggregation: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4222fc469387ac060d5618bf1b9c7de8502a43277c2ce2baba824cd18e066f41(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09b09786ee329d00a9f13af2d5fdf09f422fa0081717548856e45146c9a17da0(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d834e2877f486e3e7cdd49135fd5fd5eea42910a47519792cbc9566bb0e558f3(
    *,
    page_number: jsii.Number,
    page_size: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fcdde6144405e8734ededa49ed9bb6578d64cdcd90c6f7e51acde8330a711b9(
    *,
    background_color: typing.Optional[builtins.str] = None,
    background_visibility: typing.Optional[builtins.str] = None,
    border_color: typing.Optional[builtins.str] = None,
    border_style: typing.Optional[builtins.str] = None,
    border_thickness: typing.Optional[builtins.str] = None,
    border_visibility: typing.Optional[builtins.str] = None,
    gutter_spacing: typing.Optional[builtins.str] = None,
    gutter_visibility: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PanelTitleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27efbfcc0fe34c45438d91e8063fd44d74e5bdd69a0ebca420f3bdf4e42b6593(
    *,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0207c2eeb4659b3f8ca769c11ec58ffa9972229f41b4bd0d903496369bd8086d(
    *,
    date_time_picker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ParameterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    dropdown: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ParameterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ParameterListControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    slider: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ParameterSliderControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_area: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ParameterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ParameterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59215a2d615284549d970abe550d8fe9ff7ffd15eb3bc9ce24519fe550e96fbc(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dce6d181f4a61644f72b81f973882283fdb06e8e57ce1c4117e6b052bad6e918(
    *,
    date_time_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DateTimeParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    decimal_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DecimalParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    integer_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.IntegerParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    string_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.StringParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db1e7b8eb24fd854321bd154d83042a96f338bc32ad3c58bff6055654d6ea9ee(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9c59738cb53da3762254f4572d873727eaa0a1c3e3a795b386b44151270aa95(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__806e2a821d889e6a1f2e9d0892ce06143ad353221f168c569ce8ed79cc1d3a8e(
    *,
    link_to_data_set_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75af37a6e6766837f77d5d48d2fc848b5ea5b9decd51ba041f9e0109bf65cd08(
    *,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0572813bf25289af88d9bad0046e7d2a8adbac96e42dd5a003ea1f7929d1bc81(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3140a60f08d07b18a886fe7ad1e0357eb993968bbf79ad92d445dc0eb5d0559(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__032a4e49690d1db651d95576aadd9028dc207b92af93eb7fef0c92564bb3d444(
    *,
    date_time_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DateTimeParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    decimal_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DecimalParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    integer_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.IntegerParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    string_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.StringParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__017b904cc8ba58f6f8bd9c71c01f137c8afc07e48b57becfc5a3dbbc716ad35e(
    *,
    from_: typing.Optional[jsii.Number] = None,
    to: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70094d6e08ded9d6e9351191895a3f63c3ef8c01a388f01a0eb29a0ee71fdfdd(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97849670dfceea4f015c9a258e2fd8fdb60f8fe4b9f3887b47311e282cea78d5(
    *,
    percentile_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec1e71bacd5f64473b3510a5db1d62484a15be232580485c1f854d37f6b8df9b(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b44278fe5cfe71c7aa5c35ac19790767f96988ebf71a8b31870c1584c06e97b4(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
    period_time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0210b27e3bc3834c56989f3fa34f59c5c0fcb66fb964fdc96fdfcc9766851c8(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44a7f8083afe17f7068f541cf73c6f0a0b414a6bd6c7bc9ffc83873d4cd09a8c(
    *,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    donut_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DonutOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PieChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PieChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d290cd7ba219d3a0da8b96be2229d45784fa3993a05e6c0fefd44457a6f729ed(
    *,
    pie_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PieChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66df0545014d697ad4125e09d2ec4abc2b4291bd932eda8879039a99dac03f1e(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73888a6d84575760d41ca9b5ffb6728ac74ce5a9d3b9473ebc3ab5d28bad7fdc(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PieChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f7805e890b1545fc6630d9d88081d7aa49fc2cf8d497c7446f0939e1e56be13(
    *,
    field_id: builtins.str,
    sort_by: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableSortByProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8751491bdbc701c4449cf53a79d73fef5f57db715048727c87126a8644f5b671(
    *,
    columns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    rows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0ab532acfdfb2170b5f0f6cb1689b2675b265c3c7e81e95104850b17bc04fce(
    *,
    field_id: builtins.str,
    scope: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableConditionalFormattingScopeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__043da837bcca55e21d88a6cde72bbb384e08451c1ebde5efd83f319fc2953225(
    *,
    cell: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__666391e85a7dfaf1065018136067fc9d7e27028ec8f375b1e6dad68e92de8d09(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a3daa44473bad29ce892b452a5880ea59a91dd3e6f46c71180e5752be9c860d(
    *,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e83bc604f673b90aa59968ab9b4bf98d8b9836285b7c7812aa528ddbd38609fc(
    *,
    field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_report_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94f23d64d32e10cd21faac9d6a8f7b6605ccc1e55503ac81ade15b3873974b0b(
    *,
    data_path_list: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]],
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83ffacd0157b8fa3f52b4546be6342d61af4c880713d12370032afe968f46e0a(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15682275c2340ea593e9910ab2f7f207e38d0cf93e87b80e5c1abab07f082b04(
    *,
    data_path_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableDataPathOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0bdc8c5da21a87f88e359286ad309da4b005492bb55e4e7cd379c70f0abf63b2(
    *,
    field_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26daf32220c6657273e4786dcba48ae3aee997a08fb55d1b7e1f90cdf9dde073(
    *,
    pivot_table_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7f187aa0bb094cf69c2aea68ae3475ccf5dcfd425239093b7897cd15be05b8e(
    *,
    cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_names_visibility: typing.Optional[builtins.str] = None,
    metric_placement: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_field_names_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    single_metric_visibility: typing.Optional[builtins.str] = None,
    toggle_buttons_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a108d3adddb21e02a89aecd62d0228977f03983c2e9e4740aaa235c675743922(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d6323fc5e8a6de6993b07b805f24d0d831af53bb4fd59acc47f1c2ecb04b6d7(
    *,
    column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_path: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataPathSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fec1f52c3f162b8315c5dc6ce7f80f0bed9de6e2d629b63bff56483410feb583(
    *,
    field_sort_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotFieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e50d5623a12e1bdc639165cb630a2657dc4f94bbb34aeaaebf69d5f051b35cbe(
    *,
    column_subtotal_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_subtotal_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d76d528a5f2d81251656b21c316cae0c17f678378927d2c7fceab68e34347223(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f04bd4866cb33e84b67c97b202a6aa0e026bddb8ce0608a934b57701d4e0e994(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    metric_header_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98f1beba4baf0c2b1acb54cfb02acee714cdef11d1f44312d39fe80d86418ce9(
    *,
    columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5cd05f980784e71c4b835ccae301c08346781e95ec20c5c6d4fab5d5acf4ffe1(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0c75740defed28866f2ba79fb3b2a135b48a7ab23aaf2005ed3a1d02e5bae1d(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d9bd7296105c868ad9035195c6f90c2827f5a79e93d58be6a54953dffa90316(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9563dd83c7592d684615d31a1298063109fd11a2bb03a631672aaf4adf20917(
    *,
    alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
    alternate_band_even_color: typing.Optional[builtins.str] = None,
    alternate_band_odd_color: typing.Optional[builtins.str] = None,
    base_series_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RadarChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RadarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    shape: typing.Optional[builtins.str] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RadarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    start_angle: typing.Optional[jsii.Number] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10c3a482b06092ee6d22abf27afa04deb532b6c26d98f29f4c57f4f94cf55b43(
    *,
    radar_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RadarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52f5ef626ddf42fb5e38bae8a7ac8554b68be4a32e925cf64fa98abc88930c55(
    *,
    area_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RadarChartAreaStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef4f687b0aa2ad42f562a7827b4ed3eda0108e71a56e2a11ddc19e10a5cfbcf5(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fada9aa73703fa429403118726326b68bf29fe4d8ae482fa8978dabad896cdf(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RadarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a1425a883f06e5fbfa3c04083db8c3d1d1f4cb17b8c0b95e15de65844f9c345(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4bf9558d7ba1c8eb0bcc09f5ebc61af2e451c94524b5501f54df4653265aab8(
    *,
    custom_label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4954b807fa9737eaac9037abc36a5a95c2cd8bbed82a780e8ba21a2fa48e2547(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    dynamic_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ReferenceLineStaticDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecb636f5a7ffd4f5b7e7df94a6e9939a8d36607a5b16d03769699a2b89307531(
    *,
    calculation: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    measure_aggregation_function: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46f10aed1478303f43309fd5f20a01d373f13d96f23ccfdca1ccb26bdbd46200(
    *,
    custom_label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_color: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    horizontal_position: typing.Optional[builtins.str] = None,
    value_label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ReferenceLineValueLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    vertical_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f44f1caf1d5838fa52083901d0048bf9a5b1f1e8d776f909f8ccf495b639610f(
    *,
    data_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ReferenceLineDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ReferenceLineLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    status: typing.Optional[builtins.str] = None,
    style_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ReferenceLineStyleConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9ac78245776d8f23111800bfef25fb654ef215154e0470a2be1653c2154769f(
    *,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e05dc0f16bc3f29378a74ae9891083d7ee6081b734733be871e8ffe193495c2(
    *,
    color: typing.Optional[builtins.str] = None,
    pattern: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__578d36c213d8ae577e4a303eca3c6c868bdd32ec997a196f314c1318c5f61817(
    *,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47a63cfeda2b07c1c69a139367a9a351974a56a1f88b4620d5b8632a918f0eab(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc66a0688d049a9b7a75208a246026f4108ee71438dc04d08df4e47d54d9bcaa(
    *,
    anchor_date_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AnchorDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    relative_date_type: builtins.str,
    time_granularity: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    minimum_granularity: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    relative_date_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd013d72a5cb83e308fffaa5e209dcc9a26655891997dcb7c495c5688501fc23(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
    resource: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed461bd3defdf64a18b9ff37c102c6a50396d406e655af5a3143c59be03b021b(
    *,
    expression: builtins.str,
    data_set_identifier: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87f650fad11a3c6318594304970065d92f1d9560f3b3414f90300e2053dc54a6(
    *,
    row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7cc2ea40377d4dc3d7090647fd4576458e949bd798b775ccf15a013b9c39795(
    *,
    target_visual_options: typing.Optional[builtins.str] = None,
    target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c23876552bb23894cad869a1bfea6688b1f1bf0b6e32febd287dd0c24a185f4(
    *,
    destination: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    weight: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a94cac8d18c7d9fa78eb53c155379779eb52f09e7d27fd2c40e700716c7f8e1(
    *,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SankeyDiagramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SankeyDiagramSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__346b9e514948d61427f9754ed52de80f326d3a06ae36d514b26badb87c1af33a(
    *,
    sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c9bbf2241d81aaf412f2bb97d1d6ab72bf5161a4c387c47afbd296598daab3f(
    *,
    destination_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    weight_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99465037c7f19cee5402c8a8cc201aec41e09330c089ec3ba0bfecd38224aa35(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SankeyDiagramChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e90833c17bd4c7e53b2a44dc1631d9705b98cf5d7ba4e75c45eafa82f8b3c7b8(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    x_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    y_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e035ae883757344f1da3b230708374fa7fcbbe893ec4e266aa9df728ce9da8a(
    *,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ScatterPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d76e517d6cac60b685140447e422c1bc0ecfa35403a4b61f62225ac21e30917b(
    *,
    scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7e6574784eb86d41e397fd728a9233ff88c370a5fc4e6353d471396853bbdbb(
    *,
    size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    x_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    y_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9f466e97da2ae9406a8f785bea04069ac951fa520616e0d8f2ace8bcfc21293(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ScatterPlotConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a75c97a8c8a2a8c78d9aae9d336b1ebff0b2662f95f7b3d77c5522267497cf5e(
    *,
    visibility: typing.Optional[builtins.str] = None,
    visible_range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisibleRangeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__006808d2638dbf353af0d085a31825fa28e966371bc10350cb000d77ed4f7255(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ddd38899348373bfe78c28250e06a87f797a5bde9bec531a361c23064093cb5f(
    *,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05dcf44a0b008853c5f7981982bade77af7a5573bb84cdf933605279c3600c6c(
    *,
    paper_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f9c3bc810320e00a0d2c6185852b65d4e0a322a1d79b30fab0f528c8071ecfc(
    *,
    body_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BodySectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
    footer_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    header_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a050d65a95b1d7d0662d3ef7f5a94c0a5caaf626bfbbf593ab499595cc0d0723(
    *,
    paper_margin: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SpacingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paper_orientation: typing.Optional[builtins.str] = None,
    paper_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7899424c10370d8394db35506870ff3ebf25b595a7a61ad6c039e5681be45e1f(
    *,
    free_form_layout: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FreeFormSectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8cf3ca6b34d6cceb68a26f9e2f51f20ffe4937c933d2c7fbf77750ef0d19fdb(
    *,
    after: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SectionAfterPageBreakProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0735e72e3dfc9dede89030602ecd438f5dfd42c6eb4c7ac9df5c815b943377d6(
    *,
    height: typing.Optional[builtins.str] = None,
    padding: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SpacingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57d02ef9bcb7f1327be6b53a061aff3c7df02e16c24d32c39cb07d61be5900e1(
    *,
    sheet_visual_scoping_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SheetVisualScopingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7180e0c50dc8a5a8d70d6c0e98f798cd42eb2bc6b1b30e6989c306bb0d9380ec(
    *,
    data_field_series_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataFieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_series_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98a5a24e118b72b5dc0d8939881bb7dbe56dedb1bc22ade037c8001118d25e7c(
    *,
    destination_parameter_name: builtins.str,
    value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DestinationParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff66c4953527bd851c8f88d154bab079f313d03d1705b825372e6385a8c04b4b(
    *,
    background_color: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9e75e88096b00fd3b17af9e8d7b559a38db0733ecb86c0fe0b784550e65ca14(
    *,
    grid_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20a2d2d6baff3fa470557e907b4bbbee724a0974cf1795748f33cc8da1efcbcb(
    *,
    configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SheetControlLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98d6f4f0028ae9d6b3145f602f0c88ebc6ee8cdc2a7fd3d72d64d5df71cf5d02(
    *,
    sheet_id: builtins.str,
    content_type: typing.Optional[builtins.str] = None,
    description: typing.Optional[builtins.str] = None,
    filter_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilterControlProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    layouts: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LayoutProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    name: typing.Optional[builtins.str] = None,
    parameter_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ParameterControlProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheet_control_layouts: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SheetControlLayoutProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    text_boxes: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SheetTextBoxProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    title: typing.Optional[builtins.str] = None,
    visuals: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f9509da869d74c1a8c070bf0d16312535361f6f146f49a2f608c4b1edaeb37f(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b18030ef2fa34ac222ba21c5da57678bac1c69488e13f6640311ee0c0fb5f9a(
    *,
    configuration_overrides: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SheetElementConfigurationOverridesProperty, typing.Dict[builtins.str, typing.Any]]],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cacd0f254449cae9b648689b1208d949b84917047f78fb6cf379d6f1d941582(
    *,
    name: typing.Optional[builtins.str] = None,
    sheet_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9e2cae552e9c723a892ca8af894fb9f71723b6d120addcec8b06bc65a0b0621(
    *,
    sheet_text_box_id: builtins.str,
    content: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb08203bf42bc95c411ffee09bb2e6ec9c6940033cf7291896304896a28df623(
    *,
    scope: builtins.str,
    sheet_id: builtins.str,
    visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a2a0f1eb82d70438008f1f141c8c8674a381d6c01dd4fe59ce4d7737b7adde9(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71e9ec78fe94cf84ad2a41b3a9a1aa6e2304dc7ec18a90e32de70deb4ef5febb(
    *,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67093e452f807d8cc8c13a040e3510ce55243eb17b8b622c4c3095ae9338f826(
    *,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b34a8942e8b9336f2d48e06137768358f24af2ebfc5193fa88f0bf5c8642dc93(
    *,
    max_visible_columns: typing.Optional[jsii.Number] = None,
    max_visible_rows: typing.Optional[jsii.Number] = None,
    panel_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PanelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5b2be0229e5c871b1763885f6535c43424f0762572f2046c9cce5002947c9dd(
    *,
    bottom: typing.Optional[builtins.str] = None,
    left: typing.Optional[builtins.str] = None,
    right: typing.Optional[builtins.str] = None,
    top: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccc7e0543de2412b5b25d0973329ecdb15ba6486ef62ec2852d046aef8220312(
    *,
    dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5578d43ea0b1a011b59b52c0fe1cabac17a88604a3fcc768325ba1a6dbfc78f6(
    *,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3428456c1d6e6937273bb7bff77e0be099bf226f15b89ba55693a48b702fb06(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.StringDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.StringValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8d78fa02ae2aed74712632f744886e36d8560b93267dfae1fe42091a4c8a086(
    *,
    name: builtins.str,
    values: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57a1af832712bc853d8861dfdce5b7e9e9c79c6697ec86ab8874aafd27a77bc6(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9a27ac919503c807c54ef3d99f42e3e023f1c38d8e1413a3bbd26fd0847eedd(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    field_level: typing.Optional[builtins.str] = None,
    field_level_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableFieldSubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    metric_header_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f255384b3c126bc08e0710f46935a92fe2225005f55725cd0efe34c9c00f9ca4(
    *,
    group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8364f2fe48c0bc0464f363ff5216f5f1063b4cd65dba537c35dc7ce8c18d332(
    *,
    color: typing.Optional[builtins.str] = None,
    style: typing.Optional[builtins.str] = None,
    thickness: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d27b894f1ec0b4cec4cabd1746f88e6040cb88d796dd76291eff4b899d490f50(
    *,
    field_id: builtins.str,
    text_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f89394e28ada923f4869cc0cfa0f42fb2439a4749b2845fdac145cc1d56fc6c4(
    *,
    table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42c2e423baf66d1e7f50ff7efa995d82d30c52c1b20458d69098f2c08d417d35(
    *,
    background_color: typing.Optional[builtins.str] = None,
    border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GlobalTableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    height: typing.Optional[jsii.Number] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    text_wrap: typing.Optional[builtins.str] = None,
    vertical_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fecfbbe7cc00f7928e348ba95570a7debd025e6adfa6fbf4fe7fd5cd9ebd7cc0(
    *,
    cell: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableRowConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb58f86dc6c6304bbc6ddc4e5020a60cf25cc8a4ebaea1700e21fe0ecb2dc509(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__461f5fcef3cb75d7112386f1cdbd1159d5de6647f7c7ac8fd1c8d80ca8b99549(
    *,
    field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_report_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_inline_visualizations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableInlineVisualizationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    table_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18d6da966041b103e7dce9a1a3fc25fafcac0d08d2a722ad1c11fdd22e7d3cf2(
    *,
    icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02e22ec2a18ca267b33fad8df8923023b3c31f723d612c55b32afc8b636d6cab(
    *,
    font_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a47a7e09ccdb72246681ca605f217f6041815cc516aeed9016d12e23c8659c7(
    *,
    sizing_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellImageSizingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5eba622d180f1bcb77b3e83227e5450b49cd30ee67121ac6b6fb0c5ab998428(
    *,
    content: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableFieldLinkContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    target: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99ba4b04bd7fa7922a2ecbe559b207937cfcd0787cc4282972cd273d1023b4ce(
    *,
    custom_icon_content: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableFieldCustomIconContentProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_text_content: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableFieldCustomTextContentProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d51dc70f2596619d6a5315b18b50bed1e5d2c74abc26edee57ccaf5c5943f003(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    url_styling: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableFieldURLConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cfa074160e5bafdbf057b1144a0109b2b11c0bfc47698f35e66c8595563b2f2(
    *,
    order: typing.Optional[typing.Sequence[builtins.str]] = None,
    selected_field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05fcaa5bf6c410e2af935f8264b25da0799f2c6d7bf2ed71abe5b59a0e048aef(
    *,
    image_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableFieldImageConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    link_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableFieldLinkConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5120a99bc0994de264df10390e24adb3b0cebe5817d98e35cd22922c1062fe06(
    *,
    table_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_unaggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43ffc5a657c7d8ab71c7e891383e6288b3849d068be01315ba7a92c8eb9b7367(
    *,
    data_bars: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataBarsOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c26cb8d60d809746b189a866575550498a87b206d2908f4ecbf51d2c0aca6c25(
    *,
    cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    orientation: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__400317663776ab4c1f2917b5ca054b98ec329ac4a6b7e74b2fe53c7d05080a71(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7029b932d9c112c1fe6ecc02d2e0eb0596638b76476f7b1c906fe92080315f69(
    *,
    background_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__256be354818f3c513b3d549ce4cdadb421a2b9a44d77b0faf672b7df80033342(
    *,
    bottom: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inner_horizontal: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inner_vertical: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    left: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    right: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9c50c7d74225987a470676333ef9a83392575298cbea8b837ca2a01deed3054(
    *,
    pagination_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c3e1fee2088d75155f70c29df26844380f91f745827a2efba5b2cf0fd7056df(
    *,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.UnaggregatedFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9913d7f7cd8c81d3ab5a6de937a815f1b501a0b1e766932105ba4d4f42512478(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a700ae0be708d4be1258960b8db5b08e2f8ea452e8c97ba2614605a437b54d6d(
    *,
    placeholder_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb55caa13ec433dfb729128dd290212c3647cccc81c5417fe6e8d7f5d16d1f4d(
    *,
    background_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03d070e567fad7d9cd8dca405aa13f96c1333ea18f8cd07f8ea42273349ffa59(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d2298d881ad66005671e8e4d1e57f64db9cbbbf85c324e7fe0234ade9967276(
    *,
    placeholder_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b67e4caf06894032bfdb6af12762f117b35e8b089b1830b28dc820a218948d1e(
    *,
    symbol: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8abba2be8b45aac7c1d103337d7fa70c365d9d91fe1e55fda5f53a67817a7002(
    *,
    lower_boundary: typing.Optional[jsii.Number] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[jsii.Number] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ddecb2f8770ff2b3151bb2ac36052865f02fe999bdc5236eb783ac074458694d(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87fa79e9f14d95f01ee4b2c2b464703520d2d7f06ef83a35ad51dfdd52c7cc19(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    range_maximum: builtins.str,
    range_minimum: builtins.str,
    time_granularity: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__028f35484c126e74a2a828f9819005eeed839c45b2b0c5dc53fa188d1d904140(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    range_maximum_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_minimum_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c8b5289f98e9b91efd2347c9ff86bccb1689f6fd0a3d0b6db8d1efdeb647a34(
    *,
    parameter: typing.Optional[builtins.str] = None,
    rolling_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db99536de276b5db7a33340f4f90179df4bcabea3e247e4317731fff3cf4342c(
    *,
    column_tooltip_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnTooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_tooltip_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldTooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45773945e1cd18ea20c5839ce54565e0617256f1f06ee7b3dbf129c8eeefdc1a(
    *,
    field_based_tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldBasedTooltipProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_tooltip_type: typing.Optional[builtins.str] = None,
    tooltip_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8465d0d4025300aa1b3f5db081d4f2de56cef87c2606d171932843c886c84266(
    *,
    aggregation_sort_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AggregationSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__845e823a8ebb22deb0f55b759ee054f53e2ebf7bc57a6dbb57ab8169e2e20727(
    *,
    category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    type: builtins.str,
    mover_size: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    sort_order: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d6fd877ff3cc8749f4aa7e9aff8348a33b686f2930f388b3cc377fae58bab65(
    *,
    category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    computation_id: builtins.str,
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    result_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e74ec9047e6d0d14baeae685d3635aa13a32c3c92841603a1af15967da84ce64(
    *,
    computation_id: builtins.str,
    value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae2b09c00d24bf0e485e2b650341ad38f34ecb6dcc928b3b0c88eeb0c86f820f(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40ff2b59a0d9fe5551cdcc7863824c28b845983be8f866f3b455c505b0cb9aa5(
    *,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sizes: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8689070099667e6b50fb9d5ca01dc351109d9d5918c710bb8e422e723836d24a(
    *,
    color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TreeMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    group_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    size_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TreeMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20122b4f544ea66e8eb2c9992018066cf8200ede7131282eed1012bd10255f0c(
    *,
    tree_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TreeMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8bdfe1bda8f43d44780355ece78c519b77b8c9b4582a0913836a866278ae540(
    *,
    tree_map_group_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tree_map_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb0d60efc27654f2e7a10f31bd22a1619e0045153a55817d9d0f5c7c821b9ad5(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TreeMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__086cec46ac780cfd07640896d1ea9300779c6836a4e99d85a858d9907595cd9a(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cf448941e904391367709ddde2946b89c31dedf08fc5b55d0b279c7be7223f0(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d6a84267ef69ace80812482aaa7dfbf1d324161d3d402744f6c4d22be5e3814(
    *,
    category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f9c9cd10309e0c8e3a0e4bcf3cefad595c5e7fb8b6639be658daa12f852debe(
    *,
    percent_range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PercentVisibleRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__911729a8900b71f464fc360be03b094126550e2902915e99aabd9c56262bbaa9(
    *,
    filter_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CustomActionFilterOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    navigation_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CustomActionNavigationOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    set_parameters_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CustomActionSetParametersOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    url_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CustomActionURLOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__305776f846978e140f2419b7a6fe37c4b1473f864d8736f2ce5b4a7c7dab5b9a(
    *,
    action_operations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionOperationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    custom_action_id: builtins.str,
    name: builtins.str,
    trigger: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ca8d48ea3029a97b023077c4b934dfb0a6d1aa32e7a139a67e992050bb49922(
    *,
    chart_color: typing.Optional[builtins.str] = None,
    color_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataPathColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a17406b75a6d0080bcca17351cc12b3850e11299db5acacf2f53f73fee90a20(
    *,
    bar_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BarChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    box_plot_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.BoxPlotVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    combo_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ComboChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_content_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.CustomContentVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    empty_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.EmptyVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filled_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FilledMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    funnel_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FunnelChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    gauge_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GaugeChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    geospatial_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.GeospatialMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.HeatMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    histogram_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.HistogramVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    insight_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.InsightVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    kpi_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.KPIVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    line_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LineChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    pie_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PieChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    pivot_table_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.PivotTableVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    radar_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.RadarChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sankey_diagram_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.SankeyDiagramVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scatter_plot_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ScatterPlotVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TableVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tree_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.TreeMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    waterfall_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WaterfallVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    word_cloud_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WordCloudVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97e7f6e474471c9a94e2f233e41ddbc7d9dadac00d1db66e15f3d4ecf262a51d(
    *,
    format_text: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LongFormatTextProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__895188dd0f51eb7fddd4996aec4b8caceeeb451df745adfc8d9082dcfdd9733b(
    *,
    format_text: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ShortFormatTextProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a4ce4309fd1e1c5f4cd2cbfe48dede7d90bfffc2a1205b7b6d59ae2599737ec(
    *,
    breakdowns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    categories: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5caf47a31b51b862e27a2d8d40e6573a55f6146ef4fcd61b8be5bdb1ab3f640(
    *,
    category_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WaterfallChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WaterfallChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    waterfall_chart_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WaterfallChartOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e924f32550b5a3aca9849a62366b2e0e3e3798a75767498047ff2bee26af9cc7(
    *,
    waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aba08ea7a126148022ac27ece4c7efe54b758e371ebc06701b8a8bef96fd5179(
    *,
    total_bar_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a7d46c4a6688997c19bc45a3ba348867a890ed493f473f41a191a258e4b9488(
    *,
    breakdown_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42b6502b34ccf1acaaf46afd73ddfecadd0411293c44ee48052be33597bf7495(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WaterfallChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c81c102cc41ab62641d1894a5c11c921912f386a864db21015606ff5f9b0123(
    *,
    date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6efa131bf9fd8eca60340ee9accd6f1638136e6c26a4b9cbdbd4a881c93a956d(
    *,
    end_date: builtins.str,
    start_date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9144b0f8cfb4ff98e92db4a9f759e9117ff3e44c0fa5c86ac5499774b4957460(
    *,
    group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__746fcfa6667f447492eb6876b894351f96777bbe9f8b88bf1ba1f8614c31cea0(
    *,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WordCloudFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WordCloudSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    word_cloud_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WordCloudOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15e73ef744aa9f7d3e00325b263596ae2cbe5e9332eb721c05527d15827aa4c8(
    *,
    word_cloud_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WordCloudAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af9c886ff923d6370b151e14ee383dc317f92b40dc807cd4fcb0a6a2e8acf708(
    *,
    cloud_layout: typing.Optional[builtins.str] = None,
    maximum_string_length: typing.Optional[jsii.Number] = None,
    word_casing: typing.Optional[builtins.str] = None,
    word_orientation: typing.Optional[builtins.str] = None,
    word_padding: typing.Optional[builtins.str] = None,
    word_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91e4a78fa1ff40dae0ff2b7e02cbbbacf78bd14272c794ac6d09b2ba201e180d(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__025853a74c750e49a6341cb6f02d7032d87a5cb6d002288f2d21d2e11e092d31(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.WordCloudChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8da32aafcf32570140f4a3398c868f104809ea7a94b36bb2fac9dce178f0208(
    *,
    analysis_id: builtins.str,
    aws_account_id: builtins.str,
    name: builtins.str,
    definition: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AnalysisDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]] = None,
    parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnAnalysis.AnalysisSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    status: typing.Optional[builtins.str] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    theme_arn: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e48367cd54dd9342e391cb843301b0a936d22766cb638c832b428f342aa489c(
    scope: _aws_cdk_core_f4b25747.Construct,
    id: builtins.str,
    *,
    aws_account_id: builtins.str,
    dashboard_id: builtins.str,
    name: builtins.str,
    dashboard_publish_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DashboardPublishOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    definition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DashboardVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DashboardSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8bad017d19650f323faec0b36b2ab696b4749216593cd1a29d42368e9afe1b69(
    inspector: _aws_cdk_core_f4b25747.TreeInspector,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__931b87b452937f94bdd3e2f5f24b94a904e2dab888b63f53db6e2f70228b4884(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b972d8c0c3150e9f5a1bdb792c63f2c279e226dedd4975b4da79e30fb77a918b(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48e8c8e06e7d4bae8fad721c7d0ae648922375cc8f3b218071c33324d873f611(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9159b4085acfe5d6a2168f6985c6cf8ee2d1211654ce74f200090a28a367a41(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6166a160983f3fe5ecc4dec24ccab014411608bfa6601bfe643aeed996ecf98(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.DashboardPublishOptionsProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dad7ef1e78398e551e3f72128d73794e4b508c110731d3b32fb78152d5bc63b8(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.DashboardVersionDefinitionProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62bcb2fd16475e12a58e66fad3f786954abf247b8132b2a3d6bf016b303d87b7(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.ParametersProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec6bfab964c113b8287aa298797dc1a7980041501cfad366928b8a78ee8f24f8(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.ResourcePermissionProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6322cbd31cfb4201b0d40b2f6b3f28979b28f2d4db0f57d89f5661a6452b9acf(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDashboard.DashboardSourceEntityProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__093d29b03ae1a3d648643f06f55e38223831e4cb654f49158366a3b23ebe4e52(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80e94bee2991d499e821ae8089ca34094075772a7a7a36f07d476ab8d3021f1c(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b698be7589ff435eeaa53af02cb3ce9630ee1f49c2c7a79513138c50a055a6d(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf49ccb8809892f6cfbac13f76b3481af8c8a83754ae23ff05af63ec62ae59de(
    *,
    categorical_aggregation_function: typing.Optional[builtins.str] = None,
    date_aggregation_function: typing.Optional[builtins.str] = None,
    numerical_aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16749183c430f5514e9ee9cf94ae9025f9d33ba4a8f53fb01fc6911ba191bf84(
    *,
    aggregation_function: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    sort_direction: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5075815710d94e2f81de88c7c8a6ae1d1e947322db7fd05b0d15f190af0d764e(
    *,
    default_new_sheet_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DefaultNewSheetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96edef06a056262fc22dfc9f06599f90901acca9268fc8b97ce27f39bbdbb4dc(
    *,
    anchor_option: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9176a3f0dc1a20494ce546d33d6f3fd02cec576840e08224c0264b590a6126d8(
    *,
    range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ArcAxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reserve_range: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12a771a16c265538a625aaaa712718421dd8f7fe9d51dcad4c2ef52912fc2974(
    *,
    max: typing.Optional[jsii.Number] = None,
    min: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c68645b2d68641a2901b34535a709e7b8ec320836b1ee0c7bdac1423845460d8(
    *,
    arc_angle: typing.Optional[jsii.Number] = None,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fec0672915f93e5a544811f60fad5643e68e2de357546a3ec9f169d43ffbcc9a(
    *,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0b97004ad028b08d2a7a5ab7667b7b8345578ea2c7fc1a86b5b38bfbf32001a(
    *,
    date_axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DateAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7683b81cec62e659b564f0bfa294b411bc8caa01a8a1c84da263d0f0397293f9(
    *,
    maximum: typing.Optional[jsii.Number] = None,
    minimum: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eadbe89875f8d4cec1b1202ad2d0e0460747e4f231141d7700f28964d9e24e8a(
    *,
    axis_line_visibility: typing.Optional[builtins.str] = None,
    axis_offset: typing.Optional[builtins.str] = None,
    data_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDataOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid_line_visibility: typing.Optional[builtins.str] = None,
    scrollbar_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ScrollBarOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tick_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisTickLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f8a0daab21a55eb94ef9c0c537727c8196c96099007bee2b4676901dc9dac07(
    *,
    data_driven: typing.Any = None,
    min_max: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayMinMaxRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9cafd7f59053ba60f0a6fead0d1f83670c21b659df44146d7fb59bd9032b0c62(
    *,
    apply_to: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisLabelReferenceOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c183dd904676555d4b4b9b52b9981b3e4a07253c04413d02b89ce484c6c77444(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bb18d42a6720e8a6947d59b34fa91c87d9a42db0bc3daa62fe0776eb454e285(
    *,
    step_count: typing.Optional[jsii.Number] = None,
    step_size: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70c8a36719b88116f32c7087b854b08debb7c1d6c249a59d3f7e88d319c12b99(
    *,
    base: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a541dd13c6e9b660a3afc48d1f0ba9f39e2d3128327965e202b7c6d36971d98(
    *,
    linear: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisLinearScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    logarithmic: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisLogarithmicScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2a6360bb5e2a9e553a9d7d5f0eb0725b62f5e0a6794a38dec7e7255bcb47fef(
    *,
    label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rotation_angle: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5f8bd6740c7536cd50ac17cb49112e1a5232d6eca37bb7eb30df00ab36ca544(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__deb97781027704ed6b8bd2e81c0de81a9e84cdb266a70a4ddb48d7c807e23945(
    *,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    orientation: typing.Optional[builtins.str] = None,
    reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3892b431a3a2eb3420f01a6038e29381e80cf0542e37c63f112d386e61199093(
    *,
    bar_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc5dded84b2e7dc712e22e971b152ba29be73dc90a8d31dc9f472a78f1c77580(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55183ce3561875d22b98b362c344f7f5a2c65dcfc7f77e8f98c0ec929126843f(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__009936f107949a94df6fd6e5b29ade27e95329f0007e24e685ab01d1d21805dd(
    *,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6f2aebe03941a3002aaa5510ed7717f69ca4cb6acf3a95254807dc8940a3bcd(
    *,
    bin_count_limit: typing.Optional[jsii.Number] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6afd1d4accfb726e8d23257d4580346fd5b13ac8b6dd1f4842303d88e31a35ab(
    *,
    content: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BodySectionContentProperty, typing.Dict[builtins.str, typing.Any]]],
    section_id: builtins.str,
    page_break_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SectionPageBreakConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36b8207b32011a65fd176c373dce22e8104c0d2c11a184352b570918596ae484(
    *,
    layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8ec6d64a4adf5ee0eff08f2f82aac5d4e58e363a92fca48bcaa4dcdc1158b08(
    *,
    group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7edf4fbf2bc6783bdd20fc27acf3389eca3a600449b73d15934a83c7eeb5ff44(
    *,
    box_plot_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BoxPlotOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BoxPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BoxPlotSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e37caed209193c1d3e435d4bff8b18bdab1e8e6c75403b7528f575eb186b6efc(
    *,
    box_plot_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BoxPlotAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb0333bbaf418cd72dc35b227b6952ca982091e1666e3fc23c6d7838f6b855a7(
    *,
    all_data_points_visibility: typing.Optional[builtins.str] = None,
    outlier_visibility: typing.Optional[builtins.str] = None,
    style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BoxPlotStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31960feb76515d746b202b901ec437514a07b59746c45a6b59635df52989b415(
    *,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    pagination_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3237fe0e8e28524f2700b41ce7f8fdb33da5683f603d9fc6e0ac3bf8f61631f(
    *,
    fill_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ea4f97a97a8f3ae36006d62df66b00cbf69200853fd0d5618bdb209c49a24d3(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BoxPlotChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40979e8c9cdeac16737f8670530c28ca7fcabe1533ada73a6c4b3fb5fb9a8e16(
    *,
    data_set_identifier: builtins.str,
    expression: builtins.str,
    name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc88f8639ceab7dd50c507deb39c7a07aa2682f8d0efa0556d33afd84758b9cd(
    *,
    expression: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1439ea63ce3691189a4288d7ed64470688c91daafa8a1e847c2926ccca6b5961(
    *,
    source_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CascadingControlSourceProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66f4b3a56eea4e90ccaab827f528c077cc4b860a21abcb8ec4eeae10c645e8a5(
    *,
    column_to_match: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_sheet_control_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f5221a7fa4fa42dae1139f03e97e085b67603c445c21d33fcc970a54ccc26ca(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f17c2e15254a21d2b673ea34b163a218eaae0c54a28013185a7023fbc5a435c8(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2276e4d4c34144ac6579f9743c1c47706ba807930568f1be786a950764c7e002(
    *,
    category_values: typing.Sequence[builtins.str],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7a0a159840618cc8df488aef2f7cfcfe7777161653c7c63d242786ce4251a07(
    *,
    custom_filter_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CustomFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_filter_list_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CustomFilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filter_list_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b36b9996c27d036a2e2fa590d1e67d3b6f5cd2d8ae763fd56821ebee7ae5639e(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CategoryFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9eed731152875748ace7ed453a4014d7cc2f49964293703c523a63c5166adbb3(
    *,
    axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sort_icon_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e18e75d60cad07a4699d9d9b0dcef4a23b84c9535dc61ee1186d4d40443520e(
    *,
    cluster_marker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e274be3add0374cff65a72bcc62bb25a2a9c30f337761649644a0d2cead9738e(
    *,
    simple_cluster_marker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SimpleClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__578103127e1c7b8890cc12c174614c6ffac547207d8786af69ec235da644631a(
    *,
    color_fill_type: builtins.str,
    colors: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataColorProperty, typing.Dict[builtins.str, typing.Any]]]]],
    null_value_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc1dfa396a24533c6e375d73df639a9191b10290a39bff6de23ae9fab340f44f(
    *,
    custom_colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CustomColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca3a7a72254631bb4da834d679c8b33ee3731b0c53f832263db5fca308438df5(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    colors_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColorsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__496629e1b1f0fdbb3e1be123328776a0f6de6733f0137e37dc963e5d369b4782(
    *,
    date_time_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DateTimeHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    explicit_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ExplicitHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    predefined_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PredefinedHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0aa9c07b3f5dcb8eeacf6fa5d12dd6b85f9276887b79cb179cf98920b5cae871(
    *,
    column_name: builtins.str,
    data_set_identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80fc478453e48434aedae4865927b3718b81b14697a93359c42ed8241af37efa(
    *,
    direction: builtins.str,
    sort_by: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37918655058dcc7bc7b4e254d2e3cf731b56ba5694484c14bd673cf42f4e5cf2(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9617a32a98e261e8b54e5face66386ac80e746775c9376357efd1a7e6a6f7aa9(
    *,
    bar_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    line_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc7ce369d810a32b532c61cda467acaa4576193d452b007dcdde2b298696f73c(
    *,
    bar_data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ComboChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    line_data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ComboChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bf693ad40ba36ed350932833aba32367b564d085fe7b09cc4e6cf1c1e20e546(
    *,
    combo_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ComboChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6158a9025fa3c388fe8dce90ca10cd5081067b2986f9c803a478135e0f77a54e(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba715d9ec79f63de433c29beefe15e0e8df42d7f0138d0c02256460702f9374c(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ComboChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2ba740c3f6d8a30309ecca6ef21fce583dbb520f85fca0c6d2df2bbd05d73dd(
    *,
    comparison_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ComparisonFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison_method: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2981421ee9518586342dde9a3fb34a59050f74d484b068ba3abb41b9939146ad(
    *,
    number_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db319162dc46a72097676ed463ee68b1b2d5a29e87e419337b599da7c81e2462(
    *,
    forecast: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ForecastComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    growth_rate: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GrowthRateComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maximum_minimum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MaximumMinimumComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    metric_comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MetricComparisonComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    period_over_period: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PeriodOverPeriodComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    period_to_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PeriodToDateComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_movers: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TopBottomMoversComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_ranked: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TopBottomRankedComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TotalAggregationComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    unique_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.UniqueValuesComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__260ce54f3ce2ce5ea2c21ffe9524641f4850fdc312ee472e47c0922fee55ee98(
    *,
    gradient: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingGradientColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    solid: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingSolidColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3cce66ca39c7515c5b3267ac039ed1c29e3d1757d212813d179325cb461f20e(
    *,
    expression: builtins.str,
    icon_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingCustomIconOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
    color: typing.Optional[builtins.str] = None,
    display_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__052a4096d4d0e21c8f57b98fd0d557da04d94faa52c23545d0a2856f7b5a0945(
    *,
    icon: typing.Optional[builtins.str] = None,
    unicode_icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff6de843724ab94345a0c6400bae50fa4a24d937abc2e295119d900f42ceb50e(
    *,
    color: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GradientColorProperty, typing.Dict[builtins.str, typing.Any]]],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97d862e4a85c50c1139f3ef1f614e6d75da9152be3b519612c05732ed04ea112(
    *,
    icon_display_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ea9d0e053d178c5f7ed9d43a0578eb1b68a073cc60e7f345d32aba2819024c4(
    *,
    custom_condition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingCustomIconConditionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    icon_set: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingIconSetProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c7c7f3787fcef7aed83073c60cb037202489be2d4d080fe99bd55ec27eb384b(
    *,
    expression: builtins.str,
    icon_set_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1eea2a7bbd91bd56ff24fdaf8181c112f785885778422661e33530294c03f57b(
    *,
    expression: builtins.str,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14d27c350b096a0267c6183664d0a24cfa1d53153e9d6260a5269392208551d0(
    *,
    contributor_dimensions: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    measure_field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0661a7e804c438adf52e32e8ad396f335caabf21ec4f9b9a9f828b5c4bf9a20c(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
    symbol: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76376d3ffd52c3b6f5ed567c64212552742f93c87c28e01bca215de00143449a(
    *,
    selected_fields_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    target_visuals_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterOperationTargetVisualsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29a007631b8b5484f10cf756bec18eaae974fbb36b8829e3a528a5707cb4d028(
    *,
    local_navigation_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LocalNavigationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a4a779c5b99cec7ab599ea770a1dfd33efcc602795d46631146a620b8c9674a(
    *,
    parameter_value_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SetParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc23249d6637e0c6c0d438dab26db6ca1dc77dd7820885b6875a10bd43a99e9e(
    *,
    url_target: builtins.str,
    url_template: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__baccb380931844a2c5bb6ce153c972b21ef1544e2bed9b24d5de491075f2683c(
    *,
    color: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    special_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0bfdaf5bc05511dbabd06e75741140dfa8ae9cd0b83bb8067deb0e6a0be9d9bf(
    *,
    content_type: typing.Optional[builtins.str] = None,
    content_url: typing.Optional[builtins.str] = None,
    image_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed66f89a240e218e0c8c3ba6c9a7d145cc68080d4b9132c0d1e07f2685e6efa8(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CustomContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a310f47ac79e090af0ed23f47fbf50776a7844e4ea84aaa4e0365831e4a8bcc(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_value: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33254ba3130bc49e5f51efc4cb05d1eed4b22c61ae762c05d2ea8f7143f15e95(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aab7040ac5d1962b3e703310059404d17164df0f6d46b805ed54e49d44cf8ba8(
    *,
    narrative: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17abcb30f8053b14584c3eb72e49bb753cac4e323b218f32ab841702d3d988b6(
    *,
    date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    decimal_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
    integer_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
    string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ccfaf1e44209400545f10770b059ed57547cb2f9e5caef923da26ae51989523(
    *,
    custom_values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CustomParameterValuesProperty, typing.Dict[builtins.str, typing.Any]]],
    include_null_value: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa288d76cf7caed79a8405021a8eb02cf1b19ea9755d0aa77ff4f8afb914214d(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
    violated_entities: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.EntityProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cfc8872e7946f6ede4fe2a4a911fd8bcc79da312a3feaf9d0e0ab0e2935c33a(
    *,
    ad_hoc_filtering_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AdHocFilteringOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_point_drill_up_down_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataPointDrillUpDownOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_point_menu_label_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataPointMenuLabelOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_point_tooltip_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataPointTooltipOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    export_to_csv_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ExportToCSVOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    export_with_hidden_fields_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ExportWithHiddenFieldsOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sheet_controls_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SheetControlsOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sheet_layout_element_maximization_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SheetLayoutElementMaximizationOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_axis_sort_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualAxisSortOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_menu_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualMenuOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_publish_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DashboardVisualPublishOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95ac0a43c376eeab6e6c9daabc99cad6641a22d70a49ff384d4345905e5e0475(
    *,
    source_template: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DashboardSourceTemplateProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec4b1c8f9abb3a690b756b53fc5f73110c6f67d197acf44415593c23064d92d7(
    *,
    arn: builtins.str,
    data_set_references: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataSetReferenceProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bfcab882e1b0a7459c16fa736358b5f7e1649da0e925bd5d7b5660498d64edb(
    *,
    data_set_identifier_declarations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataSetIdentifierDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AnalysisDefaultsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    calculated_fields: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CalculatedFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    column_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    filter_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterGroupProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    parameter_declarations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SheetDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1cd71b2a2397fa023c43748542c1d9990398f4d8b263021516e141f717ee5c3(
    *,
    arn: typing.Optional[builtins.str] = None,
    created_time: typing.Optional[builtins.str] = None,
    data_set_arns: typing.Optional[typing.Sequence[builtins.str]] = None,
    description: typing.Optional[builtins.str] = None,
    errors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DashboardErrorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SheetProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity_arn: typing.Optional[builtins.str] = None,
    status: typing.Optional[builtins.str] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    version_number: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__087652de777a58e6cc5f05aff691abc5496763429f2b2c21e168b276632deab2(
    *,
    export_hidden_fields_option: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ExportHiddenFieldsOptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66a928ed261b7f2a81adddd0df469ba54d9745a362b70a3ecf9ba05933985362(
    *,
    field_id: builtins.str,
    negative_color: typing.Optional[builtins.str] = None,
    positive_color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2990ac04e1845daf895f568fe9de7844c5e8cc45ced311c3a6242363c466264(
    *,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ebf8ceb14ff875af3af6b8643da1722ce9e80bb9b858aef5094e864576c82e6(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88bd694a9b51da9e5068a53df594cc196dcb929bfb4f551e5e2aab00d19d1fb8(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    data_label_types: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_content: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    overlap: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c72d17b861907d098e5bda0e212c223319d2b0e32acc9fbe3a819780c7a62c1f(
    *,
    data_path_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataPathLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maximum_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MaximumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    minimum_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MinimumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_ends_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RangeEndsLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6772eae9cb657f1d72dfa556428e880f7605aa5ff464fd4543e53b57d69f7ee7(
    *,
    color: builtins.str,
    element: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]],
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f72ad312a3f6434083b5eb1519fc9a2a3c47ae4d56abb157d1333b738af935e5(
    *,
    field_id: typing.Optional[builtins.str] = None,
    field_value: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b1fd519a1df5d1a3b591a8bb0c8c6703b7cc2f27e7e4bb36b876d7ee4c82f99(
    *,
    direction: builtins.str,
    sort_paths: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce381cea0f90c39ec0e4af27533dbb0a30a15f375c60f6ec373fce1ea5bd64a5(
    *,
    field_id: builtins.str,
    field_value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cf1a21c97ee69418e13603daa93cf4ea1805781e3d86533040e2c75a53b7db3(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__794c00e4db08799105f78127f5577f7a44af0a5ceed6b50b8e2ba48e0470a8f3(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfbdb7a441430ef0002a7319f8ecc3af008db5ee975b2c0003f5c91af43c9b06(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39d6ce72f4cfae32bbc755072ddd9306d8182f453234b0924c67305013fa24cc(
    *,
    data_set_arn: builtins.str,
    identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffb1276fd469efa21c07a6e5c83251d4ed2658706bd09094781ee19a260f6a57(
    *,
    data_set_arn: builtins.str,
    data_set_placeholder: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95b5ad19dfe069f3d64428f38946307be05acb48bede3ddbc5af9f04713df137(
    *,
    missing_date_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__439375606295e1de09676955bbc653cd0396926f2ba587fa2c1a9ee88c8b0963(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    date_granularity: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e28262e880ab4a1e2a2a8441403133b582a042964ec45737e5c875d769ba721(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69605c73216e22958282e5c37a83b2f02591f4dd5aab22418596e3d1b7207b52(
    *,
    dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rolling_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cea9df0a1b6abc984c3d6e60dc06d76fb9089b61d0d649a1ceaff2e7fcc65c28(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2962a7a0c45203491af8f1bd4b7aaa9ebd6ed9db13d1d9d685cef080baadabd8(
    *,
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70936c6088da7bd0d74d6ccbec4d00deba440742d1961d1ac73f4d15f4d7ee9a(
    *,
    name: builtins.str,
    default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DateTimeDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__824f85950bef2bd116513c64d39bd525d638eeb70cfd976f8959c13ed639dab2(
    *,
    name: builtins.str,
    values: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d87a131ac70d9448e4b7dfaf3ffaa0d685d31da4754280a03a21158f0cc1c12(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__762dd648e8e8915c30be0326b2ce7490e8659c63243baf6a93f30b099400ebef(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afdf80a85935c1d10fd8620e405bb680c8653c16ca2138ebad702459a08caa77(
    *,
    dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__edec106080316f61fb384286e5beda3518ba0387954f6063651da0a25e7ba0ab(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DecimalDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DecimalValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__adebed9e07a7e08f1bd1455352bfedcc0507dca5264b0c0de2fdf21d8727e685(
    *,
    name: builtins.str,
    values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e83454d4338a6109dd29062254bde75464130540090dc35262921011503464f(
    *,
    decimal_places: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9a0bdb1cab464ff8679346a45a7124340fda478d6ad6fafa314d04385818851(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7829bb6196bd92fb1347a7dacc197bfdd3ee38a15531061c1c676e62cd3fbcc5(
    *,
    canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a283fca5f047250b78ee659e7283fa61747b7018d37b0b422c430747d01f913(
    *,
    canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccd6879029d47ebed2b58c9c228eddbb14659c6361e54cbae121381d7f18599d(
    *,
    free_form: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DefaultFreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DefaultGridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e403ffb5c19c681c045174a81d25ff01a2874ed06222dd75de5c0c5a8c79bd48(
    *,
    interactive_layout_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DefaultInteractiveLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_layout_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DefaultPaginatedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sheet_content_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac8f28333d56a49b1a7ff80996141774addbe5918efe5beed9dc667c5279c13a(
    *,
    section_based: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3dcfee6c8538e7d761c04438cebb74e4e7ed6fcb262a6e618ed281a57c2f19e(
    *,
    canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d374fa1285668b208daffce1752c0a4961f0b534d210ea802c54b5972ecd814(
    *,
    custom_values_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CustomValuesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_value_options: typing.Optional[builtins.str] = None,
    source_field: typing.Optional[builtins.str] = None,
    source_parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe4ceafe6990c62b955d1f2778daf12dd56e699b8309df454e800604764c3cae(
    *,
    categorical_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CategoricalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    date_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DateDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numerical_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4947d789cc9737a6dab74bb656fe63d9f81ceedebcf40ea461bd90d0c5a17cc4(
    *,
    label_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5913ecbf59f0e780db8762b39235e8ab3be1b522e778ff304bdce05d96ae108b(
    *,
    arc_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ArcOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    donut_center_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DonutCenterOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__856a3cfa51fdf6fd0a7b8e58653fcde341d0412eb229a1aa07c9fee095dfb8bb(
    *,
    category_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CategoryDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericEqualityDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TimeRangeDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b2f5242b0fad4321f93ecd6642d88e20c5e2f38b7e84dedd5e283ef1d6106fe(
    *,
    select_all_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a76342c977b70befa54135e482bd4ad163e8704a12cde4861b8a96705d34c29c(
    *,
    default_value_column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    group_name_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    user_name_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f01ba9a07d855673258fc9f0387691820e38b72f5d04cdf9e3fb642f1fe4d405(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0535b9caa7bc0f5989529241ee57902786b9337c53a6525ce777188e2f1f3140(
    *,
    path: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__276f1c6f517b23eee62d19a3ed4cfb00a0225e807e7f66f05bc1be5bc4034fae(
    *,
    amount: jsii.Number,
    granularity: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed45f7d11a6f3c5ae74c5635e384418ce066e31c93371f318e952446e1f4b496(
    *,
    columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68a0f1c7b932b1e67f02418900d17f9cb2dcc1927dbd48fc4b8442283f17292e(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a10f24a03440d898d5e89d497d328b00831653b62a278324ca65ca96ddef52ee(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bffee76d2a25382c4563857c2d117a3e343af4b5170984e70a4029c25ef415b(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4566d0f5217b4da258276dd2b03d857cd25b79021ec0c15930330aa95a4d5536(
    *,
    aggregation_visibility: typing.Optional[builtins.str] = None,
    tooltip_fields: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    tooltip_title_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58bb42996227cf98d7d838c3d86d09bd7875d5066358c6de757946154deb0d41(
    *,
    field_id: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2467034994483dc1260912d3f4e901f62134b0c8503bc62b87ce3f0eec2988b1(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca35aac02d97e7e66cc2ba4caa3b2188f0582b5d9ed67390cb85dcea6d850342(
    *,
    column_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26672b93e4548bd08910decb70adfecc4e08a7d34bc9af4ea3c7c1620201882d(
    *,
    direction: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51dca7939ab3839617c9068d3b2e2772d946aa360f4c94b587eab7e2a155a218(
    *,
    field_id: builtins.str,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__124b87657f930b94dd2a4ee74a847b2c3e1868e456c7e472be2f83d17b6eda2d(
    *,
    geospatial: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a11bbeb9f1f70cc4b58792bf02d9aeee8b2c614d6aef772c7b8ccdc01acb953(
    *,
    shape: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilledMapShapeConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b37b8ad4c92decb9d6abbea55fc2892bfcf59d813167d0a34b52950979738848(
    *,
    conditional_formatting_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilledMapConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__996c9332d7d22db081ea7ad249fe18d03313b8cd55383d7995c8818b84cd18e7(
    *,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilledMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilledMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    window_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2aecc0ee208c4837c9578033fe84882b65e3bb7a222f33665c47e3a27834382(
    *,
    filled_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilledMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64deff2cc8940b5e9c20d128e696aeb0186446210b1b99a76801ca45d0e2a67c(
    *,
    field_id: builtins.str,
    format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ShapeConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac6bcf88085744d1ecf9b8ad78f5c961fd1bc0f5afd538cbc9828f315405b4db(
    *,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__747c522cff2db38ababdc616ca416c1f0bbaad3e5450ed686d29cdd222a8604d(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilledMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilledMapConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__638913be2a432dd85cd6afd0eaeacc1be67b527021857ba46e789a7faa792cc5(
    *,
    date_time_picker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    dropdown: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterListControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_date_time: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterRelativeDateTimeControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    slider: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterSliderControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_area: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2645a3ecca348bcb6ddd9edaf7dece1a230f6d8ef50e8a54cdfcd48919bae1b(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8125d83669b486dca262ab91b9a18447811457c9a61f158fc966fe7f4f9be58(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85ac1a51359f22ce66c29219edc8464ca7c29007b7250085e5e2b607e5c124ff(
    *,
    cross_dataset: builtins.str,
    filter_group_id: builtins.str,
    filters: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterProperty, typing.Dict[builtins.str, typing.Any]]]]],
    scope_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99b532857c54410a622c4589e9ed6acd5be9f710cfad98df0d88123cee396ebf(
    *,
    match_operator: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a5ca20cbd17c4af88ec327e1e7f8c9d4aa7b250b3997e4d4a07cd42c97687cd(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7625ab1e3e46b5936967088962fd07ac0966226e89e6b562009e24983323d0a(
    *,
    selected_field_options: typing.Optional[builtins.str] = None,
    selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06e18cc8085d97db1fd90a4d3b00dfab05c2b3cb99e4899a96f99e3a6357e89b(
    *,
    same_sheet_target_visual_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SameSheetTargetVisualConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89bd72abe7faf3a55676a07daf0572aa02eb6aa4ea3f1d80043e055b7e1521a6(
    *,
    category_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CategoryFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_dates_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RelativeDatesFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TimeEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TimeRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TopBottomFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd7bc988e00e114a77db48e3a49a92f914acb22ce6b0f3317c49a738c447e11c(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__acfbc829249d0e2d5db2925ff199f08d175815f54b4cf1b3106b632835eaea83(
    *,
    selected_sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1370fa00a8135bd20b225e968548b8f64bfbbcded4a9f7099a4a497f24444b6e(
    *,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd38e3f62eb6ca1919347327f33cd1f3445dd4a52ffa44382ce68496a8e39bf4(
    *,
    filter_control_id: builtins.str,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    source_filter_id: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd8d6a90a9ca3784ef0eb38d6cb93516cafd14de57b6e60118bd613495a53a96(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8fb6ca0c2232cba9adefd93cc8c6a3df28d2e005d6d45c845c3461f48597db9(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f64367ed66330789e99449900860951714a003772dd9941af443a4859df5ef3(
    *,
    font_color: typing.Optional[builtins.str] = None,
    font_decoration: typing.Optional[builtins.str] = None,
    font_size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FontSizeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_style: typing.Optional[builtins.str] = None,
    font_weight: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FontWeightProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2eea1ec2fbf52bab3ad89eee77400ba28b6e629c6263b37206191a44ca98d93b(
    *,
    relative: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f171ce2bb67b344733a663777f1299d8b94d15b871ed1d128555f582b4470eac(
    *,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b377e4d88f9d0de22a5997638a597b9ba6d2086e6caf6ab68bf0ac44f82056a(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    custom_seasonality_value: typing.Optional[jsii.Number] = None,
    lower_boundary: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[builtins.str] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__724d72a7b8bc74c6cdf72583a7346ad5a950425215c7dfc02627c737ac60587e(
    *,
    forecast_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TimeBasedForecastPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ForecastScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c296ec190aa9cdb0571154df2e357ef8d8a9b2f48b30244eea677fd1f6a928e(
    *,
    what_if_point_scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WhatIfPointScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    what_if_range_scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WhatIfRangeScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f54ef847cd92ae8b7ac64700c85a30cab90d672ef84f495f1a11c9b2bf7c1c34(
    *,
    date_time_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    string_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62cec2b8ebf236742f1b0a291d056576356344fb822aae5b1c372b9d04cc938e(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d9ea4a9fec0940ab21cca4f3917394d97661c47fc396bc1e5d698aa0184714d(
    *,
    elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c5a2673a45fd2cbd3a3374234e3722b2a63b142f708cfaea0d421f2ebdbc240(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__595fb28c4e3087a61773e5e72419f87b168dbff612a5317df0d52fb93599bcee(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4f8ba3241a3ca34d8cf51c1352ae6e3f51bb0086d05b866e1272e2c1433fbe1(
    *,
    element_id: builtins.str,
    element_type: builtins.str,
    height: builtins.str,
    width: builtins.str,
    x_axis_location: builtins.str,
    y_axis_location: builtins.str,
    background_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    border_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    loading_animation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LoadingAnimationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rendering_rules: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SheetElementRenderingRuleProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_border_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cbab328a90a7fb5b0d47cb2374a56f053e12880e40460bef814ebfe31f50e4c3(
    *,
    optimized_view_port_width: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21e4e9cdc9e83a7a30a1a852d62a2718fa5000015bf1541d7fc978b0b357f427(
    *,
    elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f4d7bfeeef0ba1679d4e04422287c3591dad73890b895061605857d2118435f(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5408b7ad9c45513c79a9c7d27fea9824628e951b373e1b8eb6d785f48225dfdb(
    *,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FunnelChartDataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FunnelChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FunnelChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__deec2c3cb1679f33656cc892f4a326aa310e0b557ed24e418324bdf7d74127d1(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    measure_data_label_style: typing.Optional[builtins.str] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__139945867af8c199f2cd2a07a16e0ebe15aeec4fb5a3481a070a36b77f6fbdc6(
    *,
    funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FunnelChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f44cac5696d984fa70bf7a48b3b626bac9cf4b5825e2ee7be3f97c62378a226(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53ba8e52b9ddc401c0d395c8b95aa21641efa1bddf68e8f93b0beae95a4fd62f(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FunnelChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4241990415d6140f5e5b81a7512dc7b0160a7360ff50b9829ab646c913e14152(
    *,
    foreground_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e44815dd5aab0a29d8a5c53286496eac76c122401332c19f768d70aa3f950daa(
    *,
    arc: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GaugeChartArcConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a61e2ae32b891e0a58ad40885a0a916f9b545e9ae253aeb96e98001745b4e90e(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GaugeChartConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__518f0635b23232e7714b54ea6bad80445809895698428139769dac9f1fdf38ff(
    *,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GaugeChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    gauge_chart_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GaugeChartOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__012cdfa537531c16ce8b36202c1f22b6e72cd76df5e86a0ae86e2d27d7e2106e(
    *,
    target_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88aa13a7a43657b84ac0b776d9f1af13953d656c06193b62876d790c9227b6af(
    *,
    arc: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ArcConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    arc_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ArcAxisConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b88947d77af9cf63ba6024b2f31c265f286ad16839391a0b6331462402b0237(
    *,
    icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3411775a2b530ed4e3c05acd4c07b5181957cc7bb4752c78b4a8ac933cccaca(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GaugeChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GaugeChartConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac99491030b0807af0037a5ad5daa0bca2a6cf96a6e379f361d50d640c230573(
    *,
    east: jsii.Number,
    north: jsii.Number,
    south: jsii.Number,
    west: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7dcb38c8a85191c9d0004754cab5a8735061556fa8d072df0b1f6547f3a191f(
    *,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    geospatial: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c14adcf773cee098865e31a68b60b4f0ecab765bbc7bb64deebb110acf6ae72(
    *,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GeospatialMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    point_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GeospatialPointStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    window_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29922be5190581199130c11ae1faf2a5c909b33547f7636faf7676808058dd53(
    *,
    geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GeospatialMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6e345279f7b64bd21f34a33b3fa16704943d7f8f291612a2c7d7cffe530bb7c(
    *,
    base_map_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5dc93630eabb85f7097df1672b181209066fa6075895cce2c27ccd5995a7c9d(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GeospatialMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afb401aaad1f5765ac0725c2bb3b394ed33254e1402c955372a938bd6b6ac71f(
    *,
    cluster_marker_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ClusterMarkerConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_point_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d85b0a5e8f407b25d63a044e9f7c56aa0fd6d813f8eacd99b9ccab13b690ec58(
    *,
    bounds: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GeospatialCoordinateBoundsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_zoom_mode: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a111a028e4e373bf6b153cc9e7ddfd0d48748c3c8cb03c58ebdf973d8186672b(
    *,
    side_specific_border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableSideBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    uniform_border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6569b3e687726ffd2ec44f7cccf9b73a024ee554aefd1c2d61235c0817234ad2(
    *,
    stops: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GradientStopProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31b8913c1550b3161634d74315447236aa93775569e3ebf10bc20277c7dc8098(
    *,
    gradient_offset: jsii.Number,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59ed64ec30102a49b32ca0de986dc1a255874ba13b16c4128472e5a24201fd94(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25e79f0995231f07cc7604c19ae4b64138d7ab43ae43d1a7426e10ff5cceb34d(
    *,
    elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GridLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4656d0cc46048a4966787bd769655891d81a14ca54e0da674f1f1a2a695d04b6(
    *,
    column_span: jsii.Number,
    element_id: builtins.str,
    element_type: builtins.str,
    row_span: jsii.Number,
    column_index: typing.Optional[jsii.Number] = None,
    row_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f36c3d22c910214e92790af15fdbf3a7521edd7f92d1dc2716a24182a8e2ceb5(
    *,
    resize_option: builtins.str,
    optimized_view_port_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78065b3da7f69fb390247444625913ea4ec553083d9f4e5e49028bb21b0dd795(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
    period_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10bf56a99f06c2e750fef7609aa2bfcd4b962017a3b839333d1b823c75cf48f1(
    *,
    layout: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    section_id: builtins.str,
    style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__905e5108acd3f80bcbcade33df12882b36abace985665223c74802e4f4d2f668(
    *,
    columns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    rows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3e085ccbf88c505d886f8127b672298ff84a37bb2defc186f4d83fa9a5354d2(
    *,
    color_scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.HeatMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.HeatMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49db0c7cacf1900534e141af92f8b1ee74ec01c4aa33fca8f3fcac6d5f8460f4(
    *,
    heat_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.HeatMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bdb240bed35e11a045da0931685e06eb777e6543403b8b81a52b22f7e93697b(
    *,
    heat_map_column_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_column_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    heat_map_row_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_row_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91b0c96a8fd040f3d935852ee29ec9388fe499dee89d8698ebda8b8ad2b4e4c5(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.HeatMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa3ec08d0d89c7326d6d34fc2aca2945cd97d2bc2cd1d773eef53a4c6e6d6e50(
    *,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cea12c7bc0d5099097d55ef1d1b393001a79f635ff351b824100e88bfa298be(
    *,
    bin_count: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BinCountOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    bin_width: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BinWidthOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_bin_type: typing.Optional[builtins.str] = None,
    start_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e4bb3c456b4405dd12258013a7caad37961c277da2f6af995b1951408045e74(
    *,
    bin_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.HistogramBinOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.HistogramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f18ee9f204a5f8ca2cdd03617839e27b1e4498fc2e743ca018bd748bdbd4d8e(
    *,
    histogram_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.HistogramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__173a0e903c915b8af6bef920ca6058732a57faed9507934001233b9350507a4d(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.HistogramConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__affe719870cf0c48710b52c2c6a04f55bfa82f21cc2e4b51b7e27f01aa7770a0(
    *,
    computations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ComputationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    custom_narrative: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CustomNarrativeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1dd67632e7bf9691eec7fd109f1d8427f8450fcf3aa62bb3aac701c9ea82322(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    insight_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.InsightConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e860b6787d414805f9b5f613e488cba4714431dcc13327b82a68381e067d90b(
    *,
    dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__544fd6b0b310771ff81431324ce78c2d8f6bd09076cfa015768965f7fe75faad(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.IntegerDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.IntegerValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e017e02705585f127ebd6a015a673849276d812097d8afa252fe83b8b5b37523(
    *,
    name: builtins.str,
    values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b1732c34725421c2ac841ba89cd8d0c1821902cd50746d9732479a489e6c07d(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46e9322cde94a687e884360de4a35524408301ffc0786d1c1f03a883f1a172c7(
    *,
    items_limit: typing.Optional[jsii.Number] = None,
    other_categories: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2cd4f36fa7ec92aab42bc94d1e9fac0efd0bc7761a06ebae83efd1cbf20eef5(
    *,
    primary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.KPIPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    progress_bar: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.KPIProgressBarConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfe176f10420499de6970b5078bae08aeb2c1c708231b6abb04cecca6c3649d4(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.KPIConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c86e64898123333c9d25543485bf0e862ca268b18f58940a86e5a5f16f013349(
    *,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.KPIFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    kpi_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.KPIOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.KPISortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2956d0e8ea8f5b11724b98b11d7539a6c2e0740548cf63214600799957cdc7b4(
    *,
    target_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    trend_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26164f41afbc23d393de4bddae214b784aa4a2be17a32d85af998dee7a4d1a32(
    *,
    comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    progress_bar: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ProgressBarOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SecondaryValueOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    trend_arrows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TrendArrowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2c56f21f568775e305a40604545dd864e7aed566a67e464a53ad25eb8477f47(
    *,
    icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9c68cf9b07ca4e0204f629c3dc908629c3c5877cf110accbaeeff9ad90e708e(
    *,
    foreground_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc648f3755fdd0295addc24c77de2d7e787b093333415aafe9d6d26c31326867(
    *,
    trend_group_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7d2cad00eb0b20203ecaac5c537e86b9e33355eaf6eac9b2943240b8e6d59d4(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.KPIConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.KPIConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5a8ae3be2f14e0382c5a15b0bc4bf41d5a57498292b9e6fa3ae28fe6a4e1035(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a7e5ef2561a6940f32619f7f9b76babe27b8e5666916e6e9ab7d5fb690bb52c(
    *,
    free_form_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    section_based_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1a52815ff01f8fd11968ba2674197b875a49f86c9002a0e6ffe6523a744088e(
    *,
    configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__457d195138ef98557536be221172d9143210e816434299b08afd1dc6156dd3eb(
    *,
    height: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cef69be20a2746dd8949b5516fe48b2c2725b53f2cac8caefb14114893d85f9(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a892952e5d3b964365a23c610d4f553bb574216e1e4421b79e0fff173bba181(
    *,
    contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    default_series_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineChartDefaultSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    forecast_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ForecastConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    series: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1c081928d7b9ea714145550f040f3c877eae6edc4f4f20264a660377a97221f(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    line_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    marker_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__172f301c86e1a7c92191e528a6d7d6c9e9671bc7606f66b31354b15725b81cfb(
    *,
    line_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b711ffa2915c7a88d8f710a3621cd73d0efb30eed7245d0e2eb84e4e24afb706(
    *,
    line_interpolation: typing.Optional[builtins.str] = None,
    line_style: typing.Optional[builtins.str] = None,
    line_visibility: typing.Optional[builtins.str] = None,
    line_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4725126ef49f4c2567215a3e21c4fba843312dcc86398b3fe83b8429d1e8133c(
    *,
    marker_color: typing.Optional[builtins.str] = None,
    marker_shape: typing.Optional[builtins.str] = None,
    marker_size: typing.Optional[builtins.str] = None,
    marker_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66cd13c303f456a7ea2ef4c2b91132e4cf81505ac369eff2b69c9bfd2761ef59(
    *,
    line_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    marker_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__764e6a41134c95d4ac3b4e56bf2da11057f640be48709dbf62101ffdc389f2b6(
    *,
    category_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d0e111b8e1938c8e8ecc91729cfdbaea698e7682cbae7467458b54c6f0cae4f(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4623b05c5e5c6a51b638262226fe6ae5069cd1693dd9ba599e3811795e7fa386(
    *,
    axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    missing_data_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MissingDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dec4ab4bdb035201666ca03bb1d93ccec4be31ca3638d94656e37a7d6fc67947(
    *,
    search_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ListControlSearchOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6f2755d888fe7114eed3ebd23b1f47ccca7ee4d0af4fe84eead0ac9c4668750(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__899280bfbc791b382837ead1af8dfef566cb5459acdc5d82ac6ef672cf64c903(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e28ae8cdac50e883e022fb266b0ec43b35432d5e783e22f9dce7fdb7de78c4f(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fbb8ec48d5d32fc163951cf3788735b4e5d2e56e24f95cba0aa95300e7e5ac4(
    *,
    target_sheet_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9ccfefd337bfb15d687773b0f08c28214a39d4273588db52719b29b61a58a2e(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__623aa7e3fd86a3f0e6e3433861d275f12d938f74238a42e56fd4c83df43a4eec(
    *,
    data_set_identifier: builtins.str,
    data_set_parameter_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22dabc5578527cc57631a32da1be46743acb90597a1d9ecfa577e20f33a407e6(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24f5e127ac1b17e5666d3c9ad8db9244d75f2e569e1c1f7ddde7d5f62e108b43(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe21f3c3e64400211fcf6c981975acbbe1ee857fe98569c63ab316fc70c7e5b5(
    *,
    calculated_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CalculatedMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    categorical_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CategoricalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    date_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DateMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numerical_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3b6f953b061d6891f09a69182d9880c876e370af3c08793e66bd9b362722515b(
    *,
    computation_id: builtins.str,
    from_value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    target_value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__232a4bc118496c7449cbdfd8d5bfa056794e178620e0f6a1e3ca5037ceb702e6(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c359da2ed53558c7fb51fcd2d47fb0875148a5de874b02f784a27282ff58456e(
    *,
    treatment_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c2e9c144eda5d09644c4292d203063382539ad3f3ba07ed9d2b570e595744a8(
    *,
    display_mode: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__709af1be6ed083c0d42c9aac226d217767796d5f56ffda82dd258f78506d1464(
    *,
    null_string: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef9dc00324bdae1096d6bcb32da0ffd48ba9b31b60da5f416445b90b050a1346(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0da159b9af4bfcbf185b9a476447c9397077b644915d1fc486a65d64e79aabe(
    *,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93695b688ebd486b486378a566e96f721976cd5a9244e6100dc6d2e5db3ea47c(
    *,
    range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fb28f487b58c66510a4ddcf57462f4ba11db7a6b038ec29f33ec95680a27908(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__070224fdacee8cb941a68519353b4984445aee007deac4994ae85d1b4337135c(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    match_operator: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7aff34c5ff3a3a3a2e631d57047a938747aab0eaf54834b205c1c427218a5945(
    *,
    currency_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CurrencyDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00dc5a36aa55956ac3070093f10452d21427698c007c768af3717d587082d0d2(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    range_maximum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_minimum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9b485a539778ef7858b497857a4341a4941e605cfc2c3c0956fffc06a85ab6b(
    *,
    parameter: typing.Optional[builtins.str] = None,
    static_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37e5a6471010547133725092c7de33169afd9289904d97a095a803d4a2c034bd(
    *,
    decimal_separator: typing.Optional[builtins.str] = None,
    thousands_separator: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ThousandSeparatorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3949f7370aecfe7f50e0927274ec2baaa769d0915cdb7d80c82a513090787803(
    *,
    percentile_aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PercentileAggregationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    simple_numerical_aggregation: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b90c02598175a5004a822765b4b674395adc4dc416d5c7de3ebef69205112dcb(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__112163e48c0afaad6152a756ea8acc6ebbab557db814c6b5b1b67f694eeaea02(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1ad64f06ff3f4b3454be13e3ba249e846ba5cfd204890feb74aa7df2ef9f302(
    *,
    page_number: jsii.Number,
    page_size: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87b20a3f65053e5a1cd31a84f88c0f865031099d3ccc66697c5510c20e1cfd1b(
    *,
    background_color: typing.Optional[builtins.str] = None,
    background_visibility: typing.Optional[builtins.str] = None,
    border_color: typing.Optional[builtins.str] = None,
    border_style: typing.Optional[builtins.str] = None,
    border_thickness: typing.Optional[builtins.str] = None,
    border_visibility: typing.Optional[builtins.str] = None,
    gutter_spacing: typing.Optional[builtins.str] = None,
    gutter_visibility: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PanelTitleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a1e8c8be43617e4e3408c201486654634d4a3bc28b9b30acda399584e7d9dba(
    *,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a8b6c6ebcab4c33e9ed7f1f734fec6d6cc444af360cf064c8a7aa3708fd2743(
    *,
    date_time_picker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ParameterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    dropdown: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ParameterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ParameterListControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    slider: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ParameterSliderControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_area: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ParameterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ParameterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de54537ba5d311f111ef4e81447a2ef53ec14146e7dc44b6516eeb16cb1660c0(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a083a696c7791ed4ab8ea02b669c15cc31f11683b796b84999688dee3cd1fb39(
    *,
    date_time_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DateTimeParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    decimal_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DecimalParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    integer_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.IntegerParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    string_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.StringParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__daccf08b3207be15007e2074e14839097c25b786f0f0a12a2eda07e64c0101c9(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f14159a5fef32514b49dafbd4713dc4faf6ec18a11fd4371b02233e6553f1ef(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb01b988bff788d74e9acce5f7c91cc2670848ec7eb27abd81c926345b73d4df(
    *,
    link_to_data_set_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d0f111279ff98cce9f0b571f568610df84051cd90b754d0a4126413eadd375c(
    *,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa2d65d57d16808f046f4958c9cf29e827410318e2a15bccfd9f430f441a23c4(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0695b9d702738315e549f7ae7ccb208e53a61a4ff6ba727a0cdefa8784a31e52(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e801d31157867bb4e87c8b3c5eeb3d91d9ee18ac67d2657fbc8f67d5a8516953(
    *,
    date_time_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DateTimeParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    decimal_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DecimalParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    integer_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.IntegerParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    string_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.StringParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1fe12a56c3d69c1a833b48dc6b93155c248e4215a4c2b66ec83b015b31528e5(
    *,
    from_: typing.Optional[jsii.Number] = None,
    to: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c900ba075c6cdb7f7817d74443a701c555d9081605d831bd90935a9142f12830(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17313aacb157c49fd09ba4abd32b5a061bfe636fd5f520e98efa18286998fba3(
    *,
    percentile_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b292bef098d2b19225fe970f423987eac05d23493cb7a9ce95da7569eef35e2(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4172bb670257f633b308cdc57cea26daeffde6ff5f1151ecb135f23d9083181d(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
    period_time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cf23556ba715122589b258a1b727e5799b5263237d8d1d9aabae305afdae409(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__598e9566ca61de8bfb4861e8f49f604f3e551f1d2368ecff06b79f71ce802897(
    *,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    donut_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DonutOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PieChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PieChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4c74c8f35e0c86a08b7d82776579a4fe8b241ef3094734000efdf8d8a794e17(
    *,
    pie_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PieChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be0f3c5ba8c55f9fa1486ddff4d5c670d46f170a993c7279f79a927dc2afbd0a(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8cc3633e31cc4def7f1bf2cc1efe5ea1ba4d98e6ca38b3a4126adb78de558d73(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PieChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac44ccfb7d82c3943c56a9b0c1ab237c2121845ab81e1899c55f977c2e16988f(
    *,
    field_id: builtins.str,
    sort_by: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableSortByProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__670516834385831da5995a92430f9a7095f5732df6d3311c9a4e2aa8c8707755(
    *,
    columns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    rows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71d76ebcd65857eeffbe9092be812c030914a27e1a2283e6d5b611da3e74f716(
    *,
    field_id: builtins.str,
    scope: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableConditionalFormattingScopeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc3d02e6ec41ddb4a4853eb689178263427e67b05f2f6790ccabd2503086303e(
    *,
    cell: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1263dd696a94a30fb0c672391f6307b1a6929b500aab65430b5d3bc0331a91b6(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0f3cb435b34bb7eb5a69c898f6eaf4590467291668e798aaf9df8eb02f601c7(
    *,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9475faf3468be8cf868e1682bd98a04641e58326bb87d0ed0d69ed4a6af5dfc(
    *,
    field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_report_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8fce886a46020121b7b5568e99d9eadb1779bb40f3f323c3c48449883f51a077(
    *,
    data_path_list: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]],
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a4a95f2eec36c28f6022e2e12048bc8f4c4e92c4a8b16ac0093d3a23d80aa28(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10f5aa2b5aa360e22367dd6e48fabdd8076de1d8cbcc9d415f097dceb1659dbd(
    *,
    data_path_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableDataPathOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__162cae8bc9ba979d41cf4b5aff6d7b3e86a1efabfaae333ecfc9a6ab87128362(
    *,
    field_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51b4f39a41063f41162a82fa1ce82d3a7b1331957efeb9fb38d66781b3323eb1(
    *,
    pivot_table_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5086005b46a28ecab863f87b69d84c42fbe69b279fae60aa95664e02f9fc3dff(
    *,
    cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_names_visibility: typing.Optional[builtins.str] = None,
    metric_placement: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_field_names_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    single_metric_visibility: typing.Optional[builtins.str] = None,
    toggle_buttons_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be9123e222eb2e603b1e13a4adbd3b18cd1bc4458e5cfd878e441abc68173a13(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ba052f8170574466e89792216e47787b147edabb6353a5e26cd79d4084dc99c5(
    *,
    column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_path: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataPathSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29e65dca3cb34f20fac9019fd52bce4f032c0d38831b1982395993ac2f2c8579(
    *,
    field_sort_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotFieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b5edd8435efcacbe02377d5357408a0ef6a130e3a370795fade30047bbb259a(
    *,
    column_subtotal_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_subtotal_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c09498405ea1b89865d374e29aba009f92cffaca5ba8d633c2b37dd49305e3f7(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62de868ec473c5969a1307b612416b2e06147143001a7aa732b02ee24b684481(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    metric_header_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53411431a7530b33c110a0ec28c99f4a4d39badb1bc98e24f83f4504f3ed9585(
    *,
    columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f014657199a848b835662e56e412b8219ec579e77011d666f52146418ef73641(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ddb3b4569b6e0c0788645e4d6b0b350ba60ec4de7b73c0ad111d916f3b488dc(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50ebc1832171cf6c141996712539bdc171409f707552ecba2487b68286025ff5(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57421022aed140f345d8fbe862d77db1662af50b2d9bf8e17d71f9f8ff30f26f(
    *,
    alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
    alternate_band_even_color: typing.Optional[builtins.str] = None,
    alternate_band_odd_color: typing.Optional[builtins.str] = None,
    base_series_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RadarChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RadarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    shape: typing.Optional[builtins.str] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RadarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    start_angle: typing.Optional[jsii.Number] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7b517550201684c2f7bb281cd2efc6c818188c1cb060fe9ae0752c5d21fc2f2(
    *,
    radar_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RadarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1c9c358d317fc830ff5bc41f3330afca57117ffedca2ea6707b3c2139b9e174(
    *,
    area_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RadarChartAreaStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33a1d6c821d1ad2098556388c548cc2fa196b6a47e23ec2de073532b4d99b67e(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__800f0c0a2bb1b43b6f8925c808e413ae0341f5bb828469887dcbcba9c266cc13(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RadarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49b5320add42accd7f4b16211a28380fa778db728e2f64019ea38b6997765a8b(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db0148d083b5cfd73390e4a1b6162718c9ec089d0f0f61186eec69ee1316e966(
    *,
    custom_label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a900895fb28c03478ed18adc5778239cc168ff94454a45e9bf89480e34a9bb68(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    dynamic_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ReferenceLineDynamicDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ReferenceLineStaticDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f972163ab4e6da0e0156540c2726a32d33cc763969a456a99681aa001834c000(
    *,
    calculation: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    measure_aggregation_function: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4c6a5c24c35813040d50db47b5ed37d6fe62801bdc54a0cdbdfd23ed613c66d(
    *,
    custom_label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ReferenceLineCustomLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_color: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    horizontal_position: typing.Optional[builtins.str] = None,
    value_label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ReferenceLineValueLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    vertical_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc532f5c60946873a990efcca7975ccbac9af85568478f4e0e93d1a82169acac(
    *,
    data_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ReferenceLineDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ReferenceLineLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    status: typing.Optional[builtins.str] = None,
    style_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ReferenceLineStyleConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41f77029834ba03165613ef83e6babf8a4aa9a1846b9d9b4ae81645b0bc8b74f(
    *,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11b23d9b31e4b32eb5341c645768a73111a971d437fe706d617a993e70e9bb59(
    *,
    color: typing.Optional[builtins.str] = None,
    pattern: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61f15c1801bf997d8255231baadefa64b0db477d03917635a86d71748b92012f(
    *,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed5115ecbb711a040d26610e998222ada8d5d5efb6b2bc8f781499edd9f942ba(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d77437279d4aca9f7446b375bbdf5e7248d78d1b935ed06f5facd24d4d99be2(
    *,
    anchor_date_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AnchorDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    relative_date_type: builtins.str,
    time_granularity: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    minimum_granularity: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    relative_date_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__711590988b63a980fbfcb7b39f0426b1112d69f6dcf65a7331deab71fd531967(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
    resource: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b57fd8837c0f25075c2c2108f044d8b01e8beefc21eefc6e270bb9cdd9b5f5a4(
    *,
    expression: builtins.str,
    data_set_identifier: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c1945067e48d0aef31beafac083801acf9e668d5d271ed969e058cf99aace27(
    *,
    row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a054d913d5883b9e5036c1d1ffe1025585547308643ebcc9cedbfcefa28873da(
    *,
    target_visual_options: typing.Optional[builtins.str] = None,
    target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffa5b76350a19df844df5c1bccf4c2f17684785cf4f02032f28af790a8277241(
    *,
    destination: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    weight: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f99955d76470f4ba9e98ec70bbaa94637bc914c5f0125aa26215785f2a65917(
    *,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SankeyDiagramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SankeyDiagramSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57c98cfba033cc5d94a17b04f6c0a15beeb496fdd250b78862ccb328deb8fc28(
    *,
    sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10ac1d8f38799d1bc851711038bfbfce586b4ee8858e57b10ef8a3bc32f7a783(
    *,
    destination_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    weight_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5238fca670d5ba3d1c572508fadf88f3f727a4097c764da5c690a04650dcfc3d(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SankeyDiagramChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5036b84d4f522624e8ed4d6bb544ba8e23ae2ea7aaefaf89e1a5b0dd88a7662(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    x_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    y_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65b98ca505ff882507fb3f8caf099818de6839f036e6255c550dc48367ce7c4d(
    *,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ScatterPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38a6722b8b62e4f094eb4d22225ed5e4f4c24fdc541524e48bd05fcd83a36a5c(
    *,
    scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2fb16b58554bc6aa41cf17168f436f8e10229ca44126a2fb9f0ae18523210b2(
    *,
    size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    x_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    y_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5aab80f6abe3c6cc7fcff1a4dc3e3ff7109e3433af28f239219ec7a4e98eb803(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ScatterPlotConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44dc6bc2fc3a6d533b939c06f8b36967a5c65cb0f488c2d8fc7c32356cf11b25(
    *,
    visibility: typing.Optional[builtins.str] = None,
    visible_range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisibleRangeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71663d3a4864e54e14cfe36def14006ca66d24b4b7260bef947090e1d8901675(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a400bbe8e0ac07338086374a2a35b92e2d7a825c289a334f56d7a4e237b2d0cb(
    *,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c347b8d2a56f5b34d16da46056b0696fc7a9b246ad51ea7b0bf684a8e32b2789(
    *,
    paper_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__560f6d75aea951cd9bae33bc6685236fbc64e8eda896b0f7dbef14d911e4f8d3(
    *,
    body_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BodySectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
    footer_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    header_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5795cbccd070ce84493464a52c0e5a6e23c2dca1182a37c291478b977a69c698(
    *,
    paper_margin: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SpacingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paper_orientation: typing.Optional[builtins.str] = None,
    paper_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2417d83a3f63a33577839f9e99c11da8d926f314d2e2da30fb46456fe626caa5(
    *,
    free_form_layout: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FreeFormSectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__885b2a451cdb41dbc2e52bbf3ccdff3faa033f24c503405d5b86a025c536541a(
    *,
    after: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SectionAfterPageBreakProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1aec607eec2e37f7bcb04fe04edf55b4603f62a87bedd980047b3b5a4d8ccac1(
    *,
    height: typing.Optional[builtins.str] = None,
    padding: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SpacingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93ba53f3b384bad98bc74a54934dffbbd702826949d9e0de289001e42430b7d9(
    *,
    sheet_visual_scoping_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SheetVisualScopingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81fb7077ac4bf734aabc0b73ae42244d481f843268367e3d705fa476eb6d98de(
    *,
    data_field_series_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataFieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_series_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a060ee5a2f3b98f16708be310ce8d517e3bcd8c3e17ed5d0c9c02bbfbcb22151(
    *,
    destination_parameter_name: builtins.str,
    value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DestinationParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1073a839c0eaf1b2810fb1fe6c32507b1c0bb93f0dd32c8d5bdf25cecfdf8aa(
    *,
    background_color: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cf52fe310a0d3e22adca96e74fd0a111b08e88da9ba1ae9834142e1a1e90944(
    *,
    grid_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c94bf2565325e683667b1bdd41f77a1e72194a3171ddff982e0d0e2370bddb33(
    *,
    configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SheetControlLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d6fff40196a8bdcd9e7c39c95596d68a8e619159c1cc287194e73ddb1e89b70(
    *,
    visibility_state: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__782ddc0bc21b686a40084341de2b13e7acacecebee2f7a56d0e1cbab9609b664(
    *,
    sheet_id: builtins.str,
    content_type: typing.Optional[builtins.str] = None,
    description: typing.Optional[builtins.str] = None,
    filter_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilterControlProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    layouts: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LayoutProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    name: typing.Optional[builtins.str] = None,
    parameter_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ParameterControlProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheet_control_layouts: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SheetControlLayoutProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    text_boxes: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SheetTextBoxProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    title: typing.Optional[builtins.str] = None,
    visuals: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12d604fb856810e239394e339e821cb79cc65ec8812d495834674fb63d78839d(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38a4710870e427213183005a7f1c1e59d0a9187b3b04a0a0fd98b3f522fe183e(
    *,
    configuration_overrides: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SheetElementConfigurationOverridesProperty, typing.Dict[builtins.str, typing.Any]]],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc5036518819074a06d7a3151ff1e712efe539c2953e683ed3619b3ad079a6ca(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__333486f3a30de91e0c5d7e6b054ab9b4ae92b3f2cf382eb8492c37cbcc3bcd5b(
    *,
    name: typing.Optional[builtins.str] = None,
    sheet_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83e625be22f11ff01c308938d355a75fb15011afd168c6c505f19161c7571c49(
    *,
    sheet_text_box_id: builtins.str,
    content: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28652a27a17131721fdc8f0f29bf1c37916eb4a7b301c11ffc1af5998fe853d7(
    *,
    scope: builtins.str,
    sheet_id: builtins.str,
    visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__baff6969f15680f9d784fc68e878bfeaa3a137c826de70edde66c3512ea04b4c(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69f0f89310e81b15a85d59f2164b6fac594deddfa9eea7c4bf4f0dbbbc9dd0e2(
    *,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6b8cf2a55f0f2b0350f5d3b3dd813441c8a4c962e64ab3b4c98465273993a49(
    *,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee822ddbed5663c047f90bceb2d1170c6b77a63bcfb32b2d330f8863b2fc151a(
    *,
    max_visible_columns: typing.Optional[jsii.Number] = None,
    max_visible_rows: typing.Optional[jsii.Number] = None,
    panel_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PanelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28c5f744484b45bef3b37db26fbc8965378a61ac42eca5ebae2515c4fa99ed4b(
    *,
    bottom: typing.Optional[builtins.str] = None,
    left: typing.Optional[builtins.str] = None,
    right: typing.Optional[builtins.str] = None,
    top: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a29da4eb4e79489a7bdc9c0487c0c66c7b95a41ba63269698b2faf8681512942(
    *,
    dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__336890f8beb864ee1828625e53126682ed1c452dc203d9dc8c8a73118408dc33(
    *,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73e1bebdac2fcac54ecdf8016957ccdb36a76fb284d61326c36f50733765b6e1(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.StringDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.StringValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b7899f4ea2e3384f878eb280858dcdad4fb98f2640dcbefe93dc1fb38a415ca(
    *,
    name: builtins.str,
    values: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4bf27e670c8ab8cd9f5635000c051662867f0ef04756fe04852fbd7e2c83aa6(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32460144ac18c67b2500cc2cd71e36cc2a3562251c9206c47ee5af61d427bf23(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    field_level: typing.Optional[builtins.str] = None,
    field_level_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableFieldSubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    metric_header_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4232af7bb85dfc7817677942d160a70d0992f7d41cbee4741d609846c5dca23b(
    *,
    group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09230d2948bab176f44a736bdcf6e0f7d47521f8bb5a3685193c15b5b2cec1c2(
    *,
    color: typing.Optional[builtins.str] = None,
    style: typing.Optional[builtins.str] = None,
    thickness: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e53c8a6faa417e001ef3a25750e4153c3596d230ce9baff48f52c24d053c58d(
    *,
    field_id: builtins.str,
    text_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a538b287e3253f9343cc93d027c152ce6ccd42012aeb09ba4debb048c5db8d68(
    *,
    table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0387cbf1eeb05dd9e5eafd513d421a9a4037e9c827ed855a3a1e758d1ea11042(
    *,
    background_color: typing.Optional[builtins.str] = None,
    border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GlobalTableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    height: typing.Optional[jsii.Number] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    text_wrap: typing.Optional[builtins.str] = None,
    vertical_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c89c50a0239a5b86d4ae4d4ff3279d3daa673d5b3383db932c6aded416e5c1f4(
    *,
    cell: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableRowConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f628cc2e0ef6dec361c6c34fe8b316d80322af1f12cf1c4b62dd56f5e752bc45(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa9f87c6d2b7059cc06f6b091f65851e6c96754cdceaaf0cd67277025424cf90(
    *,
    field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_report_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_inline_visualizations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableInlineVisualizationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    table_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41b359193fa1a0f0bee27cc10b6a79dbd80e4d1c07702e55cf8b6d50cbc1ff0f(
    *,
    icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8834fcbc2072daab606312687e5c87c6e9921b1bec4b767917bd93dc411b4d3(
    *,
    font_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9138732cd6647b0d882b40c89d654f1b358cad8a04d430a99b5f830a2d629c40(
    *,
    sizing_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellImageSizingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a71711eb13fd06de404b7c01ff20feea218d568093b09b13b6dfd14eb75c496c(
    *,
    content: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableFieldLinkContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    target: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__324efe0b31d54ab9ee6fe3ea97269ee0734e2e3aa49b4219fec40eea53f6c619(
    *,
    custom_icon_content: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableFieldCustomIconContentProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_text_content: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableFieldCustomTextContentProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97f349278b968dcd4327442e47afea23385a67b232a8a5d26b83ef802da296ae(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    url_styling: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableFieldURLConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__30c88b6b75a2cd95c5b4d04d305aaf5577ba01dd8108758443c69f8fac5e4a03(
    *,
    order: typing.Optional[typing.Sequence[builtins.str]] = None,
    selected_field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bbf7d8befe790448f950764aaed95eaf071bc724ab0c7988b33b63d01b8e69c8(
    *,
    image_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableFieldImageConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    link_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableFieldLinkConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7c677c4b8ab3f53457b2e128fa27878ba3a7fed7cabe54994fe9021c25b42a6(
    *,
    table_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_unaggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35faea7aa261d9e615c7576966277505f175bf43227655da5281b9b8fdde3ab9(
    *,
    data_bars: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataBarsOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f651a59d41595350fc39b334832442cd43bd78c088f65b26187c4af284892127(
    *,
    cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    orientation: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db0d119747653f2e41071e4f92dbf07d09aad84793dd9fe74436ead6c4f447ec(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac63757b4d1b1acfefeffe8e2aea68c11f3fff50de6102079b05995d37bc1588(
    *,
    background_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f077d91fcee57a49418e37c68e20e72616b32ac692fe583593d5745b12c8ad7(
    *,
    bottom: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inner_horizontal: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inner_vertical: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    left: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    right: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fac5ea5f39bfce15b2fd6480b14f210301b5272b83f0d66cc8146001f5dce6ff(
    *,
    pagination_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6872f396e242381ae70e064097d6fd47efc7251aca186d3418424e63aa02661(
    *,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.UnaggregatedFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ecd55a34fd01903a1b570f2c5c196e794a7f6cc2449b03759f2eddbd9abe92e(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5fb5b4c2130308950137f6933afe605d257be2047c5215f3eb419b12e2ca9b2(
    *,
    placeholder_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86655a9bb96d9d00709c755824fe5e791cbbde111387c852d0eb54253ce08a5a(
    *,
    background_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d817a588d164b6a2ac690348b9a8f8ff3c9311334134cf30f159d636ac1d85bc(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b0f2129e735e51df165e7d8ce03f8ed605871f06717e94142f33c64e05484c5(
    *,
    placeholder_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4389251b914d88133c816e4c4e8462fe6c018b6f0256bfbfc1831751da8982ef(
    *,
    symbol: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3d7fbdaef66ca353a467880c67f9eb05ed6f58b4a86a41c49bfa6514004f7ac(
    *,
    lower_boundary: typing.Optional[jsii.Number] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[jsii.Number] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a4797787fde8335c1b83cfd4ea833196e319a04d7ce5c32a02784abb1be474c(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d734946be06edbc08cf9adb841371548ec9016b664f125ffc777775f6da28d38(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    range_maximum: builtins.str,
    range_minimum: builtins.str,
    time_granularity: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38fefdcb0920652715bc4930da59005958690a04253fed9997d72f8261d453be(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    range_maximum_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_minimum_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76fa1292bb6963cb633bb10bdd7494f82119e7fd7ea99c30992078a79a4b00ec(
    *,
    parameter: typing.Optional[builtins.str] = None,
    rolling_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__741b197cc761f1a08cd066715d7e5eef2bf1831fa75d4a1af705d8aef3f426b1(
    *,
    column_tooltip_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnTooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_tooltip_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldTooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50a4936666b6d09eedf7e061446f16ae7aea979459277e79b13c2de4f033ffaa(
    *,
    field_based_tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldBasedTooltipProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_tooltip_type: typing.Optional[builtins.str] = None,
    tooltip_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d218be80d4f2886d7a7bde137e82babe3442434021260e45fab03000e6f433a8(
    *,
    aggregation_sort_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AggregationSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f3f3e929c7e32cad867295b62641c8fadc6dfb5223a53fdd0b439f867763455(
    *,
    category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    type: builtins.str,
    mover_size: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    sort_order: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3de31453d017b2641633ebd1e786e3ede9cb59e06ca82fc1bfceaebe586d45d7(
    *,
    category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    computation_id: builtins.str,
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    result_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0982dcf272f86829964a54f1f6033a586fb10f1f224629311404be2381ed3f2(
    *,
    computation_id: builtins.str,
    value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d4c99c30f8bc65960c70ff51133f0894e6f8c9fa5987f872477ae889db76fde(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb28a429f0b96f25dc530ce96a592cd6fc4ffd1075674cd3db2b49fd8fffe5c5(
    *,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sizes: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5539543240d8d04372eb0f7d1cc77e5ae44ef66561a2b1c438f096e067df8ece(
    *,
    color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TreeMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    group_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    size_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TreeMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f764447de40e70d37c628f758a7dc071eb3c650acda17c217ed8fd8d60e0c67c(
    *,
    tree_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TreeMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5acc257bf941d7b412243b3d8ea35034943d00f7c17c94d9fcc84604c58ee04(
    *,
    tree_map_group_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tree_map_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c56525612f55c1f0c8c4edecc14a1687c54d28388ae1030e28e805e9a1702c74(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TreeMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fdc21175c8c06eaa877b5f6ca2506c1618914003cc27d406312a3dee9cbb97da(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8390674c47fca9d1737968aa136c63a31ecf4b8b40aceb8f187ccc6f5f219bc5(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7f9b20a38922afdd0b6946675c62f0a6bf8dddee811cca96798237cb6237cb9(
    *,
    category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38e0a2ad5674e67bef9cbaf25875f9297a9ccf6b13974f9b3ea58bb976abe490(
    *,
    percent_range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PercentVisibleRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63f17db86a1778adb93937b159dbb1a06769ea47f41181dff93db4370cf671aa(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ee4b1b2a27cd7697dc276310fb9b2456719939802409181fd5b23ecf6629b85(
    *,
    filter_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CustomActionFilterOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    navigation_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CustomActionNavigationOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    set_parameters_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CustomActionSetParametersOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    url_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CustomActionURLOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb332f9a7ee79547c83dd4fa32eecedbc6dcfa7a682219e523df9e376dc91154(
    *,
    action_operations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionOperationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    custom_action_id: builtins.str,
    name: builtins.str,
    trigger: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__411879c5b4d62177901c623481811e12aeaa8b413c4463916432a0c33bd90344(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__453175ab972bb53876c5bbc8904e1e20556de33d2a61844606f24e988dc3fb0c(
    *,
    chart_color: typing.Optional[builtins.str] = None,
    color_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataPathColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca6ee65e1fbae9a2dbe9305f3576cad15a9eb14418abefc50c443a1a695d8dab(
    *,
    bar_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BarChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    box_plot_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.BoxPlotVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    combo_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ComboChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_content_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.CustomContentVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    empty_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.EmptyVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filled_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FilledMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    funnel_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FunnelChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    gauge_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GaugeChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    geospatial_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.GeospatialMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.HeatMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    histogram_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.HistogramVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    insight_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.InsightVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    kpi_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.KPIVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    line_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LineChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    pie_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PieChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    pivot_table_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.PivotTableVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    radar_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.RadarChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sankey_diagram_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.SankeyDiagramVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scatter_plot_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ScatterPlotVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TableVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tree_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.TreeMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    waterfall_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WaterfallVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    word_cloud_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WordCloudVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71307cc2eb08b52fcaef79cd23ccf8a829c8e2f4d4f476e324c76d122ec0363a(
    *,
    format_text: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LongFormatTextProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc5a4d621878252f0c90ceb29c65eedbecbad9e82d198fa0c46824d00f6673f7(
    *,
    format_text: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ShortFormatTextProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94b23983a945e5c5460da93385c080a39b3f5cc6b0bcd6aab582782968779cab(
    *,
    breakdowns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    categories: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2e39f796b4d5efe0cf85ccded85d3787ff12ad4422a20ddf7fdafda5aa3c1c7(
    *,
    category_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WaterfallChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WaterfallChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    waterfall_chart_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WaterfallChartOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e1e1536e0502044923a7bb00d2207b092155324914a13d283b4af95c547c6e1(
    *,
    waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WaterfallChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68f0e6f3b930c2e4dc9f161ef957a4557be781c457a5d2592b529acd754872e7(
    *,
    total_bar_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1032239ee2123c174cf348f5651e9c82780602915c2681ba5c51008755141a45(
    *,
    breakdown_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bf99ef8eb221a762bc001504748b5b5b1b1de8c4a78124fda5d3d4e8e04623c(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WaterfallChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35306bbac6a3cc00fac0833c48aa7384fff9d17882a2cb4b0d6100bdd088bf6b(
    *,
    date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb70978253d83e33fe234addb4f9be6221ef7ba5eff60ed7d0c7c57f401ec04b(
    *,
    end_date: builtins.str,
    start_date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4f623199b3edb88b5a6da0281fdc764308963fdaf708e32c7920f1c76828e9e(
    *,
    group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4423f22ef8760ab432b08954070795b27f8653a8e44f9ef24cd1b288a3c77a2(
    *,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WordCloudFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WordCloudSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    word_cloud_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WordCloudOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e917bb6e0c79d74deb00b9f2f4195f36e8d2d27f4ab63de2ba1c90926cf60f7(
    *,
    word_cloud_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WordCloudAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fbad8b50c079132b521ad82f4c1022a67f3b526b160bcba5cc31714d634d459b(
    *,
    cloud_layout: typing.Optional[builtins.str] = None,
    maximum_string_length: typing.Optional[jsii.Number] = None,
    word_casing: typing.Optional[builtins.str] = None,
    word_orientation: typing.Optional[builtins.str] = None,
    word_padding: typing.Optional[builtins.str] = None,
    word_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2db42bea1b63adf70edc7df9fafeab1155924f97464512a7128e1eb21629c85d(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6893d595258b35ca2601959ff1157114d6f0d510f1b678b362c3b1887507e658(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.WordCloudChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebd4d588b1b5be67c06ed4aac3804f644242e7a1998e888aba4708f7a2a0483f(
    *,
    aws_account_id: builtins.str,
    dashboard_id: builtins.str,
    name: builtins.str,
    dashboard_publish_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DashboardPublishOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    definition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DashboardVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDashboard.DashboardSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b60768091e5a671e526cc5a7dda7550dd47b97301923414d78b174459017a08e(
    scope: _aws_cdk_core_f4b25747.Construct,
    id: builtins.str,
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    column_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.ColumnGroupProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    column_level_permission_rules: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.ColumnLevelPermissionRuleProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_set_id: typing.Optional[builtins.str] = None,
    data_set_usage_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.DataSetUsageConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_folders: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.FieldFolderProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    import_mode: typing.Optional[builtins.str] = None,
    ingestion_wait_policy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.IngestionWaitPolicyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    logical_table_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.LogicalTableProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    physical_table_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.PhysicalTableProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    row_level_permission_data_set: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.RowLevelPermissionDataSetProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a40c2923ac931adc9e5227fd27d9e0ce2e06f9f0adca9a5fc258f274c8c0b41(
    inspector: _aws_cdk_core_f4b25747.TreeInspector,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__319c243491c3ebe14fd56a4b2912534df5743a01fc01559881202892cbfd54fd(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b83eb4dea8999ae93ebd0d3bd44b1ca109a2bfcce5e24968589ea02fd90b61e(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5aec14e835e4d6d3b06f4d5541b80ff40279c65718c511193db749adfbebe86(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.ColumnGroupProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0500f9998edc54331818183988a5c4ce83851a226fa22a6b7b44864700579cb(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.ColumnLevelPermissionRuleProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd9d855654a0270244190d342a624aa942a07051615fc31f99c457e8ce43d082(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46c86cdd228671c5da2b73e9d5351d6c18704726524549fedadd681d94fec1ea(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.DataSetUsageConfigurationProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0995afd66a6884d0ea14633c1a526bb05a96f915f4e3312e7ce61819272c8352(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.FieldFolderProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fd8afbfafe61e453080ae45095cdc0c7e5cb58fa1269605c34cea9d8dc9d0b4(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__561f931d4fcb887480f49ac733f8f5ab2c5136f51afedff875a7c9ccc5ddb0e3(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.IngestionWaitPolicyProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1fcf758419d721a50e21698fd94afd5a6c143dfea11275f2ba383876dcf6aa5(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.LogicalTableProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d4c2c85757bba744cf2014537580e4b79a7e1a25506969e089fa702c57703d4(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afd9de662f1472bb8ac9b5758802152ae4a250a848184bc446fee20811c50266(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.ResourcePermissionProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb2792fe0665cf6fb08e32620b92ac1869915cdeb976d7efaf3cec63c793021b(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.PhysicalTableProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4feb8d280630a7b48de18e43f020242fac00be3f3cef6f16ef919d43cd86dcaf(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSet.RowLevelPermissionDataSetProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af1719501244769800de67dfec86ce6daea34bc0e70210fb4ec9037ec71243c6(
    *,
    column_id: builtins.str,
    column_name: builtins.str,
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__090e4129dffeaf2101fb71ebe6d856e695d7f5ef04229f4572353551767ea19b(
    *,
    column_name: builtins.str,
    new_column_type: builtins.str,
    format: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cec012f9226ebaa351555c768bd98193287d0cba5e3a3650fd3eedd8550629f2(
    *,
    text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60c324296ed6e68a860b9d5af28df5fac62b156bb058fc972a341baea3a425ab(
    *,
    geo_spatial_column_group: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.GeoSpatialColumnGroupProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__889c97f307ddd676262e819e966d136c1cb1a172a75fe6e6c46140c9e78a254f(
    *,
    column_names: typing.Optional[typing.Sequence[builtins.str]] = None,
    principals: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9253df21023b03f198cc86b4d3438e2489ebccd7947fdcd50d8a2aecfd872c8(
    *,
    column_description: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.ColumnDescriptionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_geographic_role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a073e1a889a9c00a3055d4ef193240bade4cf95f7b52e0d0d21e13489db9ade8(
    *,
    columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.CalculatedColumnProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca22e03c50cdde617978058830a93fd3af716a6093f540bca60d7b904c4b06f6(
    *,
    columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.InputColumnProperty, typing.Dict[builtins.str, typing.Any]]]]],
    data_source_arn: builtins.str,
    name: builtins.str,
    sql_query: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55ea54d1cf4ad4affd7316c2a516ce101239d73a9fb8ca45d26b1c4b2826b0f9(
    *,
    disable_use_as_direct_query_source: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    disable_use_as_imported_source: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a44f9b379451fd15a0c906b4c9e904d7781d3a3c509ec4dcba34d4c0b51bd51f(
    *,
    columns: typing.Optional[typing.Sequence[builtins.str]] = None,
    description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ad0f80474f66de8a1500c6bf656c4ad11348f2c425feea5f74488cd530a597d(
    *,
    condition_expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a826b85f8c0c0f3d10def461de935e3ec613e73ae9b812ffcc9a6902250b760(
    *,
    columns: typing.Sequence[builtins.str],
    name: builtins.str,
    country_code: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93de8c7bbda46ee21caec20fb2d7e25b7a5395ba3bfca341abede936ea6a440b(
    *,
    ingestion_wait_time_in_hours: typing.Optional[jsii.Number] = None,
    wait_for_spice_ingestion: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c49cacb381f8dd7a1af6d82e58b62448aeda1654cee21c5da8b2f541448da651(
    *,
    name: builtins.str,
    type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__500cfe81cf37d061378f405204a5c0acaf0ddbd036e04dfcebca986b656ade9f(
    *,
    left_operand: builtins.str,
    on_clause: builtins.str,
    right_operand: builtins.str,
    type: builtins.str,
    left_join_key_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.JoinKeyPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    right_join_key_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.JoinKeyPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fff8b069a5e4c44b9eacfc019e023aa191dfce1c4b34d2d8867ec0e66bb0eaf0(
    *,
    unique_key: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0af103483ba2616564ee2031b6e942f91b914e8c6a9980305c5533b1f1326572(
    *,
    alias: builtins.str,
    source: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.LogicalTableSourceProperty, typing.Dict[builtins.str, typing.Any]]],
    data_transforms: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.TransformOperationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0eadb4b1d6b6f9b53d8d626c1546ba3c400b4b9c6aa0325f3961c7f6886b6e63(
    *,
    data_set_arn: typing.Optional[builtins.str] = None,
    join_instruction: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.JoinInstructionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    physical_table_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2a1f411cff111a5ef319caab8e1aee77d3274375e6d155b27c95e6330be75a1(
    *,
    description: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b478d6488c84c8f07f8d928a31b31cb753c4820693c6fb84826577173f7397b(
    *,
    custom_sql: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.CustomSqlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relational_table: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.RelationalTableProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    s3_source: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.S3SourceProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1f63ace7dc442bffff3145824b1d411600b0d2be5f27a7831288a2e29358b98a(
    *,
    projected_columns: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63c6398c1e03f6f97af7c39a5a8bf71d034458dfdf49a45eff5bfee15e0c9ed5(
    *,
    data_source_arn: builtins.str,
    input_columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.InputColumnProperty, typing.Dict[builtins.str, typing.Any]]]]],
    name: builtins.str,
    catalog: typing.Optional[builtins.str] = None,
    schema: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__052ef03e0a3ca92993865d2a4c8ff5ad7e85a71766fa9b9dde412e2c78bb06b8(
    *,
    column_name: builtins.str,
    new_column_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d4deeda6c6363d3071db20dc0c07cc29dcf0dbd0fecdca54d465128f4339d22(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24c0fa4af4b60f9c767899dd6ebf7a66c0e97f69e9d2f3aca4a47d9bd9070f29(
    *,
    arn: builtins.str,
    permission_policy: builtins.str,
    format_version: typing.Optional[builtins.str] = None,
    namespace: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2696fa0e8bed8e448723968db7b8df0b7e2aec74152f37816a006deac506525f(
    *,
    data_source_arn: builtins.str,
    input_columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.InputColumnProperty, typing.Dict[builtins.str, typing.Any]]]]],
    upload_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.UploadSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a770588a436f94a35d54e160d1676536abe7fe7ab2fcf3a54212bbf26de58f8(
    *,
    column_name: builtins.str,
    tags: typing.Sequence[typing.Union[CfnDataSet.ColumnTagProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__549ab51e8fad83714a826238566b12c5ebc44b9fdf44e7d1d61c754cb4da2752(
    *,
    cast_column_type_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.CastColumnTypeOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    create_columns_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.CreateColumnsOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filter_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.FilterOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    project_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.ProjectOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rename_column_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.RenameColumnOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tag_column_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.TagColumnOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59c4869e0939c2288fa4786c1bb023ab228cf0b894282e94c501ab4041b6753d(
    *,
    contains_header: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    delimiter: typing.Optional[builtins.str] = None,
    format: typing.Optional[builtins.str] = None,
    start_from_row: typing.Optional[jsii.Number] = None,
    text_qualifier: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcbf65201b1c019fd2259635b29eb8787222c3a9ee63c99c9aa3b8b9a3d370e0(
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    column_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.ColumnGroupProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    column_level_permission_rules: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.ColumnLevelPermissionRuleProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_set_id: typing.Optional[builtins.str] = None,
    data_set_usage_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.DataSetUsageConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_folders: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.FieldFolderProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    import_mode: typing.Optional[builtins.str] = None,
    ingestion_wait_policy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.IngestionWaitPolicyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    logical_table_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.LogicalTableProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    physical_table_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Mapping[builtins.str, typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.PhysicalTableProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    row_level_permission_data_set: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSet.RowLevelPermissionDataSetProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2823309fbedc7f2fb848996ea03167361f24d88056ab81e33c32cd89bd891c9(
    scope: _aws_cdk_core_f4b25747.Construct,
    id: builtins.str,
    *,
    alternate_data_source_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    aws_account_id: typing.Optional[builtins.str] = None,
    credentials: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DataSourceCredentialsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_source_id: typing.Optional[builtins.str] = None,
    data_source_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    error_info: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DataSourceErrorInfoProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    ssl_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.SslPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
    vpc_connection_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.VpcConnectionPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89e8c0d3bd1fb0670b423aaeca941792b2e89490ef01a70ee55ce8fe5376233a(
    inspector: _aws_cdk_core_f4b25747.TreeInspector,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fc88db1de7ba35d9c42ac18a967c192a0bdf78a9ed3a36fc8ffb95fa9d5020f(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3d3ba5d144819f881507eeb6bac052a7d1b41c9d52aadc3489e75d2ddddfcd4(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.DataSourceParametersProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50e40f6e1aff54204a8abbc36569b6ac038fe1636116334f2bb5b0368becc053(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__174468676923c9a90a90506f0d3b0ffb499805b3427a64b1dcd65e2ea32e0319(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.DataSourceCredentialsProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2993b6edd46f33cd70ac8d4a04544a0e7ea3ce4b1763701bf143b1451f7ac408(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d581fd88e96b7834c61441560d7251d3f221d845e5fe50433634e6b5799cb8b1(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.DataSourceParametersProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed12f02f0af860a74d00d428e0c15c302ca4f2d3ce39474d53ef376ccb904417(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.DataSourceErrorInfoProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91804e99580af8c0e0b1052149f8df6392b9f0192ce8d40d1fe2ba524132b9c3(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27bef660e685853463e4e4a343ec3f9cb91dac14f3b79cb2bc0e161d02ac801b(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.ResourcePermissionProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d057ba2a3bd71a1013260cafdc3217bf3cbfd1d1fdb56f079827c511e77ab480(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.SslPropertiesProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d1c528579ec913cac2127d6db75d6bf9f89b0fa6b10e3311629317e71dde29e(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b065dd8cefadd9a44e3e1a83439b88f994b9a5b104ed731b68ee155191e05998(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnDataSource.VpcConnectionPropertiesProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c78a70b975494058a76aefd94d61935788fcc478f7d76e2687a52fe646f84bb1(
    *,
    domain: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53320c197cba357481cfb047759cc6b3aadb0c76a6ca988476e26e6d78294d24(
    *,
    domain: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce3df1ee7ccde63f009c1b584a7e7ce39cf2a875955fba2dc8c18f11a471f983(
    *,
    work_group: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f99aefcd7147350f6dd70e0db93404effbc5656252607c459741f9133edc240f(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f01882378ca0fe13cd84d2d87916916489a35767fc155559c9e5d95396ffd0bd(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73fa5df60b6bcc6333bdebd18ccbe09835e535f164400d4ca34895cd34097169(
    *,
    password: builtins.str,
    username: builtins.str,
    alternate_data_source_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c08eaf14492fc5b951aa36b02701c4078c3e9b181410a196227087d446e1929(
    *,
    copy_source_arn: typing.Optional[builtins.str] = None,
    credential_pair: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.CredentialPairProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secret_arn: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f982d7f6acbd7958b3cb17603d49e134aa2fbe75a371bec693e638b2c283d71(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__780424355b227fbe1b279c9d93cfb70511ad834edace85699baa966ef5dafed7(
    *,
    amazon_elasticsearch_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.AmazonElasticsearchParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    amazon_open_search_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.AmazonOpenSearchParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    athena_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.AthenaParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    aurora_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.AuroraParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    aurora_postgre_sql_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.AuroraPostgreSqlParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    databricks_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DatabricksParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maria_db_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.MariaDbParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    my_sql_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.MySqlParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    oracle_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.OracleParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    postgre_sql_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.PostgreSqlParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    presto_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.PrestoParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rds_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.RdsParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    redshift_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.RedshiftParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    s3_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.S3ParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    snowflake_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.SnowflakeParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    spark_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.SparkParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sql_server_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.SqlServerParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    teradata_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.TeradataParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d075ea456f49769f37a6897ea0bc14c6415468a232ab131754c7a103ec8f9790(
    *,
    host: builtins.str,
    port: jsii.Number,
    sql_endpoint_path: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f7b9e2690feb6c45f81e0532305f93e3fd718cab9fa7b2f8ef98808842c0f9b(
    *,
    bucket: builtins.str,
    key: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9529a5834b9463c6b0f9e3e7f57b6042bd5ed7f8da4e70569b728c4537c7ed33(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66c0f6b18de7fbff2b0506d21d94736e35a2bce78ac15ff9dff465ed9ac398a4(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45a40014437174bcec974c37780be7e37d71f376e950bc74dd5236b01fea2a2c(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb85608c7a3aeefe4beea44da79a7fc9788bd701a0ce83eaa910ade63bdbf855(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b42d5040a0b94edd46888b36552d277c4bcc8765f146f13a7a2e1b19d60b3bf9(
    *,
    catalog: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b41ebddca728de10b6469e12e78f7427b8459edf99685ca672ffc8c670e77c53(
    *,
    database: builtins.str,
    instance_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec48f6e654bcb73b16f85af03ad0f41ae92d5642e2ff31773b7bddd0780d7bbe(
    *,
    database: builtins.str,
    cluster_id: typing.Optional[builtins.str] = None,
    host: typing.Optional[builtins.str] = None,
    port: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cc52f9866bc668604aeee5b70e52707ccf62e1289170c0c845940d5f1ab6175(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1714ca289a4b23686ebb2be44f562b17b08b7d6c5329beca938ec380570afb7(
    *,
    manifest_file_location: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.ManifestFileLocationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__888588b836e98aac74e14c135c1639da470fe80385f60f0c2d67e3790dd71bec(
    *,
    database: builtins.str,
    host: builtins.str,
    warehouse: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9af5264015696cca5256c8d9e0985174a61d64368599ea465b4b915b84b60c1(
    *,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a24949f80a03ed893e0ffc3b194bad3ef40aecb2529f51cdc56b2a970715c774(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__775d6f90b457a3569b2de60c35357661ef4dcc73a60f6213b8bf4d236d0d311c(
    *,
    disable_ssl: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d81de2640a59502eb6a496d8437b0a6ab93809a68743d30bc1813304b3baf2d(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15e41486446a7ee69c332a3d705b33346364a9e9ccb2d5860f5210072ca57cee(
    *,
    vpc_connection_arn: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__500be153543e40ac63afeeed0fe3978d6b99ae5d26e14bf158b05fc589f6addd(
    *,
    alternate_data_source_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    aws_account_id: typing.Optional[builtins.str] = None,
    credentials: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DataSourceCredentialsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_source_id: typing.Optional[builtins.str] = None,
    data_source_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    error_info: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.DataSourceErrorInfoProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    ssl_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.SslPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
    vpc_connection_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnDataSource.VpcConnectionPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce01bf5dd377bc8da98316ba92fe442c98399d0b29f5016212fd6b5d3d32e150(
    scope: _aws_cdk_core_f4b25747.Construct,
    id: builtins.str,
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    data_set_id: typing.Optional[builtins.str] = None,
    schedule: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnRefreshSchedule.RefreshScheduleMapProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d315cda966453045a639e9335a2a99fb6247437becad3dcba30c919da6353adf(
    inspector: _aws_cdk_core_f4b25747.TreeInspector,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c5909c0db8dfb61d048d1e2a1c59671f58b34cf2f14122435db9ddae42bddf2(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9c97ba89d913c4b690d1ca28fa451501d2397b88d57172bc54c99ba0d9f3018(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf62de584fa4aed1eadd0ddae971d18ab9cad41e791c09cc472dc5bab535ce2a(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f1f43b530b6702d3e3dd753d6f458e78119a143711733153fc506f556fab032(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnRefreshSchedule.RefreshScheduleMapProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29a68e5761f3558bacb2b4d7fa8a0931578ec1b2d8126a0210585afb602514b0(
    *,
    day_of_month: typing.Optional[builtins.str] = None,
    day_of_week: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d78e1c495104c4119265b5fce93bceeb4b1f73724b1fd472a180a659af64e9bb(
    *,
    refresh_type: typing.Optional[builtins.str] = None,
    schedule_frequency: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnRefreshSchedule.ScheduleFrequencyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    schedule_id: typing.Optional[builtins.str] = None,
    start_after_date_time: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c6a9b696733f7401d75cf9aa8eb3f20807093b6d8411a90ebda8f00a8ac932f(
    *,
    interval: typing.Optional[builtins.str] = None,
    refresh_on_day: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnRefreshSchedule.RefreshOnDayProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_of_the_day: typing.Optional[builtins.str] = None,
    time_zone: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f59d2d61b1f4f08b4c62a3293ee719c65a941d68dbefbfff51ecb56c3e993708(
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    data_set_id: typing.Optional[builtins.str] = None,
    schedule: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnRefreshSchedule.RefreshScheduleMapProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c08f232283ef62770bb6ca8b7fdf03149d3496ec705ab1e375adcd0b1bffc15a(
    scope: _aws_cdk_core_f4b25747.Construct,
    id: builtins.str,
    *,
    aws_account_id: builtins.str,
    template_id: builtins.str,
    definition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TemplateVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TemplateSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e058686f24dadbe8549c22182c3aa5054289790ee7d7630a71b2f584f6b4509(
    inspector: _aws_cdk_core_f4b25747.TreeInspector,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__710fa5d208059eeaa74adcbd24d7c6e041150973a5612d5bba0a61206407b1f0(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1122d4e8db2b42e64ff8f3a06a4c8a8537b7ca729f6654a1bf8b7e8347f4d63(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6731cd99a5b76fdee6b74bb9c2ef7aa5045d9a4fa28733a2d0cda80dd992fc95(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c90190471277837f5882a6bf8def53882a450e485b66dee2a4be3d4bdf14c597(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTemplate.TemplateVersionDefinitionProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c497d775b7ebf2a061490d9331bb741633efde9742360d13baf635ad0dd9c7db(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c600552acfd507bebf25250a4be7b48abfe7a26531c0c7b9b3858f14f559853a(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTemplate.ResourcePermissionProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3b16513140b56c46b024b451fcba3617e11b79b079bafa231d70826f6c74664(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTemplate.TemplateSourceEntityProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__498d7ec2673fdea8392289ade3d2c51dcf7c8de22cd0dbcd0c368339cf461081(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bca736a102e974c4ebd4eebeaa17db7387fdfd11299be62187e5c5c0acdde1a9(
    *,
    categorical_aggregation_function: typing.Optional[builtins.str] = None,
    date_aggregation_function: typing.Optional[builtins.str] = None,
    numerical_aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a4c170f2c7886a89d1d0043f6fa5eb5280515b4b0628ee43dccc30d53ef58fb(
    *,
    aggregation_function: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    sort_direction: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff585bda34fde512e5c2755b54bb7ea4b78c824faf15e0ae5c15bc10ef6fe418(
    *,
    default_new_sheet_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DefaultNewSheetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd9c20cc67968bb3693514fd4b4b2524ab3fa8f1565c6a3f2be2b6d22e5b9fca(
    *,
    anchor_option: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c58eec17140ba655c862f5cdfb10c3acc051fbdb0b1ae87ae38bc47f0b9edcc4(
    *,
    range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ArcAxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reserve_range: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76d317d950491bacad0685b9e125d8ac6cac4ad5f99449e4f891b3fd8cd615f7(
    *,
    max: typing.Optional[jsii.Number] = None,
    min: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e45cdab6f7976fe4bd86f9215da189bc4e8ba9e52e11b23b8db35d694fac91ea(
    *,
    arc_angle: typing.Optional[jsii.Number] = None,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e24bc71ca24a797722b17fd3fbd4bdcc269e1e933e7119cac4d4cf7f843548b(
    *,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__324dccf7649368ff55abd01f5eee190a710b66e0e7b71d885d29f858f97515d7(
    *,
    date_axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DateAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77dd09ab5da2741ff46af19d5e7bff1f72b9cebc2fadf3ee0984d7af5f2bf12b(
    *,
    maximum: typing.Optional[jsii.Number] = None,
    minimum: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae8fb016007fa5ce580eb64fca7788b0a4ed19c00aa131b1ddd847b1919f6cc4(
    *,
    axis_line_visibility: typing.Optional[builtins.str] = None,
    axis_offset: typing.Optional[builtins.str] = None,
    data_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDataOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid_line_visibility: typing.Optional[builtins.str] = None,
    scrollbar_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ScrollBarOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tick_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisTickLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1126f0bf66992cd44e47b78a987550b2282fcf1240d5e6cc6b0b0b467d6b807f(
    *,
    data_driven: typing.Any = None,
    min_max: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayMinMaxRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4f035f92109f584c7f37be962e9568751ab0447739ab9354bed6ddb7a95da7d(
    *,
    apply_to: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisLabelReferenceOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae6e90d3451d56cd56f34e5dece18dde6bc255c7df2bf621f42e70f2499e1801(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43034325dc93d42e9eefedc366412fe8ac2db4732666f266cbdfe94acebf9325(
    *,
    step_count: typing.Optional[jsii.Number] = None,
    step_size: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f28ae5504951aa359a2e63e6a301b25f58d1ff24b484f068b9ea4caec33e841(
    *,
    base: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec680681351cc2fe713a15570b9648d779c243d1ec322e8c58c1b4ad774d0bd5(
    *,
    linear: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisLinearScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    logarithmic: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisLogarithmicScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f57e9d9309e19e99da3a9f677a47fc09dacb1245950fadd888384dd206f1abd(
    *,
    label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rotation_angle: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__228879262a0291170da2a8c3c16560be1fe978a4721a01f1902aea7bf9fe751c(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c5f1904e937fed8f41b78d3c3304c973478d85dbe0f8e51c9b8ae4afd6f2a55(
    *,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    orientation: typing.Optional[builtins.str] = None,
    reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd8953d62059b65a38653ddcdc587ed4e2f085b03e836ecdf6f1b563add645f4(
    *,
    bar_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__675a3d60481fa006fa07ae13625df672f4ccc44c4ab52dd5e141b9cfdd87316e(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd07b19545d756f7bbf1bb98b51d624971e2aea528b6007b6ea250d6aacd89d0(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__866984fd8f2ff80ad3517d851b84e6b4fd85b30ca48583a7de9c98aca8092a66(
    *,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4aa82d4989d9c69c7fd7c9840a344ab7412b58990d2a688861699d371de4c211(
    *,
    bin_count_limit: typing.Optional[jsii.Number] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2968dea75bc9dce68c5aeaadcd6766b5a6ce8761e71a01ac65fabbfa29dbb81e(
    *,
    content: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BodySectionContentProperty, typing.Dict[builtins.str, typing.Any]]],
    section_id: builtins.str,
    page_break_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SectionPageBreakConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__277b091edaa72550343ffdf038b2c6b4f5709ca8f2ba5744f770e2dbe106983b(
    *,
    layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1634c4a0acf3e776a228796f30474ad051cd00ca1fbcf6a882cb02493bd09c5(
    *,
    group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__146508bc46e215e9d9014da0d66f86caa364cc19b0211f0bf10f8219dfcdda21(
    *,
    box_plot_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BoxPlotOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BoxPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BoxPlotSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2f6ff9c64d9aefb16c98fd7159fdcfe41836245311ffe735b395df0ca9b8482(
    *,
    box_plot_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BoxPlotAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26113e083824abcbdb2ae7faf9668ed8608ac650f95a303f5fb7b7632e1e1b5a(
    *,
    all_data_points_visibility: typing.Optional[builtins.str] = None,
    outlier_visibility: typing.Optional[builtins.str] = None,
    style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BoxPlotStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd8e9a59dd393f52015fa11754bae31ce72890cc96c25a05af5092a0844ed38f(
    *,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    pagination_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94465dfd5110a4ced8423c53437d72c14f7d1ef1be37fd77a6125bd464d376ee(
    *,
    fill_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36a6bcada7aa89455101e555072f2759e63ae5ebc5ac9a6b69a59748ef9f4de0(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BoxPlotChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3becd3c6f032461ed699605f6c64a3dbeca6202c5adc4fc68b2bfe470186c5cd(
    *,
    data_set_identifier: builtins.str,
    expression: builtins.str,
    name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0041a15252d178abf67ba4ae71735a9a3d64f7829a339f06d0d099418614fa25(
    *,
    expression: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38cf3170013e51f12ee5f8fbd42c570af6bee33d4debe9d6d720623d1976fc73(
    *,
    source_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CascadingControlSourceProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae7680fbd080e0cfdd2045c30c0a3edee435c10a44c9c39e5a921dd96816070d(
    *,
    column_to_match: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_sheet_control_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d68d5fbe1945068a8a6df6b2de8abe55cd64f05d6d715564bcf840bdf9518a4f(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__801f1a2e3bc6937e71d7c8276f80e2f7636c8461da87a6437d8ea147143a94dc(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9e786b12869b337cbfe28a369c6c3681e7af21140b7cd96a4d96a700ac9f8e5(
    *,
    category_values: typing.Sequence[builtins.str],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67d686bcc0963d7f63271b55f8baf47c856066e633095000abf5e739e9905107(
    *,
    custom_filter_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CustomFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_filter_list_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CustomFilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filter_list_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__193111083f72ca0c8e0db585677c8623e33804df0618c2c7e1a439b51c5c440e(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CategoryFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de6a551c022ce53830f235913ae5f23385b88d80920f9fd2a6e1b9e63c296d88(
    *,
    axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sort_icon_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3998b75924ef54725ce8414f762be2375ce677bd5db69037ea1d34e45725516e(
    *,
    cluster_marker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbce481cb1723044761d85f2ef123d4c87fe2b062cc1fbfaf1e73bf0efe719de(
    *,
    simple_cluster_marker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SimpleClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92b8b530a6cba82f7f27ddcfbf439aa8b510f61290b8c4d0c4286fa928ddb22c(
    *,
    color_fill_type: builtins.str,
    colors: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataColorProperty, typing.Dict[builtins.str, typing.Any]]]]],
    null_value_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2b59a58184dfa937fe2b39a6d5d2308c7bdbc34a78e0384842438ee16ae5efa(
    *,
    custom_colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CustomColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__618fd4b4cd30164fd1598ab7fe964a4cfc8850dab1114b4b66f7f77b2894dfde(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    colors_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColorsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b81549adbf6e858cea83b88cfc48e761688566651fb936976502f5a6eb7f264(
    *,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a3ed3450a74311d41c5c6a30bb8e212f06230d096c8178c8fe66b78c13d53d4(
    *,
    column_group_column_schema_list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnGroupColumnSchemaProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3df84fa3e2f14715431731e0fdd199be04f72bfcd2bacc5843bd3120313a0458(
    *,
    date_time_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DateTimeHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    explicit_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ExplicitHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    predefined_hierarchy: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PredefinedHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cfdbc26567352f389f32b02d05f44b827fbb299843bc2d0848d3d1263612604b(
    *,
    column_name: builtins.str,
    data_set_identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6acf2d66a5d348079ce145b4fdbc4e53c109a373c43b2e6522d8e12b76957f3b(
    *,
    data_type: typing.Optional[builtins.str] = None,
    geographic_role: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ed9d7062fd6aa35a8664f4d58837faad0809f75f48b0d56c2638c037a3d50ca(
    *,
    direction: builtins.str,
    sort_by: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fcc9abb3242726d2964931cfea6b38cf2b9a0cc3c281f728401bc5f72d2cfed4(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5a8faa7b3ba337b9bff361c9dcdfd9fa23f730f4aace1ddb75dceec870164b8(
    *,
    bar_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    line_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__37ba57ab5c5963a6ddfe7d866ab5b035543466285dc586127aeb1fd0423228ed(
    *,
    bar_data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ComboChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    line_data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ComboChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c815bb9dd99e3137c7320a7f6dfcabca2bfd720e186637ef988437941af7e46(
    *,
    combo_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ComboChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0c1f8bbb928329d8d5d4b4dd6a77831266b19568b446c7c905bed64347065e4(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__718a036498db68fdd0013a044ece3386ead6ba989512d8fa9b83fbe773056ae7(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ComboChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fcf54bb706e50464d827b9acf7683c33c7e9ec1c5c781cd91076efaa5d694709(
    *,
    comparison_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ComparisonFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison_method: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23184dd9b5c54ee7dbdbce0037545c8ecc56f5be7d097ee4ac2d0c866e4149f1(
    *,
    number_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a10857186d93b7285c0c96e12581d53440cff5bbcccf8dc79a4bf0807da36fc1(
    *,
    forecast: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ForecastComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    growth_rate: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GrowthRateComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maximum_minimum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MaximumMinimumComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    metric_comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MetricComparisonComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    period_over_period: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PeriodOverPeriodComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    period_to_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PeriodToDateComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_movers: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TopBottomMoversComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_ranked: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TopBottomRankedComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TotalAggregationComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    unique_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.UniqueValuesComputationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f84cefa451d59b1421256a0de111b071dd1faa81a78363f0f55dba2b4ec219d(
    *,
    gradient: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingGradientColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    solid: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingSolidColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2d5607f67b8ccfde571e80706984c5deece104228a3e6a8f9e848bd91e79425(
    *,
    expression: builtins.str,
    icon_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingCustomIconOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
    color: typing.Optional[builtins.str] = None,
    display_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84311484592ee5b6cff536f72855def52c41af5d4b8800671667710245ee227b(
    *,
    icon: typing.Optional[builtins.str] = None,
    unicode_icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__334da1d63cbfb714bfe523c71cc068c5d48d5e3d6899d629b2aa797e86b73e7c(
    *,
    color: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GradientColorProperty, typing.Dict[builtins.str, typing.Any]]],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b91d20806766016269f184aa1a2bd71a3ba4830c3ce68904995c1dd1c7aef3b(
    *,
    icon_display_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05c4e3b8b645273a768a6242d3f174d7aa2c4a547bca2d37e0d3105a5836ff58(
    *,
    custom_condition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingCustomIconConditionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    icon_set: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingIconSetProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a4ef380bf073d063686423013eca7f5b7cc0349c96886111bfa6bc5e5d6417b(
    *,
    expression: builtins.str,
    icon_set_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d84ff0b8fef317df7351191245c37208e1adceca84f939ea1be960fe59d85a7b(
    *,
    expression: builtins.str,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44b439d4bd14e21bca7e0651f9b5d8a68e3ac42c224d8e6f0c67eab154f610cf(
    *,
    contributor_dimensions: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    measure_field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35866f69ea5e5a9775ec48ce393a451c3a04b00f7da59d2811a73ede322b2b5b(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
    symbol: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2dbca890f9b1d41fcdd23103d058715cd57d9855daf9a6a9fb525e6759ad32c3(
    *,
    selected_fields_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    target_visuals_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterOperationTargetVisualsConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71265bfa90f418743597f20509b0be0e4a265eea4cdd0668571de7646ea32330(
    *,
    local_navigation_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LocalNavigationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa896f606093feeb32862e21def32c40f3edb217950321cdb733b21900da0f74(
    *,
    parameter_value_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SetParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3905cdc777f3d421ca70eeec079f818709b64afe652daf8955f3f9dcc942231(
    *,
    url_target: builtins.str,
    url_template: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86b447be87a4286c5e6da4f7a822239e043e7fbf0be1e4b35487b8235e47e6ac(
    *,
    color: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    special_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b3665367f48d01c090b5e82bc199992e85d3029e99058e8d07546aaa5337c83(
    *,
    content_type: typing.Optional[builtins.str] = None,
    content_url: typing.Optional[builtins.str] = None,
    image_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b6f4e6fccaea5fe90032081ed01f025445e6a08fd499b177693844ebf07ea63(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CustomContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aac370beb48c7214eada3944205cbd7384ef584924e51d6bbe66c51a76045665(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_value: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__419300a6e62f9bd1656e74e6cdfc2e83448a9def0678d2bf1b65cd9e0c0e55cb(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f20410afa339ec2e3473bf69d658651f62333dae661239e4ac27702f036dbf0(
    *,
    narrative: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9270e3bdeb9ea15491d2347767ba04d5ddfdbc74d3cef52640ef39545b0f4d8(
    *,
    date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    decimal_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
    integer_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
    string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec0a8cca92efae20221632074e4996bbf4e8ed0dfe51823c8c25f4d12a6629c6(
    *,
    custom_values: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CustomParameterValuesProperty, typing.Dict[builtins.str, typing.Any]]],
    include_null_value: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c5ac3c82d586bc6dda02d57afd47f0c6e157b749d3572b8f200afd84a8febdf(
    *,
    field_id: builtins.str,
    negative_color: typing.Optional[builtins.str] = None,
    positive_color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccb08f3731d5b3fa644c0cd8a5443d0938c28947e03b29cc8ed32020d157b0a6(
    *,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50427e728ed393f2152d27c18e60aca9343932d14fd62d3e1f884d9c8e0d3ea0(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd2fb6c1cc4eb1b465f11913556054c5a12be76bf75b2a1bb7ca18a900966382(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    data_label_types: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_content: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    overlap: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be715575992cef3d2b1173c30472e2ef7483b7da69b1402b10708e0479de7803(
    *,
    data_path_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataPathLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    maximum_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MaximumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    minimum_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MinimumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_ends_label_type: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RangeEndsLabelTypeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb770cde4584050ed058e8bbcf44462271bbf72f79f90c1dba88783d22903b49(
    *,
    color: builtins.str,
    element: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]],
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f80304bcc13ed287866c1e1083f1da65fe6b58d704bad60be6d24303bae5ef4(
    *,
    field_id: typing.Optional[builtins.str] = None,
    field_value: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__511cb2652464ad6c056f67338d2cdf388e86cec972c384c00c2c03d7bed811b9(
    *,
    direction: builtins.str,
    sort_paths: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57c4fe2cdf05e1dda3879629ad9e5bb024a415091501b8a1378be449c42f0aaa(
    *,
    field_id: builtins.str,
    field_value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6fb20bbdd428b399e64f3adbe5e196f67508800750e6019ad43b4a4991ab9299(
    *,
    column_group_schema_list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnGroupSchemaProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_set_schema: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataSetSchemaProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placeholder: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ba4c8c1fcae4b9202917e98005bf43450a15ea5b2e8455b7d2bdad01d3260bb(
    *,
    data_set_arn: builtins.str,
    data_set_placeholder: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2e8ef32cee6fa921535a37b6107d588b4b42aa9cb0c2860ceb9678457df1b54(
    *,
    column_schema_list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnSchemaProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2adddb2d43b0d25f5e41d1036f21ee3a6d29566b02fb3ff652513bba5692577e(
    *,
    missing_date_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa0dde336e0c17194877d50a73192255a3dc5b75fbff570baf27fe17d000c893(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    date_granularity: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__895d788f63729f22aaebb7a57e370c3a4f9c3eecdfcc9694bfb9c24704cb5cde(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df9318b2e9c3b327d108bf2fdc4dbebb37a16d29ff1dcbcced9132c2bbf815db(
    *,
    dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rolling_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cccbdeb3164414b43a1ad0bf25b7c9f9084d3fe70a9c617cb5ca462b16096d7(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef4a5e8b1f1ab7a8866cf418311c833400b6191e639ded1617cc8534577ffcb0(
    *,
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__225a36d9a707cb3ae605212fc2d3eccbb8b1e5fe90992f4a048fe67281208cca(
    *,
    name: builtins.str,
    default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DateTimeDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__389e07f22530a84ba49ac79f8aad47a0f3f5fa61a1d112178da1e0ddccaaa38c(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3087afe17e01b47da180b50650f9eaa52bb9539c877b6a4911fd3d702a1d9cfe(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1df706d7f22fc92dbd972382c61a3b5decd3b80a0ec349b5c3a913b116269b0d(
    *,
    dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49461cc852a7d9640a8caf8412b8cb2f3337411471e87bd5c64b1efb83da9946(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DecimalDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DecimalValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b9075101cdfafd046072b8aa836c8f7373e7965827f55e1eecc5d313c0cbabf(
    *,
    decimal_places: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3eae603c7b03821556e2dd0d89528ed3f46684a5cfe1db94ea6c0d264510b065(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c58d8c49bd0cf7077825ff6c5937ba7b4c3e7633a968e8991aa318b84ac8809e(
    *,
    canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__477d429d0129bed2a679c9d19f0d3e31b6a19cdbe772c76aa9f4bc4689c67f67(
    *,
    canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__168bc0edea090be759c0b1ae2615d7f9a3c9b599e6f2bff9e8e2acc0ec69f100(
    *,
    free_form: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DefaultFreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DefaultGridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c06fdf76c43ffbff3d43cba1b52b666e581fb511e987dcc578d11edca379643(
    *,
    interactive_layout_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DefaultInteractiveLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_layout_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DefaultPaginatedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sheet_content_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff451f2060d067be4aff2f960adb7a091ff765483aa9cf2c2656b7d6c6cdef1a(
    *,
    section_based: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52602085f257c8df2b384d5ad0e230c4dfcc961f87d1b549b829bdc8b90f3458(
    *,
    canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b300c210f681c858dab377186a03d6c5077acb77776345e9a6c5b4f55c94359(
    *,
    custom_values_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CustomValuesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_value_options: typing.Optional[builtins.str] = None,
    source_field: typing.Optional[builtins.str] = None,
    source_parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dff4d99031668281be73d0999e19566d6656aaafd6317951c7237b7b7e0aa6b(
    *,
    categorical_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CategoricalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    date_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DateDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numerical_dimension_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c028c2dc51e48adeabd977627e64630f3dee5f728262dfea3b18dc0fe1c9665a(
    *,
    label_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__51435b1f0dc0ca9cb48249f6f589c613305aca4b0f3efb76d054f7910e375ffc(
    *,
    arc_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ArcOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    donut_center_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DonutCenterOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ff487a66989ec72fbf6bdc52e0d6dbf76a356fd75ac22351481916d206ee2f1(
    *,
    category_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CategoryDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericEqualityDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TimeRangeDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ef40a0e6751ee1b5aed3ede0077fa01624b9b9150e9e5267a5ad0d40ba6ad8a(
    *,
    select_all_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ed451a7a26579021c7d598bfa9759ca125b245e13d45d88c40eafc691fedc49(
    *,
    default_value_column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    group_name_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    user_name_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8a6a6cf0027f224316a45467207b76ac3ce15e6067d819b3447ec6cbce5373a(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7255ff5d8a18eb8e710ebd09fdb30b43e574e7c63f691c001c5fddb3777b34c(
    *,
    path: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4066e36eddfeaffe28bbeef8e0a8e8b1a6dd9c7b84104362d9fcd9991902993(
    *,
    amount: jsii.Number,
    granularity: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__862204e2225433449748256e80a021791c4d9855c721b2c829809b5b235d075c(
    *,
    columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0502d5f0ee1aa82fccbb0f79f85f2959aa94cb85b055d9221fc4315ade6a7dc(
    *,
    aggregation_visibility: typing.Optional[builtins.str] = None,
    tooltip_fields: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    tooltip_title_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8c5ae9ffd7f203ed969d4d4547474d681259e315870ae717eb42714495c2c92b(
    *,
    field_id: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1228af396d112514e9a85bb85589877701d67921c200425d86589a1a44c9aab0(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a3aebe1113ae40fc6f2455a96751374f501ff3bf1d866cad03b69338676e3ca(
    *,
    column_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6f98265bf68daac1ac32731b8f4404494bb847fdb5dc2c626dfdb47121bcd7f(
    *,
    direction: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce7c2a9e2a1c2a6cff3b8436cb488739ab56f7bfe9be25b191e8bff2434c7d44(
    *,
    field_id: builtins.str,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b17bd0c26f859897e9855fd375c3c8038475b467833e5fc3738e2920f55445c2(
    *,
    geospatial: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8be42be278d7afe0a28ac77adf04aaf8d13645241f2c421d791e18a172f7d1e(
    *,
    shape: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilledMapShapeConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0aaa85f1dd40e4d9c8e08d328e8f858885176c828e21d05b1b9dc47324328abb(
    *,
    conditional_formatting_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilledMapConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20d8468ca519646bc0674fbe85f5ef07694c20e245ecad5b2d6ab728d0216abf(
    *,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilledMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilledMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    window_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2a8c99356003321b6881316c38748c0d680b3402aee167111947b62e8ad6e6a(
    *,
    filled_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilledMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed8166621531b597cd5df0331e368f78092c667d8a79e86cf99e0dcbd9dce83f(
    *,
    field_id: builtins.str,
    format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ShapeConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f20907e589c35d0395b77ec271fc2a0b6ae61d1f6873d26299deeb15b46baa8(
    *,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8d2f624efcc1f66daf3dab610af4db6216ad3e25095ef75821fcbc9f8f2f3d2(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilledMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilledMapConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4087b1f61095b937615929533f156ac331874afe0c355d29e4a4ad286ecd5096(
    *,
    date_time_picker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    dropdown: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterListControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_date_time: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterRelativeDateTimeControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    slider: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterSliderControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_area: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69f308bbb31f6a38a080ae1a844349b53ef12b615710164b2c96a3be68170e81(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__133b32a5c8eafb26d508d9d6eb3377ededa86fb064eae298d65d827b3c11d22c(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bc0b71cd813e6c43bb6413c5cb28414320bde2fe24f8605de90cebeece9fe3f(
    *,
    cross_dataset: builtins.str,
    filter_group_id: builtins.str,
    filters: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterProperty, typing.Dict[builtins.str, typing.Any]]]]],
    scope_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bef5e799f602df9fdba8eee76d93e2c85d9f2441e36739fa7fdc9c75b5ad0ad(
    *,
    match_operator: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcc2ca0575422258b194e4ed1f63bcb273d8a97da2edda7e88d5605c074578a9(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4cc556166da14a47318e9220c3ed50d5c587b5b77b70bc22b2ea7bb8403d753(
    *,
    selected_field_options: typing.Optional[builtins.str] = None,
    selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09143b1471f0755e8470022a206aa646843a177c101ac495a451736dd533d1b8(
    *,
    same_sheet_target_visual_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SameSheetTargetVisualConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ec5a99450848761dbc20aff6b28bc43ab55bc4127935b14c2a95054f338f063(
    *,
    category_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CategoryFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_dates_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RelativeDatesFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_equality_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TimeEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_range_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TimeRangeFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top_bottom_filter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TopBottomFilterProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3dd156c2ccfd172c1f279e4ff573a8b224b2f7974b02eb48a474228a4578910d(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__554bb7b9489a1f3886d98c5a487dc270094a52ed60c9f3fd219646ec46db9b8f(
    *,
    selected_sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17b9da45d06573b1f392848224dd4ba9b1b0f793950b41a3cee9966f7d65b8fb(
    *,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b6184fc335cff27ba8cf40123a108542197349935c4213fd24ff3d23f505291(
    *,
    filter_control_id: builtins.str,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    source_filter_id: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6d146a8d1122cf1ee77c523826f0ad659a4d958170d438d79a7e11ac4b11a8c(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e1341a520c19f789ef12132e35f9f54a63cbb80312e837cdc7fc7b85a5b1a6b9(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e03f62c2e8ac902b473e35ef139bb14bea3bfd39bd6a8a2a93726bd5cbc486de(
    *,
    font_color: typing.Optional[builtins.str] = None,
    font_decoration: typing.Optional[builtins.str] = None,
    font_size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FontSizeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_style: typing.Optional[builtins.str] = None,
    font_weight: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FontWeightProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6db4bbc42adf3a3dcb5d030c2a3df53940974b59d0b0a7d3d9360d2a29bdb0bc(
    *,
    relative: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c560da72c16c3efa25771054d6f29355f4fcbd0c9bebd5ca99ac67358c7d16ac(
    *,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e6583cbf3deb2a29de7d9db02e9a55272252fea5fe53a16e18e3c3216eb57aa(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    custom_seasonality_value: typing.Optional[jsii.Number] = None,
    lower_boundary: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[builtins.str] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee7361a10d7e81122664be5f86da8d58244fed20ffd2bdd6bcb4f7c46dfd14e1(
    *,
    forecast_properties: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TimeBasedForecastPropertiesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ForecastScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0eb36afd6273ed8efe73cd7bb158dbd9d6b3dd15c93a324186e9b59a682671b6(
    *,
    what_if_point_scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WhatIfPointScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    what_if_range_scenario: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WhatIfRangeScenarioProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9aa788421208ed3acb9cfdfb628214920ae043c154b65d6ffad598860bab8e97(
    *,
    date_time_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    string_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00f82d4351fe9c4a98a2d0644f4c081c08fbfbfbf9f37b8a1aa477a373f359e3(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb6e06eb52123fe604adbbe5eff621d7e8600f25ebaa35f10b560bcf4b6a55b5(
    *,
    elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ce797b4bd061c3fc0bbbdfd278986d32d68abd6e47951e989f935ad61cf7a33(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3172bc924e440e70fd5cb0f16dd7c3cd1c19549a5359bf9a0f6f8dfff3c6582f(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c1b1dd79c9c21cd7d6ede8626e36c7d6cc5db6972f51663b30caa88556bef7e(
    *,
    element_id: builtins.str,
    element_type: builtins.str,
    height: builtins.str,
    width: builtins.str,
    x_axis_location: builtins.str,
    y_axis_location: builtins.str,
    background_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    border_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    loading_animation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LoadingAnimationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    rendering_rules: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SheetElementRenderingRuleProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_border_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5a8782d0b88dafcdd737da7b6388e805c9afd098072d42b60bbbfffc8ea665e(
    *,
    optimized_view_port_width: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33532fecf59a8fd1b2559844246b823f12aa903e8c3f3962bfc33c454c5a074e(
    *,
    elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57d6b58316a87596e0b1dfdf02593c19d149cf9a1a4a0452e14506c574afeac7(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7894bea9eefaa198de81159a2875591a22c4cc0213f032dfb54fd7c4db79e65(
    *,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FunnelChartDataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FunnelChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FunnelChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0a9788225d95e58712597cdd15ec6d4922ce1b8a67da91ae63f3d65c3231381(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    measure_data_label_style: typing.Optional[builtins.str] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b3e4967b8870e2f9aeba35ed1817cf62dc1858604baf2b17eb18a5e2345d284(
    *,
    funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FunnelChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b32b57a19e5c94c2982de4233918ecc99b8492b0629104c22f62ee69a3b95678(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6071461d6d44ae1f5921c023b13ce02eacd3007ed4afdda1b560733b9a3e4ea5(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FunnelChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3814212b35ce4db426938b8e933d076da21546f5930c38c9a4d6a5577d7df55(
    *,
    foreground_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ea0d075e2f7a419bd65fa799057076c4284749eb54920acd176a09b478e9394(
    *,
    arc: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GaugeChartArcConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57311cca522979452f32997947e94350eeb4a1a43f9a41e5c08bb67cc8b85a96(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GaugeChartConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16c88c5a72a584244b501470b218910adf497f2fdb65dd782c8555222114d4da(
    *,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GaugeChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    gauge_chart_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GaugeChartOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f65304a46f589455003fa2a86d986dd89fbde900828af97a83b14ec102ab073(
    *,
    target_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee6c2ce6efe15f57b996163b9204eb061a8012f34a94ae9c82b015f5376f0127(
    *,
    arc: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ArcConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    arc_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ArcAxisConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__691f985cb25589eecf18cc6406f6dedbfc2fde876e9cd2a30cbc5a2eb83ec404(
    *,
    icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55e199338bbd91a61a0542a1cd7cb461c653243b00e7f7cd831a8a9dd939b0dd(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GaugeChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GaugeChartConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e522f75057544989433e42dc7a8890f432dc8921bf0ce4900c3bd02a8f871306(
    *,
    east: jsii.Number,
    north: jsii.Number,
    south: jsii.Number,
    west: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd4160bf08ccc6687eb96e90ad18f8efbe27a3881713e0237828399a522fb2b2(
    *,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    geospatial: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4df968e87fff955904704defcb9dfaef1f61cd7a3457ad4e0e073a3942343b2(
    *,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GeospatialMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    point_style_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GeospatialPointStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    window_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4001044275eb482560b80f5fdfde01d1972c41d2ff127b4f8e6b211c4eea2cd(
    *,
    geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GeospatialMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f78a7c7a89324910652df3168c75316283365fbe16b1aea6b2729d1c520359f1(
    *,
    base_map_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c634669eda1265acb83611d745ab058b78ddbb3fb91d5d8825f44067be8d913(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GeospatialMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a233dbb2e5660f13ba7ef4c47d20ea0421ca09be116482dd51ce5d5b16e9d602(
    *,
    cluster_marker_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ClusterMarkerConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_point_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0c472835de8e3d2ac8d01cf338efdf00edbf1f051544b6fb1b22a3d5dbd11e4(
    *,
    bounds: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GeospatialCoordinateBoundsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    map_zoom_mode: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbc95f3cf2b0b1a710fd02d2beb65902ef5d3392a351f8c9c0b8359ee01d54f7(
    *,
    side_specific_border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableSideBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    uniform_border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2776d0b0bb49448cca8076e504ce1bfdbd727a1b40b6b20f7279eb43f7842b6b(
    *,
    stops: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GradientStopProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__015b1dcb0f6e7a9d65caf924c62ede6640cd584bb904886667028b592d7cede6(
    *,
    gradient_offset: jsii.Number,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e58938d73e03b6025c0a575cddae61679efb92a4a8ae44597fe83babd0b3d9da(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21bc265609484c37c9e13436e7c6cc5d5f9ec43695b283f93355f6f03b676ce7(
    *,
    elements: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GridLayoutElementProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__863f2614b6770ae1b4676c3297edfb57a0e0047dee678ccebc8410e0eddd9634(
    *,
    column_span: jsii.Number,
    element_id: builtins.str,
    element_type: builtins.str,
    row_span: jsii.Number,
    column_index: typing.Optional[jsii.Number] = None,
    row_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2d6273484ab22bf05075d65358f1f38554c9cb280c42deb853291616137c3a9(
    *,
    resize_option: builtins.str,
    optimized_view_port_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84701fc23f7aa63650c22ca7d92d199af3ea8567210fc9b9e0bd555f61cebaca(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
    period_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ef94c3a3e8e7dbabd73669efa7416593fe4f324525684fbb7ff75b11bc48f3a(
    *,
    layout: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    section_id: builtins.str,
    style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a92cdc553c53e5b50a54b9b199c7389fee8d5a4d679470a79157d2e5fa9c08b3(
    *,
    columns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    rows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7072130ce3e4e6a5bdfe8b1eadd9fa3bf74924c9d38b0c9f29152fbfa8e2524b(
    *,
    color_scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.HeatMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.HeatMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e3fd252e2c5ea63493fbbb7ad5ad1f50b31619097efda5a316e5e9bd9e29c22(
    *,
    heat_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.HeatMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04122ae3f20b1e55768a6649066c5b1edc2736da800f8d41188f5584b5b55c44(
    *,
    heat_map_column_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_column_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    heat_map_row_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_row_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1adc7e1121576aa0e7248feaea0759c096809b66225b10c8ac83a13348bb903c(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.HeatMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6610cc9bf6d861a1fb87e7b83ce8035a6bc62879d31a8582f2d0961f6801e114(
    *,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5076d846e9250b18e6ccfd809b8b00d737f4db5161e007b30bbcb1705c5e57a(
    *,
    bin_count: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BinCountOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    bin_width: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BinWidthOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_bin_type: typing.Optional[builtins.str] = None,
    start_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef33952bc9141e873fb82a75bbf27bdac0dc32ab34bb5307b25de48b0ca32028(
    *,
    bin_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.HistogramBinOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.HistogramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0e1783f5b5886123b9f7f7a979f3ae40ea4d890770d70e00ccb502273481771(
    *,
    histogram_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.HistogramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4372e43613ae307237846434dea564d5c862af5e043655fe3e4f02e5139ee9c6(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.HistogramConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6462f9c9234baa859425aae598e4c68d698c2da3517e01a6c4c29d8ae60129f4(
    *,
    computations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ComputationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    custom_narrative: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CustomNarrativeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a53135c107293ffefdce6f0a7229aff9a8e330a07af447b6f977c5ea0b625eb2(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    insight_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.InsightConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a97c9f90f4d058cd8ced529a29db488cd1777d2834bf263b9729245e4cfae595(
    *,
    dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad2f6d533686102b6bdb88d11fc19337f5d96e6da3070acaad65cd9353a6b6f5(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.IntegerDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.IntegerValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2754edf7b793b1387ebdaaff5a63ebdf6864d3636f19b731a50e14b4a288fad1(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__acc77cfd0baca29acedfc800fa378c5f8bff05c3c31a77f092ab5e290aa9061f(
    *,
    items_limit: typing.Optional[jsii.Number] = None,
    other_categories: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fca720a4c0ae8857ce3d4e947a54506b1a8a1d4c4b5ec2d1d84ce48266a9118d(
    *,
    primary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.KPIPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    progress_bar: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.KPIProgressBarConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6d9049ce24facb977b9736ac502833ee27635adbf2d083a1818ef68d930e93c(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.KPIConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0095f2ed855f00c031073f5a985cd08a3ddf1e41c51003271f6739577d1b5e92(
    *,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.KPIFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    kpi_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.KPIOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.KPISortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c70f30261320a94ad217222b1c85836c858fb1be89eb4e0f7ae5bbe6937833b1(
    *,
    target_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    trend_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0323eedecc56313e0b9f7a00ddba85eb1fff256405499c3140462b65ef072731(
    *,
    comparison: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    progress_bar: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ProgressBarOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SecondaryValueOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_value_font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    trend_arrows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TrendArrowOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb5836e50d3abc34aeb960a6bd9c5bd367487eade59f8c826b0b15a6d7da1300(
    *,
    icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2e21288bd12931fe08ca6ce7a3c71751c3df19c811d3ed14c124668595bc0ca(
    *,
    foreground_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33b253eb7e7045b9964ff7f2bf4545674c95e2d1c85e6f1b6ce76020d0127637(
    *,
    trend_group_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc97e42c3914fad54bc7f9471e0c125ae623dbf7f3d431f0b7d9756dcf27da4c(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.KPIConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.KPIConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a1fb861f9ad7ece5edf93e8aba2af0f9c5c9b0fa3434651e1c9ab80d89d5423(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48567ce06ab8f4438ea3c57029063c6be2a1acce544a3890f1a95ca30da121a9(
    *,
    free_form_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    grid_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    section_based_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__504be645140d32a6a7fd5a6f055896fb69f4ea60c2856694cc4c2dc535b5f433(
    *,
    configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c0e4676ff7adb314ff2f71defb32730779226e61104cf1971386c7a8b56f0bee(
    *,
    height: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ccf66b798df838b19dc69c3f32211fca45de84f681d3b3ae9c99ba959238801(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a28a2370876a149246e9baab467b2be66e23cd80014e99a45766b1e754262441(
    *,
    contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    default_series_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineChartDefaultSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    forecast_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ForecastConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    reference_lines: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    series: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__121e7f03f9327779047c46584816c36d7cc3cca1ee8605090357810780c17997(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    line_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    marker_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__317d18f262fabf4c4d25c2b562f978a4ce604f55dbedcecf2e2d1f2a9023a857(
    *,
    line_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcf29ed0eed8563f3b9d3a5066a71502b30fd80da85fb2fe1a37c9965233de02(
    *,
    line_interpolation: typing.Optional[builtins.str] = None,
    line_style: typing.Optional[builtins.str] = None,
    line_visibility: typing.Optional[builtins.str] = None,
    line_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__89a0f588beb1fc026b2b73e32f2d4cab0b2e966d50d1a75dd56dcb55b5c3e67b(
    *,
    marker_color: typing.Optional[builtins.str] = None,
    marker_shape: typing.Optional[builtins.str] = None,
    marker_size: typing.Optional[builtins.str] = None,
    marker_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca3e5aba20762e5e684de205be7b571ba029a30082c04622b99428617fe268df(
    *,
    line_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    marker_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b66bbc318f7c3a7ab6bcbd9470383cade2262c582d43e45e9b5bce50c1e59219(
    *,
    category_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36484ddac8fa54bbb02c3c090ea6ec08b427bc05d77d268432e021722c24a396(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fdabfa0c37dcb1c5639059703a6dee0b545440338e261e1d6f3b2b11bf63e629(
    *,
    axis_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    missing_data_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MissingDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85307f8b0ffa316b10f6265fda4919aada7e4f84dce18bdfad4e03774aa7d3f3(
    *,
    search_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ListControlSearchOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec5b714d61e0dc89447102d54b30b7b888260342ce9f96464ccfc6c3125d75ea(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0abeb54c7dd4d269d172c461bf1348eef16fef9a6f135b1921c9431094e1c7d(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10b8a84c08a0f4fa62e19db1efdb1c82205c4e7575540c19468957360f00994d(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__313d38638c0e10fc3c75ba94b57a69d64c9edc4eef729cb86a04df056f125ceb(
    *,
    target_sheet_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d11adbd6a79fdd9da8536fe5ac63207af0b758d4acab898c47d4fbcc1f7c0395(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f158c328ee5ded448e6a5cec1001e528a04907ba9679324484373ce3ac48c922(
    *,
    data_set_identifier: builtins.str,
    data_set_parameter_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c070aecc1c4e14ca10c74181daac36d896d586b0053828ad3d340580c25a6f94(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c5678ff7029f08a14dfb053eafdb8975c70f84f07d40b4e20a973534acaefd0(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60df1a815fc1857fb068fc71edfec6e462093abd7430f2f3967dfb40e6e171e6(
    *,
    calculated_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CalculatedMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    categorical_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CategoricalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    date_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DateMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numerical_measure_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9cc0fce1e439b8b098f4ba0e5a329c153940802785d2e2a3182cab55609137df(
    *,
    computation_id: builtins.str,
    from_value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    target_value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce3e4b27390623a5fea91f88938f39a2661b870a476ab82e79f1c722bd4fdb43(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a29c7b80f03bc691c706579b3fbc4dbd104d89933402b11e99b318b89bead604(
    *,
    treatment_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7ea6f072086a7438b043928ce4104949a1591aa69f7d41590b44c3d030a8390(
    *,
    display_mode: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48f0f0fef64bf4339d36ebdf70b44980825c7532476cf686825b791826a892c0(
    *,
    null_string: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93d8ea50e69fba3ee87a375505d369d6e5a129e3c3504a31c67bb3652dc683ce(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__defa462056d49f39ed2a441770c6ff30a569efa75bb580c49167dd02b648aabc(
    *,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__450c6eeea8db42ceb8da21060479905496ef2731d51271c1dac11fedc0de4944(
    *,
    range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e91c57d94904cee14d192a73d38dd4453671ca740ea20644f164e28f0538a524(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0c7649847cadd8aca5822743593e956166c0c0de9a346345bf1928e7c34c5fc(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    match_operator: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5dbf7c6911ddca52a95ad9207d4ef33a16a1f6c53b76e92b544b0083d6468d14(
    *,
    currency_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CurrencyDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    number_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b10405831f4737b6e1f4cefdaab019c2b7924e010958775605196c32c306abaa(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    range_maximum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_minimum: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8151062daa8c08abd26cdf15519cdabb4ada61425aa8bfc105077f605a6ac4f3(
    *,
    parameter: typing.Optional[builtins.str] = None,
    static_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef52e0adcdf7c4affbe622a41d45b3bb36a2f5ce0cd860f836e53df32d87eafd(
    *,
    decimal_separator: typing.Optional[builtins.str] = None,
    thousands_separator: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ThousandSeparatorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__60865f3ef5e9b1a0a80d2eb52985dc7cda4086f43cc4b81400560fdc1ace8cab(
    *,
    percentile_aggregation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PercentileAggregationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    simple_numerical_aggregation: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c0231818db68b0694f544295adc11eac3f3802c1ce4705f5ed445d19f5473ee(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c84162b566349c6d221f0589e47f33d92ba179f3b8564a97886042013b73065e(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    aggregation_function: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbdac14920743145395dc439bb93c33959e5ecc4447f120c8fb7fa7d74d9ad96(
    *,
    page_number: jsii.Number,
    page_size: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc4850c28f964aac51af2f26fc7094a1a386ee77679e927a2f2685e339174ae2(
    *,
    background_color: typing.Optional[builtins.str] = None,
    background_visibility: typing.Optional[builtins.str] = None,
    border_color: typing.Optional[builtins.str] = None,
    border_style: typing.Optional[builtins.str] = None,
    border_thickness: typing.Optional[builtins.str] = None,
    border_visibility: typing.Optional[builtins.str] = None,
    gutter_spacing: typing.Optional[builtins.str] = None,
    gutter_visibility: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PanelTitleOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf3688869b05d616c7dae229a3cf9249c5707b88580ef11075d7946e00680a74(
    *,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4318b6e65fc6bf3045ef085124f750b76f9010e79f51409f5f80cc7660b7594(
    *,
    date_time_picker: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ParameterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    dropdown: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ParameterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    list: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ParameterListControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    slider: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ParameterSliderControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_area: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ParameterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ParameterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e433dd5e6b7e2bd85a298bd6e810a89e42f1009ba197714a9320e08caabe9edb(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__368309055ad7c63750fe3dc2b80de2180903ad9aa3f59bc1e7b0bed12a244598(
    *,
    date_time_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DateTimeParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    decimal_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DecimalParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    integer_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.IntegerParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    string_parameter_declaration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.StringParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67a040bccc553a4b58b2fd721bc869173bf276058bf21ae00d16bcac16981228(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf7ded3da390b3fdc06b3f7bdc723b725650e0b0ac55f62248715a8644f72960(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selectable_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c9a0c23906196bc8b2dd97de574cf7abbc9c3ee041315229d3f58a4a6b29571(
    *,
    link_to_data_set_column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b285ac78165ed93ca21745aa6139a5ac9adf6d50308879b5ae65eeb9e79bf42(
    *,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf3033bc1187c04e787737d664e2524d54d3d2c4e9368dfc1e2d9ff925cac203(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd6178b7f841026bc7cb485bc578cea52b53aada109d833bc5044919125ee9eb(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82d71de5b9463d9f445bc2256bae7c4bb0932b64e8b005ecc493cba03f1a709e(
    *,
    from_: typing.Optional[jsii.Number] = None,
    to: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22e1d2b4e47a5d124f8f44833569abed1d81aa1eb3ea7f7bb439726de7b95b40(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    negative_value_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bf6f0badbb862d081f1d1bfda80fe3c1ce55ba99e6712e5b03d2fab9144639b(
    *,
    percentile_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6802920f34fddd7614e1d44ef06b4ef95537f0e792dc32d4291c430be3afa89(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8c446ba7e83422b30febab3ef109a7f5740c9b5a0705f66c40d481985a8da13(
    *,
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
    period_time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11011ce1e97e61489dbed7a96144a1fb83f7e0ff71fdea9ea3e6697b870d332f(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e8439ffb05b795551cb3ae1339175e9ef969ef85a035171dab7b9da5360eaf8(
    *,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    donut_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DonutOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PieChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PieChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    value_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74f755486f07e76fce4278da9e4219ecded215a2ddbd33a1b85db597d4f4f5ae(
    *,
    pie_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PieChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81612f9fd1ab90ff031810ba5bad26b4842fa156835b19426b336be4d1d4ec54(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e40a6ef83bed4089763b489f09c076f28757eac1531a54109d03a91b9e14fb51(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PieChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08bf2450f02b03e55baf9773d089f470b61d24921b572c70c11e850db0c20af2(
    *,
    field_id: builtins.str,
    sort_by: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableSortByProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3409ee4a8dd6c9d4722ab1155dc0d0e1b631c9df9003f0b4f675dd9f00e17202(
    *,
    columns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    rows: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__357c43f89872d9a67bf98d306540fdbe5dcb0f0742d31d7100bac9e828787629(
    *,
    field_id: builtins.str,
    scope: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableConditionalFormattingScopeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b937871ea87c127d6788b44584abb29e8b1435faaf9ba392f38886f6fc528858(
    *,
    cell: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__035d0cac94a0acbd4823e600a95aa9da7ae66b81da88295d8ddefd9585e1c7cd(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25a9461603e54716f57702474f0abd9b3505021be84e5850458cb3edba1543ec(
    *,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f1cc5c1c6fa51a2410b7d3eb133d223b015b3ef2562aaf44a2c8d2e1c8d1a1a(
    *,
    field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_report_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58654b6ff119260e31338943d528cd5ac758c9244e58c5b0cb29d78290a6831f(
    *,
    data_path_list: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]]]]],
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cff7dda3c65652234ff946f8989ac8aed08551d1cd74f446e16e3da03c275f52(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec91a762a2bb3f5c0f7941952de70e5c55eefe3e31d17dde1a87e14e375b46d6(
    *,
    data_path_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableDataPathOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    selected_field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4e5047fede2835330e36fc5e9be361e03046e7d6b611a56ee8ce2479c9ca92c(
    *,
    field_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__851fcb9d26c3f48a528ffacff0b32bd8241dc4362adea47fdac79bff9dc9c236(
    *,
    pivot_table_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55807bc671c89984c46690c703e569d2dc2fa225ac0382c96199f3470740b615(
    *,
    cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_names_visibility: typing.Optional[builtins.str] = None,
    metric_placement: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_field_names_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    single_metric_visibility: typing.Optional[builtins.str] = None,
    toggle_buttons_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec8b553e0faa555f569c0327c205f520226fa16640532faad76ece9ec04cd91e(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0fb6a5f79e2cd053d8a1106abc8be4d5c7d07e590bc291a51de0dd18a61716e0(
    *,
    column: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_path: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataPathSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__424551c1a70d72cef9ec805a9a9e360d8f9248fc1c69bab2150765e0869a3a71(
    *,
    field_sort_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotFieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5d6729c91fe72bf1cbd0bb576ebf0b0de75aef2ff9e57ecddf2d1785bd67e33(
    *,
    column_subtotal_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_subtotal_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__146828c2a834df67b29e4968b17f81d6956be56036ccab98eccdd63b1aae632a(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8a2015b32c17c40bc2e896b60c957295ef26ac76ab46c67985ab068067e7783(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    metric_header_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cdc19a96d146feace31864ec2aceb0a0a587458f54185acf5b83cc75c88a0574(
    *,
    columns: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2fbeff0581bdd92eb128cdd5bd61027d5452cd5207160e3d0d0c85d11411d649(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__095a9eea9257aa9c90b7df132a754f7103ffb64cd51a997998e081eb1d730337(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fe678ae2b6d868b07d32dcbe9fe979faeabac00317121d42f08e1d3e4bf380f(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96f7757eb87c230efcce250df70fb551839f1a71d53fd5adcadaa44d3129daec(
    *,
    alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
    alternate_band_even_color: typing.Optional[builtins.str] = None,
    alternate_band_odd_color: typing.Optional[builtins.str] = None,
    base_series_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RadarChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RadarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    shape: typing.Optional[builtins.str] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RadarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    start_angle: typing.Optional[jsii.Number] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d8bf0e7e9dc42df37a53ddcf58192e5fe86aecfb15833acb48d3fcc7b4eb4c4(
    *,
    radar_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RadarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__097e9c133742d068d61cacad3b4f0432216e37ff94eefbdc1d55772acec58fc5(
    *,
    area_style_settings: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RadarChartAreaStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e72e8280ca99dece4ab1785fc1d83ad258d0876ee04d2f491e276e0a139da57(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    color_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d64fd9efcc95ec898ca909a2759e9ce1934fdf3a7effd0190eba7f20d2a7eee(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RadarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5088b07837546460f883aabdea7314c35114296b8869c5c97c6300a31ff7fd4(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed4c82403805b57bdb385478e81e2b81849d4bb6f2b22cbdb4263fe4dadfe363(
    *,
    custom_label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f951199320edb751350a5c9a70a386180fb3093e41174bb3d2666184ff3efa0b(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    dynamic_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ReferenceLineDynamicDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ReferenceLineStaticDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7691d7ab751d6135e0ca0bf93dcb6da2fef97a5ed77bd57edab2e022a3449c5(
    *,
    calculation: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    measure_aggregation_function: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6681fa3f7ecf41b46f494147d4c15e6f4f01510780fe1655653912ba8cfafb4a(
    *,
    custom_label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ReferenceLineCustomLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_color: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    horizontal_position: typing.Optional[builtins.str] = None,
    value_label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ReferenceLineValueLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    vertical_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bff8e571bf73d0416515ef0837435b6e6faf6e0a5308c9c43fcdd3872f409454(
    *,
    data_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ReferenceLineDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    label_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ReferenceLineLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    status: typing.Optional[builtins.str] = None,
    style_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ReferenceLineStyleConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__895e4cec174e07b469a195a4fa6b7ecd2790e36ecd1e66196fca6e9f1fbad499(
    *,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0420fcff71b3b7d3a6389bd01a087cc94aa02ac89dac45c3e69666ae1f84289b(
    *,
    color: typing.Optional[builtins.str] = None,
    pattern: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e334758eac1d605c590ffe46ef717e16df6946b9f617bee8e33308704a05f45c(
    *,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    relative_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f86545a16d0420903a655e122d7d64eee742623db2564c6e735dbdb7e9b9785(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffbb840ad1107d349338ba41684b863ffbda9809024b0529c9f576978cc1472f(
    *,
    anchor_date_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AnchorDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    relative_date_type: builtins.str,
    time_granularity: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    minimum_granularity: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    relative_date_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b09dc6ec382166a1a6c8698f327de3b289c8f7a0b69e9220ca28cb85e7971fe(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
    resource: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7e77f6441c5544d1c8c5d9f12874f640744c309900b2677ffa601010a931035(
    *,
    expression: builtins.str,
    data_set_identifier: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__38d10353bdfdd52716b5673584f61452563aae5f84d7ebc4f1c5eb66d4ceb50f(
    *,
    row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11c541b5cf7f2cd1485b2524dde8d774defdf9b2b48a8154476f2ac511274ec2(
    *,
    target_visual_options: typing.Optional[builtins.str] = None,
    target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6dce4ab950f301b2e353e1b4bd56f85d40b706fe9023788d6cdb549c8064ad7(
    *,
    destination: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    weight: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb16f663ef34bb6f0fdf5be0267ea4e70629740cfad1aaee67602b96f531ce4b(
    *,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SankeyDiagramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SankeyDiagramSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7ee6fa6b9e0ac59dfbbc6089b942df5b6eea4db627435d6822b25c09bb09a70(
    *,
    sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b3817f41ae7ba394a810a11843e666c6017f6692e6877119dfca6b5cb66fa53(
    *,
    destination_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    weight_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a8fa08a3314084d5cec3f251f6416ecd68485fbaf0c4daa05f6df7373e9caf2(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SankeyDiagramChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c50887dda6fefb9488c05547f6e535268a9a532d818feb4367b8bdc2a2fd3c5(
    *,
    category: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    x_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    y_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__989de1bd52abd6d91e073dc3d1e256c4a3fd11a99dcd4b53ddec0a10cb6d86ba(
    *,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ScatterPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    x_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__574b4d8c89b9f543bca9431e42f05d3fb3c4650e0a6d8f6665183ccc430b0d8d(
    *,
    scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7960b944e5bac5cc6b38549e3794e1da16ad0d4e3b99d941b4ad6c03f8c203a(
    *,
    size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    x_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    y_axis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4da2f448e052b587e661c3748e378a7920d7a8c729aa4d7258410705196be454(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ScatterPlotConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1861cacdaea4f9ce19ced5ae32e70faedac10e12c81e9cb782ba03dcc13a912b(
    *,
    visibility: typing.Optional[builtins.str] = None,
    visible_range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisibleRangeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75eeeab3ab6156ca5bc9507d047ebc08435a23bedc51bda121b979329d875d2c(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ba43ed7db0782d63dcb671f48fe5b87c90b6e049f7dc86c84bb4ab9f079cd0c(
    *,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d01dc390894c0ec232c06f911078e3e095b464cdff27ecb4dd7ed6e2e45fd414(
    *,
    paper_canvas_size_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__332983e5bd59cfea1d53e8a4fcfaab6cbb7ae50f853934ec5b7dbb2f6a86a7ef(
    *,
    body_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BodySectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    canvas_size_options: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]]],
    footer_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    header_sections: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a18714d8a417e62e64387933abd5bbf8d41dd57a11b35f8c43d82b0509168f79(
    *,
    paper_margin: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SpacingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paper_orientation: typing.Optional[builtins.str] = None,
    paper_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4357f7980b3ac7e5a36d219436f994672508105418f941db07f7929bf16defa(
    *,
    free_form_layout: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FreeFormSectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b70b963165cbcd8724d0b022680232a27fa7eb3b6cf8ee98cc87250dcb408369(
    *,
    after: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SectionAfterPageBreakProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e03d7b592feef121508b2403c225dd3d3e505634f182cfb2969241bc2573b42c(
    *,
    height: typing.Optional[builtins.str] = None,
    padding: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SpacingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cbebab0daebeae96874493fe135a970b3bb48532d93e9bc5dd1001d64ffa4ce7(
    *,
    sheet_visual_scoping_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SheetVisualScopingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ef94b9975654ae2a8f70919ae08af8698a96af5e3c8504efce56300ed0bddbc(
    *,
    data_field_series_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataFieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_series_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58d4e967cd00306ecb039e9e8e03c7f16a7b75013bfc7aee1aa23a67ae0ed659(
    *,
    destination_parameter_name: builtins.str,
    value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DestinationParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d6a55475f6abba68c2957a70aef92cb7bbd42b1359357187e55e6f197948faf(
    *,
    background_color: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33a7cc8555d6e123f5d793e59883d050ab8a3ec183e819e20c206f3c5558af26(
    *,
    grid_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9831f60ab74b87f9b2c51fb29e72f0a7483fc63c0f21859f373870853f270dbf(
    *,
    configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SheetControlLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b5cbe7b2e49d923ec415b843f2fc1da19e40269ce5cdfdf78cbb44cfc6888e4a(
    *,
    sheet_id: builtins.str,
    content_type: typing.Optional[builtins.str] = None,
    description: typing.Optional[builtins.str] = None,
    filter_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterControlProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    layouts: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LayoutProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    name: typing.Optional[builtins.str] = None,
    parameter_controls: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ParameterControlProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheet_control_layouts: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SheetControlLayoutProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    text_boxes: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SheetTextBoxProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    title: typing.Optional[builtins.str] = None,
    visuals: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9182daf0924b1ee487eb1f46fa7870581807713db24720374b72d78b6b11f11f(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b516f185464bcee70a0bdaf1a78a2d71a4c22a57f8c6518dad766d97322a132(
    *,
    configuration_overrides: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SheetElementConfigurationOverridesProperty, typing.Dict[builtins.str, typing.Any]]],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21f7115f0aced40a4d9034224651b3271649c96bddc733a72edfef865bd911dd(
    *,
    name: typing.Optional[builtins.str] = None,
    sheet_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__543333098e297089353569c26abb78effe002d1c93675ccffdcbe6048994335c(
    *,
    sheet_text_box_id: builtins.str,
    content: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d59337d6fc58ccfb926e1fdef6ac2c99f7544715b325382c4e778b0cdf2b3b1(
    *,
    scope: builtins.str,
    sheet_id: builtins.str,
    visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b62b50a2f8d157300d1e0e5fa5d9703e0bacf64fb17a557783e5d07e07abc41f(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac6a683c36447f6cc1a60f8ed5e6ebd52eb0b6e540a654eb5e64c62c496d0bb7(
    *,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13e00de9440e5e65d1325bdb54bdffb6c281d402d0c109d942e64360d0be202c(
    *,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21c7f6b5ebf3a4cc33c865adc4e1b6d978259efe55ae5538a6b7d8bda686006d(
    *,
    max_visible_columns: typing.Optional[jsii.Number] = None,
    max_visible_rows: typing.Optional[jsii.Number] = None,
    panel_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PanelConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e20034a0c57a2cd823e62adc76a3be4950ac258bdb0ab7f63047ab063ef4c5f8(
    *,
    bottom: typing.Optional[builtins.str] = None,
    left: typing.Optional[builtins.str] = None,
    right: typing.Optional[builtins.str] = None,
    top: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdb82b2f5f87cd8248c76d68629866eea5e572817604a317a7adaa674df402f7(
    *,
    dynamic_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40e7ac5fffd8efbe5888f760223c0c2935df76675627b0ad43a50560b4f9bb01(
    *,
    null_value_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da717b40d4a97a18632c272f1c7e294a9fe141c9ec726f7da27828fc32279969(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.StringDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    value_when_unset: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.StringValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7e7823e45ca3c359bf27bc35e04105106ed9fb2667cc720232838ea57e93b49(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd162de8714c9bfbd3ca8d73eb00058046e6fd2772b4877effa9721ad32b7433(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    field_level: typing.Optional[builtins.str] = None,
    field_level_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableFieldSubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    metric_header_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfc08ee6fc7d3dc678431485ec4293e696ceee84ca8da8478bd0f6aec63ba6ee(
    *,
    group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a78c9fb72eb06f1a7bfc8123ef9fc027380f27ee4563bc683d70950c21fdce36(
    *,
    color: typing.Optional[builtins.str] = None,
    style: typing.Optional[builtins.str] = None,
    thickness: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f7b19da59b0b0ce369aa6af3a7f2a8429384948f628227a0eaa12a8d8f0cc32(
    *,
    field_id: builtins.str,
    text_format: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fac214beeb3c59ad5a438008eebe38504d998a55c118355e2c3edfff4259e375(
    *,
    table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e353b0906ffc42d0e046297d9a7ec55687049c364505829f4f93a9b3feefd2fc(
    *,
    background_color: typing.Optional[builtins.str] = None,
    border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GlobalTableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    font_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    height: typing.Optional[jsii.Number] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    text_wrap: typing.Optional[builtins.str] = None,
    vertical_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__752956e3167affcac6f43e69db63679b855c6dfe13aae3193489127e3c96139e(
    *,
    cell: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableRowConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ba82da3036cab59a3a4df98757ba822839a9ade1db327ffe6dcf895d855ffcc(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3690ac3d20c6a56f25234e21f03e753e64da4171793e35022060f27f8c3213c9(
    *,
    field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    paginated_report_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_inline_visualizations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableInlineVisualizationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    table_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    total_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TotalOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__46ae24aecee747f525712a3eacf17a785fe369b02aa34105a1d02a4181366f1e(
    *,
    icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed2c979bb1ab67ef5004ba9030e62dc46cc138163435ec58212b53e6c1e228cd(
    *,
    font_configuration: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f0066e703797ff66476dacc898065fc9f9d1bf23e8991fd5f947868a2c2b4d7(
    *,
    sizing_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellImageSizingConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0df78a18009d1148af9d972ff114b12b7128d03dd8ebebea80b1ceda8050f058(
    *,
    content: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableFieldLinkContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]]],
    target: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98fb493ae0affa22d8837ab4e43dbc713820eb728462c38b8584c6f251589864(
    *,
    custom_icon_content: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableFieldCustomIconContentProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_text_content: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableFieldCustomTextContentProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb22c78fb95b867e24c21290926f33f2901013392e9a8d3bd201564ffbca0071(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    url_styling: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableFieldURLConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8094b48247b8fd26a9d16c7c2422354a003341b3c824a77610a2d6a66b10c37d(
    *,
    order: typing.Optional[typing.Sequence[builtins.str]] = None,
    selected_field_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17906605ce701441ec5974d576e14f116fd0c7495f18214d4714163e6ab3c097(
    *,
    image_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableFieldImageConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    link_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableFieldLinkConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d748a1d97a591403c464cdf9b9eebcb5dd8951f3ec87e56159747e39443f2444(
    *,
    table_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_unaggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__596441c6f755f9b531be56569889b0b5d27480ea078a49d151a424c9c9cedb85(
    *,
    data_bars: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataBarsOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4644728c2f0e48039960fe1ae046384e1c8e4d2f25a8e85f10af19210b32a8bf(
    *,
    cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    header_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    orientation: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1866401a03347cf54e3c443e4abfd8855dfbb464b92d5c54beb138bb99104a3c(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e042f546df8c09b712295455ebeb342c2d72dbef7814e9281ada6c4e15629a0(
    *,
    background_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__923b6737c5e4d6ee25bc46262ffe461329f836ab963a340e58f2db883e52a6b0(
    *,
    bottom: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inner_horizontal: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    inner_vertical: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    left: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    right: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    top: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d8bfdb0d14396bf09b63e5ad62fcc98948eb2ed4b6a76e6f306e3f882eceff79(
    *,
    pagination_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    row_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f4825d84ad9afafd8238ebc0f26f127847df2d9ff4c7ee1a3c311178529e24a(
    *,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.UnaggregatedFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c862a95a3f2de46e8b96594fa14813e90bb47d8245233ea0dc8b79c55c625042(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f34ef286783509032bd241f42e5c8e0588e8446c9de42e83ed47cf958a772f2f(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
    violated_entities: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.EntityProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3023bc8928d71a604add70dea7460abac66c102c04b10e32d363a78667058d8(
    *,
    arn: builtins.str,
    data_set_references: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataSetReferenceProperty, typing.Dict[builtins.str, typing.Any]]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5662926ff0bf7e1b6f8620b610ab49b47d25bcd56ee6994c22c1ce8c7a1a4da9(
    *,
    source_analysis: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TemplateSourceAnalysisProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    source_template: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TemplateSourceTemplateProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e70b381a5ecc510942be4843c252ac74c8d58c2608ef88d906dd1b56336413c(
    *,
    arn: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0df77e44def83f43d195e623b70ecf79dea128ea53b02d8f1434f9e850f2716f(
    *,
    data_set_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataSetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    analysis_defaults: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AnalysisDefaultsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    calculated_fields: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CalculatedFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    column_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    filter_groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilterGroupProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    parameter_declarations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SheetDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f02a1cb0b1d3bc271bc81c1c5de6e57182f108cbf816f3777c6308098d61d5ff(
    *,
    created_time: typing.Optional[builtins.str] = None,
    data_set_configurations: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataSetConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    description: typing.Optional[builtins.str] = None,
    errors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TemplateErrorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sheets: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SheetProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity_arn: typing.Optional[builtins.str] = None,
    status: typing.Optional[builtins.str] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    version_number: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0b5602e0bc05ac7707ecc57c97065daa81224895daaa3849dc99049c5e4879a(
    *,
    placeholder_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25c55600e7a726facbee06cbc15f52c7886bf0e4123873d75917f1d795113bc5(
    *,
    background_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    icon: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    text_color: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31b28b66b0e8cb070fb76eda0675c147ee6dc9af416347b3b48195010067bced(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cbab6b4dab2a153e0e3e0e4281ef3f41a77341a7372de21ed7e72ef03765aab2(
    *,
    placeholder_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__caee7777108fbd9f61fb6d591d68411fdc47241bd8397559b7029d5c1eef9dce(
    *,
    symbol: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45aa0f9578b2ad37353c36d2efab39de7d13d3f7860c784784df659cb45bccbc(
    *,
    lower_boundary: typing.Optional[jsii.Number] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[jsii.Number] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68fb13fa54532373c849bebe069c7f1494f2263761e9c812018c1bcc1b922641(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4abc91996aefc14ce46b194f1ddf9e244e5e38dca94a9c79e1b7ab8329ca39f2(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    range_maximum: builtins.str,
    range_minimum: builtins.str,
    time_granularity: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80d2e359add74055b1301f3cdf06ed7046f74cf48a6b1b317f47c41d4136b780(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    null_option: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
    range_maximum_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    range_minimum_value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4978b81eeb0495f6e43674661bb3534c3b28c9d41a19596829fc9c7cb3ea2ef(
    *,
    parameter: typing.Optional[builtins.str] = None,
    rolling_date: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    static_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f1c67569cde922ce4ecadfdc62fa36c88adaeb23b4ecd724fbe00028b9d62a5(
    *,
    column_tooltip_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnTooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_tooltip_item: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldTooltipItemProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5f6afe2ebc1023d254ba6c2fb9f34fb1aec031e3f0ce9e4349a13947b0a4001(
    *,
    field_based_tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldBasedTooltipProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    selected_tooltip_type: typing.Optional[builtins.str] = None,
    tooltip_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75b21c57d26c1429928271e3d18ee6ecd8bc5eeda4aca5b97b29455adc282749(
    *,
    aggregation_sort_configurations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AggregationSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    filter_id: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e523e81a8a822ac835cbf241e7d6d2d578f885930096fe78d96619210c19bf6c(
    *,
    category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    computation_id: builtins.str,
    time: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    type: builtins.str,
    mover_size: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    sort_order: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5c526e822a5c0b2a3d13ee52792f8a74f08c7da4c9385f8c612d531bf0c6d93(
    *,
    category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    computation_id: builtins.str,
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    result_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b07d21e860b48c4ec3238938af6ace3dcb1fef6a5c372b9213cb58265046f20(
    *,
    computation_id: builtins.str,
    value: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9843aa0f958c8b4e757ba83e8b1122fa661853b0b4483d9d269635122a99e24(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_cell_style: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf3a489de43ffa01157133eb8e5808a957a7e78950664c4aebeec4552455cdf5(
    *,
    colors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    groups: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    sizes: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__529103c650fe1879629205714288e1749761b854c2d26a1e31c334c22fee49a0(
    *,
    color_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    color_scale: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TreeMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    group_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    size_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TreeMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tooltip: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e70c1ccd2e00794a1a1939cfdba81cdbb013279650d8d016d922f43b2d7a4fd(
    *,
    tree_map_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TreeMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe4db29e596f9be2693a5f97c7db2891c307687b9d06eb4fd63a450ba2d2d9f8(
    *,
    tree_map_group_items_limit_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tree_map_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06742e795e567fb5efd0261dde48c0a3873f3950809950f55d25cba439ac40b3(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TreeMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbb4b2a7e25495d4e8f218946007d1c13ec72dd09c97bc2aa713409a31f469d2(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f48952ac3a775ac4c7280e2794aa266a3eac2764100e4a9c96d27c667abaa85(
    *,
    column: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]]],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__438383d5e80165a5807146d73a1c3386440df8b631cbf18c4f39b5283be81e54(
    *,
    category: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]],
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83ffca8c86947f5c3288c0273eb8c866eaf2ca20e72ee520518263b4ccdde408(
    *,
    percent_range: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PercentVisibleRangeProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__721dcf015696e45dc7d09593bb8afff317b821d4b0355fd9eb2dd35ae2cbcd3c(
    *,
    filter_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CustomActionFilterOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    navigation_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CustomActionNavigationOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    set_parameters_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CustomActionSetParametersOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    url_operation: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CustomActionURLOperationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e341cc4d788437d4da39ccbd43c09c5a09195d5ff3ef61b1a95f537f98c529f(
    *,
    action_operations: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionOperationProperty, typing.Dict[builtins.str, typing.Any]]]]],
    custom_action_id: builtins.str,
    name: builtins.str,
    trigger: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83c636bccc6ecd52cee36ffb92a521268b248394dc32fe179ba8f955493011c0(
    *,
    chart_color: typing.Optional[builtins.str] = None,
    color_map: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataPathColorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__923a0cb2672aaacb0a393194555664e6ec18ec302e409be9652375393a3c0336(
    *,
    bar_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BarChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    box_plot_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.BoxPlotVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    combo_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ComboChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    custom_content_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.CustomContentVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    empty_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.EmptyVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    filled_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FilledMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    funnel_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FunnelChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    gauge_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GaugeChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    geospatial_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.GeospatialMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    heat_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.HeatMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    histogram_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.HistogramVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    insight_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.InsightVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    kpi_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.KPIVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    line_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LineChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    pie_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PieChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    pivot_table_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.PivotTableVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    radar_chart_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.RadarChartVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sankey_diagram_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.SankeyDiagramVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    scatter_plot_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ScatterPlotVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    table_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TableVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tree_map_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TreeMapVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    waterfall_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WaterfallVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    word_cloud_visual: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WordCloudVisualProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62fc9d0a5aaf9b73b4ab4ec8953073a61db943549b6fc08a6a8422a6120285a6(
    *,
    format_text: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LongFormatTextProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e753584f968bf87b7fc2deca1ea47670c40e02e7b84f70b36c21364ba13ae989(
    *,
    format_text: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ShortFormatTextProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f2d41a9250a39eb4f2db0b0768f29bc32fe0167b368ab60a0d0db64df89c523(
    *,
    breakdowns: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    categories: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    values: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c262143fe18a1d2385a0f8329fc92f26eaf7aec22ea1fea95a32d6392c52e769(
    *,
    category_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    data_labels: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WaterfallChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    legend: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WaterfallChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    visual_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    waterfall_chart_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WaterfallChartOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__419d921a031125f8a5cbc9397d538b44a166b5a86ad16ef517bd23d9c32d207c(
    *,
    waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WaterfallChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3502b6423d8b8b916d6ae7d88cf10140b3c4351cd01644c4580494e306a871f1(
    *,
    total_bar_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bb06da3783264c73b7109c1dd8984bb17ee1045c8efdf2f97d04694500a932a(
    *,
    breakdown_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7bdbd11276f3f7f72104beec60b5ee768d0938e52d644ace00f99958298be8d8(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WaterfallChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae1b84eaed34d7a24ba20dd80b298b6650902ff3d5ddf079c09751afa5cc50d2(
    *,
    date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85b2c5ba7ea1aa73214826545ff6c486b9ed4553d658c0f89d86c2328b385a16(
    *,
    end_date: builtins.str,
    start_date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9b49495ea318089a289d9a1bd2521b9e843819d58c219917b5a27fc3779a986(
    *,
    group_by: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    size: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f79af8d57f9ee39da663706547784f114fa8193dc3865331992be1b6f9ff9e7(
    *,
    category_label_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WordCloudFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sort_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WordCloudSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    word_cloud_options: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WordCloudOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4da3ca444204cbc42e8cd4cf6d6bf294b802283c048cad1611677b3c66582290(
    *,
    word_cloud_aggregated_field_wells: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WordCloudAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd1ce26606c639e3a3c42d27cc07ab8232eb7b103c1ecbfcb9bfb90cb48503ec(
    *,
    cloud_layout: typing.Optional[builtins.str] = None,
    maximum_string_length: typing.Optional[jsii.Number] = None,
    word_casing: typing.Optional[builtins.str] = None,
    word_orientation: typing.Optional[builtins.str] = None,
    word_padding: typing.Optional[builtins.str] = None,
    word_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04069ff21989ec3b74f74ab26c2da06c9883c11532f7eca2b45657f0584342cf(
    *,
    category_items_limit: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    category_sort: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bf0f20f1d7f4cfb7a2b93de3398fc1f42214b8325cb769c64134112652e6e39(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    chart_configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.WordCloudChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    column_hierarchies: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    subtitle: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    title: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da0ede0a029c9a18c5efd81310d5eb827b7628e83eab5b86d1ab1e34c44eec6d(
    *,
    aws_account_id: builtins.str,
    template_id: builtins.str,
    definition: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TemplateVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    source_entity: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTemplate.TemplateSourceEntityProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d97a2c65ae01ccf3d3b3226a5b98f0f7f565cbd27de714e800586e3987daee9(
    scope: _aws_cdk_core_f4b25747.Construct,
    id: builtins.str,
    *,
    aws_account_id: builtins.str,
    theme_id: builtins.str,
    base_theme_id: typing.Optional[builtins.str] = None,
    configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.ThemeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5d31b7e255a7b05ca5a1496c05085a78a898e35c5f197cc2365e78dabb5caf0(
    inspector: _aws_cdk_core_f4b25747.TreeInspector,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1df7c989fc0afd3dd38b6c47d8f5c86c3515abcce558c01f87cdc5ac6a11113d(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d3ee86e9952db24447ec18879c76c44056075efb6920e9002b7d33dde3f93bd(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39a6bb0be980507d80e6e81076d1abd10638efc69ecb18d73fce6b319f3a01ff(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6c2318a4831aa5433ea87f62920e560a286ca012b581830a91a36e41e0abb8e(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ec269ee627a8c5d80e3a3005e7ba13140b45bf5213eeda4cbfa4503c6967ccd(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTheme.ThemeConfigurationProperty]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72e82ae0b5892c79676dc350f2edbff8b64848ab7f4862a7f80f193aa100af33(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__409212622d84e420d87b39a6b168407dddcca251f4b9c92af1195f8b84e8573a(
    value: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.List[typing.Union[_aws_cdk_core_f4b25747.IResolvable, CfnTheme.ResourcePermissionProperty]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23c3e2dd891065878d4e73d25428ed2511f9a3b3acb5426683428914de618d6e(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a13afdb34f7384c58342de00287aba691901bdc53eec64918eda62d353f9ebad(
    *,
    show: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__898cca280e845aa5606f1c03dd507419feadf4ec4852f879c1b41557c7d61780(
    *,
    colors: typing.Optional[typing.Sequence[builtins.str]] = None,
    empty_fill_color: typing.Optional[builtins.str] = None,
    min_max_gradient: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d68d6fb2efed6c0a00eb6974e574f5b01ea6dbb5c107b2a15a71c8352f934c2(
    *,
    font_family: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e8a6ba1bbe327f848e775d5d339603f487fa18ce125690eb51053635f103c3a(
    *,
    show: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c56c66aaf5ef70ebbb94a27700268f46ad23aa1cb66ad1e88e3832595df1a735(
    *,
    show: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1aa3ff38c9c3662f2c93cec3c13f9cc49bdf27513b58194e3001974cf0bc9cc(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a75e77eb907668958a7e13163e7e7684ada34f0b85239695bd2953991a8c5520(
    *,
    tile: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.TileStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    tile_layout: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.TileLayoutStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f460d11d699592a86fbe5608e9fdb598fe65cce6ee119f3c1aa89a62b2f3ae5d(
    *,
    data_color_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.DataColorPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    sheet: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.SheetStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    typography: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.TypographyProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    ui_color_palette: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.UIColorPaletteProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40389bf90e3dbaac39f81c1ed5783fd088358f206b44cfa6dcebf45a4dbd1a61(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef4d9a8672060f10978f0b81e2d71bb3037e6c1560d90d506194b949a68d8523(
    *,
    arn: typing.Optional[builtins.str] = None,
    base_theme_id: typing.Optional[builtins.str] = None,
    configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.ThemeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    created_time: typing.Optional[builtins.str] = None,
    description: typing.Optional[builtins.str] = None,
    errors: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.ThemeErrorProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    status: typing.Optional[builtins.str] = None,
    version_number: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4672b8b341aeb421f770e3908e8a197ef7bf17a582fd68535ebcdf24faff8199(
    *,
    gutter: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.GutterStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    margin: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.MarginStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb2825e22f00040b7d88e0e46dad98276e68de257ba97aa9fbd06e624444611b(
    *,
    border: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.BorderStyleProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86bb85bfa58dc441a72d3f9fa98766a3b553cc423a9b0aa3981b2f594fa5a872(
    *,
    font_families: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.FontProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1ea3a241509fa1fd36b2d63a314b3d8a616d8f5176dc04e867c156c4812d8e3(
    *,
    accent: typing.Optional[builtins.str] = None,
    accent_foreground: typing.Optional[builtins.str] = None,
    danger: typing.Optional[builtins.str] = None,
    danger_foreground: typing.Optional[builtins.str] = None,
    dimension: typing.Optional[builtins.str] = None,
    dimension_foreground: typing.Optional[builtins.str] = None,
    measure: typing.Optional[builtins.str] = None,
    measure_foreground: typing.Optional[builtins.str] = None,
    primary_background: typing.Optional[builtins.str] = None,
    primary_foreground: typing.Optional[builtins.str] = None,
    secondary_background: typing.Optional[builtins.str] = None,
    secondary_foreground: typing.Optional[builtins.str] = None,
    success: typing.Optional[builtins.str] = None,
    success_foreground: typing.Optional[builtins.str] = None,
    warning: typing.Optional[builtins.str] = None,
    warning_foreground: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f20cc5143bf1b8e687a71b6d9fa8043da08667d0c19f92778e5356a1fc547c59(
    *,
    aws_account_id: builtins.str,
    theme_id: builtins.str,
    base_theme_id: typing.Optional[builtins.str] = None,
    configuration: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.ThemeConfigurationProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnTheme.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4680edc6f6b2057974aff33c9b1063112db6614eb0a8bdd7a535ebc3b74918d3(
    scope: _aws_cdk_core_f4b25747.Construct,
    id: builtins.str,
    *,
    availability_status: typing.Optional[builtins.str] = None,
    aws_account_id: typing.Optional[builtins.str] = None,
    dns_resolvers: typing.Optional[typing.Sequence[builtins.str]] = None,
    name: typing.Optional[builtins.str] = None,
    role_arn: typing.Optional[builtins.str] = None,
    security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    vpc_connection_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5491d9d4666ceb63d67d17a157e7d874620e63fe0fe43f0563e1503d673fa0b4(
    inspector: _aws_cdk_core_f4b25747.TreeInspector,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d49e60683256456b6ad85831d4f05c5d106c5363b475fb28a0862a0533a1189(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13582bd74cd7e94246e413250f4427ad4517ff55211e2f6304e7f410beda7b82(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d0f579038be90670f13351cc4fc38c021b446f20c77fba5f17a5f7885330fa6(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__802cdf5aa12ba0e2fe964f603e4df307be17fa1ae0af2d5bfd0f94bf7309d5e4(
    value: typing.Optional[typing.List[builtins.str]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b40a735d5d57bfa63044434042d2af339daca63634ca28998ee1cb3ef9159bd0(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7350d69cdef3677d8796a65059f3e485ca830f96a4d9381224f4f326889bd8d9(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecd927b3730a2850a7ac182ae4a642ced034abd86826012a1793cc415eb1a716(
    value: typing.Optional[typing.List[builtins.str]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a853350a1db3b5789ae0ec54a9fead1ee7db62eaa814d118e7a26925f7b34cc(
    value: typing.Optional[typing.List[builtins.str]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b06476e97e1ff2870dae4fe81aeb18aea72a1a57f6bef58ac4feca51a4cb4083(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a72db4469aeefbfd88b4c7db01b70031b9af40f619e2ec47f00b35a850aedec(
    *,
    availability_zone: typing.Optional[builtins.str] = None,
    error_message: typing.Optional[builtins.str] = None,
    network_interface_id: typing.Optional[builtins.str] = None,
    status: typing.Optional[builtins.str] = None,
    subnet_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c07040a69bddbfbf2504c9858341608cb5b0fd8a41c8f94dca1472236429a573(
    *,
    availability_status: typing.Optional[builtins.str] = None,
    aws_account_id: typing.Optional[builtins.str] = None,
    dns_resolvers: typing.Optional[typing.Sequence[builtins.str]] = None,
    name: typing.Optional[builtins.str] = None,
    role_arn: typing.Optional[builtins.str] = None,
    security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_core_f4b25747.CfnTag, typing.Dict[builtins.str, typing.Any]]]] = None,
    vpc_connection_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass
